package com.ninexiu.sixninexiu.activity

import android.app.Dialog
import android.content.Context
import android.content.Intent
import android.text.TextUtils
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.bean.AccountCertifyData
import com.ninexiu.sixninexiu.bean.AccountCertifyResult
import com.ninexiu.sixninexiu.bean.BaseResultInfo
import com.ninexiu.sixninexiu.common.ShuMeiHelperUtil
import com.ninexiu.sixninexiu.common.net.ApiParams
import com.ninexiu.sixninexiu.common.net.NSGsonObjectNewCallback
import com.ninexiu.sixninexiu.common.net.NSRequestParams
import com.ninexiu.sixninexiu.common.net.NsOkHttpClient
import com.ninexiu.sixninexiu.common.util.Constants
import com.ninexiu.sixninexiu.common.util.MyToast
import com.ninexiu.sixninexiu.common.util.NSLog
import com.ninexiu.sixninexiu.common.util.Utils
import com.ninexiu.sixninexiu.login.LoginRequest
import com.ninexiu.sixninexiu.login.ServerException
import com.ninexiu.sixninexiu.view.setVisible
import kotlinx.android.synthetic.main.activity_account_bind_phone.*
import kotlinx.android.synthetic.main.activity_account_bind_phone.accountStatusView
import kotlinx.android.synthetic.main.activity_account_bind_phone.llContainer
import kotlinx.android.synthetic.main.activity_account_bind_phone.tvTopInfo
import kotlinx.android.synthetic.main.activity_account_identity.*
import org.greenrobot.eventbus.EventBus
import org.greenrobot.eventbus.Subscribe

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/03/04
 *     desc   : 此界面统一为 【手机号 + 验证码】   适用界面为 : 绑定手机号,更换绑定手机号,设置密码，忘记密码
 *     version: 1.0
 * </pre>
 */
class AccountBindPhoneActivity : BaseActivity() {
    companion object {
        const val Tag = "AccountBindPhoneActivity >> "

        const val TYPE_BIND_PHONE = 0                 // 绑定手机号
        const val TYPE_CHANGE_PHONE = 1               // 更换绑定手机号(验证原来的手机号)
        const val TYPE_CHANGE_PHONE_SECOND = 2        // 更换绑定手机号(输入新的手机号)
        const val TYPE_SET_PWD = 3                    // 设置密码
        const val TYPE_FORGET_PWD = 4                 // 忘记密码

        const val TYPE = "type"
        const val PHONE_NUMBER = "phone_number"
        const val VERIFICATION_CODE = "verification_code"

        fun startActivity(context: Context, type: Int) {
            val intent = Intent(context, AccountBindPhoneActivity::class.java)
            intent.putExtra(TYPE, type)
            context.startActivity(intent)
        }
    }

    private val type: Int by lazy {
        intent?.getIntExtra(TYPE, -1) ?: -1
    }

    override fun initDatas() {
        super.initDatas()
        // 获取tip提示信息
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.ACCOUNT_CERTIFY_TIPS, null, object : NSGsonObjectNewCallback<AccountCertifyResult>() {
            override fun onFailure(statusCode: Int, errorMsg: String?) {
                MyToast.MakeToast(errorMsg ?: "")
            }

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: AccountCertifyResult?) {
                MyToast.MakeToast(message ?: "")
                if (statusCode == 200) {
                    response?.data?.let { setTipData(it) }
                }
            }
        })
    }

    // 根据不同的type设置不同的头部提示信息
    private fun setTipData(tipData: AccountCertifyData) {
        // 设置头部tip提示
        when (type) {
            TYPE_BIND_PHONE -> tvTopInfo.text = tipData.bind_phone?.header_tip
            TYPE_CHANGE_PHONE -> tvTopInfo.text = tipData.update_phone?.verify_tip
            TYPE_CHANGE_PHONE_SECOND -> AccountSecurityHelper.setPhoneNumberHighLight(this, tvTopInfo, tipData.update_phone?.update_tip)
            TYPE_SET_PWD -> tvTopInfo.text = tipData.set_pwd?.verify_tip
            TYPE_FORGET_PWD -> tvTopInfo.text = tipData.forget_pwd?.verify_tip
        }
    }

    // 通过authCodeType来区分获取验证码的url
    private var authCodeType: LoginRequest.AuthCodeType? = null
    override fun initViews() {
        super.initViews()

        leftFinish.setOnClickListener { finish() }

        etPhone.getFocus = {
            etPhone.setTextColor(resources.getColor(R.color.color_333333))
            etVerificationCode.setTextColor(resources.getColor(R.color.color_cccccc))
        }

        etVerificationCode.getFocus = {
            etPhone.setTextColor(resources.getColor(R.color.color_cccccc))
            etVerificationCode.setTextColor(resources.getColor(R.color.color_333333))
        }

        // 设置title和按钮以及获取 验证码的type(用来区分获取验证码的url,以前的逻辑是封装了一个枚举类，先不动)
        when (type) {
            TYPE_BIND_PHONE -> {
                tvTitle.text = "绑定手机"
                btBindConfirm.text = "确定"
                authCodeType = LoginRequest.AuthCodeType.BINDING
            }
            TYPE_CHANGE_PHONE -> {
                tvTitle.text = "更换绑定手机"
                btBindConfirm.text = "下一步"
                //注意 : 这里走的是解绑的获取验证码url
                authCodeType = LoginRequest.AuthCodeType.UNBINDING
            }
            TYPE_CHANGE_PHONE_SECOND -> {
                tvTitle.text = "更换绑定手机"
                btBindConfirm.text = "确定"
                // 注意 : 这里是更换绑定手机第二步,要获取的是新的手机号的验证码,和绑定流程一样
                authCodeType = LoginRequest.AuthCodeType.BINDING
            }
            // 设置密码和忘记密码使用的获取验证码的url相同
            TYPE_SET_PWD -> {
                tvTitle.text = "设置密码"
                btBindConfirm.text = "下一步"
                authCodeType = LoginRequest.AuthCodeType.FIND
            }
            TYPE_FORGET_PWD -> {
                tvTitle.text = "忘记密码"
                btBindConfirm.text = "下一步"
                authCodeType = LoginRequest.AuthCodeType.FIND
            }
        }

        // 获取验证码
        tvCode.setOnClickListener {
            getVerificationCode()
        }

        // 获取验证码倒计时结束重置状态
        tvCode.timeOver = {
            tvCode.isClickable = true
            tvCode.setBackgroundResource(R.drawable.button_shape)
        }

        btBindConfirm.setOnClickListener {
            userConfirm()
            // 关闭键盘
            AccountSecurityHelper.hideKeyBoard(etPhone)
        }
    }

    private val shuMeiHelperUtil = ShuMeiHelperUtil()   // 滑动拼图工具类

    // 一 . 获取验证码(先拼图校验)
    private fun getVerificationCode() {
        NSLog.d(Tag, "获取验证码之拼图校验...")
        if (Utils.isNotClickable()) {
            return
        }

        // 验证手机号码格式
        if (!verificationPass(needVerPhone = true)) {
            return
        }

        val phoneNumber = etPhone.text?.toString()
        shuMeiHelperUtil.startShuMei(this, object : ShuMeiHelperUtil.OnShuMeiVerListener {
            override fun onShuMeiValidate(rid: String?, pass: Boolean) {
                if (pass) {
                    shuMeiHelperUtil.dismissVerDialog()
                    if (!phoneNumber.isNullOrBlank() && !rid.isNullOrBlank()) {
                        gerVerificationCodeReal(rid, phoneNumber)
                    }
                } else {
                    MyToast.MakeToast("校验不通过，请重试")
                }
            }

            override fun onShuMeiError(code: Int) {
            }

        })
    }

    // 二 . 真正获取验证码
    private fun gerVerificationCodeReal(validate: String, phoneNumber: String) {
        NSLog.d(Tag, "获取验证码...")
        if (authCodeType == null) {
            return
        }

        showProgressDialog(this.getString(R.string.reg_get_captcha), true)

        LoginRequest.phoneNumberAuthInterface(validate, authCodeType, phoneNumber, object : LoginRequest.CallBack {
            override fun success(obj: Any?) {
                showProgressDialog()
                obj?.let {
                    if (it is String && it.isNotEmpty() && TextUtils.equals("200", it)) {
                        // todo : 此时是否应该将手机号设为固定不可更改
                        MyToast.MakeToast("获取手机验证码成功!")
                        // 获取验证码开始倒计时
                        tvCode.isClickable = false
                        tvCode.setBackgroundResource(R.drawable.button_shape_grey)
                        tvCode.startCutDown(pre = "重新发送(", post = ")", timeCut = 60, endT = "获取验证码") { time ->
                            time.toString()
                        }
                    } else {
                        MyToast.MakeToast("获取手机验证码失败!")
                    }
                }
            }

            override fun error(errorCode: Int) {
                showProgressDialog()
                ServerException.showErrorToast(this@AccountBindPhoneActivity, errorCode)
            }

            override fun neterror(errorCode: Int, message: String?) {
                showProgressDialog()
                MyToast.MakeToast(message ?: "")
            }

        })
    }

    // 三 . 用户点击确认 : 需要通过type执行不同的操作
    private fun userConfirm() {
        if (!verificationPass(needVerPhone = true, needVerCode = true)) {
            return
        }

        when (type) {
            // 绑定手机号 -> 确认绑定
            TYPE_BIND_PHONE -> nextStepBindPhone()
            // 1.验证原有的手机号验证码
            TYPE_CHANGE_PHONE -> nextStepVerificationCode()
            // 2.再走一个新的绑定流程
            TYPE_CHANGE_PHONE_SECOND -> nextStepChangeBindPhone()
            // 设置密码和忘记密码接下来使用的是同一个界面，进行type区分
            TYPE_SET_PWD -> nextStepDoPwd(TYPE_SET_PWD)
            TYPE_FORGET_PWD -> nextStepDoPwd(TYPE_FORGET_PWD)
        }

    }

    // 下一步 : TYPE_SET_PWD : 设置密码   TYPE_FORGET_PWD : 忘记密码  将数据带到下一页【设置密码】即可
    private fun nextStepDoPwd(type: Int) {
        val phoneNumber = etPhone.text?.toString()
        val code = etVerificationCode.text?.toString()
        if (!phoneNumber.isNullOrBlank() && !code.isNullOrBlank()) {
            AccountSetPwdActivity.startActivity(this, type, phoneNumber, code)
        }
    }

    // 下一步 : TYPE_CHANGE_PHONE : 更换手机号第一步 : 验证老手机号及验证码
    private fun nextStepVerificationCode() {
        val params = getParams() ?: return
        NsOkHttpClient.getNsOkHttpClient().doPost(Constants.PHONE_CHANGE_OLD_VERIFICATION, params, object : NSGsonObjectNewCallback<BaseResultInfo>() {
            override fun onFailure(statusCode: Int, errorMsg: String?) {
                MyToast.MakeToast(errorMsg ?: "")
            }

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: BaseResultInfo?) {
                MyToast.MakeToast(message ?: "")
                if (statusCode == 200) {
                    startActivity(this@AccountBindPhoneActivity, TYPE_CHANGE_PHONE_SECOND)   // 绑定新的手机号
                } else {
                    NSLog.d(Tag, "code : $statusCode")
                }
            }
        })
    }

    // 下一步 : TYPE_BIND_PHONE : 用户绑定手机号
    private fun nextStepBindPhone() {
        val uid = NineShowApplication.mUserBase?.uid ?: return
        val params = getParams() ?: return
        params.put(ApiParams.REQ_UID, uid)

        /*//如果是第三方账号 todo : 为什么有这个判断
            if (Utils.isThreadAccount()) {
                final String mPwd = mRegAccount_et.getText().toString().trim();
                int checkCode = LoginUtil.checkLoginInput(phoneNum, mPwd);
                if (checkCode != 200) {
                    ServerException.showErrorToast(RegisterActivity.this, checkCode);
                    return;
                }
                NineShowApplication.mUserBase.setPassword(mPwd);
            }
            params.put("pwd", NineShowApplication.mUserBase.getPassword());*/

        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.PHONE_BINGING_MOBILE_PATH, params, object : NSGsonObjectNewCallback<BaseResultInfo>() {
            override fun onFailure(statusCode: Int, errorMsg: String?) {
                MyToast.MakeToast(errorMsg ?: "")
            }

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: BaseResultInfo?) {
                MyToast.MakeToast(message ?: "")
                if (statusCode == 200) {
                    NineShowApplication.mUserBase?.phone = etPhone.text?.toString()
                    NineShowApplication.mUserBase?.request_bind = 0
                    // 成功界面
                    showStatusView(AccountIdentityActivity.STATUS_RESULT)
                    accountStatusView.setStatus(isSuc = true, status = message, confirm = "完成") {
                        // 可以通过EventBus关闭界面,因为绑定手机号和更换手机号(第二步),成功后都是此步骤，在更换手机号逻辑中，此界面跳转了两次
                        EventBus.getDefault().post(AccountBindPhoneCloseEvent())
                    }
                } else {
                    // todo : 放开固定的手机号
                    NSLog.d(Tag, "code : $statusCode")
                }
            }
        })
    }

    // 下一步 : TYPE_CHANGE_PHONE_SECOND: 更换手机号第二步 : 绑定新的手机号
    private fun nextStepChangeBindPhone() {
        val uid = NineShowApplication.mUserBase?.uid ?: return
        val params = getParams() ?: return
        params.put(ApiParams.REQ_UID, uid)

        NsOkHttpClient.getNsOkHttpClient().doPost(Constants.PHONE_BINGING_NEW_MOBILE_PATH, params, object : NSGsonObjectNewCallback<BaseResultInfo>() {
            override fun onFailure(statusCode: Int, errorMsg: String?) {
                MyToast.MakeToast(errorMsg ?: "")
            }

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: BaseResultInfo?) {
                MyToast.MakeToast(message ?: "")
                if (statusCode == 200) {
                    NineShowApplication.mUserBase?.phone = etPhone.text?.toString()
                    NineShowApplication.mUserBase?.request_bind = 0
                    // 成功界面
                    showStatusView(AccountIdentityActivity.STATUS_RESULT)
                    accountStatusView.setStatus(isSuc = true, status = message, confirm = "完成") {
                        // 可以通过EventBus关闭界面,因为绑定手机号和更换手机号(第二步),成功后都是此步骤，在更换手机号逻辑中，此界面跳转了两次
                        EventBus.getDefault().post(AccountBindPhoneCloseEvent())
                    }
                } else {
                    // todo : 放开固定的手机号
                    NSLog.d(Tag, "code : $statusCode")
                }
            }
        })
    }


    // 以下为工具方法
    // ***************// ***************// ***************// ***************// ***************// ***************

    // 获取统一的params
    private fun getParams(): NSRequestParams? {
        val phoneNumber = etPhone.text?.toString()
        val code = etVerificationCode.text?.toString()
        if (phoneNumber.isNullOrBlank() || code.isNullOrBlank()) {
            return null
        }

        val params = NSRequestParams()

        params.put(ApiParams.Register.REQ_REGISTER_PHONENUM, phoneNumber)
        params.put(ApiParams.Register.REQ_REGISTER_CODE, code)

        return params
    }


    // 统一验证流程(验证手机号码是否为空，手机号码是否格式正确，验证码是否格式正确)
    private fun verificationPass(needVerPhone: Boolean = true, needVerCode: Boolean = false): Boolean {
        // 需要验证手机号
        if (needVerPhone) {
            val phoneNumber = etPhone.text?.toString()
            if (phoneNumber.isNullOrBlank()) {
                MyToast.MakeToast(getString(R.string.account_phone_empty))
                return false
            }

            if (phoneNumber.trim().length != 11 || !Utils.isMobileNO(phoneNumber)) {
                MyToast.MakeToast("手机号格式不正确!")
                return false
            }

        }

        // 需要验证 验证码格式是否正确
        if (needVerCode) {
            val code = etVerificationCode.text?.toString()
            if(code.isNullOrBlank()) {
                MyToast.MakeToast(getString(R.string.account_verification_code_empty))
                return false
            }

            if (code.isNullOrBlank() || code.length != 6) {
                MyToast.MakeToast("验证码错误，请点击重试")
                return false
            }
        }

        return true
    }


    // 展示不同状态的view
    private fun showStatusView(status: Int) {
        when (status) {
            AccountIdentityActivity.STATUS_CONTAINER -> {
                llContainer.setVisible(true)
                accountStatusView.setVisible(false)
            }
            AccountIdentityActivity.STATUS_RESULT -> {
                llContainer.setVisible(false)
                accountStatusView.setVisible(true)
            }
        }
    }


    private var dialog: Dialog? = null
    private fun showProgressDialog(info: String? = null, show: Boolean = false) {
        if (show && !info.isNullOrBlank()) {
            dialog = Utils.showProgressDialog(this, info, false)
            dialog?.show()
            return
        }

        if (!show && dialog?.isShowing == true) {
            dialog?.dismiss()
            dialog = null
        }
    }

    override fun setContentView() {
        EventBus.getDefault().register(this)
        setContentView(R.layout.activity_account_bind_phone)
    }

    @Subscribe
    fun closeActivity(event: AccountBindPhoneCloseEvent) {
        Utils.exitActivityAnimation(this@AccountBindPhoneActivity)
    }

    override fun onDestroy() {
        super.onDestroy()
        if (EventBus.getDefault().isRegistered(this)) {
            EventBus.getDefault().unregister(this)
        }
    }
}

// EventBus中关闭的Event
class AccountBindPhoneCloseEvent