package com.ninexiu.sixninexiu.activity

import android.content.Context
import android.content.Intent
import android.os.Bundle
import android.view.View
import androidx.recyclerview.widget.LinearLayoutManager
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.adapter.PermissionSettingAdapter
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.bean.AccountHideData
import com.ninexiu.sixninexiu.bean.AccountHideResponse
import com.ninexiu.sixninexiu.common.ConfigSpHelper
import com.ninexiu.sixninexiu.common.net.NSGsonObjectNewCallback
import com.ninexiu.sixninexiu.common.net.NSRequestParams
import com.ninexiu.sixninexiu.common.net.NsOkHttpClient
import com.ninexiu.sixninexiu.common.permission.PermissionHelp
import com.ninexiu.sixninexiu.common.recycler.NSBaseRecyclerView
import com.ninexiu.sixninexiu.common.util.Constants
import com.ninexiu.sixninexiu.common.util.MyToast
import com.ninexiu.sixninexiu.common.util.NSLog
import com.ninexiu.sixninexiu.common.util.manager.RequestManager
import com.ninexiu.sixninexiu.view.dialog.AccountHideBottomDialog
import com.ninexiu.sixninexiu.view.dialog.CommonConfirmCancelDialog
import com.ninexiu.sixninexiu.view.setVisible
import kotlinx.android.synthetic.main.activity_accounty_hide.*

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/03/29
 *     desc   : 用户隐私设置
 *     version: 1.0
 * </pre>
 */
class AccountHideActivity : BaseActivity() {
    companion object {
        fun startActivity(context: Context) {
            val intent = Intent(context, AccountHideActivity::class.java)
            context.startActivity(intent)
        }
    }

    override fun initDatas() {
        super.initDatas()
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.ACCOUNT_GET_USER_HIDE, null, object : NSGsonObjectNewCallback<AccountHideResponse>() {
            override fun onFailure(statusCode: Int, errorMsg: String?) {
                MyToast.MakeToast(errorMsg ?: "")
            }

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: AccountHideResponse?) {
                if (statusCode == 200) {
                    response?.data?.let {
                        setData(it)
                    }
                }
            }
        })

        initPrivacyData()
    }

    private var atRoom = 0
    private var showOnLine = 0
    private var atRoomOriginal = 0
    private var showOnLineOriginal = 0
    private fun setData(data: AccountHideData) {
        atRoom = data.at_room
        showOnLine = data.show_online

        // 原始数据
        atRoomOriginal = atRoom
        showOnLineOriginal = showOnLine

        // 设置房间内标签
        if (atRoom == 1) {
            ivLabelSwitch.setImageResource(R.drawable.checkbox_pressed)
        } else {
            ivLabelSwitch.setImageResource(R.drawable.checkbox_normal)
        }

        // 是否在线
        if (showOnLine == 1) {
            tvHideStatus.text = "在线"
        } else {
            tvHideStatus.text = "隐身"
        }
    }

    override fun initViews() {
        super.initViews()

        btHideLeft.setOnClickListener {
            submit()
        }

        val info = NineShowApplication.mUserBase
        if (info != null && info.is_anchor != 0) {
            containerLabel.setVisible(false)        // 主播端不显示
        } else {
            containerLabel.setVisible(true)
        }

        // 设置房间标签开关
        containerLabel.setOnClickListener {
            if (atRoom == 0) {
                CommonConfirmCancelDialog.showDialog(this, "要开启在房间中状态吗?", "开启后，他人可以发现你在房间中，方便更好遇见你哦", "取消", "确定") {
                    atRoom = 1
                    ivLabelSwitch.setImageResource(R.drawable.checkbox_pressed)
                }
            } else {
                CommonConfirmCancelDialog.showDialog(this, "要关闭在房间中状态吗?", "关闭后，他人无法看到你的房间状态", "取消", "确定") {
                    atRoom = 0
                    ivLabelSwitch.setImageResource(R.drawable.checkbox_normal)
                }
            }
        }

        // 设置在线状态
        containerHide.setOnClickListener {
            AccountHideBottomDialog(this, showOnLine) { isHide ->
                if (isHide) {
                    showOnLine = 0
                    tvHideStatus.text = "隐身"
                } else {
                    showOnLine = 1
                    tvHideStatus.text = "在线"
                }
            }.show()
        }

        // 黑名单
        containerBlack.setOnClickListener {
            val intent = Intent(this, BlackListActivity::class.java)
            startActivity(intent)
        }

        initPrivacyView()
    }

    // 以前的隐私设置，现在合并到这里
    private fun initPrivacyData() {
        val mPermissionStateInfoList = PermissionHelp.getInstance().permissionStateInfoList
        val mAdapter = PermissionSettingAdapter(mPermissionStateInfoList, this)
        rv_permission.layoutManager = LinearLayoutManager(this)
        rv_permission.adapter = mAdapter
        mAdapter.notifyDataSetChanged()
        rv_permission.setOnItemClickLinstener { _: Int, _: View? -> PermissionHelp.getInstance().goToMenu(this) }

        tv_see_privacy_agreement.setOnClickListener {
            AdvertiseActivity.start(this, false, true, "https://www.9xiu.com/activity/agreement", "用户协议与隐私政策")
        }
    }


    private var addressStatus = ConfigSpHelper.getInstance().liveEnterRoomAddressStatus
    private var addressStatusOrigin = addressStatus

    // 以前的隐私设置，现在合并到这里
    private fun initPrivacyView() {
        val userBase = NineShowApplication.mUserBase
        if (userBase == null) {
            tv_1_1.setVisible(false)
            layout_enter_room_address.setVisible(false)
        } else {
            tv_1_1.setVisible(true)
            layout_enter_room_address.setVisible(true)
        }

        setReferEnterRoomView()

        RequestManager.create().getEnterAddressStat {
            addressStatus = ConfigSpHelper.getInstance().liveEnterRoomAddressStatus
            setReferEnterRoomView()
        }

        layout_enter_room_address.setOnClickListener {
            if (cb_live_enter_room_addres == null) {
                return@setOnClickListener
            }
            val addressStatusTemp = !addressStatus
            addressStatus = addressStatusTemp
            setReferEnterRoomView()
        }
    }

    /**
     * 刷新进房状态
     */
    private fun setReferEnterRoomView() {
        NSLog.d("accountHide : ","$addressStatus")
        if (addressStatus) {
            cb_live_enter_room_addres.setImageResource(R.drawable.checkbox_pressed)
        } else {
            cb_live_enter_room_addres.setImageResource(R.drawable.checkbox_normal)
        }
    }

    override fun setContentView() {
        setContentView(R.layout.activity_accounty_hide)
    }

    /**
     * 监听Back键按下事件,方法2:
     * 注意:
     * 返回值表示:是否能完全处理该事件
     * 在此处返回false,所以会继续传播该事件.
     * 在具体项目中此处的返回值视情况而定.
     */
    override fun onBackPressed() {
        if(addressStatus != addressStatusOrigin) {
            RequestManager.create().postEnterAddressStat(addressStatus)
        }
        submit()
    }

    // 提交用户更改
    private fun submit() {
        NSLog.d("room : $atRoom  , online : $showOnLine")
        if (atRoom == atRoomOriginal && showOnLine == showOnLineOriginal) {
            finish()
            return
        }

        val params = NSRequestParams()
        params.put("at_room", atRoom)
        params.put("show_online", showOnLine)
        NsOkHttpClient.getNsOkHttpClient().doPost(Constants.ACCOUNT_SET_USER_HIDE, params, object : NSGsonObjectNewCallback<AccountHideResponse>() {
            override fun onFailure(statusCode: Int, errorMsg: String?) {
                MyToast.MakeToast(errorMsg ?: "")
                finish()
            }

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: AccountHideResponse?) {
                if (statusCode != 200) {
                    MyToast.MakeToast(message ?: "")
                }
                finish()
            }
        })

    }
}