package com.ninexiu.sixninexiu.activity

import android.annotation.SuppressLint
import android.content.Context
import android.content.Intent
import android.os.Handler
import android.text.SpannableStringBuilder
import android.text.Spanned
import android.text.method.LinkMovementMethod
import android.text.style.ForegroundColorSpan
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.bean.AccountCertifyData
import com.ninexiu.sixninexiu.bean.AccountCertifyResult
import com.ninexiu.sixninexiu.bean.BaseResultInfo
import com.ninexiu.sixninexiu.common.net.NSGsonObjectNewCallback
import com.ninexiu.sixninexiu.common.net.NSRequestParams
import com.ninexiu.sixninexiu.common.net.NsOkHttpClient
import com.ninexiu.sixninexiu.common.util.*
import com.ninexiu.sixninexiu.view.ClickSpanImpl
import com.ninexiu.sixninexiu.view.setVisible
import kotlinx.android.synthetic.main.activity_account_identity.*

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/03/03
 *     desc   : 实名认证
 *     version: 1.0
 * </pre>
 */
class AccountIdentityActivity : BaseActivity() {
    companion object {
        const val Tag = "AccountIdentityActivity >> "
        const val STATUS_CONTAINER = 1
        const val STATUS_COMMIT = 2
        const val STATUS_RESULT = 3
        fun startActivity(context: Context) {
            val intent = Intent(context, AccountIdentityActivity::class.java)
            context.startActivity(intent)
        }
    }

    override fun onResume() {
        super.onResume()
        getData()
    }

    private fun getData() {
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.ACCOUNT_CERTIFY_TIPS, null, object : NSGsonObjectNewCallback<AccountCertifyResult>() {
            override fun onFailure(statusCode: Int, errorMsg: String?) {
                MyToast.showShort(errorMsg ?: "")
            }

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: AccountCertifyResult?) {
                MyToast.showShort(message ?: "")
                if (statusCode == 200) {
                    response?.data?.let { setIdentityData(it) }
                }
            }
        })
    }

    private var waitTime = 0
    private var data: AccountCertifyData? = null
    private fun setIdentityData(data: AccountCertifyData) {
        this.data = data
        waitTime = data.certify_info?.wait_time ?: 0
        tvTopInfo.text = data.certify_info?.header_tip
        tvContact.text = data.certify_info?.footer_tip

        data.certify_info?.certify_tip?.let {
            // 实名认证请认证填写，5次认证失败将无法再认证（0/5）
            val startIndex = it.indexOf("（")
            val endIndex = it.indexOf("）")

            if (startIndex != -1 && endIndex != -1 && startIndex <= it.length && endIndex + 1 <= it.length) {
                val ssb = SpannableStringBuilder(it)
                ssb.setSpan(ForegroundColorSpan(resources.getColor(R.color.color_ff567b)), startIndex, endIndex + 1, Spanned.SPAN_EXCLUSIVE_EXCLUSIVE)
                tvCount.text = ssb
            }
        }

        data.certify_info?.agreement_tip?.let {
            // 认证即视为已阅读并同意《九秀认证须知》
            val startIndex = it.indexOf("《")
            val endIndex = it.indexOf("》")

            if (startIndex != -1 && endIndex != -1 && startIndex <= it.length && endIndex <= it.length && data.certify_info.show_agreement == 1) {
                val ssb = SpannableStringBuilder(it)
                ssb.setSpan(ForegroundColorSpan(resources.getColor(R.color.color_ff567b)), startIndex, endIndex + 1, Spanned.SPAN_EXCLUSIVE_EXCLUSIVE)
                ssb.setSpan(ClickSpanImpl {
                    data.certify_info.certify_agreement?.let { link ->
                        AdvertiseActivity.start(this, false, true, link)
                    }
                }, startIndex, endIndex, Spanned.SPAN_EXCLUSIVE_EXCLUSIVE)

                tvAgree.text = ssb
                tvAgree.movementMethod = LinkMovementMethod.getInstance()
            } else if (data.certify_info.show_agreement == 1) {
                tvAgree.text = it
            }
        }
    }


    var canFinish = true
    override fun initViews() {
        super.initViews()
        etName.getFocus = {
            llName.setBackgroundResource(R.drawable.bg_account_selected)
            llNumber.setBackgroundResource(R.drawable.bg_account_normal)
            etName.setTextColor(resources.getColor(R.color.color_333333))
            etNumber.setTextColor(resources.getColor(R.color.color_cccccc))
        }

        etNumber.getFocus = {
            llName.setBackgroundResource(R.drawable.bg_account_normal)
            llNumber.setBackgroundResource(R.drawable.bg_account_selected)
            etName.setTextColor(resources.getColor(R.color.color_cccccc))
            etNumber.setTextColor(resources.getColor(R.color.color_333333))
        }

        left_btn_finish.setOnClickListener {
            if (canFinish) {
                finish()
            }
        }

        btIdentityConfirm.setOnClickListener {
            userConfirm()

            // 关闭键盘
            AccountSecurityHelper.hideKeyBoard(etNumber)
        }
    }

    override fun onBackPressed() {
        if (canFinish) {
            super.onBackPressed()
        }
    }

    // 用户确认
    private fun userConfirm() {
        if (etName.text.isNullOrBlank()) {
            MyToast.showShort(getString(R.string.account_identity_name_empty))
            return
        }

        val number = etNumber.text
        if (number.isNullOrBlank()) {
            MyToast.showShort(getString(R.string.account_identity_number_empty))
            return
        }

        // 服务器提供时间不对
        if (waitTime <= 0) {
            MyToast.showShort("服务器Error")
            return
        }

        val params = NSRequestParams()
        params.put("real_name", etName.text.toString())
        params.put("idcard", number.toString())

        NsOkHttpClient.getNsOkHttpClient().doPost(Constants.ACCOUNT_CERTIRY_IDENTITY_INFO, params, object : NSGsonObjectNewCallback<BaseResultInfo>() {
            override fun onFailure(statusCode: Int, errorMsg: String?) {
                MyToast.showShort(errorMsg ?: "")
            }

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: BaseResultInfo?) {
                if (statusCode == 200) {
                    NSLog.d(Tag, "提交成功")
                    showStatusView(STATUS_COMMIT)       // 展示提交界面
                    canFinish = false                   // 用户这时候不能做任何关闭操作

                    // 倒计时
                    setTime(waitTime)
                } else {
                    MyToast.showShort(message ?: "")
                }
            }
        })
    }

    val handler = Handler()

    val runnable = Runnable {
        if (--waitTime <= 0) {
            NSLog.d(Tag, "waitTime : 获取结果")
            // todo : 判断结果
            getResult()
        } else {
            NSLog.d(Tag, "waitTime : $waitTime")
            setTime(waitTime)
        }
    }

    // 设置倒计时时间
    @SuppressLint("SetTextI18n")
    private fun setTime(time: Int) {
        tvTime.text = "$time"
        handler.postDelayed(runnable, 1000)
    }

    // 获取实名认证结果，倒计时结束后才处理结果信息
    private fun getResult() {
        handler.removeCallbacks(runnable)
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.ACCOUNT_CERTIRY_IDENTITY_RESULT, null, object : NSGsonObjectNewCallback<BaseResultInfo>() {
            override fun onFailure(statusCode: Int, errorMsg: String?) {
                MyToast.showShort(errorMsg ?: "")       // 处理出错情况
                canFinish = true
                accountStatusView.setStatus(isSuc = false, status = "查询认证结果失败", confirm = "确认", selfFinish = false,userConfirm = {
                    finish()
                })
                showStatusView(STATUS_RESULT)
            }

            override fun onSuccess(statusCode: Int, responseString: String?, msg: String?, response: BaseResultInfo?) {
                canFinish = true

                // 根据结果显示不同的界面
                when (statusCode) {
                    200, 500 -> {    // 成功/查询频繁
                        accountStatusView.setStatus(isSuc = true, status = msg, confirm = "完成", userConfirm = {
                            finish()
                        })
                    }
                    402 -> {        // 认证信息不符合
                        accountStatusView.setStatus(isSuc = false, status = "认证失败", info = msg, confirm = "重新认证", selfFinish = false, userConfirm = {
                            showStatusView(STATUS_CONTAINER)
                            getData()
                        })
                    }
                }
                showStatusView(STATUS_RESULT)
            }
        })
    }

    // 展示不同状态的view
    private fun showStatusView(status: Int) {
        when (status) {
            STATUS_CONTAINER -> {
                llContainer.setVisible(true)
                tvContact.setVisible(true)
                accountCommit.setVisible(false)
                accountStatusView.setVisible(false)
            }
            STATUS_COMMIT -> {
                tvCommit.text = data?.certify_info?.loadding_tip
                llContainer.setVisible(false)
                tvContact.setVisible(false)
                accountCommit.setVisible(true)
                accountStatusView.setVisible(false)
            }
            STATUS_RESULT -> {
                llContainer.setVisible(false)
                tvContact.setVisible(false)
                accountCommit.setVisible(false)
                accountStatusView.setVisible(true)
            }
        }
    }

    override fun setContentView() {
        setContentView(R.layout.activity_account_identity)
    }

}