package com.ninexiu.sixninexiu.activity

import android.content.Context
import android.text.Html
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.view.dialog.BaseDialog
import com.ninexiu.sixninexiu.view.fitterViewSize
import kotlinx.android.synthetic.main.dialog_account_identity.*
import org.jetbrains.anko.displayMetrics

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/03/09
 *     desc   : 实名认证弹窗 | 身份认证弹窗 -> 使用code来区分
 *     version: 1.0
 * </pre>
 */
class AccountIdentityDialog private constructor(context: Context, val code: String, val info: String? = null, val onConfirm: (() -> Unit)? = null) : BaseDialog(context) {
    companion object {
        const val CODE_BIND_PHONE = "9002"            // 手机绑定
        const val CODE_ACCOUNT_IDENTITY = "9003"      // 实名认证

        fun showDialog(context: Context, code: String, info: String? = null, onConfirm: (() -> Unit)? = null): AccountIdentityDialog {
            val dialog = AccountIdentityDialog(context, code, info, onConfirm)
            dialog.show()
            return dialog
        }

        fun showDialog(context: Context, code: String, info: String? = null): AccountIdentityDialog {
            val dialog = AccountIdentityDialog(context, code, info)
            dialog.show()
            return dialog
        }

        fun showDialog(context: Context, code: String): AccountIdentityDialog {
            val dialog = AccountIdentityDialog(context, code)
            dialog.show()
            return dialog
        }
    }

    override fun getContentView(): Int {
        return R.layout.dialog_account_identity
    }

    val width = context.displayMetrics.widthPixels

    override fun initView() {
        super.initView()

        tvCancel.setOnClickListener {
            dismiss()
        }

        tvConfirm.setOnClickListener {
            when (code) {
                CODE_BIND_PHONE -> {
                    onConfirm?.invoke() ?: doBindPhone()    // 绑定手机号
                }
                CODE_ACCOUNT_IDENTITY -> {
                    onConfirm?.invoke() ?: doAccountIdentity()  // 实名认证
                }
            }
            dismiss()
        }

        // 区分实名认证还是手机绑定
        when (code) {
            CODE_BIND_PHONE -> {
                tvInfo.text = info ?: Html.fromHtml("由于相关法律法规<br/>想要进行此操作<br/>您需要进行<b>实名手机号</b>认证")
                ivTopBg.setImageResource(R.drawable.icon_user_phone_auth_dialog_bg)
            }

            CODE_ACCOUNT_IDENTITY -> {
                tvInfo.text = info
                ivTopBg.setImageResource(R.drawable.ic_account_identity_bg)
            }
        }

        fitterViewSize(dialogContainer, { (width * 0.72).toInt() }, { (it * 1.05).toInt() })
        fitterViewSize(ivTopBg, { (width * 0.72).toInt() }, { (it * 0.556).toInt() })
    }

    private fun doAccountIdentity() {
        AccountIdentityActivity.startActivity(context)
    }


    private fun doBindPhone() {
        AccountBindPhoneActivity.startActivity(context, AccountBindPhoneActivity.TYPE_BIND_PHONE)
    }


}