package com.ninexiu.sixninexiu.activity

import android.annotation.SuppressLint
import android.content.Intent
import android.graphics.Rect
import android.os.Bundle
import android.view.View
import androidx.recyclerview.widget.GridLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.adapter.AccountLockAdapter
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.bean.AccountLockData
import com.ninexiu.sixninexiu.bean.AccountLockItem
import com.ninexiu.sixninexiu.bean.AccountLockResult
import com.ninexiu.sixninexiu.common.net.NSGsonObjectNewCallback
import com.ninexiu.sixninexiu.common.net.NsOkHttpClient
import com.ninexiu.sixninexiu.common.statistics.StatisticsEventID
import com.ninexiu.sixninexiu.common.statistics.StatisticsUtil
import com.ninexiu.sixninexiu.common.util.Constants
import com.ninexiu.sixninexiu.common.util.MyToast
import com.ninexiu.sixninexiu.common.util.manager.RequestManager
import com.ninexiu.sixninexiu.fragment.BaseManagerFragment
import com.ninexiu.sixninexiu.fragment.EditUserInfoFragment
import com.ninexiu.sixninexiu.view.dp2px
import com.ninexiu.sixninexiu.view.setVisible
import kotlinx.android.synthetic.main.activity_account_see_lock.*

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/03/29
 *     desc   : 谁看过我的列表
 *     version: 1.0
 * </pre>
 */
class AccountLockFragment : BaseManagerFragment() {
    companion object {
        fun getInstance(bundle: Bundle? = null): AccountLockFragment {
            val fragment = AccountLockFragment()
            bundle?.let { fragment.arguments = bundle }
            return fragment
        }
    }

    // 完善
    private var infoData = mutableListOf<AccountLockItem>()
    private val infoAdapter = AccountLockAdapter(infoData)


    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        // 设置adapter
        recy.layoutManager = GridLayoutManager(context, 3)
        recy.addItemDecoration(decoration)
        recy.adapter = infoAdapter
        tvComplete.setOnClickListener {
            StatisticsUtil.onEvent(StatisticsEventID.UM_LOOKEDME_SUPPLEMENT_CLICK)
            goToEditInfoFragment()
        }

        StatisticsUtil.onEvent(StatisticsEventID.UM_PERSON_SEE_ME)

        initData()
    }


    private fun initData() {
        getData()
    }

    private fun getData() {
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.ACCOUNT_SEE_ME_LOCK, null, object : NSGsonObjectNewCallback<AccountLockResult>() {
            override fun onFailure(statusCode: Int, errorMsg: String?) {
                MyToast.showShort(errorMsg ?: "")
            }

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: AccountLockResult?) {
                if (statusCode == 200 && response != null && response.data != null && response.data.imgArr?.size ?: 0 > 0) {
                    // 显示完善资料提醒
                    setInfoData(response.data)

                    constrantInfo.setVisible(true)
                    constraintEmpty.setVisible(false)
                    StatisticsUtil.onEvent(StatisticsEventID.UM_LOOKEDME_SUPPLEMENT)
                } else {
                    constrantInfo.setVisible(false)
                    constraintEmpty.setVisible(true)
                }
            }
        })
    }

    // 显示完善用户资料
    @SuppressLint("SetTextI18n")
    private fun setInfoData(data: AccountLockData) {
        if (multiplyView == null){
            return
        }
        infoData.clear()
        multiplyView.clear()
        data.info?.let { infoData.addAll(it) }
        infoAdapter.notifyDataSetChanged()

        tvCount.text = data.desc
        tvAnchorCount.text = "+${data.lookedUserCount}"


        rlAnchor.setVisible(data.imgArr?.size ?: 0 > 0)

        var datas = data.imgArr

        if (datas?.size ?: 0 > 4) {
            datas = datas?.subList(0, 4)
        }

        // 设置头像
        datas?.filterIndexed { index, _ ->  index < 4}?.forEach {
            multiplyView?.addTheMultiplySingleView(it)
        }

        // todo : 测试代码
        /*NSLog.d("AccountInfo avator : ", "${data.imgArr?.size ?: -1}")
        rlAnchor.setVisible(true)
        val url = "https://gimg2.baidu.com/image_search/src=http%3A%2F%2Fimage.wangchao.net.cn%2Ffengjing%2F1327174432223.jpg&refer=http%3A%2F%2Fimage.wangchao.net.cn&app=2002&size=f9999,10000&q=a80&n=0&g=0n&fmt=jpeg?sec=1632911369&t=dc680df814ced2b2f1acf082ffbe2cac"
        for (index in 0..3) {
            multiplyView.addTheMultiplySingleView(url)
        }*/
    }

    private val divider: Int by lazy {
        context?.let {
            dp2px(it, 7.5f)
        } ?: 0
    }

    // 设置间隔
    val decoration = object : RecyclerView.ItemDecoration() {
        override fun getItemOffsets(outRect: Rect, view: View, parent: RecyclerView, state: RecyclerView.State) {
            super.getItemOffsets(outRect, view, parent, state)
            outRect.left = divider
            outRect.right = divider
            outRect.top = divider
            outRect.bottom = divider
        }
    }


    override fun setLayoutId(): Int = R.layout.activity_account_see_lock


    //跳转个人资料页
    private fun goToEditInfoFragment() {
        if (NineShowApplication.mUserBase?.uid?.toInt() ?: 0 == 0) {
            return
        }

        RequestManager.create().getPersonalInfoData(0, NineShowApplication.mUserBase!!.uid) { response ->
            val contextTemp = context
            if (response != null && response.data != null && contextTemp != null) {
                val bundleGo = Bundle()
                bundleGo.putSerializable("personalInfo", response.data)
                bundleGo.putInt(EditUserInfoFragment.FROM_TYPE, EditUserInfoFragment.LOOK_ME_TYPE)
                val intent = Intent(contextTemp, SubPageActivity::class.java)
                intent.putExtra(SubPageActivity.CLASSFRAMENT, EditUserInfoFragment::class.java)
                intent.putExtras(bundleGo)
                intent.putExtra("bundle", bundleGo)
                startActivity(intent)


            }
        }
    }

    fun refreshData(){
        getData()
    }

}