package com.ninexiu.sixninexiu.activity

import android.content.Context
import android.content.Intent
import android.text.TextUtils
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.bean.BaseResultInfo
import com.ninexiu.sixninexiu.common.net.NSGsonObjectNewCallback
import com.ninexiu.sixninexiu.common.net.NSRequestParams
import com.ninexiu.sixninexiu.common.net.NsOkHttpClient
import com.ninexiu.sixninexiu.common.util.Constants
import com.ninexiu.sixninexiu.common.util.MyToast
import com.ninexiu.sixninexiu.common.util.NSLog
import com.ninexiu.sixninexiu.common.util.Utils
import com.ninexiu.sixninexiu.login.LoginActivity
import com.ninexiu.sixninexiu.view.setVisible
import kotlinx.android.synthetic.main.activity_account_identity.*
import kotlinx.android.synthetic.main.activity_account_modifypwd.*
import kotlinx.android.synthetic.main.activity_account_setpwd.accountStatusView
import kotlinx.android.synthetic.main.activity_account_setpwd.btPwdConfirm
import kotlinx.android.synthetic.main.activity_account_setpwd.llContainer
import org.greenrobot.eventbus.EventBus
import org.greenrobot.eventbus.Subscribe

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/03/05
 *     desc   : 修改密码界面
 *     version: 1.0
 * </pre>
 */
class AccountModifyPwdActivity : BaseActivity() {
    companion object {
        const val Tag = "AccountSetPwdActivity >> "

        fun startActivity(context: Context) {
            val intent = Intent(context, AccountModifyPwdActivity::class.java)
            context.startActivity(intent)
        }
    }

    override fun initViews() {
        accountOldPwd.setEditSelected(true)
        accountNewPwd.setEditSelected(false)
        accountNewPwdConfirm.setEditSelected(false)

        // 焦点转换，切换背景
        accountOldPwd.onEditGetFocus = {
            accountOldPwd.setEditSelected(true)
            accountNewPwd.setEditSelected(false)
            accountNewPwdConfirm.setEditSelected(false)
        }

        accountNewPwd.onEditGetFocus = {
            accountOldPwd.setEditSelected(false)
            accountNewPwd.setEditSelected(true)
            accountNewPwdConfirm.setEditSelected(false)
        }

        accountNewPwdConfirm.onEditGetFocus = {
            accountOldPwd.setEditSelected(false)
            accountNewPwd.setEditSelected(false)
            accountNewPwdConfirm.setEditSelected(true)
        }

        leftFinish.setOnClickListener {
            if (canFinish) {
                finish()
            } else {
                reLogin()
            }
        }

        tvForgetPwd.setOnClickListener {
            AccountBindPhoneActivity.startActivity(this, AccountBindPhoneActivity.TYPE_FORGET_PWD)
        }

        // 忘记密码/设置密码
        btPwdConfirm.setOnClickListener {
            userConfirmPwd()
            // 关闭键盘
            AccountSecurityHelper.hideKeyBoard(accountNewPwdConfirm)
        }
    }

    // 用户确认 : 对密码进行格式验证
    private fun userConfirmPwd() {
        val pwdOld = accountOldPwd.getEditTextPwd()
        if (!verificationPwd(pwdOld, true)) {
            return
        }

        val pwdNew = accountNewPwd.getEditTextPwd()
        if (!verificationPwd(pwdNew, false)) {
            return
        }

        val pwdNewConfirm = accountNewPwdConfirm.getEditTextPwd()
        if (!verificationPwd(pwdNewConfirm, false)) {
            return
        }

        if (!TextUtils.equals(pwdNew, pwdNewConfirm)) {
            MyToast.MakeToast("新密码两次输入不一致，请重新输入")
            return
        }

        val token = NineShowApplication.mUserBase?.token
        if (TextUtils.isEmpty(token)) {
            return
        }

        if (pwdOld.isNullOrBlank() || pwdNew.isNullOrBlank()) {
            return
        }

        val params = NSRequestParams()
        params.put("token", token)
        params.put("oldpassword", AccountSecurityHelper.toURLEncoded(pwdOld))
        params.put("password", AccountSecurityHelper.toURLEncoded(pwdNew))

        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.CHANGE_PASSWORD, params, object : NSGsonObjectNewCallback<BaseResultInfo>() {
            override fun onFailure(statusCode: Int, errorMsg: String?) {
                MyToast.MakeToast(errorMsg ?: "")
            }

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: BaseResultInfo?) {
                MyToast.MakeToast(message ?: "")
                if (statusCode == 200) {
                    // 修改密码 -> 成功界面
                    canFinish = false
                    showStatusView(AccountIdentityActivity.STATUS_RESULT)
                    accountStatusView.setStatus(isSuc = true, status = "修改成功", confirm = "完成") {
                        reLogin()
                    }
                } /*else {
                    when (statusCode) {
                        4111 -> MyToast.MakeToast("旧密码错误")
                        400 -> MyToast.MakeToast("新旧密码不能相同")
                        else -> MyToast.MakeToast("修改失败")
                    }
                }*/
            }
        })
    }

    private fun reLogin() {
        EventBus.getDefault().post(ReloginCloseEvent())
        MyToast.MakeToast("修改成功,请重新登录")
        Utils.logout()
        startActivity(Intent(this, LoginActivity::class.java))
        Utils.exitActivityAnimation(this)
    }

    private fun verificationPwd(pwd: String?, isOld: Boolean): Boolean {
        if (pwd.isNullOrBlank()) {
            if (isOld) {
                MyToast.MakeToast("旧密码不能为空，请重新输入")
            } else {
                MyToast.MakeToast("新密码不能为空，请重新输入")
            }
            return false
        }

        if (pwd.length < 6 || pwd.length > 16) {
            if (isOld) {
                MyToast.MakeToast("旧密码不正确，请重新输入")
            } else {
                MyToast.MakeToast("新密码不正确，请重新输入")
            }
            return false
        }
        return true
    }


    // 展示不同状态的view
    private fun showStatusView(status: Int) {
        when (status) {
            AccountIdentityActivity.STATUS_CONTAINER -> {
                llContainer.setVisible(true)
                accountStatusView.setVisible(false)
            }
            AccountIdentityActivity.STATUS_RESULT -> {
                llContainer.setVisible(false)
                accountStatusView.setVisible(true)
            }
        }
    }

    private var canFinish = true
    override fun onBackPressed() {
        if (canFinish) {
            super.onBackPressed()
        } else {
            reLogin()
        }
    }

    @Subscribe
    fun closeActivity(event: AccountBindPhoneCloseEvent) {
        // 用户中间点忘记密码需要关闭此界面
        Utils.exitActivityAnimation(this)
    }

    override fun onDestroy() {
        super.onDestroy()
        if (EventBus.getDefault().isRegistered(this)) {
            EventBus.getDefault().unregister(this)
        }
    }


    override fun setContentView() {
        EventBus.getDefault().register(this)
        setContentView(R.layout.activity_account_modifypwd)
    }
}