package com.ninexiu.sixninexiu.activity

import android.content.Context
import android.content.Intent
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.bean.UserBase
import com.ninexiu.sixninexiu.bean.UserInfoResult
import com.ninexiu.sixninexiu.common.net.NSGsonObjectNewCallback
import com.ninexiu.sixninexiu.common.net.NSRequestParams
import com.ninexiu.sixninexiu.common.net.NsOkHttpClient
import com.ninexiu.sixninexiu.common.statistics.StatisticsEventID
import com.ninexiu.sixninexiu.common.statistics.StatisticsUtil
import com.ninexiu.sixninexiu.common.util.Constants
import com.ninexiu.sixninexiu.common.util.MyToast
import com.ninexiu.sixninexiu.common.util.NSLog
import com.ninexiu.sixninexiu.common.util.Utils
import com.ninexiu.sixninexiu.login.ThirdLoginUtil
import com.ninexiu.sixninexiu.view.AccountSettingItemView
import com.ninexiu.sixninexiu.view.dialog.CommonConfirmCancelDialog
import com.umeng.socialize.UMShareAPI
import com.umeng.socialize.bean.SHARE_MEDIA
import kotlinx.android.synthetic.main.activity_account_security.*
import org.greenrobot.eventbus.EventBus
import org.greenrobot.eventbus.Subscribe

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/03/02
 *     desc   : 账户与安全界面
 *     version: 1.0
 * </pre>
 */
class AccountSecurityActivity : BaseActivity() {
    companion object {
        const val Tag = "AccountSecurityActivity >> "
        const val BIND_THIRD_QQ = 0
        const val BIND_THIRD_WECHAT = 1
        const val BIND_THIRD_SINA = 2

        const val SOURCE_QQ = "qq"
        const val SOURCE_WECHAT = "weixin"
        const val SOURCE_SINA = "weibo"

        const val BIND = 1
        fun startActivity(context: Context) {
            val intent = Intent(context, AccountSecurityActivity::class.java)
            context.startActivity(intent)
        }
    }

    // 是否需要在onResume的时候刷新(第三方绑定的时候不需要，否则会接口请求过于频繁)
    private var needResumeRefresh = true
    override fun onResume() {
        super.onResume()
        if (needResumeRefresh) {
            getUserAccountData()
        }
    }

    private fun getUserAccountData() {
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_USER_INFO, null, object : NSGsonObjectNewCallback<UserInfoResult>() {
            override fun onFailure(statusCode: Int, errorMsg: String?) {
                MyToast.showShort(errorMsg ?: "")
            }

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: UserInfoResult?) {
                MyToast.showShort(message ?: "")
                if (statusCode == 200) {
                    response?.data?.let { setAccountData(it) }
                    NSLog.d(Tag, response?.data?.nickname)
                }
            }
        })
    }

    override fun initEvents() {
        super.initEvents()

        // 未认证或认证失败
        itemIdentity.setOnClickListener {
            data?.certify_status?.let {
                if (it == 0 || it == 3) {
                    StatisticsUtil.onEvent(StatisticsEventID.UM_ACCOUNT_IDENTITY)
                    AccountIdentityActivity.startActivity(this)
                }
            }
        }

        // 绑定手机号/更换绑定手机号
        itemPhone.setOnClickListener {
            if (data?.phone?.isEmpty() != false) {
                AccountBindPhoneActivity.startActivity(this, AccountBindPhoneActivity.TYPE_BIND_PHONE)   // 绑定手机号
            } else {
                AccountBindPhoneActivity.startActivity(this, AccountBindPhoneActivity.TYPE_CHANGE_PHONE) // 更换绑定手机号
            }
            StatisticsUtil.onEvent(StatisticsEventID.UM_ACCOUNT_BIND_PHONE)
        }

        // 设置密码/修改密码
        itemPwd.setOnClickListener {
            /**
             * isEditedPwd字段 : 只有用户在一键登录和三方登录的时候才会返回
             * 1. 一键登录&三方登录 : 用户如果设置过密码，返回true，未设置，返回false
             * 2. isEditedPwd默认设置为true，即用户除了一键登录和三方登录按服务器返回的isEditedPwd来设置此字段以外，其他情况都是默认用户设置过密码的
             */
            if (NineShowApplication.mUserBase?.isEditedPwd != true) {
                if (data?.phone?.isBlank() != false) {
                    MyToast.showShort("绑定手机号码后才能设置密码")
                } else {
                    StatisticsUtil.onEvent(StatisticsEventID.UM_ACCOUNT_MODIFY_PWD)
                    AccountBindPhoneActivity.startActivity(this, AccountBindPhoneActivity.TYPE_SET_PWD)
                }
            } else {
                if (data?.phone?.isBlank() != false) {
                    MyToast.showShort("绑定手机号码后才能修改密码")
                } else {
                    StatisticsUtil.onEvent(StatisticsEventID.UM_ACCOUNT_MODIFY_PWD)
                    AccountModifyPwdActivity.startActivity(this)
                }
            }
        }

        itemDestroy.setOnClickListener {
            val intent = Intent(this, LogoutProcessActivity::class.java)
            startActivity(intent)
        }

        // 解绑QQ/绑定QQ
        itemQQ.setOnClickListener {
            if (data?.bind_qq ?: 0 == 1) {
                thirdUnBind(SOURCE_QQ, "QQ")
            } else {
                thirdBind(BIND_THIRD_QQ)
            }
            StatisticsUtil.onEvent(StatisticsEventID.UM_ACCOUNT_BIND_THIRD)
        }

        // 解绑微信/绑定微信
        itemWeChat.setOnClickListener {
            if (data?.bind_weixin ?: 0 == 1) {
                thirdUnBind(SOURCE_WECHAT, "微信")
            } else {
                thirdBind(BIND_THIRD_WECHAT)
            }
            StatisticsUtil.onEvent(StatisticsEventID.UM_ACCOUNT_BIND_THIRD)
        }

        // 解绑微博/绑定微博
        itemSina.setOnClickListener {
            if (data?.bind_weibo ?: 0 == 1) {
                thirdUnBind(SOURCE_SINA, "微博")
            } else {
                thirdBind(BIND_THIRD_SINA)
            }
            StatisticsUtil.onEvent(StatisticsEventID.UM_ACCOUNT_BIND_THIRD)
        }
    }

    // 解绑第三方账号
    private fun thirdUnBind(source: String, thirdName: String) {
        CommonConfirmCancelDialog.showDialog(this, "提示", "解除绑定，将无法使用${thirdName}快捷登录此账号，是否解除${thirdName}绑定？", onConfirm = {
            thirdUnBindReal(source)
        })
    }

    // 真正的解绑
    private fun thirdUnBindReal(source: String) {
        val params = NSRequestParams()
        params.put("source", source)

        NsOkHttpClient.getNsOkHttpClient().doPost(Constants.ACCOUNT_UNBIND_THIRD, params, object : NSGsonObjectNewCallback<UserInfoResult>() {
            override fun onFailure(statusCode: Int, errorMsg: String?) {
                MyToast.showShort(errorMsg ?: "")
            }

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: UserInfoResult?) {
                MyToast.showShort(message ?: "")
                if (statusCode == 200) {
                    // 绑定成功以后刷新数据
                    getUserAccountData()
                }
            }
        })
    }

    private val umShareAPI: UMShareAPI by lazy {
        UMShareAPI.get(this)
    }

    private fun thirdBind(type: Int) {
        needResumeRefresh = false
        when (type) {
            BIND_THIRD_QQ -> {
                ThirdLoginUtil.getInstents().thirdLogIn(umShareAPI, this, SHARE_MEDIA.QQ, callBack)
            }
            BIND_THIRD_WECHAT -> {
                ThirdLoginUtil.getInstents().thirdLogIn(umShareAPI, this, SHARE_MEDIA.WEIXIN, callBack)
            }
            BIND_THIRD_SINA -> {
                ThirdLoginUtil.getInstents().thirdLogIn(umShareAPI, this, SHARE_MEDIA.SINA, callBack)
            }
        }
    }

    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        super.onActivityResult(requestCode, resultCode, data)
        umShareAPI.onActivityResult(requestCode, resultCode, data)
    }

    // 吊起第三方回调
    val callBack: ThirdLoginUtil.ThirdCallBack = object : ThirdLoginUtil.ThirdCallBack {
        override fun onCancel(errorMsg: String?) {
            needResumeRefresh = true
            MyToast.showShort(errorMsg ?: "授权失败,您已取消授权")
        }

        override fun sinaCallBack(openId: String?, accessToken: String?, source: String?) {
            thirdBindReal(SOURCE_SINA, openId, accessToken,"")
        }

        override fun qqCallBack(openId: String?, accessToken: String?,unionid:String?, source: String?) {
            thirdBindReal(SOURCE_QQ, openId, accessToken,unionid)
        }

        override fun wxLoginCallBack(openId: String?, accessToken: String?, source: String?) {
            thirdBindReal(SOURCE_WECHAT, openId, accessToken,"")
        }
    }


    // 服务器绑定
    private fun thirdBindReal(source: String, openId: String?, accessToken: String?,unionid:String?) {
        if (openId.isNullOrBlank() || accessToken.isNullOrBlank()) {
            return
        }

        val params = NSRequestParams()
        params.put("source", source)
        params.put("openid", openId)
        params.put("accesstoken", accessToken)
        unionid?.let {
            params.put("unionid", it)
        }
        params.put("os", 1)

        NsOkHttpClient.getNsOkHttpClient().doPost(Constants.ACCOUNT_BIND_THIRD, params, object : NSGsonObjectNewCallback<UserInfoResult>() {
            override fun onFailure(statusCode: Int, errorMsg: String?) {
                MyToast.showShort(errorMsg ?: "")
                needResumeRefresh = true
            }

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: UserInfoResult?) {
                needResumeRefresh = true
                MyToast.showShort(message ?: "")
                if (statusCode == 200) {
                    // 绑定成功以后刷新数据
                    getUserAccountData()
                }
            }
        })
    }


    private var data: UserBase? = null

    // 设置账户与安全数据
    private fun setAccountData(data: UserBase) {
        this.data = data
        setIdentityData(data.certify_status)
        setPwdData()
        setPhone(data.phone)
        setThirdData(data)

        itemDestroy.setStatusInfo(status = AccountSettingItemView.STATUS_ARROW)
    }

    // 设置三方 : QQ,微信,微博
    private fun setThirdData(data: UserBase) {
        // QQ
        when (data.bind_qq) {
            BIND -> {
                itemQQ.setStatusInfo(status = AccountSettingItemView.STATUS_UNBIND, unBind = "解绑", thirdInfo = data.qq_nickname)
            }
            else -> {
                itemQQ.setStatusInfo(status = AccountSettingItemView.STATUS_BIND, bind = "去绑定")
            }
        }

        // 微信
        when (data.bind_weixin) {
            BIND -> {
                itemWeChat.setStatusInfo(status = AccountSettingItemView.STATUS_UNBIND, unBind = "解绑", thirdInfo = data.weixin_nickname)
            }
            else -> {
                itemWeChat.setStatusInfo(status = AccountSettingItemView.STATUS_BIND, bind = "去绑定")
            }
        }

        // 微博
        when (data.bind_weibo) {
            BIND -> {
                itemSina.setStatusInfo(status = AccountSettingItemView.STATUS_UNBIND, unBind = "解绑", thirdInfo = data.weibo_nickname)
            }
            else -> {
                itemSina.setStatusInfo(status = AccountSettingItemView.STATUS_BIND, bind = "去绑定")
            }
        }

    }

    // 绑定手机号/更换手机号
    private fun setPhone(phone: String?) {
        if (phone?.isEmpty() != false) {
            itemPhone.setStatusInfo(status = AccountSettingItemView.STATUS_BIND, bind = "去绑定", showDot = true)
        } else {
            var phoneTemp = phone
            if (!phone.isNullOrBlank() && phone.length == 11) {
                phoneTemp = StringBuilder().append(phone.substring(0, 3)).append("****").append(phone.substring(7, 11)).toString()
            }
            itemPhone.setStatusInfo(status = AccountSettingItemView.STATUS_UNBIND, unBind = "更换", thirdInfo = phoneTemp)
        }
    }

    // 设置密码/修改密码
    private fun setPwdData() {
        if (NineShowApplication.mUserBase?.isEditedPwd != true) {       // (isEditedPwd : false) && (phone.isNotNullOrEmpty)
            itemPwd.setTitleInfo(status = AccountSettingItemView.STATUS_ARROW, title = "设置密码", showDot = true)
        } else {
            itemPwd.setTitleInfo(status = AccountSettingItemView.STATUS_ARROW, title = "修改密码", showDot = false)
        }
    }

    // 设置实名认证
    private fun setIdentityData(identityStatus: Int) {
        var certifyStatus = AccountSettingItemView.STATUS_ARROW
        var unComplete: String? = null
        var complete: String? = null
        var showDot = false
        when (identityStatus) {
            0 -> {
                certifyStatus = AccountSettingItemView.STATUS_UNIDENTITY
                unComplete = "未认证"
            }
            1 -> {
                certifyStatus = AccountSettingItemView.STATUS_IDENTITY
                complete = "已认证"
            }
            2 -> {
                certifyStatus = AccountSettingItemView.STATUS_IDENTITY
                complete = "认证成功"
            }
            3 -> {
                certifyStatus = AccountSettingItemView.STATUS_UNIDENTITY
                unComplete = "认证失败"
                showDot = true
            }
        }
        NineShowApplication.mUserBase?.certify_status = identityStatus
        itemIdentity.setStatusInfo(status = certifyStatus, unComplete = unComplete, complete = complete, showDot = showDot)
    }


    override fun setContentView() {
        EventBus.getDefault().register(this)
        setContentView(R.layout.activity_account_security)
    }

    override fun onDestroy() {
        super.onDestroy()
        if (EventBus.getDefault().isRegistered(this)) {
            EventBus.getDefault().unregister(this)
        }
    }

    @Subscribe
    fun closeActivity(event: ReloginCloseEvent) {
        // 用户重新登录时需要关闭此界面
        Utils.exitActivityAnimation(this)
    }
}

// 用户设置密码/忘记密码/修改密码以后需要重新登录
class ReloginCloseEvent