package com.ninexiu.sixninexiu.activity

import android.content.Context
import android.content.Intent
import android.content.IntentFilter
import android.os.Bundle
import android.text.TextUtils
import androidx.fragment.app.Fragment
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.bean.UserInfoResult
import com.ninexiu.sixninexiu.common.net.NSGsonObjectNewCallback
import com.ninexiu.sixninexiu.common.net.NsOkHttpClient
import com.ninexiu.sixninexiu.common.statistics.StatisticsEventID
import com.ninexiu.sixninexiu.common.statistics.StatisticsUtil
import com.ninexiu.sixninexiu.common.util.Constants
import com.ninexiu.sixninexiu.common.util.MyToast
import com.ninexiu.sixninexiu.common.util.NSReceiverAction
import kotlinx.android.synthetic.main.activity_account_see_manager.*

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/09/02
 *     desc   :
 *     version: 1.0
 * </pre>
 */
class AccountSeeManagerActivity : BaseActivity() {
    companion object {
        const val ACCOUNT_TYPE = "account_type"

        const val TYPE_SEE = 0
        const val TYPE_LOCK = 1

        fun startActivity(context: Context, type: Int) {
            val intent = Intent(context, AccountSeeManagerActivity::class.java)
            intent.putExtra(ACCOUNT_TYPE, type)
            context.startActivity(intent)
        }
    }

    private var fragmentSee: Fragment = AccountSeeMeFragment.getInstance()      // 看过我
    private var fragmentLock: Fragment = AccountLockFragment.getInstance()      // 编辑资料

    override fun setContentView() {
        setContentView(R.layout.activity_account_see_manager)
    }

    override fun initViews() {
        super.initViews()

        btSeeLeft.setOnClickListener { finish() }

        val type = intent?.getIntExtra(ACCOUNT_TYPE, TYPE_SEE) ?: TYPE_SEE      // 默认为看过我列表
        showFragment(type)
    }

    private fun showFragment(type: Int, doRefresh: Boolean = false) {
        val fragmentTemp = when (type) {
            TYPE_LOCK -> fragmentLock
            else -> fragmentSee
        }
        supportFragmentManager.beginTransaction().replace(R.id.frameContainer, fragmentTemp).commit()

        if (doRefresh) {
            when (type) {
                TYPE_LOCK -> (fragmentTemp as? AccountLockFragment)?.refreshData()
                else -> {
                    StatisticsUtil.onEvent(StatisticsEventID.UM_LOOKEDME_SUPPLEMENT_SUC)
                    (fragmentTemp as? AccountSeeMeFragment)?.refreshData()
                }
            }
        }
    }

    override fun setBroadcastFilter(filter: IntentFilter?) {
        super.setBroadcastFilter(filter)
        filter?.addAction(NSReceiverAction.ACTION_PERSONAL_INFO_REFRESH)
    }

    override fun onReceive(action: String?, type: Int, bundle: Bundle?) {
        super.onReceive(action, type, bundle)
        if (TextUtils.equals(action, NSReceiverAction.ACTION_PERSONAL_INFO_REFRESH)) {
            getUserAccountData()
        }
    }

    private fun getUserAccountData() {
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_USER_INFO, null, object : NSGsonObjectNewCallback<UserInfoResult>() {
            override fun onFailure(statusCode: Int, errorMsg: String?) {
                MyToast.showShort(errorMsg ?: "")
            }

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: UserInfoResult?) {
                MyToast.showShort(message ?: "")
                if (statusCode == 200 && response != null && response.data != null) {
                    val userBase = response.data
                    if (userBase.isPerfectLooked == 1) {
                        showFragment(TYPE_SEE, true)

                    } else {
                        showFragment(TYPE_LOCK, true)

                    }
                }
            }
        })
    }

    override fun registerReceiver() = true
}