package com.ninexiu.sixninexiu.activity

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.recyclerview.widget.LinearLayoutManager
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.adapter.AccountSeeMeAdapter
import com.ninexiu.sixninexiu.bean.AccountSeeMeResponse
import com.ninexiu.sixninexiu.bean.SeeMeData
import com.ninexiu.sixninexiu.common.net.NSGsonObjectNewCallback
import com.ninexiu.sixninexiu.common.net.NsOkHttpClient
import com.ninexiu.sixninexiu.common.statistics.StatisticsEventID
import com.ninexiu.sixninexiu.common.statistics.StatisticsUtil
import com.ninexiu.sixninexiu.common.util.Constants
import com.ninexiu.sixninexiu.common.util.MyToast
import com.ninexiu.sixninexiu.common.util.NSLog
import com.ninexiu.sixninexiu.fragment.BaseManagerFragment
import com.ninexiu.sixninexiu.view.setVisible
import kotlinx.android.synthetic.main.activity_account_see_me.*

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/03/29
 *     desc   : 谁看过我的列表
 *     version: 1.0
 * </pre>
 */
class AccountSeeMeFragment : BaseManagerFragment() {
    companion object {
        fun getInstance(bundle: Bundle? = null): AccountSeeMeFragment {
            val fragment = AccountSeeMeFragment()
            bundle?.let { fragment.arguments = bundle }
            return fragment
        }
    }

    override fun setLayoutId(): Int = R.layout.activity_account_see_me


    private val data = mutableListOf<SeeMeData>()
    private val adapter = AccountSeeMeAdapter(data)

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        StatisticsUtil.onEvent(StatisticsEventID.UM_PERSON_SEE_ME)

        val manager = LinearLayoutManager(context, LinearLayoutManager.VERTICAL, false)
        recySee.layoutManager = manager
        recySee.adapter = adapter

        // 进入个人主页
        adapter.itemClick = { uid ->
            StatisticsUtil.onEvent(StatisticsEventID.UM_PERSON_SEE_TOPERSON)
            context?.let {
                PersonalInforActivity.start(it, true, uid)
            }
        }

        initData()
    }


    private fun initData(){
        getData()
    }

    private fun getData(){
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.ACCOUNT_GET_USER_SEE_ME, null, object : NSGsonObjectNewCallback<AccountSeeMeResponse>() {
            override fun onFailure(statusCode: Int, errorMsg: String?) {
                MyToast.showShort(errorMsg ?: "")
            }

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: AccountSeeMeResponse?) {
                NSLog.d("AccountSeeMe ", "msg : ${message ?: "null"}")
                if (statusCode == 200 && response != null && response.data != null && response.data.isNotEmpty()) {
                    response.data.let {
                        data.clear()
                        data.addAll(it)
                        adapter.notifyDataSetChanged()
                    }
                    recySee?.setVisible(true)
                    tvInfo?.setVisible(true)
                    constraintEmpty?.setVisible(false)
                } else {
                    recySee?.setVisible(false)
                    tvInfo?.setVisible(false)
                    constraintEmpty?.setVisible(true)
                }
            }
        })
    }

    fun refreshData(){
        getData()
    }
}