package com.ninexiu.sixninexiu.activity

import android.content.Context
import android.content.Intent
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.bean.AccountCertifyData
import com.ninexiu.sixninexiu.bean.AccountCertifyResult
import com.ninexiu.sixninexiu.bean.BaseResultInfo
import com.ninexiu.sixninexiu.common.net.ApiParams
import com.ninexiu.sixninexiu.common.net.NSGsonObjectNewCallback
import com.ninexiu.sixninexiu.common.net.NSRequestParams
import com.ninexiu.sixninexiu.common.net.NsOkHttpClient
import com.ninexiu.sixninexiu.common.util.Constants
import com.ninexiu.sixninexiu.common.util.MyToast
import com.ninexiu.sixninexiu.common.util.NSLog
import com.ninexiu.sixninexiu.common.util.Utils
import com.ninexiu.sixninexiu.login.LoginActivity
import com.ninexiu.sixninexiu.view.setVisible
import kotlinx.android.synthetic.main.activity_account_bind_phone.*
import kotlinx.android.synthetic.main.activity_account_identity.*
import kotlinx.android.synthetic.main.activity_account_setpwd.*
import kotlinx.android.synthetic.main.activity_account_setpwd.accountStatusView
import kotlinx.android.synthetic.main.activity_account_setpwd.llContainer
import kotlinx.android.synthetic.main.activity_account_setpwd.tvTitle
import kotlinx.android.synthetic.main.activity_account_setpwd.tvTopInfo
import org.greenrobot.eventbus.EventBus
import org.jetbrains.anko.startActivity

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/03/05
 *     desc   : 此界面统一为 【设置密码】   适用界面为 : 设置密码，忘记密码
 *     version: 1.0
 * </pre>
 */
class AccountSetPwdActivity : BaseActivity() {
    companion object {
        const val Tag = "AccountSetPwdActivity >> "

        // type 类型 :  TYPE_SET_PWD【设置密码】, TYPE_FORGET_PWD【忘记密码】
        fun startActivity(context: Context, type: Int, phoneNumber: String, verificationCode: String) {
            val intent = Intent(context, AccountSetPwdActivity::class.java)
            intent.putExtra(AccountBindPhoneActivity.TYPE, type)
            intent.putExtra(AccountBindPhoneActivity.PHONE_NUMBER, phoneNumber)             // 手机号
            intent.putExtra(AccountBindPhoneActivity.VERIFICATION_CODE, verificationCode)   // 验证码
            context.startActivity(intent)
        }
    }

    private val type: Int by lazy {
        intent?.getIntExtra(AccountBindPhoneActivity.TYPE, AccountBindPhoneActivity.TYPE_SET_PWD)
                ?: AccountBindPhoneActivity.TYPE_SET_PWD
    }

    private val phoneNumber: String? by lazy {
        intent?.getStringExtra(AccountBindPhoneActivity.PHONE_NUMBER)
    }

    private val verificationCode: String? by lazy {
        intent?.getStringExtra(AccountBindPhoneActivity.VERIFICATION_CODE)
    }

    override fun initViews() {
        NSLog.d(Tag, "type : $type , number : $phoneNumber , code : $verificationCode")
        when (type) {
            AccountBindPhoneActivity.TYPE_SET_PWD -> tvTitle.text = "设置密码"
            AccountBindPhoneActivity.TYPE_FORGET_PWD -> tvTitle.text = "忘记密码"
        }

        leftFinishSetPwd.setOnClickListener {
            if (relogin) {
                reLogin()       // 设置密码完成后重新登录
            } else {
                Utils.exitActivityAnimation(this@AccountSetPwdActivity)
            }
        }

        // 忘记密码/设置密码
        btPwdConfirm.setOnClickListener {
            userConfirmPwd()
            // 关闭键盘
            AccountSecurityHelper.hideKeyBoard(accountEtPwd)
        }
    }

    // 用户确认 : 对密码进行格式验证
    private fun userConfirmPwd() {
        if (phoneNumber.isNullOrBlank() || verificationCode.isNullOrBlank()) {
            MyToast.showShort("手机或验证码不能为空")
            return
        }

        val pwd = accountEtPwd.getEditTextPwd()
        if (pwd.isNullOrBlank()) {
            MyToast.showShort("新密码不能为空，请点击重试")
            return
        }

        if (pwd.length < 6 || pwd.length > 16) {
            MyToast.showShort("密码格式不正确，请点击重试")
            return
        }

        val params = NSRequestParams()
        params.put(ApiParams.Register.REQ_REGISTER_PHONENUM, phoneNumber)
        params.put(ApiParams.Register.REQ_REGISTER_CODE, verificationCode)
        params.put("pwd", pwd)
        params.put("pwd2", pwd)

        NsOkHttpClient.getNsOkHttpClient().doPost(Constants.RESET_PASSWORD, params, object : NSGsonObjectNewCallback<BaseResultInfo>() {
            override fun onFailure(statusCode: Int, errorMsg: String?) {
                MyToast.showShort(errorMsg ?: "")
            }

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: BaseResultInfo?) {
                MyToast.showShort(message ?: "")
                if (statusCode == 200) {
                    EventBus.getDefault().post(AccountBindPhoneCloseEvent())    // 关闭上个界面
                    // 设置密码和忘记密码 -> 新密码设置好后让用户重新登录
                    relogin = true
                    showStatusView(AccountIdentityActivity.STATUS_RESULT)
                    accountStatusView.setStatus(isSuc = true, status = message, confirm = "完成") {
                        reLogin()
                    }
                } else {
                    MyToast.showShort(message)
                    NSLog.d(Tag, "code : $statusCode")
                }
            }
        })
    }

    private var relogin = false
    private fun reLogin() {
        EventBus.getDefault().post(ReloginCloseEvent())
        MyToast.showShort("设置密码成功,请重新登录")
        Utils.logout()
        startActivity(Intent(this@AccountSetPwdActivity, LoginActivity::class.java))
        Utils.exitActivityAnimation(this@AccountSetPwdActivity)
    }

    override fun onBackPressed() {
        if (!relogin) {
            super.onBackPressed()
        } else {
            reLogin()
        }
    }

    // 展示不同状态的view
    private fun showStatusView(status: Int) {
        when (status) {
            AccountIdentityActivity.STATUS_CONTAINER -> {
                llContainer.setVisible(true)
                accountStatusView.setVisible(false)
            }
            AccountIdentityActivity.STATUS_RESULT -> {
                llContainer.setVisible(false)
                accountStatusView.setVisible(true)
            }
        }
    }

    override fun initDatas() {
        super.initDatas()
        // 获取tip提示信息
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.ACCOUNT_CERTIFY_TIPS, null, object : NSGsonObjectNewCallback<AccountCertifyResult>() {
            override fun onFailure(statusCode: Int, errorMsg: String?) {
                MyToast.showShort(errorMsg ?: "")
            }

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: AccountCertifyResult?) {
                MyToast.showShort(message ?: "")
                if (statusCode == 200) {
                    response?.data?.let { setTipData(it) }
                }
            }
        })
    }

    // 根据不同的type设置不同的头部提示信息
    private fun setTipData(tipData: AccountCertifyData) {
        // 设置头部tip提示
        when (type) {
            AccountBindPhoneActivity.TYPE_SET_PWD -> AccountSecurityHelper.setPhoneNumberHighLight(this, tvTopInfo, tipData.set_pwd?.update_tip)
            AccountBindPhoneActivity.TYPE_FORGET_PWD -> if(NineShowApplication.mUserBase == null) {
                // 未登录情况需要自己去处理下tip消息
                AccountSecurityHelper.setPhoneNumberHighLight(this, tvTopInfo, tipData.forget_pwd?.update_tip,phoneNumber)
            }else {
                AccountSecurityHelper.setPhoneNumberHighLight(this, tvTopInfo, tipData.forget_pwd?.update_tip)
            }
        }
    }


    override fun setContentView() {
        setContentView(R.layout.activity_account_setpwd)
    }
}