package com.ninexiu.sixninexiu.activity

import android.app.Activity
import android.content.Intent
import android.view.View
import androidx.core.app.ActivityCompat
import androidx.core.app.ActivityOptionsCompat
import androidx.recyclerview.widget.LinearLayoutManager
import com.blankj.utilcode.util.ToastUtils
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.adapter.ConversationManagerAdapter
import com.ninexiu.sixninexiu.common.statistics.StatisticsEventID
import com.ninexiu.sixninexiu.common.statistics.StatisticsUtil
import com.ninexiu.sixninexiu.common.util.Utils
import com.ninexiu.sixninexiu.view.dialog.BaseDialog
import com.ninexiu.sixninexiu.view.dialog.CommonRemindDialog
import com.tencent.qcloud.tim.uikit.modules.conversation.ConversationManagerKit
import kotlinx.android.synthetic.main.activity_conversation_manager.*


class NsTConversationManagerActivity : BaseActivity() {
    override fun setContentView() {
        setContentView(R.layout.activity_conversation_manager)
    }

    companion object {
        fun start(context: Activity, view: View) {
            val compat: ActivityOptionsCompat = ActivityOptionsCompat.makeSceneTransitionAnimation(context, view, "conversation_manager")
            ActivityCompat.startActivity(context, Intent(context, NsTConversationManagerActivity::class.java), compat.toBundle())
        }
    }

    private lateinit var managerAdapter: ConversationManagerAdapter
    override fun initViews() {
        super.initViews()

        rv_conversaion_manager.layoutManager = LinearLayoutManager(this, LinearLayoutManager.VERTICAL, false)
        managerAdapter = ConversationManagerAdapter(this, ArrayList())
        managerAdapter.conversationList.addAll(ConversationManagerKit.getInstance().getmProvider().dataSource)
        managerAdapter.resetData()
        rv_conversaion_manager.adapter = managerAdapter
    }

    override fun initDatas() {
        super.initDatas()
    }

    override fun initEvents() {
        super.initEvents()
        if (Utils.isNotClickable()){
            return
        }

        tv_finish.setOnClickListener {
            finishAfterTransition()
        }

        cb_choose_all.setOnClickListener {
            managerAdapter.setAllChecked(cb_choose_all.isChecked)
        }

        managerAdapter.onCheckedItemChange = { conversationList ->
            var checkedNum = 0
            for (conversation in conversationList) {
                if (conversation.isChecked) {
                    checkedNum++
                }
            }

            cb_choose_all.isChecked = checkedNum == conversationList.size

            if (checkedNum > 0) {
                tv_delete_conversaion.text = "删除聊天 （$checkedNum）"
                tv_delete_conversaion.isEnabled = true
                tv_delete_conversaion.isClickable = true
            } else {
                tv_delete_conversaion.text = "删除聊天"
                tv_delete_conversaion.isEnabled = false
                tv_delete_conversaion.isClickable = false
            }
        }

        tv_delete_conversaion.setOnClickListener {
            CommonRemindDialog.create(this)
                    .setTitleText("是否将所选消息删除")
                    .setText("否", "是")
                    .setOnClickCallback { type ->
                        if (type == BaseDialog.SELECT_SECOND) {
                            StatisticsUtil.onEvent(StatisticsEventID.UM_IM_CONVERSATION_MANAGER_DELETE)
                            //删除相关操作
                            val iterator = managerAdapter.conversationList.iterator()
                            while (iterator.hasNext()) {
                                val converstaion = iterator.next()
                                if (converstaion.isChecked) {
                                    ConversationManagerKit.getInstance().deleteConversation(converstaion.id, converstaion.isGroup)
                                    iterator.remove()
                                }
                            }
                            ToastUtils.showShort("删除成功")

                            if (managerAdapter.conversationList.isEmpty()){
                                finish()
                            }
                        }
                        managerAdapter.setAllChecked(false)
                    }
        }
    }

}