package com.ninexiu.sixninexiu.activity

import android.app.Activity
import android.content.Context
import android.content.Intent
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.adapter.TypePageAdapter
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.bean.AnchorInfo
import com.ninexiu.sixninexiu.broadcast.AppBroadcastHelper
import com.ninexiu.sixninexiu.broadcast.NSDataBroadcast
import com.ninexiu.sixninexiu.common.util.LoadStateUtil
import com.ninexiu.sixninexiu.common.util.NSReceiverAction
import com.ninexiu.sixninexiu.common.util.Utils
import com.ninexiu.sixninexiu.common.util.manager.HomePageTypeManager
import com.ninexiu.sixninexiu.common.util.manager.HomePageTypeManager.SingleTypeCallBack
import com.ninexiu.sixninexiu.lib.commonpulltorefresh.PtrDefaultHandler
import com.ninexiu.sixninexiu.lib.commonpulltorefresh.PtrFrameLayout
import com.ninexiu.sixninexiu.view.StateView
import com.ninexiu.sixninexiu.view.dialog.BaseDialog
import com.tencent.bugly.crashreport.CrashReport
import com.thirdparty.utils.StatusBarUtil
import kotlinx.android.synthetic.main.activity_teenager_list.*
import kotlinx.android.synthetic.main.layout_for_show_state.*
import java.util.*
import kotlin.system.exitProcess

/**
 * <pre>
 *     @author : hetao
 *     time   : 2021/08/06
 *     desc   :
 *     version: 1.0
 * </pre>
 */
class TeenagersListActivity : BaseActivity(), StateView.OnRefreshViewListener {

    private var mTypePageAdapter: TypePageAdapter? = null
    private var mAnchorList: ArrayList<AnchorInfo>? = null
    private var mPageNum = 0

    companion object {
        fun start(context: Context, closePage: Boolean) {
            val intent = Intent(context, TeenagersListActivity::class.java)
            intent.flags = Intent.FLAG_ACTIVITY_NEW_TASK or Intent.FLAG_ACTIVITY_CLEAR_TASK
            context.startActivity(intent)
            if (closePage) (context as Activity).finish()
        }
    }

    override fun setContentView() {
        setContentView(R.layout.activity_teenager_list)
        StatusBarUtil.setTranslucentForImageViewInFragment(this, teenager_tv)
        StatusBarUtil.setTranslucentForImageViewInFragment(this, ptrpFrameLayout)
        StatusBarUtil.setLightMode(this)

        initDatas()
        initEvents()
        initTypePageData(mPageNum)
    }


    override fun initDatas() {
        super.initDatas()
        mAnchorList = ArrayList()
        ptrpFrameLayout.isLoadMoreEnable = true
        mTypePageAdapter = TypePageAdapter(this, mAnchorList, false,"首页-青少年")
        listview.adapter = mTypePageAdapter
    }

    override fun initEvents() {
        super.initEvents()
        sv_state_view.setOnRefreshListener(this)
        ptrpFrameLayout.setOnLoadMoreListener { initTypePageData(mPageNum) }

        ptrpFrameLayout.setPtrHandler(object : PtrDefaultHandler() {
            override fun onRefreshBegin(frame: PtrFrameLayout) {
                mPageNum = 0
                initTypePageData(mPageNum)
            }
        })
        teenager_exit.setOnClickListener { TeenagersAcitvity.start(this, false) }

    }


    /**
     * 获取列表数据
     */
    private fun initTypePageData(pageNum: Int) {
        LoadStateUtil.showLoading(sv_state_view, mAnchorList)
        HomePageTypeManager.getInstance().getPageData("3", pageNum,
                SingleTypeCallBack { response, isNetwork ->
                    if (ptrpFrameLayout != null) {
                        ptrpFrameLayout.refreshComplete()
                        ptrpFrameLayout.loadMoreComplete(true)
                    }
                    if (!isNetwork) {
                        LoadStateUtil.showError(sv_state_view, mAnchorList)
                        return@SingleTypeCallBack
                    }
                    if (response == null || response.data == null) {
                        setLoadHint(false,
                                NineShowApplication.applicationContext.resources.getString(R.string.sv_show_no_anchor))
                        return@SingleTypeCallBack
                    }
                    val data = response.data
                    if (data.size > 0) {
                        setLoadHint(true,
                                NineShowApplication.applicationContext.resources.getString(R.string.sv_show_no_anchor))
                        if (pageNum == 0) {
                            mPageNum = 1
                            mAnchorList?.clear()
                            mAnchorList?.addAll(data)
                        } else {
                            mAnchorList?.addAll(data)
                            mPageNum++
                        }
                        mTypePageAdapter?.notifyDataSetChanged()
                    } else {
                        setLoadHint(false,
                                NineShowApplication.applicationContext.resources.getString(R.string.sv_show_no_anchor))
                        ptrpFrameLayout.loadMoreComplete(false)
                    }
                })
    }

    /**
     * 当前页面数据状态
     * @param state
     * @param text
     */
    private fun setLoadHint(state: Boolean, text: String) {
        if (sv_state_view != null && mAnchorList != null) {
            LoadStateUtil.loadState(sv_state_view, mAnchorList, state, text)
        }
    }

    /**
     * 改变返回键逻辑
     */
    override fun onBackPressed() {
        Utils.remindDialogStyle4(this, getString(R.string.Exit), getString(R.string.ensure),
                getString(R.string.hall_cacle), R.color.color_333333, R.color.color_ff3030) { type: Int ->
            if (BaseDialog.SELECT_SECOND == type) {
                // 确定功能
                try {
                    if (!isFinishing) {
                        super.onBackPressed()
                        exitProcess(0)
                    }
                    NineShowApplication.clearNotifications()
                    AppBroadcastHelper.getInstance()
                            .sendBroadcast(NSReceiverAction.REFERSH_MESSAGE_CENTER,
                                    NSDataBroadcast.TYPE_OPERATION_DEFAULT, null)
                    NineShowApplication.mAccountManager.exitApp()
                } catch (e: Exception) {
                    CrashReport.postCatchedException(e)
                }
            }
        }

    }

    /**
     * 数据刷新
     */
    override fun onRefreshView() {
        mPageNum = 0
        initTypePageData(mPageNum)
    }

}