package com.ninexiu.sixninexiu.activity

import android.content.Context
import android.content.Intent
import android.graphics.Rect
import android.text.TextUtils
import android.view.View
import androidx.recyclerview.widget.RecyclerView
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.adapter.UserReturenActiveAdapter
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.bean.BaseResultInfo
import com.ninexiu.sixninexiu.bean.GiftReturnItem
import com.ninexiu.sixninexiu.bean.UserReturnFreeBagResult
import com.ninexiu.sixninexiu.bean.UserReturnPayTaskBean
import com.ninexiu.sixninexiu.broadcast.AppBroadcastHelper
import com.ninexiu.sixninexiu.common.net.NSGsonObjectCallback
import com.ninexiu.sixninexiu.common.net.NSGsonObjectNewCallback
import com.ninexiu.sixninexiu.common.net.NsOkHttpClient
import com.ninexiu.sixninexiu.common.statistics.StatisticsEventID
import com.ninexiu.sixninexiu.common.statistics.StatisticsUtil
import com.ninexiu.sixninexiu.common.util.Constants
import com.ninexiu.sixninexiu.common.util.MyToast
import com.ninexiu.sixninexiu.common.util.NSLog
import com.ninexiu.sixninexiu.common.util.NSReceiverAction
import com.ninexiu.sixninexiu.view.UserReturnGridLayoutManager
import com.ninexiu.sixninexiu.view.UserReturnGsonHelper.USERRETURN_OVER
import com.ninexiu.sixninexiu.view.UserReturnGsonHelper.saveJsonData
import kotlinx.android.synthetic.main.activity_user_return_active.*

/**
 * <pre>
 *     @author : hpf
 *     time   : 2020/11/20
 *     desc   : 用户回归活动 Activity -> 透明dialog
 *     version: 1.0
 * </pre>
 */
class UserReturnActiveActivity : BaseActivity() {
    companion object {
        fun startActivity(context: Context) {
            val intent = Intent(context, UserReturnActiveActivity::class.java)
            context.startActivity(intent)
        }

        fun startActivity(context: Context,souceType: Int) {
            val intent = Intent(context, UserReturnActiveActivity::class.java)
            intent.putExtra("souceType",souceType)
            context.startActivity(intent)
        }

        // top iv
        const val FITTER_TOP_IV_WIDTH_PERCENT = 0.87f
        const val FITTER_TOP_IV_HEIGHT_PERCENT = 0.3f
        const val FITTER_bot_IV_HEIGHT_PERCENT = 0.74f

        // 确定
        const val FITTER_BT_CONFIRM_PERCENT = 0.57f
        const val FITTER_BT_CONFIRM_HEIGHT_PERCENT = 0.157f

        // 关闭按钮
        const val FITTER_DIALOG_CLOSE = 0.067f

        // recy 的 item 间距
        const val ITEM_DIVIDER = 0.015f
    }

    private val widthScreen: Int by lazy {
        resources?.displayMetrics?.widthPixels ?: 0
    }

    private val divider: Int by lazy {
        (ITEM_DIVIDER * widthScreen).toInt()
    }

    private val Tag = UserReturnActiveActivity::class.java.simpleName

    // 房间来源
    private var souceType = 0

    override fun setContentView() {
        setContentView(R.layout.activity_user_return_active)

        souceType = intent.getIntExtra("souceType", 0)

    }


    // 设置间隔
    val decoration = object : RecyclerView.ItemDecoration() {
        override fun getItemOffsets(outRect: Rect, view: View, parent: RecyclerView, state: RecyclerView.State) {
            super.getItemOffsets(outRect, view, parent, state)
            val index = parent.getChildAdapterPosition(view)
            when (index % 3) {
                0 -> outRect.right = divider
                1 -> {
                    outRect.right = divider
                    outRect.left = divider
                }
                2 -> outRect.left = divider
            }
        }
    }

    var data = mutableListOf<GiftReturnItem>()
    val adapter = UserReturenActiveAdapter(data)
    val layoutManager: UserReturnGridLayoutManager = UserReturnGridLayoutManager(this, 3)

    override fun initViews() {
        ivDialogClose.setOnClickListener {
            StatisticsUtil.onEvent(StatisticsEventID.UM_USER_RETURN_FREE_BAG_CLOSE)
            finish()
        }

        tvDialogConfirm.setOnClickListener {
            // 判断用户是否绑定了手机号
            ifUserBindPhone()
        }

        // 设置adapter
        recyDialog.layoutManager = layoutManager
        recyDialog.addItemDecoration(decoration)
        recyDialog.adapter = adapter

        // 适配
        ivDialogRule.post {
            // 这里可以优化直接使用约束布局，不需要适配那么多
            fitterView(ivDialogRule, FITTER_TOP_IV_WIDTH_PERCENT, FITTER_TOP_IV_HEIGHT_PERCENT)
            fitterView(llDialogMiddle, FITTER_TOP_IV_WIDTH_PERCENT)
            fitterView(rlDialogBot, FITTER_TOP_IV_WIDTH_PERCENT, FITTER_bot_IV_HEIGHT_PERCENT)
            fitterView(tvDialogConfirm, FITTER_BT_CONFIRM_PERCENT, FITTER_BT_CONFIRM_HEIGHT_PERCENT)
            fitterView(ivDialogClose, FITTER_DIALOG_CLOSE, 1f)
        }
    }

    // 判断用户是否绑定了手机号 -> 跳转绑定手机号
    private fun ifUserBindPhone() {
        val phone = NineShowApplication.mUserBase?.phone
        if (NineShowApplication.mUserBase != null && null != phone && !TextUtils.isEmpty(phone)) {
            StatisticsUtil.onEvent(StatisticsEventID.UM_USER_RETURN_FREE_BAG_UNLOCK)
            // 领取礼包
            getFreeBag()
        } else {
            MyToast.showShort(getString(R.string.user_return_bind_phone))
            //绑定手机号
            AccountBindPhoneActivity.startActivity(this, AccountBindPhoneActivity.TYPE_BIND_PHONE)
        }

    }

    /**
     * 获取回归礼包
     */
    private fun getFreeBag() {
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_RETURN_FREE_BAG, null, object : NSGsonObjectNewCallback<BaseResultInfo>() {
            override fun onFailure(statusCode: Int, errorMsg: String?) {
                MyToast.showShort(errorMsg ?: "")
            }

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: BaseResultInfo?) {
                MyToast.showShort(message ?: "")
                if (statusCode == 200) {
                    // 获取用户状态并存储
                    checkAuthorStatus()
                }

            }
        })
    }

    // 更新用户状态并存储
    private fun checkAuthorStatus() {
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.CHECK_USER_RETURN, null, object : NSGsonObjectCallback<UserReturnPayTaskBean?>() {
            override fun onFailure(statusCode: Int, errorMsg: String) {
            }

            override fun onSuccess(statusCode: Int, rawJsonResponse: String?, response: UserReturnPayTaskBean?) {
                NSLog.d("user_return_tag >> : ", response.toString())
                if (statusCode == 200) {
                    // 保存数据
                    saveJsonData(response)
                }
                // 进入聚合页
                if (!USERRETURN_OVER) {  // 增加活动未过期判断
                    UserReturnWelfareAndLiveActivity.startActivity(this@UserReturnActiveActivity)
                }else {
                    MyToast.showShort("当前活动已过期")
                }
                finish()
            }
        })
    }

    /**
     * 展示回归礼包
     */
    override fun initDatas() {
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.SHOW_RETURN_FREE_BAG, null, object : NSGsonObjectNewCallback<UserReturnFreeBagResult>() {
            override fun onFailure(statusCode: Int, errorMsg: String?) {
                MyToast.showShort(errorMsg ?: "")
            }

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: UserReturnFreeBagResult?) {
                if (statusCode == 200) {

                    response?.data?.userInfo?.let {
                        tvDialogUserName.text = it.nickname ?: "--"
                    }

                    response?.data?.giftInfo?.let {
                        data.clear()
                        data.addAll(it)
                        layoutManager.setChildAllCount(data.size)
                        adapter.notifyDataSetChanged()
                    }
                } else {
                    MyToast.showShort(message ?: "")
                }
            }
        })

    }

    /**
     * @widthPercent : view占据屏幕宽度的percent
     * @heightPercent : view的宽高比例
     */
    private fun fitterView(view: View, widthPercent: Float, heightPercent: Float? = null) {
        val params = view.layoutParams
        val width = (widthScreen * widthPercent).toInt()
        params.width = width
        heightPercent?.let {
            NSLog.d(Tag, "height  : ${(width * heightPercent).toInt()}")
            params.height = (width * heightPercent).toInt()
        }

        view.layoutParams = params
    }

    override fun onDestroy() {
        super.onDestroy()
        if(souceType == 1){
            AppBroadcastHelper.getInstance().sendBroadcast(NSReceiverAction.ACTION_USER_RETURN_PUSH_DIALOG)
        }
    }
}