package com.ninexiu.sixninexiu.activity

import android.annotation.SuppressLint
import android.content.Context
import android.content.Intent
import android.graphics.Rect
import android.view.View
import androidx.recyclerview.widget.GridLayoutManager
import androidx.recyclerview.widget.RecyclerView
import androidx.recyclerview.widget.RecyclerView.State
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.adapter.UserReturenPayAdapter
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.bean.UserReturnPayItem
import com.ninexiu.sixninexiu.bean.UserReturnPayResult
import com.ninexiu.sixninexiu.common.net.NSGsonObjectCallback
import com.ninexiu.sixninexiu.common.net.NSGsonObjectNewCallback
import com.ninexiu.sixninexiu.common.net.NSRequestParams
import com.ninexiu.sixninexiu.common.net.NsOkHttpClient
import com.ninexiu.sixninexiu.common.util.Constants
import com.ninexiu.sixninexiu.common.util.MyToast
import com.ninexiu.sixninexiu.common.util.NSLog
import com.ninexiu.sixninexiu.common.util.Utils
import com.ninexiu.sixninexiu.login.LoginEntryActivity
import com.ninexiu.sixninexiu.pay.ZhiFuActivity
import com.ninexiu.sixninexiu.pay.ZhifuActivity
import com.ninexiu.sixninexiu.view.ORIENTATION_TOP
import com.ninexiu.sixninexiu.view.UserReturnGsonHelper
import com.ninexiu.sixninexiu.view.dialog.UserReturnRuleDialog
import com.ninexiu.sixninexiu.view.fitterViewPosition
import kotlinx.android.synthetic.main.activity_user_return_pay.*
import java.net.HttpURLConnection

/**
 * <pre>
 *     @author : hpf
 *     time   : 2020/11/18
 *     desc   : 用户回归充值 透明 activity -> 实现弹窗功能
 *     version: 1.0
 * </pre>
 */
class UserReturnPayActivity : BaseActivity() {
    companion object {
        fun startActivity(context: Context) {
            val intent = Intent(context, UserReturnPayActivity::class.java)
            context.startActivity(intent)
        }

        private val Tag = UserReturnPayActivity::class.java.simpleName

        // 适配 -> 倒计时,支付,recy位置比例
        private const val TEXTVIEW_CUTDOWN = 0.5
        private const val TEXTVIEW_USER_PAY = 0.055
        private const val RECY_POSITION = 0.1

        // recy 的 topMargin,条目适配
        const val RECY_ITEM_WIDTH = 0.38
        const val RECY_ITEM_PERCENT = 0.801
        const val RECY_TOP_MARGIN = 0.1516

        // recy 的 item 的间距
        const val RECY_ITEM__DECORATION_TOP = 0.055
        const val RECY_ITEM__DECORATION_LEFT = 0.032

        const val USER_RETURN_ACTIVITY_OVER = 499 // 用户回归活动过期
    }

    override fun setContentView() {
        setContentView(R.layout.activity_user_return_pay)
    }

    private val widthScreen: Int by lazy {
        resources?.displayMetrics?.widthPixels ?: 0
    }

    private val data = mutableListOf<UserReturnPayItem>()
    val adapter = UserReturenPayAdapter(data)
    override fun initViews() {
        // 设置间隔
        val decoration = object : RecyclerView.ItemDecoration() {
            override fun getItemOffsets(outRect: Rect, view: View, parent: RecyclerView, state: State) {
                super.getItemOffsets(outRect, view, parent, state)
                val index = parent.getChildAdapterPosition(view)
                if (index > 1) {
                    outRect.top = (RECY_ITEM__DECORATION_TOP * widthScreen).toInt()
                }

                if (index % 2 == 0) {
                    outRect.right = (RECY_ITEM__DECORATION_LEFT * widthScreen).toInt()
                } else {
                    outRect.left = (RECY_ITEM__DECORATION_LEFT * widthScreen).toInt()
                }
            }
        }

        recyReturn.layoutManager = GridLayoutManager(this, 2)
        recyReturn.addItemDecoration(decoration)
        recyReturn.adapter = adapter
        tvReturnCutdown.post {
            // 调整倒计时位置
            fitterViewPosition(tvReturnCutdown, ORIENTATION_TOP) {
                // it.text = "活动倒计时:15天"
                (returnFrameTop.measuredHeight * TEXTVIEW_CUTDOWN).toInt()
            }

            // 设置充值提示位置
            fitterViewPosition(tvReturnPay, ORIENTATION_TOP) {
                // it.text = "已经充值500000元"
                (returnFrameBot.measuredHeight * TEXTVIEW_USER_PAY).toInt()
            }

            // 设置 recyclerView topMargin
            fitterViewPosition(recyReturn, ORIENTATION_TOP) {
                (returnFrameBot.measuredHeight * RECY_TOP_MARGIN).toInt()
            }
        }

        returnViewCancel.setOnClickListener { finish() }

        // 用户回归活动弹窗
        returnViewRule.setOnClickListener {
            UserReturnRuleDialog(this@UserReturnPayActivity, UserReturnRuleDialog.USER_RETURN_PAY_TYPE).show()
        }

        adapter.userClickItem = { status, id, position ->
            NSLog.d(Tag, "status : $status , id : $id , position : $position")
            when (status) {
                UserReturenPayAdapter.ITEM_CLICK_PAY -> {
                    if(NineShowApplication.mUserBase == null) {
                        //MyToast.showShort("您还未登录")
                        Utils.startLogin(this, LoginEntryActivity.FROM_LIVEROOM)
                    }else {
                        // 充值跳转
                        ZhiFuActivity.startActivity(this)
                        // startActivity(Intent(this, ZhifuActivity::class.java))
                    }
                }
                UserReturenPayAdapter.ITEM_CLICK_RECEIVE -> {
                    receivePayResult(id, position)
                }
            }
        }
    }

    // 领取奖励
    private fun receivePayResult(id: Int, pos: Int) {
        val params = NSRequestParams()
        params.put("id", id)
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.PAY_TASK_RECEIVE, params, object : NSGsonObjectNewCallback<UserReturnPayResult>() {
            override fun onFailure(statusCode: Int, errorMsg: String?) {
                NSLog.d(Tag, "status 0 : $statusCode")
                MyToast.showShort(errorMsg ?: "")
            }

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: UserReturnPayResult?) {
                MyToast.showShort(message ?: "")
                NSLog.d(Tag, "status : $statusCode")
                if (statusCode == 200) {
                    // 领取成功
                    if (data[pos].id == id && pos < adapter.itemCount) {
                        data[pos].status = 2 // 修改状态
                        adapter.notifyItemChanged(pos)
                    }
                    // toastView.show()
                }
            }
        })
    }

    // 加载数据
    override fun onResume() {
        super.onResume()
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.PAY_TASK_LIST, null, object : NSGsonObjectCallback<UserReturnPayResult>() {
            override fun onSuccess(statusCode: Int, rawJsonResponse: String?, response: UserReturnPayResult?) {
                when (statusCode) {
                    HttpURLConnection.HTTP_OK -> {
                        response?.data?.list?.let {
                            data.clear()
                            data.addAll(it)
                            adapter.notifyDataSetChanged()
                        }
                        tvReturnPay.text = "已充值 ${response?.data?.money ?: 0} 元"
                        tvReturnCutdown.setTime("活动倒计时: ", response?.data?.over_time, "天","活动已结束")
                    }
                    // 当前活动已经过期
                    USER_RETURN_ACTIVITY_OVER -> {
                        // 写入数据
                        UserReturnGsonHelper.saveJsonDataOver()
                        MyToast.showShort("当前活动已过期")
                        finishDelay()
                    }
                }

            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
            }
        })
    }

    fun finishDelay() {
        tvReturnCutdown.postDelayed({ finish() }, 1000)
    }

    @SuppressLint("SetTextI18n")
    override fun initDatas() {

    }
}
