package com.ninexiu.sixninexiu.adapter

import android.app.Activity
import android.content.Intent
import android.os.Bundle
import android.text.TextUtils
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.FrameLayout
import android.widget.ImageView
import android.widget.RelativeLayout
import android.widget.TextView
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.activity.MainTabActivity
import com.ninexiu.sixninexiu.activity.PersonalInforActivity
import com.ninexiu.sixninexiu.activity.SubPageActivity
import com.ninexiu.sixninexiu.adapter.viewholder.*
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.audio.DynamicHelper
import com.ninexiu.sixninexiu.bean.AnchorInfo
import com.ninexiu.sixninexiu.bean.Dynamic
import com.ninexiu.sixninexiu.broadcast.AppBroadcastHelper
import com.ninexiu.sixninexiu.broadcast.NSDataBroadcast
import com.ninexiu.sixninexiu.common.util.*
import com.ninexiu.sixninexiu.common.util.manager.RequestManager
import com.ninexiu.sixninexiu.login.LoginActivity
import com.opensource.svgaplayer.SVGAParser
import com.opensource.svgaplayer.SVGAVideoEntity

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/07/07
 *     desc   : 关注 : 动态广场
 *     version: 1.0
 * </pre>
 */
class AttentionUserDynamicAdapter(val activity: Activity?, var titleData: MutableList<Boolean>, var anchorData: List<AnchorInfo>, var dynamicData: MutableList<Dynamic>, val mSmileyParser: SmileyParser) : RecyclerView.Adapter<RecyclerView.ViewHolder>() {
    private var svgParser: SVGAParser? = null
    private var svgEntry: SVGAVideoEntity? = null

    init {
        svgParser = SVGAParser(activity)
        svgParser?.decodeFromAssets("anchor_focus_head.svga", object : SVGAParser.ParseCompletion {
            override fun onComplete(entry: SVGAVideoEntity) {
                // NSLog.d("svgEntry : ", "svg is onComplete")
                svgEntry = entry
            }

            override fun onError() {
                // NSLog.d("svgEntry : ", "svg is onError")
            }

        })
    }

    companion object {
        const val TYPE_DYNAMIC_VIDEO = 10
        const val TYPE_DYNAMIC_SYSTEM = 4
        const val TYPE_DYNAMIC_AUDIO = 5
        const val TYPE_DYNAMIC_PICTURE = 1
        const val TYPE_DYNAMIC_TEXT = 0
        const val TYPE_ANCHOR = 101

        const val TYPE_REFRESH_REGION = 100
    }

    private var currentDynamic: Dynamic? = null

    private var photoAlbumUtils: PhotoAlbumUtils? = null
    private var rootview: RelativeLayout? = null
    private var childAt: FrameLayout? = null
    private var skipOrigin = 0 //跳转起点  默认是动态广场页面

    fun getData(): Dynamic? {
        return currentDynamic
    }

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): RecyclerView.ViewHolder {
        if (viewType == TYPE_ANCHOR) {
            return AttentionAnchorViewHolder(LayoutInflater.from(parent.context).inflate(R.layout.item_attention_anchor, parent, false))
        } else {
            val view = LayoutInflater.from(parent.context).inflate(R.layout.item_dynamic_content, parent, false)
            return when (viewType) {
                TYPE_DYNAMIC_VIDEO -> {
                    DynamicVideoHolder(view)
                }
                TYPE_DYNAMIC_SYSTEM -> {
                    DynamicSystemHolder(view)
                }
                TYPE_DYNAMIC_AUDIO -> {
                    DynamicAudioHolder(view)
                }
                else -> {
                    DynamicImageHolder(view)
                }
            }
        }
    }

    override fun getItemCount(): Int {
        return dynamicData.size + 1
    }

    var loadMoreAnchorData: (() -> Unit)? = null

    private var adapter: AttentionAnchorItemAdapter? = null

    override fun onBindViewHolder(holder: RecyclerView.ViewHolder, position: Int, payloads: MutableList<Any>) {
        if (!payloads.isNullOrEmpty() && payloads[0] == TYPE_REFRESH_REGION && adapter != null) {
            adapter?.notifyDataSetChanged()
        } else {
            super.onBindViewHolder(holder, position, payloads)
        }
    }

    override fun onBindViewHolder(holder: RecyclerView.ViewHolder, position: Int) {
        when (getItemViewType(position)) {
            TYPE_ANCHOR -> {
                val anchorHolder = holder as? AttentionAnchorViewHolder ?: return
                anchorHolder.tvAttentionAnchor.text = if (titleData[0]) "关注的主播" else "王牌主播推荐"
                anchorHolder.tvAttentionAnchorDynamic.text = if (titleData[1]) "关注的动态" else "推荐动态"

                val manager = LinearLayoutManager(anchorHolder.itemView.context, LinearLayoutManager.HORIZONTAL, false)
                anchorHolder.anchorRecy.layoutManager = manager

                // todo : test  处理下数据进行测试
                /* titleData[0] = false
                anchorData.forEachIndexed { index, info ->
                    info.isplay = index % 2
                    info.isfollow = 0
                }*/

                adapter = AttentionAnchorItemAdapter(anchorHolder.itemView.context, svgEntry, titleData, anchorData)
                adapter?.followClick = ::followAnchor

                anchorHolder.anchorRecy.adapter = adapter
                loadMoreListener(anchorHolder.anchorRecy, manager)
            }
            else -> {
                if (position - 1 < dynamicData.size) {
                    val dynamic = dynamicData[position - 1]

                    (holder as? BaseDynamicContentHolder)?.setupData(holder.itemView.context,null, dynamic, position, mOnClickDynamicCallBack)
                    when {
                        getItemViewType(position) == TYPE_DYNAMIC_PICTURE || getItemViewType(position) == TYPE_DYNAMIC_TEXT -> {
                            (holder as DynamicImageHolder).setOnDynamicChangeListener(object : DynamicImageHolder.ImageDynamicListener {
                                override fun onDynamicChange(dynamicInfo: Dynamic) {
                                    currentDynamic = dynamicInfo
                                }

                                override fun onDynamicImageClick(pos: Int, url: String, imageViews: ArrayList<ImageView>, isVideo: Boolean) {
                                    onImageClick(pos, dynamic, imageViews)

                                    // 上报数据
                                    DynamicHelper.addElement(dynamic.dynamicid)
                                }
                            })
                        }
                        getItemViewType(position) == TYPE_DYNAMIC_VIDEO -> {
                            (holder as DynamicVideoHolder).setOnDynamicChangeListener(object : BaseDynamicContentHolder.DynamicListener {
                                override fun onDynamicChange(dynamicInfo: Dynamic) {
                                    currentDynamic = dynamicInfo
                                }
                            })
                        }
                        getItemViewType(position) == TYPE_DYNAMIC_SYSTEM -> {
                            (holder as DynamicSystemHolder).setOnDynamicChangeListener(object : BaseDynamicContentHolder.DynamicListener {
                                override fun onDynamicChange(dynamicInfo: Dynamic) {
                                    currentDynamic = dynamicInfo
                                }
                            })
                        }
                        getItemViewType(position) == TYPE_DYNAMIC_AUDIO -> {
                            (holder as? DynamicAudioHolder)?.setOnDynamicChangeListener(object : BaseDynamicContentHolder.DynamicListener {
                                override fun onDynamicChange(dynamicInfo: Dynamic) {
                                    currentDynamic = dynamicInfo
                                }
                            })

                            (holder as? DynamicAudioHolder)?.let {
                                it.currentAudioPlayPos = { dynamicInfo, isPlay, pos ->
                                    currentDynamic = dynamicInfo
                                    changeData(isPlay, pos - 1)
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    // 关注用户
    private fun followAnchor(pos: Int) {
        if (NineShowApplication.mUserBase == null) {
            activity?.startActivity(Intent(activity, LoginActivity::class.java))
            return
        }

        if (anchorData.isNullOrEmpty() || pos < 0 || pos >= anchorData.size) {
            return
        }
        val item = anchorData[pos]

        RequestManager.create().attentionUser(item.uid, 1) { code, message ->
            if (code == 200) {
                item.isfollow = 1
                adapter?.notifyItemChanged(pos)
            }
            if (!TextUtils.isEmpty(message)) {
                MyToast.MakeToast(message)
            }
        }
    }

    // 横向滑动到最后三个条目，进行刷新
    private fun loadMoreListener(anchorRecy: RecyclerView, manager: LinearLayoutManager) {
        anchorRecy.addOnScrollListener(object : RecyclerView.OnScrollListener() {
            override fun onScrollStateChanged(recyclerView: RecyclerView, newState: Int) {
                super.onScrollStateChanged(recyclerView, newState)
                if (anchorData.size - 3 >= 0 && manager.findLastVisibleItemPosition() >= anchorData.size - 3) {
                    loadMoreAnchorData?.invoke()
                }
            }
        })
    }

    // 如果当前音频正在播放，那么就暂停视频的播放
    var isAudioCurrentPlaying: (() -> Unit)? = null

    // 修改正在播放音频的数据
    private fun changeData(isPlay: Boolean, pos: Int) {
        if (isPlay) {
            // 暂停视频的播放
            isAudioCurrentPlaying?.invoke()
        }

        if (!dynamicData.isNullOrEmpty() && pos >= 0 && pos < dynamicData.size) {
            dynamicData[pos].isPlayAudio = isPlay

            if (isPlay) {
                // 上报语音的动态
                DynamicHelper.addElement(dynamicData[pos].dynamicid)
            }
        }
    }

    /**
     * 图片的点击事件
     */
    private fun onImageClick(pos: Int, dynamic: Dynamic, imageViews: ArrayList<ImageView>) {
        val photoList = java.util.ArrayList<String>()
        for (i in dynamic.photo.indices) {
            val photothumburl: String = dynamic.photo[i].photothumburl
            NSLog.e("----", "--------photothumburl----ssssss---$photothumburl")
            val replaceUrl = photothumburl.replace("_s.", "_b.") // 把小图url变成大图图片
            if (!replaceUrl.contains("_s.")) {
                NSLog.e("----", "--------replaceUrl----bbbbb---$replaceUrl")
                photoList.add(replaceUrl)
            }
        }
        activity?.overridePendingTransition(0, 0)
        val photothumburl: String = dynamic.photo[pos].photothumburl
        val replaceUrl = photothumburl.replace("_s.", "_b.") // 把小图url变成大图图片

        val strClass: String? = activity?.toString()?.substring(activity.toString().lastIndexOf(".") + 1, activity.toString().indexOf("@"))

        //默认从发现页面取出主布局页面

        //默认从发现页面取出主布局页面
        when (strClass) {
            "SubPageActivity" -> {
                rootview = (activity as SubPageActivity).rootView as RelativeLayout
            }
            "MainTabActivity" -> {
                rootview = (activity as MainTabActivity).rootView as RelativeLayout
            }
            else -> {
                childAt = ((activity as PersonalInforActivity).findViewById<View>(
                        android.R.id.content) as ViewGroup).getChildAt(0) as FrameLayout
                rootview = RelativeLayout(activity)
                childAt?.addView(rootview)
                val layoutParams: ViewGroup.LayoutParams = rootview!!.layoutParams
                if (FringeAdapterHelper.isNotch_Sreen(activity)) {
                    //如果是刘海或者水滴屏，屏幕高度加上状态栏高度防止图片页面黑色背景漏出来
                    layoutParams.height = NineShowApplication.getScreenHeight(activity) + Utils.getStatusBarHeight(activity)
                } else {
                    layoutParams.width = NineShowApplication.getScreenWidth(activity)
                }
                rootview?.layoutParams = layoutParams
                skipOrigin = 1 //个人资料页调起的适配器
            }
        }

        photoAlbumUtils = object : PhotoAlbumUtils(imageViews, rootview, activity, pos, 1, photoList, null) {
            override fun goEnd() {
                if (skipOrigin == 1) { //是从个人资料页调起的适配器
                    childAt?.removeView(rootview)
                }
                val bundle = Bundle()
                bundle.putBoolean("canBack", true)
                AppBroadcastHelper.getInstance().sendBroadcast(NSReceiverAction.ACTION_INTERCEPT_PRESS_BACK,
                        NSDataBroadcast.TYPE_OPERATION_DEFAULT, bundle)
                rootview = null
                photoAlbumUtils = null
            }
        }
    }


    override fun getItemViewType(position: Int): Int {
        val type = when (position) {
            0 -> TYPE_ANCHOR
            else -> dynamicData[position - 1].type
        }

        NSLog.d("DynamicItemType : ", "position : $position , type : $type")
        return type
    }

    /* fun setDatas(datas: List<Dynamic>) {
         dynamicList.clear()
         dynamicList.addAll(datas)
         notifyDataSetChanged()
     }*/

    fun cancleSelect() {
        if (photoAlbumUtils != null) {
            photoAlbumUtils?.cancleSelect()
        }
    }


    private var mOnClickDynamicCallBack: DynamicDataAdapter.OnClickDynamicCallBack? = null

    fun setOnClickDynamicCallBack(onClickDynamicCallBack: DynamicDataAdapter.OnClickDynamicCallBack?) {
        mOnClickDynamicCallBack = onClickDynamicCallBack
    }

    override fun onViewAttachedToWindow(holder: RecyclerView.ViewHolder) {
        super.onViewAttachedToWindow(holder)
        if (holder is BaseDynamicContentHolder) {
            holder.startSvgAnimation(holder.itemView)
        }
    }
}

class AttentionAnchorViewHolder(view: View) : RecyclerView.ViewHolder(view) {
    val tvAttentionAnchor: TextView = view.findViewById(R.id.tvAttentionAnchor)
    val anchorRecy: RecyclerView = view.findViewById(R.id.anchorRecy)
    val tvAttentionAnchorDynamic: TextView = view.findViewById(R.id.tvAttentionAnchorDynamic)
}