package com.ninexiu.sixninexiu.adapter

import android.content.Context
import android.text.Html
import android.text.TextUtils
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.TextView
import androidx.core.content.ContextCompat
import androidx.recyclerview.widget.RecyclerView
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.common.util.UIUtils
import com.ninexiu.sixninexiu.view.dp2px
import com.tencent.qcloud.tim.uikit.modules.conversation.base.ConversationInfo
import com.tencent.qcloud.tim.uikit.modules.message.MessageInfo
import com.tencent.qcloud.tim.uikit.utils.ScreenUtil
import kotlinx.android.synthetic.main.item_conversation_manager.view.*

class ConversationManagerAdapter(val context: Context, var conversationList: ArrayList<ConversationInfo>) : RecyclerView.Adapter<ConversationManagerAdapter.ConversationManagerHolder>() {
    class ConversationManagerHolder(val view: View) : RecyclerView.ViewHolder(view)

    var onCheckedItemChange: ((conversationList: ArrayList<ConversationInfo>) -> Unit)? = null

    fun resetData(){
        for (conversation in conversationList) {
            conversation.isChecked = false
        }
    }

    public fun setAllChecked(checked: Boolean) {
        if (checked) {
            for (conversation in conversationList) {
                conversation.isChecked = true
            }
            notifyDataSetChanged()
        } else {
            for (conversation in conversationList) {
                conversation.isChecked = false
            }
            notifyDataSetChanged()
        }
        onCheckedItemChange?.invoke(conversationList)
    }

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): ConversationManagerHolder {
        val view = LayoutInflater.from(context).inflate(R.layout.item_conversation_manager, parent, false)
        return ConversationManagerHolder(view)
    }

    override fun getItemCount(): Int {
        return conversationList.size
    }

    override fun onBindViewHolder(holder: ConversationManagerHolder, position: Int) {
        val conversation = conversationList[position]
        holder.view.tv_chat_nickname.text = conversation.title
        holder.view.iv_chat_avatar.setRadius(ScreenUtil.getPxByDp(5f))
        if (conversation.iconUrlList != null) {
            holder.view.iv_chat_avatar.setConversation(conversation)
        }
        if (conversation.unRead > 0) {
            UIUtils.showView(holder.view.tv_chat_unread)
            holder.view.tv_chat_unread.text = "${conversation.unRead}"
        } else {
            UIUtils.goneView(holder.view.tv_chat_unread)
        }
        setLastMsgTxt(conversation.lastMessage, holder.view.tv_chat_lastmessage)

        holder.view.iv_chat_avatar?.setRadius(dp2px(context,23))

        holder.view.cb_chat_check.isChecked = conversation.isChecked
        holder.view.setOnClickListener {
            conversation.isChecked = !conversation.isChecked
            onCheckedItemChange?.invoke(conversationList)
            notifyItemChanged(position, -1)
        }
    }

    override fun onBindViewHolder(holder: ConversationManagerHolder, position: Int, payloads: MutableList<Any>) {
        if (payloads.isEmpty()) {
            super.onBindViewHolder(holder, position, payloads)
        } else {
            holder.view.cb_chat_check.isChecked = conversationList[position].isChecked
        }
    }

    private fun setLastMsgTxt(lastMsg: MessageInfo?, lastMsgView: TextView) {
        if (lastMsg != null && !TextUtils.isEmpty(lastMsg.extra.toString())) {
            lastMsgView.text = Html.fromHtml(lastMsg.extra.toString())
        } else {
            lastMsgView.text = ""
        }
    }

}