package com.ninexiu.sixninexiu.adapter

import android.text.Spannable
import android.text.SpannableStringBuilder
import android.text.style.ForegroundColorSpan
import android.text.style.ImageSpan
import android.view.View
import android.widget.ImageView
import android.widget.TextView
import com.chad.library.adapter.base.BaseQuickAdapter
import com.chad.library.adapter.base.BaseViewHolder
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.bean.CommentData
import com.ninexiu.sixninexiu.common.util.GlideUtils
import com.ninexiu.sixninexiu.common.util.SmileyParser
import com.ninexiu.sixninexiu.common.util.TimeUtil
import com.ninexiu.sixninexiu.common.util.Utils
import com.ninexiu.sixninexiu.view.VerticalImageSpan
import com.ninexiu.sixninexiu.view.setVisible

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/03/31
 *     desc   :
 *     version: 1.0
 * </pre>
 */
class DynamicCommentAdapter(data: MutableList<CommentData>, val mSmileyParser: SmileyParser) :
        BaseQuickAdapter<CommentData, DynamicCommentAdapter.DynamicCommentHolder>(R.layout.item_dynamic_comment, data) {
    companion object {
        private const val mToLevelTag = "[tomanagelevel]"
    }

    var onCommentItemClick: ((CommentData) -> Unit)? = null

    override fun convert(helper: DynamicCommentAdapter.DynamicCommentHolder?, item: CommentData?) {
        helper ?: return
        item ?: return

        val context = helper.itemView.context

        // 头像
        GlideUtils.loadCirclePic(context, item.headimage, helper.ivAnchor)

        // 用户名(区分守护和主播)
        val nickName = item.nickname
        val level = getToNickNameTagLevel(item)
        if (level == 0) {
            helper.tvNickName.text = nickName
        } else {
            val drawable = Utils.getDynamicCommentLevelDrawable(level)
            val builder = SpannableStringBuilder("$nickName   ")
            builder.setSpan(VerticalImageSpan(context, drawable, ImageSpan.ALIGN_BOTTOM), nickName.length + 2, nickName.length + 3, Spannable.SPAN_INCLUSIVE_EXCLUSIVE)
            helper.tvNickName.text = builder
        }

        // 时间
        helper.tvTime.text = TimeUtil.getDescriptionTimeFromTimestamp(item.curtime)

        // 内容
        val builder: SpannableStringBuilder?
        if (item.touid == 0L) {
            builder = SpannableStringBuilder(item.content)
        } else {
            val content = context.getString(R.string.dynamic_comment_03, item.tonickname, item.content)
            builder = SpannableStringBuilder(content)
            val nickNameEndIndex = getToNameStartIndex(content, item, builder)
            // 给用户的名字设置link跟颜色
            builder.setSpan(ForegroundColorSpan(context.resources.getColor(R.color.public_selece_textcolor)), 2, nickNameEndIndex,
                    Spannable.SPAN_INCLUSIVE_EXCLUSIVE)
        }

        helper.tvContent.text = mSmileyParser.addSmileySpans1(builder)


        // 点击事件
        helper.itemView.setOnClickListener {
            onCommentItemClick?.invoke(item)
        }


        if (helper.layoutPosition == data.size - 1) {
            helper.viewDivider.setVisible(false)
        } else {
            helper.viewDivider.setVisible(true)
        }

    }

    private fun getToNameStartIndex(content: String, dyComment: CommentData, builder: SpannableStringBuilder): Int {
        val levelLabelStartIndex: Int = content.indexOf(mToLevelTag)
        val levelLabelEndIndex: Int = levelLabelStartIndex + mToLevelTag.length
        if (getToNickNameTagLevel(dyComment) == 0) {
            builder.replace(levelLabelStartIndex, levelLabelEndIndex, "")
            return levelLabelStartIndex
        }
        val drawable = Utils.getDynamicCommentLevelDrawable(getToNickNameTagLevel(dyComment))
        builder.setSpan(VerticalImageSpan(mContext, drawable, ImageSpan.ALIGN_BOTTOM), levelLabelStartIndex, levelLabelEndIndex,
                Spannable.SPAN_INCLUSIVE_EXCLUSIVE)
        return levelLabelEndIndex + 2
    }

    private fun getToNickNameTagLevel(dyComment: CommentData): Int {
        if (dyComment.toguardgid == 0 && dyComment.toisowner != 1) { // 既不是守护又不是主播
            return 0
        }
        if (dyComment.toguardgid != 0) { // 守护
            return 1
        }
        return if (dyComment.toisowner == 1) { // 主播
            2
        } else 0
    }


    inner class DynamicCommentHolder(view: View) : BaseViewHolder(view) {
        val ivAnchor = view.findViewById<ImageView>(R.id.itemIvAnchor)
        val tvNickName = view.findViewById<TextView>(R.id.itemTvNickName)
        val tvTime = view.findViewById<TextView>(R.id.itemTvTime)
        val tvContent = view.findViewById<TextView>(R.id.itemTvContent)
        val viewDivider = view.findViewById<View>(R.id.itemViewDivider)
    }
}
