package com.ninexiu.sixninexiu.adapter

import android.annotation.SuppressLint
import android.content.Context
import android.content.Intent
import android.os.Bundle
import android.text.Spannable
import android.text.SpannableString
import android.text.SpannableStringBuilder
import android.text.TextUtils
import android.text.style.AbsoluteSizeSpan
import android.text.style.ForegroundColorSpan
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.core.content.ContextCompat
import androidx.recyclerview.widget.RecyclerView
import com.blankj.utilcode.util.ConvertUtils
import com.google.gson.GsonBuilder
import com.google.gson.JsonSyntaxException
import com.loopj.android.http.BaseJsonHttpResponseHandler
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.activity.PersonalInforActivity
import com.ninexiu.sixninexiu.activity.SubPageActivity
import com.ninexiu.sixninexiu.activity.VideoShowActivity
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.bean.AnchorDynamicDetailResult
import com.ninexiu.sixninexiu.bean.DynamicNoticeInfo
import com.ninexiu.sixninexiu.bean.VideoRoomBean.VideoInfo
import com.ninexiu.sixninexiu.common.inter.OnItemClickListener
import com.ninexiu.sixninexiu.common.net.NSRequestParams
import com.ninexiu.sixninexiu.common.util.*
import com.ninexiu.sixninexiu.fragment.AnchorDynamicDetailFragment
import com.ninexiu.sixninexiu.view.setVisible
import com.tencent.imsdk.TIMFriendshipManager
import com.tencent.imsdk.TIMManager
import com.tencent.imsdk.TIMUserProfile
import com.tencent.qcloud.tim.uikit.utils.TimeUtils
import cz.msebera.android.httpclient.Header
import kotlinx.android.synthetic.main.ns_dynamic_notice_item.view.*
import java.util.*


/**
 * <pre>
 *     @author : zhangbing
 *     time   : 2020/08/17
 *     desc   :
 *     version: 1.0
 * </pre>
 */
class DynamicNoticeAdapter(val context: Context, var dynamicList: List<DynamicNoticeInfo>) : RecyclerView.Adapter<DynamicNoticeAdapter.DynamicNoticeHolder>() {
    // 1 是评论 2 点赞  3 关乎 4 评论回复
    companion object {
        val DYNAMIC_TYPE_LIKE = 2
        val DYNAMIC_TYPE_ATTENTION = 3
        val DYNAMIC_TYPE_COMMENT = 1
        val DYNAMIC_TYPE_REPLY = 4
        val DYNAMIC_TYPE_SHARE = 5

        //1 文本或图片  2=>歌曲 3=>视频 10 视频
        val DYNAMIC_TYPE_PIC_TEXT = 1
        val DYNAMIC_TYPE_MUSIC = 5
        val DYNAMIC_TYPE_Video = 10
    }



    private val mSmileyParser: SmileyParser = SmileyParser.getInstance()

    class DynamicNoticeHolder(val view: View) : RecyclerView.ViewHolder(view)

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): DynamicNoticeHolder {
        val view = LayoutInflater.from(parent.context).inflate(R.layout.ns_dynamic_notice_item, parent, false)
        return DynamicNoticeHolder(view)
    }

    override fun getItemCount(): Int {
        return dynamicList.size
    }

    override fun onBindViewHolder(holder: DynamicNoticeHolder, position: Int) {
        val dynamicInfo = dynamicList[position]

        val localUser=TIMFriendshipManager.getInstance().queryUserProfile(dynamicInfo.extra.fromuid)
        if (localUser!=null){
            GlideUtils.loadCirclePic(context, localUser.faceUrl, holder.view.iv_user_avatar)
            holder.view.tv_user_name.text = localUser.nickName
        }else{
            holder.view.tv_user_name.text = dynamicInfo.extra.fromname
            GlideUtils.loadCirclePic(context, dynamicInfo.extra.fromheadimage, holder.view.iv_user_avatar)
        }

        holder.view.tv_dynamic_sendTime.text = TimeUtils.getChatTime(false, dynamicInfo.send_time * 1000L)
        holder.view.iv_user_avatar.setOnClickListener {
            PersonalInforActivity.start(context, dynamicInfo.extra.isAnchor == 1, dynamicInfo.extra.fromuid)
        }
        if (dynamicInfo.acttype == DYNAMIC_TYPE_ATTENTION || dynamicInfo.acttype == DYNAMIC_TYPE_LIKE || dynamicInfo.acttype == DYNAMIC_TYPE_SHARE) {
            holder.view.tv_dynamic_content.setTextColor(context.resources.getColor(R.color.color_666666))
            if (!TextUtils.isEmpty(dynamicInfo.push_source)) {
                val builder = SpannableStringBuilder(dynamicInfo.content.plus("·").plus(dynamicInfo.push_source))
                val startIndex = dynamicInfo.content.length
                val endIndex = dynamicInfo.content.length + dynamicInfo.push_source.length+1
                builder.setSpan(ForegroundColorSpan(ContextCompat.getColor(context, R.color.color_999999)), startIndex, endIndex, Spannable.SPAN_INCLUSIVE_EXCLUSIVE)
                builder.setSpan(AbsoluteSizeSpan(ConvertUtils.sp2px(13f)), startIndex, endIndex, Spannable.SPAN_INCLUSIVE_EXCLUSIVE)
                holder.view.tv_dynamic_content.text = builder
            }else{
                holder.view.tv_dynamic_content.text = dynamicInfo.content
            }
            setupDynamicContent(holder, dynamicInfo)
            setupClick(holder, dynamicInfo)
        } else if (dynamicInfo.acttype == DYNAMIC_TYPE_COMMENT) {
            val contentBuilder = SpannableStringBuilder(dynamicInfo.extra.msgContent + "")
            holder.view.tv_dynamic_content.text = mSmileyParser.addSmileySpans1(contentBuilder)
            val foregroundBlackSpan = ForegroundColorSpan(context.resources.getColor(R.color.color_333333))
            if (contentBuilder.length - 1 > 0){
                contentBuilder.setSpan(foregroundBlackSpan, 0, contentBuilder.length - 1, Spannable.SPAN_EXCLUSIVE_INCLUSIVE)
            }
            setupDynamicContent(holder, dynamicInfo)
            setupClick(holder, dynamicInfo)
        } else if (dynamicInfo.acttype == DYNAMIC_TYPE_REPLY) {
            if (dynamicInfo.extra.uid == NineShowApplication.mUserBase?.uid.toString()) {
                val contentBuilder = SpannableStringBuilder("回复  我：${dynamicInfo.extra.msgContent}")
                val foregroundGraySpan = ForegroundColorSpan(context.resources.getColor(R.color.c_999999))
                contentBuilder.setSpan(foregroundGraySpan, 0, 6, Spannable.SPAN_EXCLUSIVE_INCLUSIVE)
                holder.view.tv_dynamic_content.text = mSmileyParser.addSmileySpans1(contentBuilder)
            } else {
                val contentBuilder = SpannableStringBuilder("回复  ${dynamicInfo.extra.name}：${dynamicInfo.extra.msgContent}")
                val foregroundGraySpan = ForegroundColorSpan(context.resources.getColor(R.color.c_999999))
                contentBuilder.setSpan(foregroundGraySpan, 0, 4 + dynamicInfo.extra.name.length, Spannable.SPAN_EXCLUSIVE_INCLUSIVE)
                holder.view.tv_dynamic_content.text = mSmileyParser.addSmileySpans1(contentBuilder)
            }
            setupDynamicContent(holder, dynamicInfo)
            setupClick(holder, dynamicInfo)
        }

        if (position == itemCount - 1) {
            holder.view.view_line.visibility = View.GONE
        } else {
            holder.view.view_line.visibility = View.VISIBLE
        }
    }

    private fun setupClick(holder: DynamicNoticeHolder, dynamicInfo: DynamicNoticeInfo) {
        holder.view.setOnClickListener {
            if (onItemClickListener!=null){
                onItemClickListener?.onItemClick(-1,dynamicInfo)
            }
        }
    }


    private var onItemClickListener: OnItemClickListener<DynamicNoticeInfo>?=null

    fun setOnItemClickListener(onItemClickListener: OnItemClickListener<DynamicNoticeInfo>){
        this.onItemClickListener=onItemClickListener
    }


    @SuppressLint("SetTextI18n")
    private fun setupDynamicContent(holder: DynamicNoticeHolder, dynamicInfo: DynamicNoticeInfo) {
        if (dynamicInfo.extra.type== DYNAMIC_TYPE_MUSIC || !TextUtils.isEmpty(dynamicInfo.extra.image)) {
            holder.view.tv_dynamic.visibility = View.GONE
            holder.view.iv_dynamic_pic.visibility = View.VISIBLE
            holder.view.tv_pic_number.setVisible(false)

            if (dynamicInfo.extra.type==DYNAMIC_TYPE_MUSIC){
                holder.view.ll_dynamic_video.visibility = View.VISIBLE
                holder.view.ll_dynamic_video.setBackgroundResource(R.drawable.shape_dynamic_share_circle)
                holder.view.iv_dynamic_video.setImageResource(R.drawable.ic_dynamic_voice_icon)
                GlideUtils.loadCirclePic(context, dynamicInfo.extra.portrait, holder.view.iv_dynamic_pic, R.drawable.icon_personal_default_bg)
            }else if (dynamicInfo.extra.type == 3 || dynamicInfo.extra.type == 10) {
                holder.view.ll_dynamic_video.visibility = View.VISIBLE
                holder.view.ll_dynamic_video.setBackgroundResource(R.drawable.shape_dynamic_share_round)
                holder.view.iv_dynamic_video.setImageResource(R.drawable.ic_dynamic_share_video_play)
                GlideUtils.loadSimpleImgWithRoundCorner(context, dynamicInfo.extra.image, holder.view.iv_dynamic_pic, R.drawable.icon_personal_default_bg, ConvertUtils.dp2px(8f))
            } else {
                holder.view.ll_dynamic_video.visibility = View.GONE
                GlideUtils.loadSimpleImgWithRoundCorner(context, dynamicInfo.extra.image, holder.view.iv_dynamic_pic, R.drawable.icon_personal_default_bg, ConvertUtils.dp2px(8f))
                if(dynamicInfo.extra.photo_num > 1) {
                    holder.view.tv_pic_number.setVisible(true)
                    holder.view.tv_pic_number.text = "+${dynamicInfo.extra.photo_num}"
                }else {
                    holder.view.tv_pic_number.setVisible(false)
                }

            }

        } else {
            holder.view.iv_dynamic_pic.visibility = View.GONE
            holder.view.ll_dynamic_video.visibility = View.GONE
            holder.view.tv_pic_number.setVisible(false)
            if(!TextUtils.isEmpty(dynamicInfo.extra.dynamicContent)) {
                holder.view.tv_dynamic.visibility = View.VISIBLE
                val contentBuilder = SpannableStringBuilder(dynamicInfo.extra.dynamicContent + "")
                if (mSmileyParser.haveSmiley(contentBuilder)) {
                    holder.view.tv_dynamic.maxLines = 2
                } else {
                    holder.view.tv_dynamic.maxLines = 3
                }
                holder.view.tv_dynamic.text = mSmileyParser.addSmileySpans1(contentBuilder)
            } else {
                holder.view.tv_dynamic.visibility = View.GONE
            }
        }
    }
}