package com.ninexiu.sixninexiu.adapter

import android.app.Activity
import android.content.Context
import androidx.viewpager.widget.ViewPager
import com.chad.library.adapter.base.BaseMultiItemQuickAdapter
import com.chad.library.adapter.base.BaseQuickAdapter.SpanSizeLookup
import com.chad.library.adapter.base.BaseViewHolder
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.adapter.viewholder.BannerViewHolder
import com.ninexiu.sixninexiu.bean.AdvertiseInfo
import com.ninexiu.sixninexiu.bean.AnchorInfo
import com.ninexiu.sixninexiu.bean.HomeInfo
import com.ninexiu.sixninexiu.common.statistics.StatisticsEventID
import com.ninexiu.sixninexiu.common.statistics.StatisticsUtil
import com.ninexiu.sixninexiu.common.util.Constants
import com.ninexiu.sixninexiu.common.util.CountTechnology.TDEventMap
import com.ninexiu.sixninexiu.common.util.CountTechnology.TDEventName
import com.ninexiu.sixninexiu.common.util.RoomUtils
import com.ninexiu.sixninexiu.common.util.Utils
import com.ninexiu.sixninexiu.values.EnterRoomValue
import com.ninexiu.sixninexiu.view.HomeHotAnchorItemView
import com.ninexiu.sixninexiu.view.dp2px
import com.ninexiu.sixninexiu.view.mzbanner.MZBannerViewVoice
import com.ninexiu.sixninexiu.view.setVisible
import org.jetbrains.anko.displayMetrics

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/06/23
 *     desc   :
 *     version: 1.0
 * </pre>
 */
class HomeHotAdapter(list: List<HomeInfo>) : BaseMultiItemQuickAdapter<HomeInfo, BaseViewHolder>(list) {
    // 打开标签里的视频
    var openVideoAction: (() -> Unit)? = null

    // 点击分类 Title 查看更多
    var showMoreAnchor: ((Int) -> Unit)? = null

    init {
        addItemType(HomeInfo.TYPE_ANCHOR, R.layout.adapter_anchor_home_item)
        addItemType(HomeInfo.TYPE_BANNER, R.layout.adapter_banner_home_hot)
    }

    init {
        setSpanSizeLookup(SpanSizeLookup { _, position ->
            return@SpanSizeLookup when (getDefItemViewType(position)) {
                HomeInfo.TYPE_ANCHOR -> 1
                else -> 2
            }
        })
    }

    override fun convert(helper: BaseViewHolder?, item: HomeInfo?) {
        helper ?: return
        item ?: return

        when (item.currentType) {
            // 推荐，新人，热门
            HomeInfo.TYPE_ANCHOR -> {
                helper.getView<HomeHotAnchorItemView>(R.id.itemLeft).setAnchor(item.anchorInfo, item.index) {

                    openAnchorLiveRoom(helper.itemView.context, it, item.dealWithType)
                }
            }

            // banner
            HomeInfo.TYPE_BANNER -> {
                val data = item.bannerInfo
                val banner = helper.getView<MZBannerViewVoice<AdvertiseInfo>>(R.id.bannerHome)
                if (data?.isNullOrEmpty() == false) {
                    banner.setVisible(true)
                    // 动态设置banner高度
                    val params = banner.layoutParams
                    params.height = (helper.itemView.context.displayMetrics.widthPixels - dp2px(helper.itemView.context, 14)) * 88 / 363
                    banner.layoutParams = params
                    with(banner) {
                        // 设置banner样式
//                        setIndicatorRes(R.drawable.icon_banner_dot_normal, R.drawable.icon_banner_dot_selected)
                        setIndicatorVisible(true)
                        setIndicatorAlign(MZBannerViewVoice.IndicatorAlign.CENTER)
                        setDelayedTime(data[0].loop_time)
                        if(data.size == 1){
                            setCanLoop(false)
                        }else if(data.size > 1){
                            setCanLoop(true)
                        }
                        setPages(data) { BannerViewHolder() }

                        addPageChangeListener(object : ViewPager.OnPageChangeListener {
                            override fun onPageSelected(adPos: Int) {
                                StatisticsUtil.onEvent(StatisticsEventID.MAIN_AD_SCROLL)
                                /*if (!data.isNullOrEmpty() && adPos < data.size) {
                                    StatisticsUtil.submitAdClickEvent(StatisticsUtil.AD_LOC_BANNER, data[adPos].id, StatisticsUtil.AD_ACTION_SHOW)
                                }*/
                            }

                            override fun onPageScrolled(position: Int, positionOffset: Float, positionOffsetPixels: Int) {}
                            override fun onPageScrollStateChanged(state: Int) {}
                        })
                    }
                } else {
                    banner.setVisible(false)
                }
            }
        }

    }


    private val liveEventMap: MutableMap<String, Int> = TDEventMap.liveEventMap

    // 设置数数统计数据
    private fun setLiveEventMap(key: String) {
        val count = liveEventMap[key] ?: 0.plus(1)
        liveEventMap[key] = count
    }

    // 进入主播直播间
    private fun openAnchorLiveRoom(context: Context?, anchorInfo: AnchorInfo, dealWithType: Int) {
        if (Utils.isNotClickable()) {
            return
        }

        if (context == null || !RoomUtils.viewLiveRoomNoLogin(context as? Activity)) {
            return
        }

        anchorInfo.enterFrom = EnterRoomValue.ENTER_ROOM_HOMEPAGE_HOT
        anchorInfo.fromSoucre = "首页-热门"
        Utils.openLiveRoom(context, anchorInfo)

        val event = when (dealWithType) {
            HomeInfo.TYPE_RECOMMEND -> StatisticsEventID.MAIN_RECOMEND_CK
            HomeInfo.TYPE_NEW -> StatisticsEventID.MAIN_BEST_NEW_CK
            HomeInfo.TYPE_HOT -> StatisticsEventID.MAIN_HOT_CK
            HomeInfo.TYPE_EXCEL_RECOMMEND -> StatisticsEventID.MAIN_TODAY_SELECT_CK
            else -> null
        }

        event?.let {
            StatisticsUtil.onEvent(it)
        }
        StatisticsUtil.onEvent(StatisticsEventID.MAIN_HOT_ALL_ANCHOR_CK)
    }
}