package com.ninexiu.sixninexiu.adapter

import android.app.Activity
import android.content.Context
import android.content.Intent
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.FrameLayout
import android.widget.ImageView
import android.widget.RelativeLayout
import androidx.recyclerview.widget.RecyclerView
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.activity.MainTabActivity
import com.ninexiu.sixninexiu.activity.PersonalInforActivity
import com.ninexiu.sixninexiu.activity.SubPageActivity
import com.ninexiu.sixninexiu.activity.TranslucentSubPageActivity
import com.ninexiu.sixninexiu.adapter.viewholder.*
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.audio.DynamicHelper
import com.ninexiu.sixninexiu.bean.Dynamic
import com.ninexiu.sixninexiu.bean.Topic
import com.ninexiu.sixninexiu.broadcast.AppBroadcastHelper
import com.ninexiu.sixninexiu.broadcast.NSDataBroadcast
import com.ninexiu.sixninexiu.common.util.*
import com.ninexiu.sixninexiu.fragment.DynamicDetailNewFragment
import com.ninexiu.sixninexiu.view.dp2px

/**
 * <pre>
 *     @author : zhangbing
 *     time   : 2020/09/05
 *     desc   : 动态adapter
 *     version: 1.0
 * </pre>
 */
class TopicDynamicDataAdapter(val context: Context?,
                              var dynamicList: ArrayList<Dynamic>,
                              val isEnterAnchorPagehome: Boolean,
                              val currentTopic:Topic?,
                              val isShowAtten: Boolean) : RecyclerView.Adapter<RecyclerView.ViewHolder>() {

    companion object {
        const val TYPE_DYNAMIC_VIDEO = 10
        const val TYPE_DYNAMIC_SYSTEM = 4
        const val TYPE_DYNAMIC_AUDIO = 5
        const val TYPE_DYNAMIC_PICTURE = 1
    }

    private var currentDynamic: Dynamic? = null

    private var photoAlbumUtils: PhotoAlbumUtils? = null
    private var rootview: RelativeLayout? = null
    private var childAt: FrameLayout? = null
    private var skipOrigin = 0 //跳转起点  默认是动态广场页面

    fun getData(): Dynamic? {
        return currentDynamic
    }

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): RecyclerView.ViewHolder {
        val view = LayoutInflater.from(context).inflate(R.layout.item_dynamic_content, parent, false)
        return when (viewType) {
            TYPE_DYNAMIC_VIDEO -> {
                DynamicVideoHolder(view)
            }
            TYPE_DYNAMIC_SYSTEM -> {
                DynamicSystemHolder(view)
            }
            TYPE_DYNAMIC_AUDIO -> {
                DynamicAudioHolder(view)
            }
            else -> {
                DynamicImageHolder(view)
            }
        }
    }

    override fun getItemCount(): Int {
        return dynamicList.size
    }

    override fun onBindViewHolder(holder: RecyclerView.ViewHolder, position: Int) {
        val dynamic = dynamicList[position]
        if (context != null) {
            if (position == itemCount - 1) {
                (holder.itemView.layoutParams as ViewGroup.MarginLayoutParams).setMargins(0, 0, 0, dp2px(context, 150))
            } else {
                (holder.itemView.layoutParams as ViewGroup.MarginLayoutParams).setMargins(0, 0, 0, 0)
            }
            (holder as BaseDynamicContentHolder).setupData(context, currentTopic, dynamic, position, mOnClickDynamicCallBack)
            when {
                getItemViewType(position) == TYPE_DYNAMIC_VIDEO -> {
                    (holder as DynamicVideoHolder).setOnDynamicChangeListener(object : BaseDynamicContentHolder.DynamicListener {
                        override fun onDynamicChange(dynamicInfo: Dynamic) {
                            currentDynamic = dynamicInfo
                        }
                    })
                }
                getItemViewType(position) == TYPE_DYNAMIC_SYSTEM -> {
                    (holder as DynamicSystemHolder).setOnDynamicChangeListener(object : BaseDynamicContentHolder.DynamicListener {
                        override fun onDynamicChange(dynamicInfo: Dynamic) {
                            currentDynamic = dynamicInfo
                        }
                    })
                }
                getItemViewType(position) == TYPE_DYNAMIC_AUDIO -> {
                    (holder as DynamicAudioHolder).setOnDynamicChangeListener(object : BaseDynamicContentHolder.DynamicListener {
                        override fun onDynamicChange(dynamicInfo: Dynamic) {
                            currentDynamic = dynamicInfo
                        }
                    })
                    (holder as? DynamicAudioHolder)?.let {
                        it.currentAudioPlayPos = {dynamic, isPlay, pos ->
                            changeData(isPlay, pos)
                        }
                    }
                }

                else -> {
                    (holder as DynamicImageHolder).setOnDynamicChangeListener(object : DynamicImageHolder.ImageDynamicListener {
                        override fun onDynamicChange(dynamicInfo: Dynamic) {
                            currentDynamic = dynamicInfo
                        }

                        override fun onDynamicImageClick(pos: Int, url: String, imageViews: ArrayList<ImageView>, isVideo: Boolean) {
                            onImageClick(pos, dynamic, imageViews)

                            // 上报数据
                            DynamicHelper.addElement(dynamic.dynamicid)
                        }
                    })
                }
            }
        }
    }

    // 如果当前音频正在播放，那么就暂停视频的播放
    var isAudioCurrentPlaying: (() -> Unit)? = null

    // 修改正在播放音频的数据
    private fun changeData(isPlay: Boolean, pos: Int) {
        if (isPlay) {
            // 暂停视频的播放
            isAudioCurrentPlaying?.invoke()
        }

        if (!dynamicList.isNullOrEmpty() && pos >= 0 && pos < dynamicList.size) {
            dynamicList[pos].isPlayAudio = isPlay

            if (isPlay) {
                // 上报语音的动态
                DynamicHelper.addElement(dynamicList[pos].dynamicid)
            }
        }
    }

    /**
     * 图片的点击事件
     */
    private fun onImageClick(pos: Int, dynamic: Dynamic, imageViews: ArrayList<ImageView>) {
        val photoList = java.util.ArrayList<String>()
        for (i in dynamic.photo.indices) {
            val photothumburl: String = dynamic.photo[i].photothumburl
            NSLog.e("----", "--------photothumburl----ssssss---$photothumburl")
            val replaceUrl = photothumburl.replace("_s.", "_b.") // 把小图url变成大图图片
            if (!replaceUrl.contains("_s.")) {
                NSLog.e("----", "--------replaceUrl----bbbbb---$replaceUrl")
                photoList.add(replaceUrl)
            }
        }
        (context as Activity).overridePendingTransition(0, 0)
        val photothumburl: String = dynamic.photo[pos].photothumburl
        val replaceUrl = photothumburl.replace("_s.", "_b.") // 把小图url变成大图图片

        val strClass: String = context.toString().substring(context.toString().lastIndexOf(".") + 1, context.toString().indexOf("@"))

        //默认从发现页面取出主布局页面

        //默认从发现页面取出主布局页面
        if (strClass == "TranslucentSubPageActivity") {
            childAt = ((context as TranslucentSubPageActivity).findViewById<View>(
                    android.R.id.content) as ViewGroup).getChildAt(0) as FrameLayout
            rootview = RelativeLayout(context)
            childAt?.addView(rootview)
            val layoutParams: ViewGroup.LayoutParams = rootview!!.layoutParams
            if (FringeAdapterHelper.isNotch_Sreen(context)) {
                //如果是刘海或者水滴屏，屏幕高度加上状态栏高度防止图片页面黑色背景漏出来
                layoutParams.height = NineShowApplication.getScreenHeight(context) + Utils.getStatusBarHeight(context)
            } else {
                layoutParams.width = NineShowApplication.getScreenWidth(context)
            }
            rootview?.layoutParams = layoutParams
            skipOrigin = 1 //个人资料页调起的适配器
        }

        photoAlbumUtils = object : PhotoAlbumUtils(imageViews, rootview, context, pos, 1, photoList, null) {
            override fun goEnd() {
                if (skipOrigin == 1) { //是从个人资料页调起的适配器
                    childAt?.removeView(rootview)
                }
                val bundle = Bundle()
                bundle.putBoolean("canBack", true)
                AppBroadcastHelper.getInstance().sendBroadcast(NSReceiverAction.ACTION_INTERCEPT_PRESS_BACK,
                        NSDataBroadcast.TYPE_OPERATION_DEFAULT, bundle)
                rootview = null
                photoAlbumUtils = null
            }
        }
    }


    override fun getItemViewType(position: Int): Int {
        return dynamicList[position].type
    }

    fun setDatas(datas: List<Dynamic>) {
        dynamicList.clear()
        dynamicList.addAll(datas)
        notifyDataSetChanged()
    }

    fun addDatas(datas: List<Dynamic>) {
        dynamicList.addAll(datas)
        notifyDataSetChanged()
    }

    fun cancleSelect() {
        if (photoAlbumUtils != null) {
            photoAlbumUtils?.cancleSelect()
        }
    }


    private var mOnClickDynamicCallBack: DynamicDataAdapter.OnClickDynamicCallBack? = null

    fun setOnClickDynamicCallBack(onClickDynamicCallBack: DynamicDataAdapter.OnClickDynamicCallBack?) {
        mOnClickDynamicCallBack = onClickDynamicCallBack
    }

    override fun onViewAttachedToWindow(holder: RecyclerView.ViewHolder) {
        super.onViewAttachedToWindow(holder)
        if (holder is BaseDynamicContentHolder) {
            holder.startSvgAnimation(holder.itemView)
        }
    }
}