package com.ninexiu.sixninexiu.adapter

import android.content.Context
import android.text.TextUtils
import android.view.View
import android.view.ViewGroup
import android.widget.ImageView
import android.widget.TextView
import androidx.constraintlayout.widget.ConstraintLayout
import com.chad.library.adapter.base.BaseQuickAdapter
import com.chad.library.adapter.base.BaseViewHolder
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.activity.UserReturnPayActivity
import com.ninexiu.sixninexiu.adapter.UserReturenPayAdapter.UserReturnHolder
import com.ninexiu.sixninexiu.bean.UserReturnPayItem
import com.ninexiu.sixninexiu.common.util.GlideUtils
import com.ninexiu.sixninexiu.common.util.NSLog
import com.ninexiu.sixninexiu.view.UserReturnLinearlayout
import com.ninexiu.sixninexiu.view.fitterViewSize
import org.jetbrains.anko.displayMetrics

/**
 * <pre>
 *     @author : hpf
 *     time   : 2020/11/19
 *     desc   : 用户回归充值 adapter
 *     version: 1.0
 * </pre>
 */

class UserReturenPayAdapter(data: MutableList<UserReturnPayItem>) :
        BaseQuickAdapter<UserReturnPayItem, UserReturnHolder>(R.layout.item_user_return_pay, data) {

    companion object {
        private const val ITEM_TITLE_HEIGHT_PERCENT = 0.22
        private const val ITEM_TV_STATUS_PERCENT = 0.3
        const val ITEM_CLICK_RECEIVE = 1 // 领取
        const val ITEM_CLICK_PAY = 0    // 充值
        private const val ITEM_IV_PERCENT = 0.158
    }

    var userClickItem: ((Int, Int, Int) -> Unit)? = null  // Int : 状态 , Int : id , Int : position

    override fun convert(helper: UserReturnHolder?, item: UserReturnPayItem?) {
        helper ?: return
        item ?: return

        helper.tvTitle.text = item.explain
        helper.tvGiftName.text = item.name

        val param = helper.ivGift.layoutParams
        if (!TextUtils.isEmpty(item.form) && item.form.equals("special")) {
            helper.tvGiftNum.visibility = View.GONE
            // 适配
            param.width = ViewGroup.LayoutParams.WRAP_CONTENT
            param.height = ViewGroup.LayoutParams.WRAP_CONTENT
        } else {
            val widthScreen = helper.itemView.context.displayMetrics.widthPixels
            helper.tvGiftNum.visibility = View.VISIBLE
            helper.tvGiftNum.setNumber(item.count)
            param.width = (widthScreen * ITEM_IV_PERCENT).toInt()
            param.height = (widthScreen * ITEM_IV_PERCENT).toInt()
        }
        helper.ivGift.layoutParams = param

        item.img?.let {
            GlideUtils.loadImageView(helper.itemView.context, it, helper.ivGift)
        }

        with(helper.itemTvStatus) {
            when (item.status) {
                // 可领取
                1 -> {
                    helper.itemTvStatus.text = "领取"
                    setBackgroundResource(R.drawable.adapter_user_receive)
                    setTextColor(resources.getColor(R.color.white))
                    isClickable = true
                }
                // 已经领取/过期
                2, 3 -> {
                    helper.itemTvStatus.text = "已领取"
                    setBackgroundResource(R.drawable.adapter_user_received)
                    setTextColor(resources.getColor(R.color.color_646464))
                    isClickable = false
                }
                // 充值
                0 -> {
                    helper.itemTvStatus.text = "充值"
                    setBackgroundResource(R.drawable.adapter_user_pay)
                    setTextColor(resources.getColor(R.color.color_7900A9))
                    isClickable = true
                }
            }
        }

        // 用户充值/领取
        helper.itemTvStatus.setOnClickListener {
            userClickItem?.invoke(item.status, item.id, helper.adapterPosition)
        }
    }

    fun dp2px(context: Context, dp: Int) = (context.resources.displayMetrics.density * dp).toInt()

    inner class UserReturnHolder(val view: View) : BaseViewHolder(view) {
        val tvTitle: TextView = view.findViewById(R.id.tvTitle)
        val ivGift: ImageView = view.findViewById(R.id.ivGift)
        val tvGiftNum: UserReturnLinearlayout = view.findViewById(R.id.tvGiftNum)
        val itemTvStatus: TextView = view.findViewById(R.id.itemTvStatus)
        val tvGiftName: TextView = view.findViewById(R.id.tvGiftName)
        val itemContent: ConstraintLayout = view.findViewById(R.id.itemContent)

        init {
            // 适配
            val widthScreenSize = view.context.resources.displayMetrics.widthPixels

            val params = itemContent.layoutParams
            NSLog.d("item_view_width : ", "$widthScreenSize")

            val itemWidth = (widthScreenSize * UserReturnPayActivity.RECY_ITEM_WIDTH).toInt()
            val itemHeight = (itemWidth * UserReturnPayActivity.RECY_ITEM_PERCENT).toInt()
            params.width = itemWidth
            params.height = itemHeight
            itemContent.layoutParams = params

            val params1 = tvTitle.layoutParams
            params1.height = (itemHeight * ITEM_TITLE_HEIGHT_PERCENT).toInt()
            tvTitle.layoutParams = params1

            // 适配按钮
            fitterViewSize(itemTvStatus, {
                (widthScreenSize * ITEM_TITLE_HEIGHT_PERCENT).toInt()
            }, {
                (it * ITEM_TV_STATUS_PERCENT).toInt()
            })
        }
    }
}