package com.ninexiu.sixninexiu.adapter

import android.annotation.SuppressLint
import android.text.TextUtils
import android.view.View
import android.widget.ImageView
import android.widget.TextView
import androidx.constraintlayout.widget.ConstraintLayout
import com.chad.library.adapter.base.BaseQuickAdapter
import com.chad.library.adapter.base.BaseViewHolder
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.bean.UserReturnLiveItem
import com.ninexiu.sixninexiu.common.util.GlideUtils
import com.ninexiu.sixninexiu.view.fitterViewSize


/**
 * <pre>
 *     @author : hpf
 *     time   : 2020/11/24
 *     desc   :
 *     version: 1.0
 * </pre>
 */
class UserReturnLiveAdapter(data: MutableList<UserReturnLiveItem>) : BaseQuickAdapter<UserReturnLiveItem, UserReturnLiveAdapter.LiveHolder>(R.layout.item_live_adapter, data) {
    companion object {
        private const val IV_TOP_PERCENT = 0.886f
        private const val IV_SELF_PERCENT = 0.348f

        private const val CONTAINER_PERCENT = 0.8f
        private const val CONTAINER_SELF_PERCENT = 1.208f

        private const val COVER_PERCENT = 0.76f
        private const val COVER_SELF_PERCENT = 1f

        const val INTO_PROFILE = 0
        const val INTO_LIVE_ROOM = 1
    }

    // 用户进入个人主页或者直播间
    var userClick: ((UserReturnLiveItem,Int) -> Unit)? = null

    @SuppressLint("SetTextI18n")
    override fun convert(helper: LiveHolder?, item: UserReturnLiveItem?) {
        helper ?: return
        item ?: return

        helper.tvItemName.text = item.nickname ?: "_ _"


        if(null == item.age) {
            helper.tvItemAge.visibility = View.GONE
        }else {
            if(item.age == 0) {
                helper.tvItemAge.visibility = View.GONE
            }else {
                helper.tvItemAge.visibility = View.VISIBLE
                helper.tvItemAge.text = "${item.age}岁"
            }
        }

        if(null == item.city) {
            helper.ivItemLocation.visibility = View.GONE
        }else {
            helper.ivItemLocation.visibility = View.VISIBLE
        }

        helper.tvItemLocation.text = item.city

        item.phonehallposter?.let {
            GlideUtils.loadImageView(helper.itemView.context, it, helper.ivItemCover)
        }

        if(!TextUtils.isEmpty(item.sex) && TextUtils.equals(item.sex,"1")) {
            helper.ivItemSex.setImageResource(R.drawable.icon_male)
        }else {
            helper.ivItemSex.setImageResource(R.drawable.icon_female)
        }

        // 进入个人主页
        helper.userInfoContainer.setOnClickListener {
            userClick?.invoke(item,INTO_PROFILE)
        }

        // 进入主播直播间
        helper.ivTop.setOnClickListener {
            userClick?.invoke(item, INTO_LIVE_ROOM)
        }

        helper.itemContainer.setOnClickListener {
            userClick?.invoke(item,INTO_LIVE_ROOM)
        }
    }

    inner class LiveHolder(view: View) : BaseViewHolder(view) {
        val ivTop = view.findViewById<ImageView>(R.id.ivTop)
        val itemContainer = view.findViewById<ConstraintLayout>(R.id.itemContainer)
        val ivItemCover = view.findViewById<ImageView>(R.id.ivItemCover)
        val ivItemSex = view.findViewById<ImageView>(R.id.ivItemSex)
        val tvItemName = view.findViewById<TextView>(R.id.tvItemName)
        val tvItemAge = view.findViewById<TextView>(R.id.tvItemAge)
        val tvItemLocation = view.findViewById<TextView>(R.id.tvItemLocation)
        val userInfoContainer = view.findViewById<ConstraintLayout>(R.id.userInfoContainer)
        val ivItemLocation = view.findViewById<ImageView>(R.id.ivItemLocation)


        init {
            val widthScreen = view.context.resources.displayMetrics.widthPixels
            fitterViewSize(ivTop, { (widthScreen * IV_TOP_PERCENT).toInt() }, { (it * IV_SELF_PERCENT).toInt() })
            fitterViewSize(itemContainer, { (widthScreen * CONTAINER_PERCENT).toInt() }, { (it * CONTAINER_SELF_PERCENT).toInt() })
            fitterViewSize(ivItemCover, { (widthScreen * COVER_PERCENT).toInt() }, { (it * COVER_SELF_PERCENT).toInt() })
        }
    }

}