package com.ninexiu.sixninexiu.adapter.auction

import android.content.Intent
import android.content.IntentFilter
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.recyclerview.widget.LinearLayoutManager
import com.blankj.utilcode.util.ToastUtils
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.activity.BidDetailsH5Activity
import com.ninexiu.sixninexiu.activity.SubPageActivity
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.bean.AuctionGoodsList
import com.ninexiu.sixninexiu.common.net.NSGsonObjectNewCallback
import com.ninexiu.sixninexiu.common.net.NSRequestParams
import com.ninexiu.sixninexiu.common.net.NsOkHttpClient
import com.ninexiu.sixninexiu.common.util.Constants
import com.ninexiu.sixninexiu.common.util.NSReceiverAction
import com.ninexiu.sixninexiu.common.util.Utils
import com.ninexiu.sixninexiu.fragment.BasePagerFragment
import com.ninexiu.sixninexiu.fragment.auction.OrderDetailsFragment
import com.ninexiu.sixninexiu.lib.smartrefresh.api.RefreshLayout
import com.ninexiu.sixninexiu.lib.smartrefresh.listener.OnRefreshListener
import com.ninexiu.sixninexiu.login.LoginEntryActivity
import kotlinx.android.synthetic.main.fragment_live_goods_list.*
import kotlinx.android.synthetic.main.layout_for_show_state.*

class LiveGoodsListFragment : BasePagerFragment() , OnRefreshListener {
    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View? {
        return inflater.inflate(R.layout.fragment_live_goods_list, container, false)
    }

    companion object {
        const val GOODS_LIST_TYPE_AUCTION = 1 //竞拍
        const val GOODS_LIST_TYPE_BUY_NOW = 2 //一口价
        fun newInstance(type: Int, rid: String): LiveGoodsListFragment {
            val args = Bundle()
            args.putInt("goods_list_type", type)
            args.putString("room_id", rid)
            val fragment = LiveGoodsListFragment()
            fragment.arguments = args
            return fragment
        }
    }

    private lateinit var goodsAdapter: AuctionGoodsAdapter
    private var goodsType = GOODS_LIST_TYPE_AUCTION
    private lateinit var roomId:String
    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        if (arguments != null) {
            goodsType = arguments!!.getInt("goods_list_type")
            roomId = arguments!!.getString("room_id","")
        }
        rv_goods_list.layoutManager = LinearLayoutManager(context, LinearLayoutManager.VERTICAL, false)
        goodsAdapter = AuctionGoodsAdapter(context!!, goodsType, ArrayList())
        rv_goods_list.adapter = goodsAdapter

        refresh_layout.setEnableLoadMore(false);
        refresh_layout.setEnableOverScrollDrag(true);
        refresh_layout.setOnRefreshListener(this);

        goodsAdapter.buynowClick = setOnClickListener@{ view, goods ->
            if (NineShowApplication.mUserBase == null) {
                Utils.startLogin(activity, LoginEntryActivity.FROM_LIVEROOM)
                return@setOnClickListener
            }

            if (goods.stock_num <= 0) {
                ToastUtils.showShort("库存不足")
            } else {
                //跳转确认订单页
                val intent = Intent(context, SubPageActivity::class.java)
                intent.putExtra(SubPageActivity.CLASSFRAMENT, OrderDetailsFragment::class.java)
                val bundle = Bundle()
                bundle.putParcelable("goods", goods)
                bundle.putInt("from_type", OrderDetailsFragment.FROM_TYPE_MAKE_ORDER_BUYNOW)
                intent.putExtra("bundle", bundle)
                startActivity(intent)

            }
        }
        goodsAdapter.goodsClick = setOnClickListener@ { view, goods ->
            if (NineShowApplication.mUserBase == null) {
                Utils.startLogin(activity, LoginEntryActivity.FROM_LIVEROOM)
                return@setOnClickListener
            }
            BidDetailsH5Activity.start(context, goods, goodsType)
        }

        getGoodsListData()

        sv_state_view?.setOnRefreshListener {
            getGoodsListData()
        }
    }

    /**
     * 获取商品列表
     */
    private fun getGoodsListData() {
        val params = NSRequestParams()
        params.put("type", goodsType)
        params.put("rid", roomId)
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_AUCTION_GOODS_LIST, params, object : NSGsonObjectNewCallback<AuctionGoodsList>() {

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: AuctionGoodsList?) {
                refresh_layout?.finishRefresh()
                if (response != null && response.code == 200) {
                    if (!response.data.isNullOrEmpty()) {
                        sv_state_view?.showSuccess()
                        goodsAdapter?.goodsList = response.data
                        goodsAdapter?.notifyDataSetChanged()
                    }else{
                        sv_state_view?.showEmpty("暂无商品")
                    }
                }
            }

            override fun onFailure(statusCode: Int, errorMsg: String) {
                refresh_layout?.finishRefresh()
                ToastUtils.showShort(errorMsg)
            }

        })
    }

    override fun onRefresh(refreshLayout: RefreshLayout) {
        getGoodsListData()
    }

    override fun registerReceiver(): Boolean {
        return true
    }

    override fun setBroadcastFilter(filter: IntentFilter?) {
        super.setBroadcastFilter(filter)

        filter?.addAction(NSReceiverAction.ACTION_BIDDING_COMMODITY_REFRESH)
    }

    override fun onReceive(action: String?, type: Int, bundle: Bundle?) {
        super.onReceive(action, type, bundle)
        if (NSReceiverAction.ACTION_BIDDING_COMMODITY_REFRESH == action) {
//            var sell_type = bundle?.getInt("sell_type")
//            if (sell_type == 1 && goodsType == 1){
//                getGoodsListData()
//            }
//            if (sell_type == 2 && goodsType == 2){
                getGoodsListData()
//            }
        }
    }
}