package com.ninexiu.sixninexiu.adapter.liveroom

import android.content.Context
import android.graphics.Color
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.core.content.ContextCompat
import androidx.recyclerview.widget.RecyclerView
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.bean.ContributionTopUser
import com.ninexiu.sixninexiu.common.util.GlideUtils
import com.ninexiu.sixninexiu.common.util.NSLog
import com.ninexiu.sixninexiu.view.dp2px
import com.ninexiu.sixninexiu.view.getDrawableResource
import com.ninexiu.sixninexiu.view.setVisible
import kotlinx.android.synthetic.main.layout_contribut_user_day.view.*

class ContributionTopUserAdapter(val context: Context, var userList: MutableList<ContributionTopUser>) : RecyclerView.Adapter<ContributionTopUserAdapter.ContributionTopUserHolder>() {
    class ContributionTopUserHolder(val view: View) : RecyclerView.ViewHolder(view)

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): ContributionTopUserHolder {
        val view = LayoutInflater.from(context).inflate(R.layout.layout_contribut_user_day, parent, false)
        return ContributionTopUserHolder(view)
    }

    override fun getItemCount(): Int {
        NSLog.d("TestSize : ", userList.size.toString())
        return userList.size
    }

    override fun onBindViewHolder(holder: ContributionTopUserHolder, position: Int) {
        val contributionUser = userList[position]
        GlideUtils.loadCirclePic(context, contributionUser.head, holder.view.iv_contribution_day_user_avatar, R.drawable.icon_default_avatar)

        holder.view.tv_contribution_day_value?.text = convertNumber(contributionUser.price)
        holder.view.tv_contribution_day_value.setTextColor(ContextCompat.getColor(context,R.color.white))
        holder.view.tv_contribution_day_value?.delegate?.backgroundColor = Color.parseColor("#88000000")

        // 本月和本场
        if (contributionUser.type == 1 || contributionUser.type == 2) {
            holder.view.iv_contribution_day_user_avatar?.setVisible(true)
            holder.view.tv_contribution_day?.setVisible(true)
            holder.view.tv_contribution_day_value?.setVisible(true)
            holder.view.tv_contribution_day_number?.setVisible(true)

            holder.view.iv_contribution_day_user_avatar?.borderWidth = dp2px(context, 1).toFloat()
            if (contributionUser.type == 1) {//月贡献第一
                holder.view.iv_contribution_day_user_avatar?.borderColor = Color.parseColor("#FFEAA3")
                holder.view.tv_contribution_day_value?.delegate?.backgroundColor = Color.parseColor("#CCFFDF70")
                holder.view.tv_contribution_day?.delegate?.setBackgroundColorStartMidEnd(Color.parseColor("#FFEDB8"), Color.parseColor("#FFEAAD"), Color.parseColor("#FFD55B"))
                holder.view.tv_contribution_day_number?.text = ""
                holder.view.tv_contribution_day?.text = "本月"
                holder.view.tv_contribution_day_number?.setBackgroundResource(R.drawable.icon_liveroom_contribution_first)
                holder.view.tv_contribution_day_value.setTextColor(ContextCompat.getColor(context,R.color.color_69472e))
            } else {//日贡献
                if(contributionUser.rank <= 3) {
                    holder.view.tv_contribution_day_value.setTextColor(ContextCompat.getColor(context,R.color.color_69472e))
                    holder.view.tv_contribution_day_number?.setBackgroundResource(getDrawableResource(context,"ic_top_number_"+contributionUser.rank))
                    holder.view.tv_contribution_day_number?.text = ""
                }else {
                    // holder.view.tv_contribution_day_number?.text = "${contributionUser.rank}"
                    // holder.view.tv_contribution_day_number?.background = null
                }

                when (contributionUser.rank) {
                    1 -> {
                        holder.view.iv_contribution_day_user_avatar?.borderColor = Color.parseColor("#FFE8E5")
                        holder.view.tv_contribution_day_value?.delegate?.backgroundColor = Color.parseColor("#CCF3CFCA")
                        holder.view.tv_contribution_day?.delegate?.setBackgroundColorStartMidEnd(Color.parseColor("#E4B7B0"), Color.parseColor("#FFDFDA"), Color.parseColor("#E4B7B0"))
                    }
                    2 -> {
                        holder.view.iv_contribution_day_user_avatar?.borderColor = Color.parseColor("#D7E1FF")
                        holder.view.tv_contribution_day_value?.delegate?.backgroundColor = Color.parseColor("#CCD3D7E3")
                        holder.view.tv_contribution_day?.delegate?.setBackgroundColorStartMidEnd(Color.parseColor("#B1BAD5"), Color.parseColor("#D6DEF5"), Color.parseColor("#B1BAD5"))
                    }
                    3 -> {
                        holder.view.iv_contribution_day_user_avatar?.borderColor = Color.parseColor("#FACFB2")
                        holder.view.tv_contribution_day_value?.delegate?.backgroundColor = Color.parseColor("#CCD3A988")
                        holder.view.tv_contribution_day?.delegate?.setBackgroundColorStartMidEnd(Color.parseColor("#BE9574"), Color.parseColor("#F2C6A7"), Color.parseColor("#AE866C"))
                    }
                }
            }
        } else {//其他数据
            holder.view.iv_contribution_day_user_avatar?.setVisible(true)
            holder.view.tv_contribution_day?.setVisible(false)
            holder.view.tv_contribution_day_value?.setVisible(contributionUser.price != 0L)
            holder.view.tv_contribution_day_number?.setVisible(false)
            holder.view.iv_contribution_day_user_avatar?.borderWidth = 0f
        }

        holder.view.setOnClickListener {
            onUserClick?.invoke(contributionUser)
        }
    }


    private fun convertNumber(number: Long): String {
        return when {
            number < 10000 -> {
                "$number"
            }
            number / 10000 > 100 -> {
                "${number / 10000}w"
            }
            else -> {
                "${String.format("%.1f", number.toDouble() / 10000)}w"
            }
        }

    }

    var onUserClick: ((user: ContributionTopUser) -> Unit)? = null
}