package com.ninexiu.sixninexiu.adapter.tencentIm

import android.content.Context
import android.text.TextUtils
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.recyclerview.widget.RecyclerView
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.audio.AudioItemView
import com.ninexiu.sixninexiu.bean.CustomGreetBean
import kotlinx.android.synthetic.main.item_follow_hello_content_empty.view.*
import kotlinx.android.synthetic.main.item_follow_hello_content_text.view.*
import kotlinx.android.synthetic.main.item_follow_hello_content_voice.view.*

class FollowHelloContentAdapter(val context: Context?, var customGreetBean: CustomGreetBean?) : RecyclerView.Adapter<FollowHelloContentAdapter.FollowHelloContentHolder>() {

    class FollowHelloContentHolder(val view: View) : RecyclerView.ViewHolder(view)

    companion object {
        const val TYPE_EMPTY = 0
        const val TYPE_TEXT = 1
        const val TYPE_VOICE = 2
    }

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): FollowHelloContentHolder {
        val view: View = when (viewType) {
            TYPE_TEXT -> {
                LayoutInflater.from(parent.context).inflate(R.layout.item_follow_hello_content_text, parent, false)
            }
            TYPE_VOICE -> {
                LayoutInflater.from(parent.context).inflate(R.layout.item_follow_hello_content_voice, parent, false)
            }
            else -> {
                LayoutInflater.from(parent.context).inflate(R.layout.item_follow_hello_content_empty, parent, false)
            }
        }
        return FollowHelloContentHolder(view)
    }

    override fun getItemCount(): Int {
        if (customGreetBean != null) {
            return customGreetBean!!.data.content.size
        }
        return 0
    }

    override fun getItemViewType(position: Int): Int {
        if (customGreetBean != null) {
            val sayContent = customGreetBean!!.data.content[position]
            if (!TextUtils.isEmpty(sayContent.say_content)) {
                return if (sayContent.say_type == 1) {
                    TYPE_VOICE
                } else {
                    TYPE_TEXT
                }
            }
        }
        return TYPE_EMPTY
    }

    override fun onBindViewHolder(holder: FollowHelloContentHolder, position: Int) {
        val content = customGreetBean?.data?.content!![position]
        when (getItemViewType(position)) {
            TYPE_TEXT -> {
                holder.view.tv_content_text_name.text = "${position + 1}"
                holder.view.iv_content_text_edit.setOnClickListener {
                    onEditClick?.invoke(position, TYPE_TEXT, content)
                }
                holder.view.tv_content_text?.setOnClickListener {
                    onEditClick?.invoke(position, TYPE_TEXT, content)
                }
                holder.view.iv_content_text_clear.setOnClickListener {
                    onClearClick?.invoke(position, TYPE_TEXT, content,null)
                }
                holder.view.tv_content_text.text = content?.say_content
            }

            TYPE_VOICE -> {
                holder.view.tv_content_voice_name.text = "${position + 1}"
                holder.view.iv_content_voice_edit.setOnClickListener {
                    onEditClick?.invoke(position, TYPE_VOICE, content)
                }
                holder.view.iv_content_voice_clear.setOnClickListener {
                    onClearClick?.invoke(position, TYPE_VOICE, content, holder.view.avi_content_voice)
                }

                holder.view.avi_content_voice.setAudioItemSource(content.say_content, content.speech_tm)

            }

            TYPE_EMPTY -> {
                holder.view.tv_content_empty_name.text = "${position + 1}"
                holder.view.fl_content_add_text.setOnClickListener {
                    onEditClick?.invoke(position, TYPE_TEXT, content)
                }

                holder.view.rl_content_add_voice.setOnClickListener {
                    onEditClick?.invoke(position, TYPE_VOICE, content)
                }
            }

        }
    }

    var onEditClick: ((position: Int, viewType: Int, data: CustomGreetBean.DataBean.ContentBean) -> Unit)? = null
    var onClearClick: ((position: Int, viewType: Int, data: CustomGreetBean.DataBean.ContentBean, voiceView: AudioItemView?) -> Unit)? = null
}