package com.ninexiu.sixninexiu.adapter.topic

import android.content.Context
import android.content.Intent
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.recyclerview.widget.RecyclerView
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.activity.SubPageActivity
import com.ninexiu.sixninexiu.activity.TranslucentSubPageActivity
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.bean.Topic
import com.ninexiu.sixninexiu.common.util.GlideUtils
import com.ninexiu.sixninexiu.fragment.topic.DynamicTopicDetailsFragment
import com.ninexiu.sixninexiu.fragment.topic.DynamicTopicListParentFragment
import com.ninexiu.sixninexiu.view.dp2px
import com.ninexiu.sixninexiu.view.setVisible
import kotlinx.android.synthetic.main.item_dynamic_topic_list.view.*

/**
 * <pre>
 *     @author : bing
 *     time   : 2021/7/12
 *     desc   :
 *     version: 1.0
 * </pre>
 */
class DynamicTopicListAdapter(val context: Context, val isFollow:Boolean, private val topicList: MutableList<Topic>) : RecyclerView.Adapter<DynamicTopicListAdapter.DynamicTopicListHolder>() {
    class DynamicTopicListHolder(val view: View) : RecyclerView.ViewHolder(view)

    var onTopicFollowClick: ((position: Int, topic: Topic) -> Unit)? = null

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): DynamicTopicListHolder {
        val view = LayoutInflater.from(context).inflate(R.layout.item_dynamic_topic_list, parent, false)
        return DynamicTopicListHolder(view)
    }

    override fun getItemCount(): Int {
        return topicList.size
    }

    override fun onBindViewHolder(holder: DynamicTopicListHolder, position: Int) {
        val topic = topicList[position]
        if (topic.title != null && topic.title!!.length > 18) {
            holder.view.tv_topic_name.text = "${topic.title!!.substring(0, 18)}..."
        } else {
            holder.view.tv_topic_name.text = topic.title
        }

        holder.view.tv_dynamic_count.setVisible(isFollow)
        holder.view.tv_dynamic_count.text="${formatCount(topic.total)} 动态"

        holder.view.iv_topic_tip.setVisible(topic.is_activity == 1)
        holder.view.tv_topic_follow.setVisible(!isFollow && topic.isfollow != 1)
        GlideUtils.loadSimpleImgWithRoundCorner(context, topic.url, holder.view.iv_topic_cover, R.drawable.anthor_moren_item, dp2px(context, 8))

        if (isFollow) {
            if (topic.introduce != null && topic.introduce.length > 18) {
                holder.view.tv_topic_desc.text = "${topic.introduce.substring(0, 18)}..."
            } else {
                holder.view.tv_topic_desc.text = topic.introduce
            }
        } else {
            holder.view.tv_topic_desc.text = "${formatCount(topic.total)} 动态"
        }

        holder.view.setOnClickListener {
            //跳详情
            val intent = Intent(context, TranslucentSubPageActivity::class.java)
            intent.putExtra(TranslucentSubPageActivity.CLASSFRAMENT, DynamicTopicDetailsFragment::class.java)
            val bundle = Bundle()
            bundle.putParcelable(DynamicTopicDetailsFragment.KEY_TOPIC, topic)
            intent.putExtra("bundle",bundle)
            context.startActivity(intent)
        }

        holder.view.tv_topic_follow.setOnClickListener {
            onTopicFollowClick?.invoke(position, topic)
        }
    }

    private fun formatCount(total: Int): String {
        return if (total<10000){
            "$total"
        }else{
            "${String.format("%.1f",total.toDouble()/10000)}万"
        }
    }
}