package com.ninexiu.sixninexiu.audio

import android.annotation.SuppressLint
import android.content.Context
import android.graphics.Color
import android.util.AttributeSet
import android.view.LayoutInflater
import android.view.View
import androidx.constraintlayout.widget.ConstraintLayout
import androidx.core.content.ContextCompat
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.common.statistics.StatisticsEventID
import com.ninexiu.sixninexiu.common.statistics.StatisticsUtil
import com.ninexiu.sixninexiu.common.util.MyToast
import com.ninexiu.sixninexiu.common.util.NSLog
import com.ninexiu.sixninexiu.view.dp2px
import com.ninexiu.sixninexiu.view.setVisible
import kotlinx.android.synthetic.main.view_audio_item.view.*

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/03/22
 *     desc   : 语音封装条目
 *     version: 1.0
 * </pre>
 */
@SuppressLint("Recycle")
class AudioItemView @JvmOverloads constructor(context: Context, attrs: AttributeSet? = null, defStyleAttr: Int = 0) : ConstraintLayout(context, attrs, defStyleAttr) {
    companion object {
        const val Tag = "AudioItemView >>"
    }

    var onStartPlayClick: (() -> Unit)? = null

    init {
        LayoutInflater.from(context).inflate(R.layout.view_audio_item, this)

        val arr = context.obtainStyledAttributes(attrs, R.styleable.AudioItemView)
        val delVisible = arr.getBoolean(R.styleable.AudioItemView_del_visible, true)
        val infoVisible = arr.getBoolean(R.styleable.AudioItemView_info_visible, true)
        val radius = arr.getDimensionPixelSize(R.styleable.AudioItemView_voice_radius, dp2px(getContext(), 23))
        arr.recycle()

        tvAudioListen.setVisible(infoVisible)
        ivAudioDel.setVisible(delVisible)
        itemAudioContainer.delegate.cornerRadius_TR = radius
        itemAudioContainer.delegate.cornerRadius_BL = radius
        itemAudioContainer.delegate.cornerRadius_BR = radius

        itemAudioContainer.setOnClickListener {
            onStartPlayClick?.invoke()?:startPlay()
        }

        // 删除音频文件
        ivAudioDel.setOnClickListener {
            deleteAudio()
            onAudioDel?.invoke()
        }
    }

    fun startPlay() {
        path?.let {
            StatisticsUtil.onEvent(StatisticsEventID.UM_DYNAMIC_LISTEN_VOICE)
            AudioPlayerManager.startPlayAudioPause(it, duration, onAudioPlayerListener)
        }
    }

    var onAudioDel: (() -> Unit)? = null

    fun deleteAudio() {
        duration = 0
        path?.let {
            AudioPlayerManager.releasePlayer()
            audioRecordManager.deleteAudioFile(it)
        }
        path = null
    }

    private val onAudioPlayerListener = object : OnAudioPlayerListener {
        override fun onAudioPlayStart(path: String) {
            audioPlayStatus?.invoke(true)
            audioWaveView.startWave()
        }

        override fun onAudoPlayCutDown(path: String, duration: Int) {
            tvAudioTime.text = "${duration}\""
            tvAudioListen.text = "正在试听"
        }

        @SuppressLint("SetTextI18n")
        override fun onAudioPlayEnd(path: String, isError: Boolean) {
            audioPlayStatus?.invoke(false)
            if (isError) {
                MyToast.showShort(context.getString(R.string.audio_play_error))
            }

            audioWaveView.stopWave()
            tvAudioTime.text = "${duration}\""
            tvAudioListen.text = "点击试听"
        }
    }

    // 回调音频的播放状态
    var audioPlayStatus: ((Boolean) -> Unit)? = null

    private val audioRecordManager = AudioRecordManager()

    private var duration = 0
    private var path: String? = null

    @SuppressLint("SetTextI18n")
    fun setAudioItemSource(path: String, duration: Int) {
        this.duration = duration
        tvAudioTime.text = "${duration}\""
        this.path = path
    }

    // 重置播放的ui
    fun reset() {
        audioWaveView.stopWave()
        tvAudioTime.text = "${duration}\""
    }
}


