package com.ninexiu.sixninexiu.audio

import android.animation.ValueAnimator
import android.annotation.SuppressLint
import android.content.Context
import android.graphics.Canvas
import android.graphics.Color
import android.graphics.Paint
import android.graphics.RectF
import android.util.AttributeSet
import android.util.Log
import android.view.View
import android.view.animation.LinearInterpolator
import androidx.constraintlayout.widget.ConstraintLayout
import com.ninexiu.sixninexiu.R
import kotlin.math.log

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/03/18
 *     desc   : 录音过程中的进度view
 *     version: 1.0
 * </pre>
 */
class AudioProgressView @JvmOverloads constructor(context: Context, attrs: AttributeSet? = null, defStyleAttr: Int = 0) : View(context, attrs, defStyleAttr) {
    companion object {
        private const val PROGRESS_WIDTH = 5f
    }

    private var maxProgress = 60f  // 录音的最大时长

    private val paint = Paint()

    init {
        paint.isAntiAlias = true
        paint.isDither = true
        paint.style = Paint.Style.STROKE
        paint.strokeCap = Paint.Cap.ROUND
        paint.strokeJoin = Paint.Join.ROUND
        paint.strokeWidth = 10f

        val arr = context.obtainStyledAttributes(attrs, R.styleable.AudioProgressView)
        maxProgress = arr.getFloat(R.styleable.AudioProgressView_wave_progress, 60f)
        paint.color = arr.getColor(R.styleable.AudioProgressView_wave_progress_color, context.resources.getColor(R.color.color_ff7c89))
        arr.recycle()
    }

    private var progress = PROGRESS_WIDTH

    private var animator: ValueAnimator? = null

    // 开始计时
    fun startProgress() {
        progress = 0f
        if (animator == null) {
            animator = ValueAnimator.ofFloat(0f, maxProgress)
            animator?.addUpdateListener {
                Log.d("AudioProgressView : ", "${it.animatedValue}")
                progress = it.animatedValue as? Float ?: 0f
                invalidate()
            }
            animator?.duration = (maxProgress * 1000).toLong()
        }
        animator?.interpolator = LinearInterpolator()
        animator?.cancel()
        animator?.start()
    }

    // 重置
    fun resetProgress() {
        animator?.cancel()
        progress = 0f
        invalidate()
    }

    @SuppressLint("DrawAllocation")
    override fun onDraw(canvas: Canvas?) {
        super.onDraw(canvas)

        val rectF = RectF(PROGRESS_WIDTH, PROGRESS_WIDTH, measuredWidth.toFloat() - PROGRESS_WIDTH, measuredHeight.toFloat() - PROGRESS_WIDTH)
        canvas?.drawArc(rectF, -90f, ((progress * 1f) / maxProgress) * 360, false, paint)
    }

    override fun onDetachedFromWindow() {
        super.onDetachedFromWindow()
        animator?.let {
            animator = null
            clearAnimation()
        }
    }
}