package com.ninexiu.sixninexiu.audio

import android.annotation.SuppressLint
import android.content.Context
import android.graphics.Canvas
import android.graphics.Color
import android.graphics.Paint
import android.graphics.RectF
import android.util.AttributeSet
import android.util.Log
import android.view.View
import com.ninexiu.sixninexiu.R

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/03/20
 *     desc   :
 *     version: 1.0
 * </pre>
 */
@SuppressLint("Recycle")
class AudioVoiceWaveView @JvmOverloads constructor(context: Context, attrs: AttributeSet? = null, defStyleAttr: Int = 0) : View(context, attrs, defStyleAttr) {
    companion object {
        const val Tag = "AudioVoice >> "
        const val MODEL_MIDDLE = 0
        const val MODEL_BOTTOM = 1
    }

    private val paint = Paint()

    // 组数(多少个条目为一组)
    private var groupItemCount = 3

    // 条目总个数 : 最好为奇数，具有对称性
    private var itemCount = 5


    // 最低高度
    private var itemMinHeight = 10f

    // 最高高度
    private var itemMaxHeight = 80f

    // 条目宽度
    private var itemWidth = 6f

    // 条目间隔
    private var divider = 6f

    // 1s刷新的帧数
    private var frameCount = 10

    // 1f 应该刷新的高度 (f : 代表帧)
    private var frameDis = 0f

    // 绘制的方向
    private var mode = MODEL_MIDDLE

    init {
        paint.isAntiAlias = true
        paint.isDither = true
        paint.style = Paint.Style.FILL
        paint.strokeCap = Paint.Cap.ROUND
        paint.strokeJoin = Paint.Join.ROUND
        paint.strokeWidth = 5f

        val arr = context.obtainStyledAttributes(attrs, R.styleable.AudioVoiceWaveView)
        itemCount = arr.getInt(R.styleable.AudioVoiceWaveView_wave_count, 5)
        groupItemCount = arr.getInt(R.styleable.AudioVoiceWaveView_wave_group_count, 3)
        itemMinHeight = arr.getFloat(R.styleable.AudioVoiceWaveView_wave_item_min, 10f)
        itemMaxHeight = arr.getFloat(R.styleable.AudioVoiceWaveView_wave_item_max, 50f)
        paint.color = arr.getColor(R.styleable.AudioVoiceWaveView_wave_color, Color.WHITE)
        mode = arr.getInt(R.styleable.AudioVoiceWaveView_wave_model, 0)

        arr.recycle()
    }

    override fun onMeasure(widthMeasureSpec: Int, heightMeasureSpec: Int) {
        val specModeW = MeasureSpec.getMode(widthMeasureSpec)
        var specSizeW = MeasureSpec.getSize(widthMeasureSpec)

        val specModeH = MeasureSpec.getMode(heightMeasureSpec)
        var specSizeH = MeasureSpec.getSize(heightMeasureSpec)

        val minViewWidth = (itemCount * (itemWidth + divider)).toInt()
        if (specModeW == MeasureSpec.AT_MOST && specModeH == MeasureSpec.AT_MOST) {
            specSizeH = itemMaxHeight.toInt()
            specSizeW = minViewWidth
        } else if (specModeW == MeasureSpec.AT_MOST) {
            specSizeW = minViewWidth
        } else if (specModeH == MeasureSpec.AT_MOST) {
            specSizeH = itemMaxHeight.toInt()
        }

        setMeasuredDimension(specSizeW, specSizeH)
    }

    // 这里存储的一组高度(所有的item都是这此一组的高度范围内变化得出的)
    private val groupArray = mutableListOf<Float>()

    // 初始化数组,这里存储的是组的下标
    private val initArray = mutableListOf<Float>()

    // 进行变化的数组
    private var tempArray = mutableListOf<Float>()


    @SuppressLint("DrawAllocation")
    override fun onDraw(canvas: Canvas?) {
        super.onDraw(canvas)

        if (tempArray.isNullOrEmpty()) {
            // 绘制初始化数组
            if (initArray.isNullOrEmpty() || groupArray.isNullOrEmpty()) {
                getInitItemArray()
            }

            tempArray = initArray
        }

        Log.d(Tag, "initArray : size : ${initArray.size} $initArray")
        Log.d(Tag, "tempArray : size : ${tempArray.size} $tempArray")


        // left
        val leftStart = (measuredWidth - itemWidth * itemCount - divider * (itemCount - 1)) / 2

        // 统一转换成tempArray来绘制
        for ((index, item) in tempArray.withIndex()) {
            if (item >= 0) {
                var itemLeft = leftStart + index * (itemWidth + divider)
                val itemTop = (measuredHeight - item) / 2
                val rect = when (mode) {
                    MODEL_BOTTOM -> {       // 从底部开始绘制
                        RectF(itemLeft, measuredHeight - item, itemLeft + itemWidth, measuredHeight.toFloat())
                    }
                    else -> {               // 从中间开始绘制
                        RectF(itemLeft, itemTop, itemLeft + itemWidth, itemTop + item)
                    }
                }
                canvas?.drawRoundRect(rect, 5f, 5f, paint)
            }
        }
    }

    // 记录每个条目应该是增长还是缩减  mapItem<所有的item下标 , item高度增长/缩减>
    private val mapItem = mutableMapOf<Int, Boolean>()

    /**
     * 波浪动画变换 todo : 后期待优化
     */
    private fun getWaveChangeArray() {
        if (initArray.isNullOrEmpty()) {
            getInitItemArray()
            mapItem.clear()
            tempArray.clear()
        }

        if (mapItem.isNullOrEmpty()) {
            // 计算出变换数组
            for ((index, item) in initArray.withIndex()) {
                if (item >= 0) {
                    mapItem[index] = (item != groupArray[groupArray.size - 1])
                }
            }
        }

        if (tempArray.isNullOrEmpty()) {
            tempArray = initArray
        }

        var copyArray = mutableListOf<Float>()
        tempArray.forEach {
            copyArray.add(it)
        }

        tempArray.clear()

        for ((index, item) in copyArray.withIndex()) {
            if (item >= 0) {
                var isAdd = mapItem[index] ?: true
                var temp = item
                if (temp <= itemMinHeight && !isAdd) {
                    isAdd = true
                }

                if (temp >= itemMaxHeight && isAdd) {
                    isAdd = false
                }

                if (isAdd) {
                    temp += frameDis
                } else {
                    temp -= frameDis
                }

                tempArray.add(index, temp)
                mapItem[index] = isAdd
            }
        }

        invalidate()
        postDelayed(runnable, (1000 / 2 / frameCount).toLong())
    }

    private val runnable = Runnable {
        getWaveChangeArray()
    }

    fun startWave() {
        removeCallbacks(runnable)
        postDelayed(runnable, 300)
    }

    fun stopWave() {
        removeCallbacks(runnable)
        mapItem.clear()
        tempArray.clear()
        invalidate()
    }


    /**
     * 两个重要的数组 :
     * 1. 高度数组，所有条目的高度都从这个里面得到
     * 2. 所有的条目的高度(这里存储了在高度数组中的下标，具体绘制时才取值)
     */

    @SuppressLint("LongLogTag")
    private fun getInitItemArray() {
        if (groupItemCount <= 1) {
            return
        }

        groupArray.clear()

        // 1. 计算出组中的高度范围
        val dis = (itemMaxHeight - itemMinHeight) / (groupItemCount - 1)    // 递增数

        // 计算出 1f(f : 代表帧) 应该变化的高度
        frameDis = (itemMaxHeight - itemMinHeight) / (frameCount - 1)

        val startHeight = itemMinHeight
        for (index in 0 until groupItemCount) {
            groupArray.add(startHeight + index * dis)
        }

        if (groupArray.isNullOrEmpty()) {
            return
        }

        // todo : 拿到高度数组
        Log.d(Tag, "groupArray : $groupArray")


        initArray.clear()

        // 填充数组
        for (index in 0 until itemCount) {
            initArray.add(index, 0f)
        }

        // 2. 计算出所有条目的高度(这里是计算出在高度数组[groupArray]中的下标)
        // todo : 奇数限制
        val middleIndex = itemCount / 2

        /**
         * 计算所有高度的高度(在高度数组中的下标）
         */
        var isAdd = false
        var groupIndex = groupArray.size - 1
        for (index in middleIndex downTo 0) {
            val postIndex = (middleIndex - index) + middleIndex

            // 防止越界
            if (index >= 0 && postIndex <= itemCount - 1) {
                initArray[index] = groupArray[groupIndex]
                initArray[postIndex] = groupArray[groupIndex]
            }

            if (isAdd) {
                if (++groupIndex == groupArray.size - 1) {
                    isAdd = false
                }
            } else {
                if (--groupIndex == 0) {
                    isAdd = true
                }
            }
        }


        Log.d(Tag, "initArray : $initArray")
    }

    override fun onDetachedFromWindow() {
        super.onDetachedFromWindow()
        stopWave()
    }
}






























