package com.ninexiu.sixninexiu.audio

import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.bean.*
import com.ninexiu.sixninexiu.common.net.NSGsonObjectNewCallback
import com.ninexiu.sixninexiu.common.net.NSRequestParams
import com.ninexiu.sixninexiu.common.net.NsOkHttpClient
import com.ninexiu.sixninexiu.common.util.Constants
import com.ninexiu.sixninexiu.common.util.MyToast
import com.ninexiu.sixninexiu.common.util.NSLog
import com.ninexiu.sixninexiu.fragment.DynamicDetailNewFragment

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/03/31
 *     desc   : 动态详情的管理 : 主要负责一些数据的请求和判断处理
 *     version: 1.0
 * </pre>
 */
object DynamicDetailHelper {
    /**
     * 获取动态详情
     */
    fun getDynamicDetailData(dynamicId: Long, token: String?, onSuccess: (Dynamic) -> Unit, onFail: (() -> Unit)? = null) {
        if (dynamicId == 0L || dynamicId == -1L) {
            onFail?.invoke()
            return
        }
        val params = NSRequestParams()
        params.put("id", dynamicId)
        token?.let {
            params.put("token", it)
        }

        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_DYNAMIC_DETAIL_LIST, params, object : NSGsonObjectNewCallback<AnchorDynamicDetailResult>() {
            override fun onFailure(statusCode: Int, errorMsg: String?) {
                MyToast.showShort(errorMsg ?: "")
                onFail?.invoke()
            }

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: AnchorDynamicDetailResult?) {
                NSLog.d(DynamicDetailNewFragment.Tag, responseString ?: "null")
                if (statusCode == 200 && response != null && response.data != null) {
                    onSuccess.invoke(response.data)
                } else {
                    if (response != null) {
                        MyToast.showShort(message ?: "")
                    }else {
                        MyToast.showShort("动态已被删除! ")
                    }
                    onFail?.invoke()
                }
            }
        })
    }

    /**
     * 获取评论详情
     */
    fun getDynamicCommentData(dynamicId: Long, token: String?, pageNum: Int, onSuccess: (MutableList<CommentData>) -> Unit, onFail: () -> Unit) {
        if (dynamicId == 0L || dynamicId == -1L) {
            onFail.invoke()
            return
        }
        val params = NSRequestParams()
        params.put("id", dynamicId)
        params.put("page", pageNum)
        token?.let {
            params.put("token", it)
        }

        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_DYNAMIC_COMMENT_LIST2, params, object : NSGsonObjectNewCallback<AnchorDetailResult>() {
            override fun onFailure(statusCode: Int, errorMsg: String?) {
                MyToast.showShort(errorMsg ?: "")
                onFail.invoke()
            }

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: AnchorDetailResult?) {
                NSLog.d(DynamicDetailNewFragment.Tag, responseString ?: "null")
                if (statusCode == 200 && response != null && !response.data.isNullOrEmpty()) {
                    onSuccess.invoke(response.data)
                } else {
                    MyToast.showShort(message ?: "")
                    onFail.invoke()
                }
            }
        })
    }

    /**
     * 回复评论或动态
     */
    fun replyCommentOrDynamic(token: String?, type: Int, dynamicId: Long, commentData: CommentData?, content: String, onSuccess: (CommentData) -> Unit, onFail: (() -> Unit)? = null) {
        if (dynamicId == 0L || dynamicId == -1L) {
            onFail?.invoke()
            return
        }

        val tempType = if (type == 10) {    // 视频类型
            3
        } else {
            type
        }

        val params = NSRequestParams()
        params.put("type", tempType)
        params.put("subid", dynamicId)      // 动态id
        params.put("touid", commentData?.uid ?: 0)  // 0 : 回复动态  else : 回复评论
        params.put("content", content)

        token?.let {
            params.put("token", it)
        }

        NsOkHttpClient.getNsOkHttpClient().doPost(Constants.REPLY_COMMENT_URL2, params, object : NSGsonObjectNewCallback<CommentResult>() {
            override fun onFailure(statusCode: Int, errorMsg: String?) {
                // MyToast.showShort(errorMsg ?: "")
                onFail?.invoke()
            }

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: CommentResult?) {
                NSLog.d(DynamicDetailNewFragment.Tag, responseString ?: "null")
                if (statusCode == 200) {    // 后台其实将返回的评论数据已经返回了，不过原来的逻辑没有使用，有些参数缺失了
                    val newComment = CommentData()
                    newComment.curtime = System.currentTimeMillis() / 1000
                    newComment.uid = NineShowApplication.mUserBase?.uid ?: 0L
                    newComment.headimage = NineShowApplication.mUserBase?.avatarUrl120
                    newComment.nickname = NineShowApplication.mUserBase?.nickname

                    commentData?.let {
                        newComment.touid = it.uid
                        newComment.toguardgid = it.guardgid
                        newComment.tonickname = it.nickname
                    }

                    newComment.content = content
                    onSuccess.invoke(newComment)
                } else {
                    // MyToast.showShort(message ?: "")
                    onFail?.invoke()
                }
            }
        })
    }

    /**
     * 动态点赞
     */
    fun likeTheDynamic(token: String?, dynamicId: Long, onSuccess: () -> Unit, onFail: (() -> Unit)? = null) {
        if (dynamicId == 0L || dynamicId == -1L) {
            onFail?.invoke()
            return
        }
        val params = NSRequestParams()
        params.put("subid", dynamicId)      // 动态id
        token?.let { params.put("token", it) }
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.DYNAMIC_PRAISE_URL, params, object : NSGsonObjectNewCallback<CommentResult>() {
            override fun onFailure(statusCode: Int, errorMsg: String?) {
                MyToast.showShort(errorMsg ?: "")
                onFail?.invoke()
            }

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: CommentResult?) {
                NSLog.d(DynamicDetailNewFragment.Tag, responseString ?: "null")
                if (statusCode == 200) {
                    onSuccess.invoke()
                } else {
                    MyToast.showShort(message ?: "")
                    onFail?.invoke()
                }
            }
        })
    }

}