package com.ninexiu.sixninexiu.audio

import android.text.TextUtils
import com.ninexiu.sixninexiu.bean.AccountSeeMeResponse
import com.ninexiu.sixninexiu.common.ConfigSpHelper
import com.ninexiu.sixninexiu.common.net.NSGsonObjectNewCallback
import com.ninexiu.sixninexiu.common.net.NSRequestParams
import com.ninexiu.sixninexiu.common.net.NsOkHttpClient
import com.ninexiu.sixninexiu.common.util.Constants
import com.ninexiu.sixninexiu.common.util.MyToast
import com.ninexiu.sixninexiu.common.util.NSLog
import com.ninexiu.sixninexiu.common.util.TimeUtil

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/03/29
 *     desc   : 此类负责统计动态界面视频，图片，语音的观看次数
 *     version: 1.0
 * </pre>
 */
object DynamicHelper {
    private const val Tag = "DynamicHelper : "
    private const val MAX_SIZE = 10
    private var dynamicList: MutableList<String>? = null

    // 添加动态id
    fun addElement(id: Long) {
        if (id == 0L || id == -1L) {
            return
        }

        val tempId = id.toString()

        if (dynamicList == null) {
            dynamicList = mutableListOf()
        }

        if (addDataToLocalDynamic(tempId)) {
            dynamicList?.add(tempId)

            if (dynamicList?.size ?: 0 == MAX_SIZE) {
                upDynamicDataLoad()
            }
        }
    }

    // 上传动态数据   主动上传 : 页面切换时候可以上传     被动上传 : 数量达到最大
    fun upDynamicDataLoad() {
        if (dynamicList?.isNullOrEmpty() == false) {
            NSLog.d(Tag, "reach max : ${dynamicList.toString()}")

            val dynamicStrData = dynamicList?.joinToString(separator = ",") ?: ""
            val params = NSRequestParams()
            params.put("dynamic_ids", dynamicStrData)
            NsOkHttpClient.getNsOkHttpClient().doPost(Constants.GET_DYNAMIC_SEE_VIEW_NUM, params, object : NSGsonObjectNewCallback<AccountSeeMeResponse>() {
                override fun onFailure(statusCode: Int, errorMsg: String?) {
                    NSLog.d(Tag, "上传动态数据失败...${errorMsg ?: "null"}")
                    dynamicList?.clear()
                }

                override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: AccountSeeMeResponse?) {
                    NSLog.d(Tag, "上传动态数据成功...")
                    dynamicList?.clear()
                }
            })

        }
    }

    /**
     * 获取本地存储的动态数据并加入动态，看是否可以成功
     */
    private fun addDataToLocalDynamic(dynamicInfo: String): Boolean {
        NSLog.d(Tag, "local data : 待加入数据 -> $dynamicInfo")

        // 判断本地数据是否过期(仅一天数据有效)
        if (getDynamicTimeStatus()) {
            NSLog.d(Tag, "local data : 过期置空...")
            // 过期的话,将存储数据置空
            ConfigSpHelper.getInstance().dynamicRecordData = ""
        }

        // 获取到本地数据
        val dynamicData = ConfigSpHelper.getInstance().dynamicRecordData

        NSLog.d(Tag, "local data : $dynamicData")


        var dynamicList = mutableListOf<String>()

        if (dynamicData.isNullOrBlank()) {
            NSLog.d(Tag, "local data : 加入数据成功...0")
            dynamicList.add(dynamicInfo)
            ConfigSpHelper.getInstance().dynamicRecordData = dynamicList.joinToString(separator = ",")
            return true
        }

        dynamicList.addAll(dynamicData.split(","))
        if (dynamicList.contains(dynamicInfo)) {
            NSLog.d(Tag, "local data : 数据重复了")
            return false
        }

        NSLog.d(Tag, "local data : 加入数据成功...1")

        dynamicList.add(dynamicInfo)
        ConfigSpHelper.getInstance().dynamicRecordData = dynamicList.joinToString(separator = ",")
        return true
    }


    /**
     * 获取本地存储的日期
     */
    private fun getDynamicTimeStatus(): Boolean {
        val preTime = ConfigSpHelper.getInstance().dynamicRecordTime

        val currentTime = TimeUtil.getUserReturnDayTime(System.currentTimeMillis())

        if (TextUtils.isEmpty(preTime)) {
            // 时间更新
            ConfigSpHelper.getInstance().dynamicRecordTime = currentTime
            return true
        }

        NSLog.d(Tag, "pre : $preTime , cur : $currentTime")
        if (preTime != currentTime) {
            // 时间更新
            ConfigSpHelper.getInstance().dynamicRecordTime = currentTime
            return true
        }
        return false
    }

    const val MAX_VIEW_NUMBER = 10000000 // 1 千万

    // 转换浏览次数
    fun formatViewNumber(number: Int): String {
        if (number < 10000) {
            return "$number"
        }

        if (number >= MAX_VIEW_NUMBER) {
            return "999.99w+"
        }

        val height = number / 10000

        val nextHeight = (number % 10000) / 1000

        return "${height}.${nextHeight}w"
    }


}
