package com.ninexiu.sixninexiu.common.IM.custom

import android.annotation.SuppressLint
import android.content.Context
import android.content.Intent
import android.os.Bundle
import android.text.SpannableStringBuilder
import android.text.TextUtils
import android.view.LayoutInflater
import android.widget.ImageView
import android.widget.RelativeLayout
import android.widget.TextView
import androidx.constraintlayout.widget.ConstraintLayout
import androidx.recyclerview.widget.GridLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.activity.SubPageActivity
import com.ninexiu.sixninexiu.audio.AudioItemView
import com.ninexiu.sixninexiu.common.util.*
import com.ninexiu.sixninexiu.fragment.DynamicDetailNewFragment
import com.ninexiu.sixninexiu.view.dp2px
import com.ninexiu.sixninexiu.view.setVisible
import com.tencent.qcloud.tim.uikit.component.picture.imageEngine.impl.GlideEngine
import com.tencent.qcloud.tim.uikit.modules.chat.layout.message.holder.ICustomMessageViewGroup
import com.tencent.qcloud.tim.uikit.modules.message.MessageInfo
import org.json.JSONObject

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/03/24
 *     desc   : 自定义动态消息 : 视频，音频，图片
 *     version: 1.0
 * </pre>
 */
class CustomDynamicChatMsgDraw {
    companion object {
        const val TYPE_DYNAMIC_VIDEO = 10       // 视频
        const val TYPE_DYNAMIC_PICTURE = 1      // 图片
        const val TYPE_DYNAMIC_VOICE = 5        // 语音
        const val divider = 4

        val INSTANCE: CustomDynamicChatMsgDraw by lazy(mode = LazyThreadSafetyMode.SYNCHRONIZED) {
            CustomDynamicChatMsgDraw()
        }
    }

    private val mSmileyParser = SmileyParser.getInstance()

    @SuppressLint("InflateParams")
    fun onDraw(context: Context, parent: ICustomMessageViewGroup, json: String, info: MessageInfo) {
        if (TextUtils.isEmpty(json)) {
            return
        }

        val view = LayoutInflater.from(context).inflate(R.layout.message_adapter_dynamic, null, false)

        val ivAnchor = view.findViewById<ImageView>(R.id.ivAnchor)
        val tvNickName = view.findViewById<TextView>(R.id.tvNickName)
        val tvContent = view.findViewById<TextView>(R.id.tvContent)
        val audioItemView = view.findViewById<AudioItemView>(R.id.audioItemView)
        val rlVideo = view.findViewById<RelativeLayout>(R.id.rlVideo)
        val ivVideoCover = view.findViewById<ImageView>(R.id.ivVideoCover)
        val tvVideoTime = view.findViewById<TextView>(R.id.tvVideoTime)
        val picRecy = view.findViewById<RecyclerView>(R.id.picRecy)
        val container = view.findViewById<ConstraintLayout>(R.id.dynamicContainer)

        try {
            val jsonObject = JSONObject(json)
            val anchor = jsonObject.optString("dyHeadImageUrl")
            if (!anchor.isNullOrBlank()) {
                GlideUtils.loadCirclePic(context, anchor, ivAnchor)
            }

            val nickName = jsonObject.optString("nickName")
            tvNickName.text = nickName ?: ""

            val content = jsonObject.optString("contentText") ?: ""
            val builder = SpannableStringBuilder(content)
            tvContent.text = mSmileyParser.addSmileySpans1(builder)

            val dynamicId = jsonObject.getLong("dynamicId")

            when (jsonObject.optInt("dynamicType")) {
                TYPE_DYNAMIC_VOICE -> {
                    audioItemView.setVisible(true)
                    rlVideo.setVisible(false)
                    picRecy.setVisible(false)


                    val voiceUrl = jsonObject.optString("voiceUrl")
                    if (voiceUrl.isNullOrBlank()) {
                        audioItemView.setVisible(false)
                    } else {
                        audioItemView.setVisible(true)
                        audioItemView.setAudioItemSource(voiceUrl, jsonObject.optInt("voiceDuration"))
                    }
                }
                TYPE_DYNAMIC_VIDEO -> {
                    audioItemView.setVisible(false)
                    rlVideo.setVisible(true)
                    picRecy.setVisible(false)

                    jsonObject.optString("videoCover").let { GlideEngine.loadCornerImage(ivVideoCover, it, null) }
                    tvVideoTime.text = Utils.getPKToTime(Utils.parseDouble(jsonObject.optString("videoTime")).toInt())
                }
                TYPE_DYNAMIC_PICTURE -> {
                    audioItemView.setVisible(false)
                    rlVideo.setVisible(false)
                    picRecy.setVisible(true)

                    picRecy?.let { initRecyAdapter(context, it, dynamicId, jsonObject.optString("picUrls")) }
                }
                else -> {
                    audioItemView.setVisible(false)
                    rlVideo.setVisible(false)
                    picRecy.setVisible(false)
                }
            }

            container.setOnClickListener {
                goToDetailFragment(context, dynamicId)
            }

        } catch (e: Exception) {
            e.printStackTrace()
        }

        NSLog.d("CustomDynamicChatMsgDraw : ", "json : $json")
        NSLog.d("CustomDynamicChatMsgDraw : ", "info : $info")

        parent.addMessageContentView(view)
    }

    private fun goToDetailFragment(context: Context, dynamicId: Long) {
        if (dynamicId == -1L) {
            MyToast.MakeToast("动态审核中，无法操作！")
            return
        }
        val intentShop = Intent(context, SubPageActivity::class.java)
        intentShop.putExtra(SubPageActivity.CLASSFRAMENT, DynamicDetailNewFragment::class.java)
        val bundle = Bundle()
        bundle.putLong("id", dynamicId)
        bundle.putInt("type", 0)
        intentShop.putExtras(bundle)
        context.startActivity(intentShop)
    }

    //231 - 24  = 207 - 4 = 203
    private var msgDynamicPicAdapter: MsgDynamicPicAdapter? = null
    private fun initRecyAdapter(context: Context, picRecy: RecyclerView, dynamicId: Long, pics: String) {
        if (picRecy.adapter != null && picRecy.layoutManager != null) {
            return
        }
        val picLists = pics.split(",")
        if (picLists.isNullOrEmpty()) {
            return
        }

        val itemHeight = if (picLists.size > 2) {
            dp2px(context, (231 - 24 - divider * 2) / 3)
        } else {
            dp2px(context, (231 - 24 - divider) / 2)
        }

        val count = if (picLists.size <= 2) {
            2
        } else {
            3
        }
        val manager = GridLayoutManager(context, count)
        picRecy.layoutManager = manager
        picRecy.addItemDecoration(DynamicRecyDecoration(picLists.size, dp2px(context, divider / 2)))
        msgDynamicPicAdapter = MsgDynamicPicAdapter(picLists, itemHeight)
        picRecy.adapter = msgDynamicPicAdapter
        msgDynamicPicAdapter?.onItemClick = {
            goToDetailFragment(context, dynamicId)
        }
    }
}