package com.ninexiu.sixninexiu.common.IM.custom

import android.annotation.SuppressLint
import android.content.Context
import android.content.Intent
import android.os.Bundle
import android.text.TextUtils
import android.view.LayoutInflater
import android.view.View
import com.blankj.utilcode.util.ConvertUtils
import com.blankj.utilcode.util.ToastUtils
import com.google.gson.Gson
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.activity.PersonalInforActivity
import com.ninexiu.sixninexiu.activity.SubPageActivity
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.audio.DynamicDetailHelper
import com.ninexiu.sixninexiu.bean.ChatDynamicData
import com.ninexiu.sixninexiu.common.statistics.StatisticsEventID
import com.ninexiu.sixninexiu.common.statistics.StatisticsUtil
import com.ninexiu.sixninexiu.common.util.GlideUtils
import com.ninexiu.sixninexiu.common.util.SmileyParser
import com.ninexiu.sixninexiu.common.util.TimeUtil
import com.ninexiu.sixninexiu.common.util.UIUtils
import com.ninexiu.sixninexiu.common.util.manager.RequestManager
import com.ninexiu.sixninexiu.fragment.DynamicDetailNewFragment
import com.tencent.qcloud.tim.uikit.modules.chat.layout.message.holder.ICustomMessageViewGroup
import com.tencent.qcloud.tim.uikit.modules.chat.layout.message.holder.IOnPersonalDynamicClick
import com.tencent.qcloud.tim.uikit.modules.message.MessageInfo
import kotlinx.android.synthetic.main.message_adapter_loc_dynamic.view.*

/**
 * <pre>
 *     @author : zhangbing
 *     time   : 2021/03/24
 *     desc   : 自定义聊天对象信息展示
 *     version: 1.0
 * </pre>
 */
class CustomLocDynamicChatMsgDraw {
    companion object {
        val INSTANCE: CustomLocDynamicChatMsgDraw by lazy(mode = LazyThreadSafetyMode.SYNCHRONIZED) {
            CustomLocDynamicChatMsgDraw()
        }
    }


    fun onDraw(context: Context, parent: ICustomMessageViewGroup, json: String, info: MessageInfo,dynamicClick:IOnPersonalDynamicClick) {
        if (TextUtils.isEmpty(json)) {
            return
        }

        val locDynamicInfo = Gson().fromJson<ChatDynamicData>(json, ChatDynamicData::class.java)

        val view = LayoutInflater.from(context).inflate(R.layout.message_adapter_loc_dynamic, null, false)

        if (locDynamicInfo.type == 3) {//文本
            UIUtils.goneView(view.iv_chat_dynamic_image)
            UIUtils.goneView(view.fl_chat_dynamic_video)
            UIUtils.goneView(view.audio_chat_voice)
            UIUtils.showView(view.tv_chat_dynamic_content)

            view.tv_chat_dynamic_content.text = SmileyParser.getInstance().addSmileySpans1(locDynamicInfo.content)
        } else if (locDynamicInfo.type == 4) {//图片
            UIUtils.showView(view.iv_chat_dynamic_image)
            UIUtils.goneView(view.fl_chat_dynamic_video)
            UIUtils.goneView(view.audio_chat_voice)
            UIUtils.showView(view.tv_chat_dynamic_content)
            GlideUtils.loadSimpleImgWithRoundCorner(context, locDynamicInfo.imageurl, view.iv_chat_dynamic_image, R.drawable.icon_personal_default_bg, ConvertUtils.dp2px(4f))
            view.tv_chat_dynamic_content.text = SmileyParser.getInstance().addSmileySpans1(locDynamicInfo.content)
        } else if (locDynamicInfo.type == 5) {//语音
            UIUtils.goneView(view.iv_chat_dynamic_image)
            UIUtils.goneView(view.fl_chat_dynamic_video)
            UIUtils.showView(view.audio_chat_voice)
            if (TextUtils.isEmpty(locDynamicInfo.content)) {
                UIUtils.goneView(view.tv_chat_dynamic_content)
            } else {
                UIUtils.showView(view.tv_chat_dynamic_content)
                view.tv_chat_dynamic_content.text = SmileyParser.getInstance().addSmileySpans1(locDynamicInfo.content)
            }
            if (!TextUtils.isEmpty(locDynamicInfo.voiceurl)) {
                view.audio_chat_voice.setAudioItemSource(locDynamicInfo.voiceurl!!, locDynamicInfo.duration)
            }
            view.audio_chat_voice.onStartPlayClick = {
                locDynamicInfo.id?.let {
                    DynamicDetailHelper.getDynamicDetailData(it.toLong(), NineShowApplication.mUserBase?.token,
                            {
                                view.audio_chat_voice.startPlay()
                            }, {
                        dynamicClick.onDynamicDelete(info)
                    })
                }
            }
        } else if (locDynamicInfo.type == 6) {//视频
            UIUtils.showView(view.iv_chat_dynamic_image)
            UIUtils.showView(view.fl_chat_dynamic_video)
            UIUtils.goneView(view.audio_chat_voice)
            UIUtils.showView(view.tv_chat_dynamic_content)

            GlideUtils.loadSimpleImgWithRoundCorner(context, locDynamicInfo.imageurl, view.iv_chat_dynamic_image, R.drawable.icon_personal_default_bg, ConvertUtils.dp2px(4f))
            view.tv_chat_dynamic_content.text = SmileyParser.getInstance().addSmileySpans1(locDynamicInfo.content)
        }
        if (!TextUtils.isEmpty(locDynamicInfo.province)) {
            view.tv_chat_dynamic_loction.visibility = View.VISIBLE
            view.tv_chat_dynamic_loction.text = locDynamicInfo.province
        } else {
            view.tv_chat_dynamic_loction.visibility = View.GONE
        }
        if (!TextUtils.isEmpty(locDynamicInfo.tm)) {
            view.tv_chat_dynamic_time.text = TimeUtil.getTime(locDynamicInfo.tm!!.toLong()*1000L)
        }

//        view.setOnClickListener {
//            if (!TextUtils.isEmpty(locDynamicInfo.id)) {
//                val intentShop = Intent(context, SubPageActivity::class.java)
//                intentShop.putExtra(SubPageActivity.CLASSFRAMENT, DynamicDetailNewFragment::class.java)
//                val bundle = Bundle()
//                bundle.putLong("id", locDynamicInfo.id!!.toLong())
//                bundle.putInt("type", 0)
//                intentShop.putExtras(bundle)
//                context.startActivity(intentShop)
//            }
//        }

        view.setOnClickListener {
            locDynamicInfo.id?.let {
                DynamicDetailHelper.getDynamicDetailData(it.toLong(), NineShowApplication.mUserBase?.token,
                        {
                            StatisticsUtil.onEvent(StatisticsEventID.UM_IM_CHAT_LOCAL_DYNAMIC)
                            PersonalInforActivity.start(context, false, false, info.fromUser.toLong(), 1)
                        }, {
                    dynamicClick.onDynamicDelete(info)
                })
            }
        }

        parent.addMessageItemView(view)
    }

}