package com.ninexiu.sixninexiu.common.IM.custom

import android.annotation.SuppressLint
import android.content.Context
import android.graphics.BitmapFactory
import android.text.Spannable
import android.text.SpannableStringBuilder
import android.text.TextUtils
import android.text.style.ImageSpan
import android.view.LayoutInflater
import android.view.View
import androidx.core.content.ContextCompat
import com.google.gson.Gson
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.activity.PersonalInforActivity
import com.ninexiu.sixninexiu.bean.ChatDynamicData
import com.ninexiu.sixninexiu.common.statistics.StatisticsEventID
import com.ninexiu.sixninexiu.common.statistics.StatisticsUtil
import com.ninexiu.sixninexiu.common.util.*
import com.ninexiu.sixninexiu.view.VerticalImageSpan
import com.tencent.qcloud.tim.uikit.modules.chat.layout.message.holder.ICustomMessageViewGroup
import com.tencent.qcloud.tim.uikit.modules.message.MessageInfo
import kotlinx.android.synthetic.main.item_dynamic_content.view.*
import kotlinx.android.synthetic.main.message_adapter_loc_personalinfo.view.*
import java.lang.StringBuilder

/**
 * <pre>
 *     @author : zhangbing
 *     time   : 2021/03/24
 *     desc   : 自定义聊天对象信息展示
 *     version: 1.0
 * </pre>
 */
class CustomLocPersonalInfoChatMsgDraw {
    companion object {
        val INSTANCE: CustomLocPersonalInfoChatMsgDraw by lazy(mode = LazyThreadSafetyMode.SYNCHRONIZED) {
            CustomLocPersonalInfoChatMsgDraw()
        }
    }

    @SuppressLint("InflateParams")
    fun onDraw(context: Context, parent: ICustomMessageViewGroup, json: String, info: MessageInfo) {
        if (TextUtils.isEmpty(json)) {
            return
        }

        val locPersonalInfo = Gson().fromJson<ChatDynamicData>(json, ChatDynamicData::class.java)

        val view = LayoutInflater.from(context).inflate(R.layout.message_adapter_loc_personalinfo, null, false)
        GlideUtils.loadCirclePic(context, locPersonalInfo.headimage, view.iv_chat_avatar)
        view.tv_chat_nickname.text = locPersonalInfo.nickname
        //年龄性别
        if (locPersonalInfo.age > 0) {
            view.tv_chat_sex.visibility = View.VISIBLE
            view.tv_chat_sex.text = "${locPersonalInfo.age}"
        } else {
            view.tv_chat_sex.visibility = View.GONE
        }
        when {
            TextUtils.equals(locPersonalInfo.sex, "男") -> {
                view.tv_chat_sex?.visibility = View.VISIBLE
                val sexDrawable = ContextCompat.getDrawable(context, R.drawable.icon_personal_man)
                sexDrawable?.setBounds(0, 0, sexDrawable.minimumWidth, sexDrawable.minimumHeight)
                view.tv_chat_sex?.setCompoundDrawables(sexDrawable, null, null, null)
                view.tv_chat_sex?.background = ContextCompat.getDrawable(context, R.drawable.shape_gradient_man)
                view.item_dynamic_tv_age?.setTextColor(ContextCompat.getColor(context,R.color.color_4785ff))
            }
            TextUtils.equals(locPersonalInfo.sex, "女") -> {
                view.tv_chat_sex?.visibility = View.VISIBLE
                val sexDrawable = ContextCompat.getDrawable(context, R.drawable.icon_personal_woman)
                sexDrawable?.setBounds(0, 0, sexDrawable.minimumWidth, sexDrawable.minimumHeight)
                view.tv_chat_sex?.setCompoundDrawables(sexDrawable, null, null, null)
                view.tv_chat_sex?.background = ContextCompat.getDrawable(context, R.drawable.shape_gradient_woman)
                view.item_dynamic_tv_age?.setTextColor(ContextCompat.getColor(context,R.color.color_ff3366))
            }
            else -> {
                view.tv_chat_sex?.setCompoundDrawables(null, null, null, null)
                view.tv_chat_sex?.background = ContextCompat.getDrawable(context, R.drawable.shape_gradient_no)
            }
        }

        //身份标识和位置标识
        val sb = StringBuilder()
        if (locPersonalInfo.identity == 2) {
            sb.append("主播")
        } else if (!TextUtils.isEmpty(locPersonalInfo.trade)) {
            sb.append(locPersonalInfo.trade)
        }
        if (!TextUtils.isEmpty(locPersonalInfo.province)) {
            sb.append("·")
            sb.append(locPersonalInfo.province)
        }
        view.tv_chat_isanchor.text = sb

        //图片或者签名
        if (!locPersonalInfo.img.isNullOrEmpty()) {
            UIUtils.goneView(view.view_chat_line)
            UIUtils.goneView(view.tv_chat_sign)
            UIUtils.showView(view.asi_chat_pics)
            view.asi_chat_pics.setImages(locPersonalInfo.img, false)
            view.asi_chat_pics.setAsivClickListener { pos, url, imageViews, isVideo ->
                StatisticsUtil.onEvent(StatisticsEventID.UM_IM_CHAT_LOCAL_PERSONAL)
                PersonalInforActivity.start(context,false,false,info.fromUser.toLong(),1,false)
            }
            view.setOnClickListener {
                StatisticsUtil.onEvent(StatisticsEventID.UM_IM_CHAT_LOCAL_PERSONAL)
                PersonalInforActivity.start(context,false,false,info.fromUser.toLong(),1,false)
            }
        } else {
            UIUtils.showView(view.view_chat_line)
            UIUtils.showView(view.tv_chat_sign)
            UIUtils.goneView(view.asi_chat_pics)

            val builder = SpannableStringBuilder("  ${locPersonalInfo.signature}")
            val bitmap = BitmapFactory.decodeResource(context.resources, R.drawable.icon_chat_personal_sign);
            val imageSpan = VerticalImageSpan(context, bitmap, ImageSpan.ALIGN_CENTER)
            builder.setSpan(imageSpan, 0, 1, Spannable.SPAN_INCLUSIVE_EXCLUSIVE)
            view.tv_chat_sign.text = builder

            view.setOnClickListener {
                StatisticsUtil.onEvent(StatisticsEventID.UM_IM_CHAT_LOCAL_PERSONAL)
                PersonalInforActivity.start(context,false,info.fromUser,false)
            }
        }




        parent.addMessageItemView(view)
    }

}