package com.ninexiu.sixninexiu.common.httphelp

import com.google.gson.GsonBuilder
import com.google.gson.JsonSyntaxException
import com.loopj.android.http.BaseJsonHttpResponseHandler
import com.loopj.android.http.RequestHandle
import com.ninexiu.sixninexiu.bean.*
import com.ninexiu.sixninexiu.common.net.*
import com.ninexiu.sixninexiu.common.util.Constants
import cz.msebera.android.httpclient.Header
import okhttp3.Call

/**
 * <pre>
 *     @author : zhangbing
 *     time   : 2021/07/13
 *     desc   : 话题相关 接口请求,数据处理
 *     version: 1.0
 * </pre>
 */
object DynamicTopicHelper {
    const val TAG = "DynamicTopicHelper"

    /**
     * 获取话题分类置顶数据
     */
    fun getTopicTopList(onSuccess: (TopicTopListBean) -> Unit, onFail: ((Int, String?) -> Unit)?) {
        val params = NSRequestParams()
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_DYNAMIC_TOPIC_TOP_LIST, params, object : NSGsonObjectNewCallback<TopicTopListBean?>() {
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: TopicTopListBean?) {
                if (response != null && response.code == 200) {
                    onSuccess.invoke(response)
                    return
                }
                onFail?.invoke(statusCode, message)
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                onFail?.invoke(statusCode, errorMsg)
            }
        })
    }

    /**
     * 获取话题推荐
     */
    private var topicCall: Call? = null
    fun getRecommendTopic(onSuccess: (TopicTopListBean) -> Unit, onFail: ((Int, String?) -> Unit)? = null) {
        val params = NSRequestParams()
        val httpClient =NsOkHttpClient.getNsOkHttpClient()
        topicCall = httpClient.doGet(Constants.GET_DYNAMIC_TOPIC_RECOMMEND, params, object : NSGsonObjectNewCallback<TopicTopListBean?>() {
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: TopicTopListBean?) {
                if (response != null && response.code == 200) {
                    onSuccess.invoke(response)
                    return
                }
                onFail?.invoke(statusCode, message)
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                onFail?.invoke(statusCode, errorMsg)
            }
        })
    }



    /**
     * 获取话题分类
     */
    fun getTopicTabList(onSuccess: (TopicTabListBean) -> Unit, onFail: ((Int, String?) -> Unit)? = null) {
        val params = NSRequestParams()

        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_DYNAMIC_TOPIC_TAB_LIST, params, object : NSGsonObjectNewCallback<TopicTabListBean?>() {
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: TopicTabListBean?) {
                if (response != null && response.code == 200) {
                    onSuccess.invoke(response)
                    return
                }
                onFail?.invoke(statusCode, message)
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                onFail?.invoke(statusCode, errorMsg)
            }

        })
    }

    /**
     * 获取话题分类 下话题
     */
    fun getTopicListByTab(page: Int, tabId: Int?, onSuccess: (TopicTopListBean) -> Unit, onFail: ((Int, String?) -> Unit)? = null) {
        val params = NSRequestParams()
        params.put("page",page)
        params.put("id",tabId)
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_DYNAMIC_TOPIC_LIST_TAB, params, object : NSGsonObjectNewCallback<TopicTopListBean?>() {
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: TopicTopListBean?) {
                if (response != null && response.code == 200 && response.data != null) {
                    onSuccess.invoke(response)
                    return
                }
                onFail?.invoke(statusCode, message)
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                onFail?.invoke(statusCode, errorMsg)
            }

        })
    }

    /**
     * 获取话题的详情
     */
    fun getTopicDetails(params: NSRequestParams, onSuccess: (TopicDynamicListBean) -> Unit, onFail: ((Int, String?) -> Unit)?){
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_DYNAMIC_TOPIC_INFO,params,object : NSGsonObjectNewCallback<TopicDynamicListBean?>(){
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: TopicDynamicListBean?) {
                if (response != null && response.code == 200 && response.data != null) {
                    onSuccess.invoke(response)
                    return
                }
                onFail?.invoke(statusCode, message)
            }
            override fun onFailure(statusCode: Int, errorMsg: String?) {
                onFail?.invoke(statusCode, errorMsg)
            }
        })
    }

    /**
     * 关注话题
     */
    fun followTopic(id :Int?, onSuccess: (String?) -> Unit, onFail: ((Int, String?) -> Unit)?){
        val params = NSRequestParams()
        params.put("id",id)
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_DYNAMIC_TOPIC_FOLLOW,params,object : NSGsonObjectNewCallback<BaseBean<Nothing>?>(){
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: BaseBean<Nothing>?) {
                if (response != null && response.code == 200) {
                    onSuccess.invoke(message)
                    return
                }
                onFail?.invoke(statusCode, message)
            }
            override fun onFailure(statusCode: Int, errorMsg: String?) {
                onFail?.invoke(statusCode, errorMsg)
            }
        })
    }

    /**
     * 取消关注话题
     */
    fun cancelFollowTopic(id :Int?, onSuccess: (String?) -> Unit, onFail: ((Int, String?) -> Unit)?){
        val params = NSRequestParams()
        params.put("id",id)
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_DYNAMIC_TOPIC_CANCEL_FOLLOW,params,object : NSGsonObjectNewCallback<BaseBean<Nothing>?>(){
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: BaseBean<Nothing>?) {
                if (response != null && response.code == 200 ) {
                    onSuccess.invoke(message)
                    return
                }
                onFail?.invoke(statusCode, message)
            }
            override fun onFailure(statusCode: Int, errorMsg: String?) {
                onFail?.invoke(statusCode, errorMsg)
            }
        })
    }


    /**
     * 获取话题历史
     */
    fun getHistoryTopic(onSuccess: (TopicTopListBean) -> Unit, onFail: ((Int, String?) -> Unit)? = null) : RequestHandle {
        val params = NSRequestParams()
        return NSAsyncHttpClient.getInstance().get(Constants.GET_DYNAMIC_TOPIC_HISTORT, params, object : NSJsonResponseHandler<TopicTopListBean?>() {
            override fun onSuccess(statusCode: Int, rawJsonResponse: String?, response: TopicTopListBean?) {
                if (response != null && response.code == 200) {
                    onSuccess.invoke(response)
                    return
                }
                onFail?.invoke(statusCode, rawJsonResponse)
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                onFail?.invoke(statusCode, errorMsg)
            }
        })
    }

    /**
     * 删除话题历史
     */
    fun deleteHistoryTopic(topicId:String,onSuccess: (BaseResultInfo) -> Unit, onFail: ((Int, String?) -> Unit)? = null) :RequestHandle{
        val params = NSRequestParams()
        params.put("id", topicId)
        return NSAsyncHttpClient.getInstance().get(Constants.GET_DELETE_DYNAMIC_TOPIC_HISTORT, params, object : BaseJsonHttpResponseHandler<BaseResultInfo?>() {

            override fun onSuccess(statusCode: Int, headers: Array<out Header>?, rawJsonResponse: String?, response: BaseResultInfo?) {
                if (response != null && response.code == 200) {
                    onSuccess.invoke(response)
                    return
                }
                onFail?.invoke(statusCode, rawJsonResponse)
            }

            override fun onFailure(statusCode: Int, headers: Array<out Header>?, rawJsonResponse: Throwable?, rawJsonData: String?, errorResponse: BaseResultInfo?) {
                onFail?.invoke(statusCode, rawJsonResponse?.message)
            }

            override fun parseResponse(rawJsonData: String?, isFailure: Boolean): BaseResultInfo? {
                val builder = GsonBuilder()
                val gson = builder.create()
                var resultInfo: BaseResultInfo? = null
                try {
                    resultInfo = gson.fromJson(rawJsonData, BaseResultInfo::class.java)
                } catch (e: JsonSyntaxException) {
                    e.printStackTrace()
                    resultInfo = null
                    onFail?.invoke(0, "数据解析异常，请重试")
                }
                return resultInfo
            }
        })
    }



}