package com.ninexiu.sixninexiu.common.httphelp

import android.text.TextUtils
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.bean.*
import com.ninexiu.sixninexiu.common.net.*
import com.ninexiu.sixninexiu.common.util.Constants
import okhttp3.Call
import java.lang.ref.SoftReference
import java.util.ArrayList
import java.util.HashMap

/**
 * <pre>
 *     @author : zhangbing
 *     time   : 2021/07/13
 *     desc   : 话题相关 接口请求,数据处理
 *     version: 1.0
 * </pre>
 */
object StoreHelper {
    const val TAG = "StoreHelper"

    const val TYPE_BEAUTY_NUMBER = 1 //购买靓号
    const val TYPE_BEAUTY_DRESSUP = 2 //购买装扮
    const val TYPE_BEAUTY_PROPS = 3 //购买道具
    const val TYPE_BEAUTY_VIP = 4 //购买VIP


    const val TENTHOUSAND: Long = 10000
    const val A_HUNDRED_MILLION: Long = 100000000

    const val BUBBLE_BASE_URL = "https://img.img.9xiu.com/public/mobile/mobileapp/chatbubble/"


    fun getChatBubbleImg(index: Int, chatBgId: String?): String {
        return "${BUBBLE_BASE_URL}0${index + 1}/${chatBgId}.png"
    }

    /**
     * 获取我的道具列表
     */
    fun getMyProps(onSuccess: (PropsListBean) -> Unit, onFail: ((Int, String?) -> Unit)?) {
        val params = NSRequestParams()
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_STORE_MY_PROPS, params, object : NSGsonObjectNewCallback<PropsAllBean?>() {
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: PropsAllBean?) {
                if (response != null && response.code == 200) {
                    onSuccess.invoke(response.data)
                    return
                }
                onFail?.invoke(statusCode, message)
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                onFail?.invoke(statusCode, errorMsg)
            }
        })
    }

    /**
     * 获取靓号列表
     */
    fun getBeautyNumberList(onSuccess: (HashMap<String, ArrayList<Account>>) -> Unit, onFail: ((Int, String?) -> Unit)?) {
        val params = NSRequestParams()
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.ACCOUNT_LIST, params, object : NSGsonObjectNewCallback<BeautyNumberList>() {
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: BeautyNumberList?) {
                if (response != null && response.code == 200) {
                    onSuccess.invoke(response.data)
                    return
                }
                onFail?.invoke(statusCode, message)
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                onFail?.invoke(statusCode, errorMsg)
            }
        })
    }

    /**
     * 搜索靓号
     */
    fun searchBeautyNumber(number: String, onSuccess: (HashMap<String, ArrayList<Account>>) -> Unit, onFail: ((Int, String?) -> Unit)?) {
        val params = NSRequestParams()
        params.put("accountid", number)
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.SEARCH_ACCOUNT, params, object : NSGsonObjectNewCallback<BeautyNumberList>() {
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: BeautyNumberList?) {
                if (response != null && response.code == 200) {
                    onSuccess.invoke(response.data)
                    return
                }
                onFail?.invoke(statusCode, message)
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                onFail?.invoke(statusCode, errorMsg)
            }
        })
    }

    /**
     * 获取个性装扮的tab
     */
    fun getDressUpTab(onSuccess: (List<DressUpTab>) -> Unit, onFail: ((Int, String?) -> Unit)?) {
        val params = NSRequestParams()
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_STORE_DRESS_UP_TAB, params, object : NSGsonObjectNewCallback<DressUpTabBean?>() {
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: DressUpTabBean?) {
                if (response != null && response.code == 200) {
                    onSuccess.invoke(response.data)
                    return
                }
                onFail?.invoke(statusCode, message)
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                onFail?.invoke(statusCode, errorMsg)
            }
        })
    }


    /**
     * 获取个性装扮的tab
     */
    fun getDressUpGoodsList(tab_id: Int, onSuccess: (List<DressUpGoods>) -> Unit, onFail: ((Int, String?) -> Unit)?) {
        val params = NSRequestParams()
        params.put("type_id", tab_id)
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_STORE_DRESS_UP_GOODS_LIST, params,object : NSGsonObjectNewCallback<DressUpGoodsListBean?>() {
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: DressUpGoodsListBean?) {
                if (response != null && response.code == 200) {
                    onSuccess.invoke(response.data)
                    return
                }
                onFail?.invoke(statusCode, message)
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                onFail?.invoke(statusCode, errorMsg)
            }
        })
    }

    /**
     * 获取个性装扮的tab
     */
    fun buyBeautyNumber(beautyNumber: Account, price: BuyTimeList, sendTo: String? = null, onSuccess: (StoreBuyResult?) -> Unit, onFail: ((Int, String?, String?) -> Unit)?) {
        val params = NSRequestParams()
        params.put("accountid", beautyNumber.accountid)
        params.put("month", price.type)
        if (sendTo != null) {
            params.add("profituid", sendTo)
        }

        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.BUY_ACCOUNT, params, object : NSGsonObjectNewCallback<StoreBeautyNumberResultBean?>() {
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: StoreBeautyNumberResultBean?) {
                if (response != null && response.code == 200) {
                    onSuccess.invoke(response.data)
                    return
                }
                onFail?.invoke(statusCode, message, responseString)
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                onFail?.invoke(statusCode, errorMsg, null)
            }
        })
    }


    /**
     * 获取个性装扮的tab
     */
    fun getMyDressupTab(onSuccess: (List<DressUpTab>) -> Unit, onFail: ((Int, String?) -> Unit)?) {
        val params = NSRequestParams()
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_MY_DRESSUP_TAB, params, object : NSGsonObjectNewCallback<DressUpTabBean?>() {
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: DressUpTabBean?) {
                if (response != null && response.code == 200) {
                    onSuccess.invoke(response.data)
                    return
                }
                onFail?.invoke(statusCode, message)
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                onFail?.invoke(statusCode, errorMsg)
            }
        })
    }

    /**
     * 获取个性装扮的tab
     */
    fun getMyDressupData(tab_id: Int, onSuccess: (List<DressUpGoods>) -> Unit, onFail: ((Int, String?) -> Unit)? = null) {
        val params = NSRequestParams()
        params.put("type_id", tab_id)
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_MY_DRESSUP_LIST, params, object : NSGsonObjectNewCallback<DressUpGoodsListBean?>() {
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: DressUpGoodsListBean?) {
                if (response != null && response.code == 200) {
                    onSuccess.invoke(response.data)
                    return
                }
                onFail?.invoke(statusCode, message)
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                onFail?.invoke(statusCode, errorMsg)
            }
        })
    }


    /**
     * 获取vip
     */
    fun getVipList(onSuccess: (List<VipPrivilege>) -> Unit, onFail: ((Int, String?) -> Unit)?) {
        val params = NSRequestParams()
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_STORE_VIP_LIST, params, object : NSGsonObjectNewCallback<VipPrivilegeDataBean?>() {
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: VipPrivilegeDataBean?) {
                if (response != null && response.code == 200) {
                    response?.data?.let { onSuccess.invoke(it) }
                    return
                }
                onFail?.invoke(statusCode, message)
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                onFail?.invoke(statusCode, errorMsg)
            }
        })
    }

    /**
     * 获取商城-道具
     */
    fun getPropDetail(onSuccess: (List<StoreProps>) -> Unit, onFail: ((Int, String?) -> Unit)?) {
        val params = NSRequestParams()
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_STORE_PROPS, params, object : NSGsonObjectNewCallback<StorePropsBean?>() {
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: StorePropsBean?) {
                if (response != null && response.code == 200) {
                    response.data.let { onSuccess.invoke(it) }
                    return
                }
                onFail?.invoke(statusCode, message)
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                onFail?.invoke(statusCode, errorMsg)
            }
        })
    }

    /**
     * 购买隐身卡
     */
    fun buyPropsYinshen(props: StoreProps, price: BuyTimeList, sendTo: String? = null, onSuccess: (StoreBuyResult?) -> Unit, onFail: ((Int, String?, String?) -> Unit)?) {
        val params = NSRequestParams()
        params.put("profituid", sendTo)
        params.put("times", price.type)
        params.put("type", 0)
        if (sendTo != null) {
            params.add("profituid", sendTo)
        }

        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.SHOP_PROP_BUY_STEALTHCARD, params, object : NSGsonObjectNewCallback<StoreBeautyNumberResultBean?>() {
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: StoreBeautyNumberResultBean?) {
                if (response != null && response.code == 200) {
                    onSuccess.invoke(response.data)
                    return
                }
                onFail?.invoke(statusCode, message, responseString)
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                onFail?.invoke(statusCode, errorMsg, null)
            }
        })
    }

    /**
     * 购买VIp前校验
     */
    fun buyVipBefore(vipInfo: VipPrivilege, price: BuyTimeList, sendTo: String? = null, onSuccess: (BaseResultInfo) -> Unit, onFail: ((Int, String?) -> Unit)?) {
        val params = NSRequestParams()
        params.put("gid", vipInfo.gid)
        if (sendTo != null) {
            params.add("profit_uid", sendTo)
        }

        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_BUY_VIP_BEFORE, params, object : NSGsonObjectNewCallback<BaseResultInfo?>() {
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: BaseResultInfo?) {
                if (response != null && response.code == 200) {
                    onSuccess.invoke(response)
                    return
                }
                onFail?.invoke(statusCode, message)
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                onFail?.invoke(statusCode, errorMsg)
            }
        })
    }

    /**
     * 购买VIP
     */
    fun buyVip(vipInfo: VipPrivilege, price: BuyTimeList, sendTo: String? = null, onSuccess: (StoreBuyResult) -> Unit, onFail: ((Int, String?, String?) -> Unit)?) {
        val params = NSRequestParams()
        params.put("month", price.type)
        params.put("gid", vipInfo.gid)
        if (sendTo != null) {
            params.add("profit_uid", sendTo)
        }

        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.USER_BUY_VIP, params, object : NSGsonObjectNewCallback<StoreBuyResultBean?>() {
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: StoreBuyResultBean?) {
                if (response != null && response.code == 200 && !response.data.isNullOrEmpty()) {
                    onSuccess.invoke(response.data[0])
                    return
                }
                onFail?.invoke(statusCode, message, responseString)
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                onFail?.invoke(statusCode, errorMsg, null)
            }
        })
    }


    fun buyDressUp(tabId: Int, dressUpGoods: DressUpGoods, price: BuyTimeList, toUser: String?, onSuccess: (StoreBuyResultBean) -> Unit, onFail: ((Int, String?, String?) -> Unit)?) {
        val requestUrl: String
        val params = NSRequestParams()

        if (tabId == 1) {//头像框
            requestUrl = Constants.GET_BUY_FRAME
            params.put("frame_id", dressUpGoods.frame_id)
            params.put("times", price.type)
        } else if (tabId == 2) {//座驾
            requestUrl = Constants.HTTP_BUY_CAR
            params.put("gid", dressUpGoods.id)
            params.put("type", 0)
            params.put("times", price.type)
        } else if (tabId == 3) {//徽章
            params.put("badge_id", dressUpGoods.badge_id)
            params.put("times", price.type)
            requestUrl = Constants.GET_BUY_BADGE
        } else if (tabId == 4) {//气泡
            requestUrl = Constants.GET_DRESSUP_BUY_BUBBLE
            params.put("gid", dressUpGoods.id)
            params.put("type", 0)
            params.put("times", price.type)
        } else if (tabId == 5) {//资料卡
            requestUrl = Constants.GET_DRESSUP_BUY_INFOCARD
            params.put("gid", dressUpGoods.id)
            params.put("type", 0)
            params.put("times", price.type)
        } else if (tabId == 6) {//麦位光圈
            requestUrl = Constants.GET_DRESSUP_BUY_MICCIRCLE
            params.put("gid", dressUpGoods.id)
            params.put("type", 0)
            params.put("times", price.type)
        } else if (tabId == 7) {//进房特效
            requestUrl = Constants.GET_DRESSUP_BUY_ENTERROOM
            params.put("gid", dressUpGoods.id)
            params.put("type", 0)
            params.put("times", price.type)
        } else {
            requestUrl = ""
        }
        if (!TextUtils.isEmpty(toUser)) {
            params.put("touser", toUser)
        }

        if (TextUtils.isEmpty(requestUrl)) {
            return
        }

        NsOkHttpClient.getNsOkHttpClient().doGet(requestUrl, params, object : NSGsonObjectNewCallback<StoreBuyResultBean?>() {
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: StoreBuyResultBean?) {
                if (response != null && response.code == 200) {
                    response.let { onSuccess.invoke(it) }
                    return
                }
                onFail?.invoke(statusCode, message, responseString)
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                onFail?.invoke(statusCode, errorMsg, null)
            }
        })
    }


    /**
     * 启用禁用靓号
     */
    fun opterateBeautyNumber(numberId: String, onSuccess: (BaseResultInfo) -> Unit, onFail: ((Int, String?) -> Unit)?) {
        val params = NSRequestParams()
        params.put("accountid", numberId)
        NsOkHttpClient.getNsOkHttpClient().doPost(Constants.EDIT_ACCOUNT_ID, params, object : NSGsonObjectNewCallback<BaseResultInfo?>() {
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: BaseResultInfo?) {
                if (response != null && response.code == 200) {
                    response.let { onSuccess.invoke(it) }
                    return
                }
                onFail?.invoke(statusCode, message)
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                onFail?.invoke(statusCode, errorMsg)
            }
        })
    }

    /**
     * 启用禁用  1开启开启  0关闭隐身
     */
    fun operateYinShen(state: Int, onSuccess: (BaseResultInfo) -> Unit, onFail: ((Int, String?) -> Unit)?) {
        val params = NSRequestParams()
        params.put("switchs", state)
        params.put("mac", NineShowApplication.IMEIcode)
        NineShowApplication.mUserBase?.let {
            params.put("token", it.token)
        }
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.CHANG_ACCOUNT_STATES, params, object : NSGsonObjectNewCallback<BaseResultInfo?>() {
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: BaseResultInfo?) {
                if (response != null) {
                    response.let { onSuccess.invoke(it) }
                    return
                }
                onFail?.invoke(statusCode, message)
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                onFail?.invoke(statusCode, errorMsg)
            }
        })
    }


    /**
     * 启用禁用装扮
     */
    fun setupDressUp(dressUpTab: DressUpTab, dressUpGoods: DressUpGoods, frameBadgeStr: String, isDress: Int, onSuccess: (BaseResultInfo) -> Unit, onFail: ((Int, String?) -> Unit)?) {
        val params = NSRequestParams()
        var requestUrl: String? = null
        if (dressUpTab.id == 1) {//设置头像框
            requestUrl = Constants.GET_SETMYFRAME
            NineShowApplication.mUserBase?.let {
                params.put("token", it.token)
            }
            params.put("sort", frameBadgeStr)
        } else if (dressUpTab.id == 2) {//座驾
            requestUrl = Constants.SET_CAR_STATUS
            NineShowApplication.mUserBase?.let {
                params.put("token", it.token)
            }
            params.put("id", "" + dressUpGoods.id)
            params.put("type", isDress)
        } else if (dressUpTab.id == 3) {//徽章
            requestUrl = Constants.GET_SETMYBADGE
            NineShowApplication.mUserBase?.let {
                params.put("token", it.token)
            }
            params.put("sort", frameBadgeStr)
        } else if (dressUpTab.id == 4) {//气泡
            requestUrl = Constants.GET_DRESSUP_BUBBLE
            params.put("id", dressUpGoods.id)
            params.put("type", isDress)
        } else if (dressUpTab.id == 5) {//资料卡
            requestUrl = Constants.GET_DRESSUP_INFOCARD
            params.put("id", dressUpGoods.id)
            params.put("type", isDress)
        } else if (dressUpTab.id == 6) {//麦位光圈
            requestUrl = Constants.GET_DRESSUP_MICCIRCLE
            params.put("id", dressUpGoods.id)
            params.put("type", isDress)
        } else if (dressUpTab.id == 7) {//进房
            requestUrl = Constants.GET_DRESSUP_ENTERROOM
            params.put("id", dressUpGoods.id)
            params.put("type", isDress)
        }

        if (requestUrl == null) {
            return
        }

        NsOkHttpClient.getNsOkHttpClient().doGet(requestUrl, params, object : NSGsonObjectNewCallback<BaseResultInfo?>() {
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: BaseResultInfo?) {
                if (response != null && response.code == 200) {
                    response.let { onSuccess.invoke(it) }
                    return
                }
                onFail?.invoke(statusCode, message)
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                onFail?.invoke(statusCode, errorMsg)
            }
        })
    }


    /**
     * 获取置顶卡的使用时间范围
     */
    fun getTimeList(date: String, gid: String, onSuccess: (TimePeriodResult) -> Unit, onFail: ((Int, String?) -> Unit)?) {
        val params = NSRequestParams()
        params.add("date", date)
        params.add("gid", gid)
        NsOkHttpClient.getNsOkHttpClient().doPost(Constants.GET_TIME_PERIODS_URL, params, object : NSGsonObjectNewCallback<TimePeriodResult?>() {
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: TimePeriodResult?) {
                if (response != null && response.code == 200) {
                    response.let { onSuccess.invoke(it) }
                    return
                }
                onFail?.invoke(statusCode, message)
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                onFail?.invoke(statusCode, errorMsg)
            }
        })
    }

    /**
     * 获取置顶卡的使用时间范围
     */
    fun userTopcard(rid: String, date: String, time: String, gid: String, onSuccess: (BaseResultInfo) -> Unit, onFail: ((Int, String?) -> Unit)?) {
        val params = NSRequestParams()
        params.add("rid", rid)
        params.add("date", date)
        params.add("time", time)
        params.add("gid", gid)
        NsOkHttpClient.getNsOkHttpClient().doPost(Constants.USE_TOPCARD, params, object : NSGsonObjectNewCallback<BaseResultInfo?>() {
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: BaseResultInfo?) {
                if (response != null && response.code == 200) {
                    response.let { onSuccess.invoke(it) }
                    return
                }
                onFail?.invoke(statusCode, message)
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                onFail?.invoke(statusCode, errorMsg)
            }
        })
    }


}