package com.ninexiu.sixninexiu.common.util

import android.text.TextUtils
import com.ninexiu.sixninexiu.bean.SvgGiftDownBean
import com.ninexiu.sixninexiu.common.AppCnfSpHelper
import com.ninexiu.sixninexiu.common.net.NSGsonObjectCallback
import com.ninexiu.sixninexiu.common.net.NsOkHttpClient
import java.lang.Exception
import java.util.concurrent.atomic.AtomicInteger

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/08/27
 *     desc   : 管理用户通过 https://api.9xiu.com/common/getGiftListBySvg 接口获取到的资源
 *
 *     giftList : 礼物图片
 *     svgaList : 礼物 svg
 *     mp4GiftList : 礼物 mp4
 *     mp4CarList : 座驾特效 mp4
 *
 *     version: 1.0
 * </pre>
 */
object AppInitDownloadResHelper {
    const val Tag = "AppInitDownloadResHelper"

    private var hasInit: Boolean = false

    // 全局变量
    var allList: SvgGiftDownBean? = null
        private set
        get() {
            if (!hasInit) {
                hasInit = true
                getAppInitGiftRes()     // 没有请求过接口的情况下,再请求一次
            }

            // 防止接口不是在最开始调用(如果不是最开始调用，先取缓存)
//            if (field == null) {
//                getResFromSave("field 为空") {
//                    field = it
//                }
//            }

            // NSLog.d(Tag, "获取所有数据 field : 礼物数据大小 : ${allList?.data?.giftList?.size ?: "null"} == ${auto.getAndIncrement()}")

            return field
        }

    // app 启动时获取所有
    fun getAppInitGiftRes(onSuccess: ((SvgGiftDownBean?) -> Unit)? = null) {
        NSLog.d(Tag, "接口请求 : 加载资源")
        hasInit = true

        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.HTTP_GET_GIFT_LIST_BYSVG, null, object : NSGsonObjectCallback<SvgGiftDownBean>() {
            override fun onSuccess(statusCode: Int, rawJsonResponse: String?, response: SvgGiftDownBean?) {

                if (response != null && response.code == 200 && response.data != null && !rawJsonResponse.isNullOrBlank()) {
                    NSLog.d(Tag, "接口请求 : 成功 -> 存储 & 礼物数据大小 ${response.data?.giftList?.size ?: "null"}")

                    // 存储
                    AppCnfSpHelper.getInstance().svgGiftList = rawJsonResponse
                    allList = response
                    // 返回数据
                    onSuccess?.invoke(response)
                    return
                }

                getResFromSave("返回数据为空", onSuccess)
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                NSLog.d(Tag, "onFailure : code : $statusCode , msg : $errorMsg")

                getResFromSave("接口请求失败", onSuccess)
            }
        })
    }

    // 使用存储数据
    private fun getResFromSave(msg: String, onSuccess: ((SvgGiftDownBean?) -> Unit)? = null) {
        val saveResponse = AppCnfSpHelper.getInstance().svgGiftList
        var allListTemp: SvgGiftDownBean? = null
        try {
            if (!TextUtils.isEmpty(saveResponse)) {
                allListTemp = GsonUtil.fromJson(saveResponse, SvgGiftDownBean::class.java)
            }

            if (allListTemp?.data != null) {
                NSLog.d(Tag, "缓存获取 : 成功 & 礼物数据大小 ${allList?.data?.giftList?.size ?: "null"} , from : $msg")
                allList = allListTemp
                onSuccess?.invoke(allListTemp)
                return
            }

        } catch (e: Exception) {
            NSLog.d(Tag, "exception : ${e.message}")
        }
        NSLog.d(Tag, "缓存获取 : 失败 , from : $msg")
        onSuccess?.invoke(null)
    }

    // 礼物面板数据集合
    private val giftMap = mutableMapOf<String, String>()        // Map : <gid , updateTime>

    // mp4 car
    private val carMp4Map = mutableMapOf<String, String>()

    const val GIFT_TYPE = 1                 // 礼物图片
    const val CAR_MP4_TYPE = 3              // 座驾特效 mp4


    /**
     * 初始化所有的礼物数据
     */
    fun initVersion(type: Int) {
        if (allList == null) {
            getResFromSave("init msg")
        }

        when (type) {
            GIFT_TYPE -> {

                for (gift in allList?.data?.giftList!!) {
                    giftMap[gift.gid] = gift.updatetime
                }

                for (gift in allList?.data?.svgaList!!) {
                    giftMap[gift.gid] = gift.updatetime
                }

                for (gift in allList?.data?.mp4GiftList!!) {
                    giftMap[gift.gid] = gift.updatetime
                }
            }
            CAR_MP4_TYPE -> {
                for (gift in allList?.data?.mp4CarList!!) {
                    carMp4Map[gift.gid] = gift.updatetime
                }
            }
        }

    }

    fun getVersion(gid: String?, type: Int): String {
        if (gid.isNullOrBlank()) {
            return ""
        }

        return when (type) {
            GIFT_TYPE -> {
                getSingleGiftVersion(type, gid, giftMap, allList?.data?.giftList) { theMap, item ->
                    item.gid?.let { theMap[it] = item.updatetime }

                }
                getSingleGiftVersion(type, gid, giftMap, allList?.data?.svgaList) { theMap, item ->
                    item.gid?.let { theMap[it] = item.updatetime }
                }
                getSingleGiftVersion(type, gid, giftMap, allList?.data?.mp4GiftList) { theMap, item ->
                    item.gid?.let { theMap[it] = item.updatetime }
                }
            }
            CAR_MP4_TYPE -> getSingleGiftVersion(type, gid, carMp4Map, allList?.data?.mp4CarList) { theMap, item ->
                item.gid?.let { theMap[it] = item.updatetime }
            }
            else -> ""
        }

    }

    // 匹配数据的version
    private fun <T> getSingleGiftVersion(type: Int, gid: String?, map: MutableMap<String, String>, list: List<T>?, iterator: (MutableMap<String, String>, T) -> Unit): String {
        if (gid.isNullOrBlank()) {
            return ""
        }

        // 如果map为空，进行缓存
        if (map.isEmpty() && list?.size ?: 0 > 0) {
            initVersion(type)
            list?.forEach {
                iterator.invoke(map, it)
            }
        }

        NSLog.d(Tag, "giftMap :  type : $type , $gid <==> ${map[gid]}")
        return map[gid] ?: ""
    }

}