package com.ninexiu.sixninexiu.common.util

import android.text.TextUtils
import android.util.Log
import com.ninexiu.sixninexiu.BuildConfig
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.bean.*
import com.ninexiu.sixninexiu.common.AppCnfSpHelper
import com.ninexiu.sixninexiu.common.net.*
import com.ninexiu.sixninexiu.common.util.svg.LiveSvgManager
import com.ninexiu.sixninexiu.values.Global
import java.util.*

/**
 * <pre>
 *     @author : bing
 *     time   : 2021/6/18
 *     desc   : 应用启动后，需要初始化请求的接口和下载的数据
 *     version: 1.0
 * </pre>
 */
class AppInitHelper {
    companion object {
        val INSTANCE: AppInitHelper by lazy(mode = LazyThreadSafetyMode.SYNCHRONIZED) {
            AppInitHelper()
        }
    }


    /**
     * 应用内的配置
     */
    fun getRoomSystemMessage(onConfigResult: ((systemConfigResult:RoomSystemMsgResult) -> Unit)? = null) {
        val asyncHttpClient = NSAsyncHttpClient.getInstance()
        val params = NSRequestParams()
        asyncHttpClient[Constants.NS_ROOM_APPCONF, params, object : NSJsonResponseHandler<RoomSystemMsgResultInfo?>() {
            override fun onSuccess(statusCode: Int, rawJsonResponse: String, response: RoomSystemMsgResultInfo?) {
                if (response != null && response.data != null) {
                    val mRoomSystemMsgResult = response.data
                    onConfigResult?.invoke(mRoomSystemMsgResult)
                    if (mRoomSystemMsgResult.priv != null && mRoomSystemMsgResult.priv.size > 0) { //房间系统消息有配置
                        NineShowApplication.setRoomSystemMessageList(mRoomSystemMsgResult.priv)
                    }
                    if (mRoomSystemMsgResult.chatWord != null
                            && mRoomSystemMsgResult.chatWord.size > 0) { //房间系统消息有配置
                        NineShowApplication.setHotWordList(response.data.chatWord)
                    }
                    NineShowApplication.isShowDouTu = mRoomSystemMsgResult.isDoupic
                    NineShowApplication.arAgencyAnchorAvatar = mRoomSystemMsgResult.oneArAnchorImg
                    NineShowApplication.personal_center_dressup_store_guide = mRoomSystemMsgResult.wearGuideTip
                    Global.SHOW_AUDIO_TAB = mRoomSystemMsgResult.show_audo_tag
                    if (mRoomSystemMsgResult.payType != null) { //支付方式
                        Global.ALIPAY_CHARGE_TYPE = mRoomSystemMsgResult.payType.ali_pay
                        Global.WEIXIN_CHARGE_TYPE = mRoomSystemMsgResult.payType.wx_pay
                    }
                    Log.d("SplashActivity", "common_status: " + mRoomSystemMsgResult.common_status)
                    if (!TextUtils.isEmpty(mRoomSystemMsgResult.short_video_url) && !BuildConfig.DEBUG) {
                        Constants.SHORT_VIDEO_URL = mRoomSystemMsgResult.short_video_url
                    }
                    AppCnfSpHelper.getInstance().showGameCenter = mRoomSystemMsgResult.show_game_sdk
                    AppCnfSpHelper.getInstance().activityNewYearSatus = mRoomSystemMsgResult.activity_2021newyear_status
                    AppCnfSpHelper.getInstance().activityStatusFor7_1_100th = mRoomSystemMsgResult.party_day_status
                    AppCnfSpHelper.getInstance().limitForLevelOne = mRoomSystemMsgResult.common_status
                    AppCnfSpHelper.getInstance().set8YearsState(mRoomSystemMsgResult.jubilee)
                    if (mRoomSystemMsgResult.topUserLevel != null && mRoomSystemMsgResult.topUserLevel.size > 0) { //自定义的等级图标
                        NineShowApplication.setUserCustomLevelList(mRoomSystemMsgResult.topUserLevel)
                    }
                }
            }

            override fun onFailure(statusCode: Int, errorMsg: String) {}
        }]
    }



    /**
     * 获取SVG礼物列表
     */
    fun getGiftListBySvg() {
        AppInitDownloadResHelper.getAppInitGiftRes { bean ->
            if(bean != null) {
                // 直播间大动画启动检查更新
                LiveSvgManager.get().downloadSvga()
            }
        }

        /*val params = NSRequestParams()
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.HTTP_GET_GIFT_LIST_BYSVG, params, object : NSGsonObjectCallback<SvgGiftDownBean?>() {
            override fun onSuccess(statusCode: Int, rawJsonResponse: String, response: SvgGiftDownBean?) {
                if (response != null && response.code == 200) {
                    AppCnfSpHelper.getInstance().svgGiftList = rawJsonResponse
                    *//**
                     * 直播间大动画启动检查更新
                     *//*
                    LiveSvgManager.get().downloadSvga()
                    *//**
                     * 礼物图片缓存
                     *//*
                    Thread(Runnable {
                        val giftPicDownManage = GiftPicDownManage.get()
                        if (response.data != null && response.data.giftList != null) {
                            for (bean in response.data.giftList) {
                                val status = giftPicDownManage.getDownloadFailureGift(bean.gid)
                                if (!TextUtils.equals(status, bean.updatetime) && !TextUtils.equals(bean.isshow, "0")) {
                                    giftPicDownManage.putDownloadFailureGift(bean.gid, bean.updatetime)
                                    try {
                                        val cache = Utils.getCachDir()
                                        Utils.downloadFile(cache, Constants.LIVE__ROOM_CHAT_URL + bean.gid + ".png?v=" + bean.updatetime, true)
                                    } catch (e: Exception) {
                                        e.printStackTrace()
                                    }
                                }
                            }
                        }
                        if (response.data != null && response.data.svgaList != null) {
                            for (bean in response.data.svgaList) {
                                val status = giftPicDownManage.getDownloadFailureGift(bean.gid)
                                if (!TextUtils.equals(status, bean.updatetime) && !TextUtils.equals(bean.isshow, "0")) {
                                    giftPicDownManage.putDownloadFailureGift(bean.gid, bean.updatetime)
                                    try {
                                        val cache = Utils.getCachDir()
                                        Utils.downloadFile(cache, Constants.LIVE__ROOM_CHAT_URL + bean.gid + ".png?v=" + bean.updatetime, true)
                                    } catch (e: Exception) {
                                        e.printStackTrace()
                                    }
                                }
                            }
                        }
                    }).start()
                }
            }

            override fun onFailure(statusCode: Int, errorMsg: String) {}
        })*/
    }


    /**
     * 系统任务徽章列表(默认的用户徽章集合，灰色的)
     */
    fun getSystemBadgesData() {
        val params = NSRequestParams()
        val url = Constants.GET_DEFAULT_BADGES_URL //系统任务徽章列表
        NSAsyncHttpClient.getInstance()[url, params, object : NSJsonResponseHandler<BadgesResult?>() {
            override fun onSuccess(statusCode: Int, rawJsonResponse: String, response: BadgesResult?) {
                if (response != null && response.data != null) {
                    storeDefaultBadgeUrls(response.data)
                }
            }

            override fun onFailure(statusCode: Int, errorMsg: String) {}
        }]
    }

    private fun storeDefaultBadgeUrls(badgesData: BadgesData) {
        val badgeUrls: MutableList<String> = ArrayList()
        val badges = badgesData.actBageList
        if (badges != null && badges.size > 0) {
            for (i in badges.indices) {
                badgeUrls.add(badges[i].url)
            }
        }
        val taskBadges = badgesData.userBadgeList
        if (taskBadges != null && taskBadges.size > 0) {
            for (i in taskBadges.indices) {
                badgeUrls.add(taskBadges[i].url + "?9696") //任务徽章随便加个后缀 请求到96*96 的图图片
            }
        }
        Utils.storeDefaultBadgeUrls(badgeUrls)
    }


    /**
     * 获取跳转的房间信息,随机跳转房间
     * @param roomId
     */
    fun getRoominfo(roomId: String, roomInfoCallBack:((roomInfo:RoomInfo)->Unit)?=null) {
        val params = NSRequestParams()
        params.put("rid", roomId)
        NSAsyncHttpClient.getInstance()[Constants.HTTP_GET_ROOMINFO, params, object : NSJsonResponseHandler<EnterRoomResultInfo?>() {
            override fun onSuccess(statusCode: Int, rawJsonResponse: String,
                          response: EnterRoomResultInfo?) {
                if (response != null) {
                    roomInfoCallBack?.invoke(response.data)
                }
            }

            override fun onFailure(statusCode: Int, errorMsg: String) {}
        }]
    }






}