package com.ninexiu.sixninexiu.common.util.CountTechnology

import android.content.Context
import android.text.TextUtils

import cn.thinkingdata.android.TDConfig
import cn.thinkingdata.android.ThinkingAnalyticsSDK
import com.ninexiu.sixninexiu.BuildConfig
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.bean.RoomInfo
import com.ninexiu.sixninexiu.common.util.DeviceInfoHelper
import com.ninexiu.sixninexiu.common.util.TimeUtil
import java.util.ArrayList
import org.json.JSONException
import org.json.JSONObject
import cn.thinkingdata.android.TDFirstEvent
import cn.thinkingdata.android.utils.TDLog
import com.ninexiu.sixninexiu.common.util.NSLog
import com.ninexiu.sixninexiu.common.util.Utils

/**
 *
 * @CreateDate: 2021/5/16 17:58
 * @Author:     wangyu
 * @Description: 数数科技事件上传(注：此类中上传数据类型不能轻易修改，一旦修改第三方SDK会录入数据库失败)
 * @Version:    1.0
 */
object TDTracker{
    const val Tag = "TDTracker"

//    val TA_APP_ID = "c28d63ff09d04e69ac1bf59cbcef416e"
    val TA_APP_ID = "debug-appid"
    private var enterTime: String? = null
    private var enterWhile: Long = -1L
    var loginWhile: Long = 0//登录时刻

    /**
     * 数据上传地址
     * 如果您使用的是云服务，请输入以下URL:
     * http://receiver.ta.thinkingdata.cn:9080
     * 如果您使用的是私有化部署的版本，请输入以下URL:
     * http://数据采集地址:9080
     */
    //    private static final String TA_SERVER_URL = "https://sdk.tga.thinkinggame.cn";
    private val TA_SERVER_URL = "http://receiver.ta.9xiu.com/logbus"

//    companion object {
//        private var tdinstance: TDTracker? = null
//            get() {
//                if (field == null) {
//                    field = TDTracker()
//                }
//                return field
//            }
//
//        @Synchronized
//        fun get(): TDTracker {
//            return tdinstance!!
//        }
//    }

    var instance: ThinkingAnalyticsSDK? = null
    private set

    /** 初始化 TA SDK  */
    fun initThinkingDataSDK(context: Context) {
        val config = TDConfig.getInstance(context, TA_APP_ID, TA_SERVER_URL)
        //        config.setMode(TDConfig.ModeEnum.DEBUG);
        instance = ThinkingAnalyticsSDK.sharedInstance(config)
        ThinkingAnalyticsSDK.enableTrackLog(BuildConfig.DEBUG)
        //初始化统计事件集合
        TDEventMap.init(-1)
        TDEventMap.initialTable()

        /**
         * 设置测试环境输出日志
         */
        TDLog.setEnableLog(BuildConfig.DEBUG)

        enableAutoTrack()
    }

    /**
     * 开启自动采集事件
     */
    private fun enableAutoTrack() {
        val typeList = ArrayList<ThinkingAnalyticsSDK.AutoTrackEventType>()
        typeList.add(ThinkingAnalyticsSDK.AutoTrackEventType.APP_START) //启动
        typeList.add(ThinkingAnalyticsSDK.AutoTrackEventType.APP_INSTALL) //安装
        typeList.add(ThinkingAnalyticsSDK.AutoTrackEventType.APP_END) //关闭
        typeList.add(ThinkingAnalyticsSDK.AutoTrackEventType.APP_CRASH) //崩溃
        //        typeList.add(ThinkingAnalyticsSDK.AutoTrackEventType.APP_CLICK) //控件点击
        instance?.enableAutoTrack(typeList)
    }

    /**
     * 上报直播间引导事件
     */
    fun setRoomGuideEvent() {
        val guideObject = JSONObject()
        try {
            guideObject.put("guide_start_time", TimeUtil.getFormatTime())
            guideObject.put("guide_name", "直播间引导")
            NSLog.d("上报直播间引导事件 $guideObject")
            instance?.track(TDEventName.LIVEROOM_STARTGUIDE, guideObject)
        } catch (e: JSONException) {
        }
    }

    /**
     * 上报进入直播间事件
     */
    fun setEnterRoomEvent(source: String, roomInfo: RoomInfo?) {
        enterTime = TimeUtil.getFormatTime()
        enterWhile = System.currentTimeMillis()
        val enterRoomObject = JSONObject()
        try {
            enterRoomObject.put("stage_id", roomInfo?.rid)
            enterRoomObject.put("stage_name", roomInfo?.nickname)
            enterRoomObject.put("stage_type", roomInfo?.roomType)
            enterRoomObject.put("streamer_id", roomInfo?.artistuid)
            enterRoomObject.put("streamer_name", roomInfo?.nickname)
            enterRoomObject.put("enter_room_from", source)
            instance?.track(TDEventName.ENTER_LIVEROOM, enterRoomObject)
        } catch (e: JSONException) {
        }
    }

    /**
     * 上报离开直播间事件
     */
    fun setOutRoomEvent(roomInfo: RoomInfo?) {
        if(enterWhile >0){
            val outRoomObject = JSONObject()
            try {
                var watchDuration = System.currentTimeMillis() - enterWhile
                outRoomObject.put("stage_id", roomInfo?.rid)
                outRoomObject.put("stage_name", roomInfo?.nickname)
                outRoomObject.put("stage_type", roomInfo?.roomType)
                outRoomObject.put("streamer_id", roomInfo?.artistuid)
                outRoomObject.put("streamer_name", roomInfo?.nickname)
                outRoomObject.put("watch_duration", watchDuration/1000)
                outRoomObject.put("enter_time", enterTime)
                enterWhile = -1L
                instance?.track(TDEventName.OUT_LIVEROOM, outRoomObject)
            } catch (e: JSONException) {
            }
        }
    }

    /**
     * 上报直播间聊天聊天事件
     */
    fun setLiveChatEvent(type: String, message_content: String?, roomInfo: RoomInfo?) {
        if(enterWhile >0) {
            val liveChatObject = JSONObject()
            try {
                var watchDuration = System.currentTimeMillis() - enterWhile
                liveChatObject.put("stage_id", roomInfo?.rid)
                liveChatObject.put("stage_name", roomInfo?.nickname)
                liveChatObject.put("stage_type", roomInfo?.roomType)
                liveChatObject.put("streamer_id", roomInfo?.artistuid)
                liveChatObject.put("streamer_name", roomInfo?.nickname)
                liveChatObject.put("enter_time", enterTime)
                liveChatObject.put("watch_duration", watchDuration / 1000)
                liveChatObject.put("message_content", message_content)
                liveChatObject.put("message_type", type)
                enterWhile = -1L
//            liveChatObject.put("live_id", roomInfo?.live_id)
                instance?.track(TDEventName.SEND_LIVE_MESSAGE, liveChatObject)
            } catch (e: JSONException) {
            }
        }
    }

    /**
     * 上报各个功能数据模块数据
     * type 0首页模块 1发现模块 3 关注模块 4我的模块 5离开或者开启新的直播间
     */
    fun sendFunctionDataEvent(type: Int) {
        val functionObject = JSONObject()
        var tdFunctionName: String? = null
        try {
            when (type) {
                0 -> {
                    val liveEventMap = TDEventMap.liveEventMap
                    for (kk in liveEventMap.keys) {
                        functionObject.put(kk, liveEventMap[kk])
                    }
                    tdFunctionName = "Live"
                }

                1 -> {
                    val findEventMap = TDEventMap.findEventMap
                    for (kk in findEventMap.keys) {
                        functionObject.put(kk, findEventMap[kk])
                    }
                    tdFunctionName = "Find"
                }

                3 -> {
                    val attentionEventMap = TDEventMap.attentionEventMap
                    for (kk in attentionEventMap.keys) {
                        functionObject.put(kk, attentionEventMap[kk])
                    }
                    tdFunctionName = "Concern"
                }

                4 -> {
                    val mineEventMap = TDEventMap.mineEventMap
                    for (kk in mineEventMap.keys) {
                        functionObject.put(kk, mineEventMap[kk])
                    }
                    tdFunctionName = "Mine"
                }

                5 -> {
                    val liveRoomEventMap = TDEventMap.liveRoomEventMap
                    for (kk in liveRoomEventMap.keys) {
                        functionObject.put(kk, liveRoomEventMap[kk])
                    }

                    tdFunctionName = "Live_Room"
                }
            }

            instance?.track(tdFunctionName, functionObject)
        } catch (e: JSONException) {
        } finally {
            //重置统计事件集合
            TDEventMap.init(type)
        }
    }


    /**
     * 上报各个table按钮点击次数统计
     */
    fun sendTableDataEvent() {
        val tabObject = JSONObject()
        val tabEventMap = TDEventMap.tableEventMap
        for (kk in tabEventMap.keys) {
            tabObject.put(kk, tabEventMap[kk])
        }
        instance?.track("Tab", tabObject)
        TDEventMap.initialTable()
    }

    /**
     * 上报用户登录及用户Id
     */
    fun login(uid: String) {
        instance?.login(uid)
        loginWhile = System.currentTimeMillis()
        publicEventProperty()       // 上传公共属性
    }

    /**
     * 退出登录
     */
    fun logOut() {
        val properties = JSONObject()
        properties.put("last_login_time", TimeUtil.getFormatTime())
        instance?.user_set(properties)
        instance?.logout()
    }

    /**
     * 记录登录时长上报
     */
    fun setLoginDuation() {

        try {
            //未登录不上报
            NineShowApplication.mUserBase?.let {
                val sessionTimeObject = JSONObject()
                var watchDuration = System.currentTimeMillis() - loginWhile
                sessionTimeObject.put("user_add", watchDuration / 1000)
                NSLog.d("上报设备新增, $sessionTimeObject")
                instance?.track(TDEventName.CURRENT_SESSION_TIME, sessionTimeObject)
            }
        } catch (e: JSONException) {
        } finally {
            loginWhile = System.currentTimeMillis()
        }
    }

    // 新增设备
    fun setUp() {
        // 上报设备新增：上报用户账号的首次事件, 事件名为 TDEventName.DEVICE_FIRST
        val properties = JSONObject()
        val deviceId = encodeHeadInfo(DeviceInfoHelper.getInstance().sDeviceInfo?.getDeviceId())
        if(!TextUtils.isEmpty(deviceId)) {
            try {
                properties.put("new_device", deviceId)
            } catch (e: JSONException) {
                e.printStackTrace()
            }

            val firstEvent = TDFirstEvent(TDEventName.DEVICE_FIRST, properties)
            firstEvent.setFirstCheckId(deviceId)
            instance?.track(firstEvent)
        }
    }

    // 上传公共属性
    fun publicEventProperty(){
        try {
            // 公共属性
            val superProperties = JSONObject()
            NineShowApplication.mUserBase?.let {
                try {
                    instance?.login(it.uid.toString())
                    // 将用户 ID 设置为首次事件的 FIRST_CHECK_ID

                    loginWhile = System.currentTimeMillis()
                    //设置用户属性上报
                    superProperties.put("role_name", it.nickname) //名称
                    superProperties.put("vip_level", it.viplevel) //vip等级
                    superProperties.put("gold", it.money) //九币
                    superProperties.put("tokenCoin", it.tokencoin) //九点
                } catch (e: JSONException) {
                    e.printStackTrace()
                }
            }
            superProperties.put("channel", encodeHeadInfo(DeviceInfoHelper.getInstance().sDeviceInfo?.getChanel())) //登录渠道
            superProperties.put("device_id", encodeHeadInfo(DeviceInfoHelper.getInstance().sDeviceInfo?.getDeviceId())) //设备ID
            superProperties.put("app_version", encodeHeadInfo(DeviceInfoHelper.getInstance().sDeviceInfo?.getVersionName())) //app版本
            superProperties.put("os_version", encodeHeadInfo(DeviceInfoHelper.getInstance().sDeviceInfo?.getDeviceOsVer())) //app系统
            superProperties.put("os", "1") //操作系统
            instance?.superProperties = superProperties
        }catch (e : JSONException) {
            NSLog.d(Tag, e.message)
        }
    }

    fun playXXLGame(roomId: String,uid: String,stageType :String,enterTime: Long){
        val liveChatObject = JSONObject()
        try {
            val dissTime = System.currentTimeMillis() / 1000 - enterTime / 1000
            liveChatObject.put("stage_id",roomId)
            liveChatObject.put("streamer_id",uid)
            liveChatObject.put("stage_type",stageType)
            liveChatObject.put("click_xxl_time",Utils.getDateOfMillis(enterTime))
            liveChatObject.put("play_xxl_duration",dissTime)
            instance?.track(TDEventName.PALY_XIAOXIAOLE, liveChatObject)
        } catch (e: JSONException) {
        }
    }

    /*UserAgent问题*/
    private fun encodeHeadInfo(headInfo: String?): String {
        if (headInfo == null) {
            return ""
        }
        val stringBuffer = StringBuffer()
        var i = 0
        val length = headInfo.length
        while (i < length) {
            val c = headInfo[i]
            if (c <= '\u001f' || c >= '\u007f') {
                stringBuffer.append(String.format("\\u%04x", c.toInt()))
            } else {
                stringBuffer.append(c)
            }
            i++
        }
        return stringBuffer.toString()
    }
}
