package com.ninexiu.sixninexiu.common.util

import android.annotation.SuppressLint
import android.content.Context
import android.graphics.Typeface
import android.os.Build
import android.text.TextUtils
import androidx.annotation.RequiresApi
import com.google.gson.GsonBuilder
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.bean.*
import com.ninexiu.sixninexiu.common.AppCnfSpHelper
import com.ninexiu.sixninexiu.common.net.NSGsonObjectNewCallback
import com.ninexiu.sixninexiu.common.net.NSRequestParams
import com.ninexiu.sixninexiu.common.net.NsOkHttpClient
import io.reactivex.Observable
import io.reactivex.ObservableEmitter
import io.reactivex.ObservableOnSubscribe
import io.reactivex.Observer
import io.reactivex.android.schedulers.AndroidSchedulers
import io.reactivex.disposables.Disposable
import io.reactivex.schedulers.Schedulers
import org.json.JSONObject
import java.util.*
import java.util.function.Consumer
import kotlin.collections.ArrayList
import kotlin.reflect.jvm.internal.impl.load.java.typeEnhancement.`TypeEnhancementKt$WhenMappings`

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/06/23
 *     desc   : 热门帮助类 : 接口请求,数据处理
 *     version: 1.0
 * </pre>
 */
object HomeHotHelper {
    const val Tag = "HomeHotHelper"

    private const val SIZE_EXCEL_RECOMMEND = 4
    private const val SIZE_RECOMMEND = 6
    private const val SIZE_NEW = 4
    private const val SIZE_LABEL_MIN = 3

    // 启动的时候加载一次热门标签即可
    private var firstLoadLabelData = true

    /**
     * 获取所有的数据
     * 1. 成功返回数据 并 进行存储
     * 2. 获取数据失败 :
     *          code = 5201 -> 封禁
     *          其他原因 -> 尝试拿存储的数据进行处理
     */
    fun getAllCategoryData(onSuccess: (MoreTypeResultInfo) -> Unit, onFail: ((Int, String?, BanUniversalBean?) -> Unit)? = null) {
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.HOT_NEW_CHANNEL, null, object : NSGsonObjectNewCallback<MoreTypeResultInfo>() {
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: MoreTypeResultInfo?) {
                NSLog.d(Tag, "statusCode : $statusCode , errorMsg : $message")

                // 正常数据
                if (statusCode == 200 && response != null && response.data != null) {
                    // 1. 存储数据
                    saveAllCategoryData(response)
                    // 2. 返回数据
                    onSuccess.invoke(response)
                    return
                }

                // 封禁
                if (statusCode == 5201 && responseString != null) {
                    // 返回封禁数据
                    val ban = BanUniversalBean()
                    try {
                        val obj = JSONObject(responseString)
                        val data = obj.optJSONObject("data")

                        if (data != null) {
                            ban.type = if (data.optInt("is_register", 0) == 1) 3 else 1
                            ban.banReason = data.optString("msg")
                            ban.beatyNumber = data.optString("accountid")
                            ban.nickName = data.optString("nickname")
                            ban.uid = data.optString("uid")
                            ban.unBlockTime = data.optString("removeTm")
                        }
                    } catch (e: Exception) {
                        NSLog.d(Tag, e.message ?: "parse error")
                    } finally {
                        onFail?.invoke(statusCode, message, ban)      // 外面显示封禁dialog
                    }
                    return
                }

                // 1. 获取存储数据
                val saveData = getSaveAllCategoryData()
                // 2. 返回数据处理结果 -> 成功返回 ，失败外层处理
                if (saveData != null) onSuccess.invoke(saveData) else onFail?.invoke(statusCode, message, null)
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                NSLog.d(Tag, "statusCode : $statusCode , errorMsg : $errorMsg")

                // 1. 获取存储数据
                val saveData = getSaveAllCategoryData()
                // 2. 返回数据处理结果 -> 成功返回 ，失败外层处理
                if (saveData != null) onSuccess.invoke(saveData) else onFail?.invoke(statusCode, errorMsg, null)
            }
        })
    }

    /**
     * 加载所有的标签数据 : 音乐，舞蹈，娱乐，视频，校园
     */
    fun getAllLabelData(onSuccess: ((HomeTagInfo) -> Unit)? = null, onError: ((Int, String?) -> Unit)? = null) {
        if (firstLoadLabelData) {        // app 启动时候加载一次，进行保存即可
            firstLoadLabelData = false
            NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_HOMETAG_LIST, null, object : NSGsonObjectNewCallback<HomeTagInfo>() {
                override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: HomeTagInfo?) {
                    if (statusCode == 200 && response != null) {
                        // 存储，返回
                        responseString?.let {
                            NineShowOtherHttpManager.getInstance().homeTag = it
                        }
                        onSuccess?.invoke(response)
                        return
                    }
                    getSaveLabelData(onSuccess, onError, statusCode, message)
                }

                override fun onFailure(statusCode: Int, errorMsg: String?) {
                    getSaveLabelData(onSuccess, onError, statusCode, errorMsg)
                }

            })
        } else {
            getSaveLabelData(onSuccess, onError, -1, "网络错误")
        }
    }

    /**
     * 加载轮播图数据
     */
    fun getAllBannerData(onSuccess: (AdvertiseResultInfo) -> Unit, onFail: ((Int, String?) -> Unit)? = null) {
        val params = NSRequestParams()
        params.put("banner_type", 1)
        params.put("position", 5)
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_AD_LIST, params, object : NSGsonObjectNewCallback<AdvertiseResultInfo>() {
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: AdvertiseResultInfo?) {
                if (statusCode == 200 && response != null) {
                    onSuccess.invoke(response)
                    return
                }
                onFail?.invoke(statusCode, message)
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                onFail?.invoke(statusCode, errorMsg)
            }
        })
    }

    /**
     * 获取热门分页数据
     */
    fun getCategoryHotData(page: Int, onSuccess: (MoreTypeResultInfo) -> Unit, onFail: ((Int, String?) -> Unit)?) {
        val params = NSRequestParams()
        params.put("page", page)
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.HOT_NEW_PAGE, params, object : NSGsonObjectNewCallback<MoreTypeResultInfo>() {
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: MoreTypeResultInfo?) {
                if (statusCode == 200 && response != null) {
                    onSuccess.invoke(response)
                    return
                }
                onFail?.invoke(statusCode, message)
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                onFail?.invoke(statusCode, errorMsg)
            }
        })
    }


    /**
     * 获取刷新的内容创建营数据
     */
    fun getCategoryCardData(cateType: String? = null, onSuccess: (MoreTypeResultInfo) -> Unit, onFail: ((Int, String?) -> Unit)? = null) {
        val params=NSRequestParams()
        cateType?.let {
            params.put("card_type",cateType)
        }
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_CONTENTTALENT_GETUSECARDROOM, params, object : NSGsonObjectNewCallback<MoreTypeResultInfo>() {
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: MoreTypeResultInfo?) {
                if (statusCode == 200 && response != null) {
                    onSuccess.invoke(response)
                    return
                }
                onFail?.invoke(statusCode, message)
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                onFail?.invoke(statusCode, errorMsg)
            }

        })
    }

    /**
     * 接口方法
     * ======================== ======================== ======================== ======================== ========================
     * 工具方法
     */

    private const val DEAL_TAG = "dealTag"

    // 对所有分类数据按规则处理
    fun dealAllCategoryData(allCategoryInfo: MoreTypeResultInfo?): MoreTypeResultInfo? {
        if (allCategoryInfo == null || allCategoryInfo.data == null) {
            return null
        }
        val data = allCategoryInfo.data

        var recommendExcelData: MutableList<AnchorInfo>? = data.excelRecommend
        val recommendData: MutableList<AnchorInfo>? = data.recommend
        val cardData: MutableList<AnchorInfo>? = data.useCardRoom
        val room666: MutableList<AnchorInfo>? = data.room666
        val room999: MutableList<AnchorInfo>? = data.room999
        val newData: MutableList<AnchorInfo>? = data.newRecommend
        val hotData: MutableList<AnchorInfo>? = data.hot

        /* NSLog.d(DEAL_TAG, "精选推荐数据 size : ${recommendExcelData?.size ?: -1}")
         NSLog.d(DEAL_TAG, "推荐数据 size : ${recommendData?.size ?: -1}")
         NSLog.d(DEAL_TAG, "卡片数据 size : ${cardData?.size ?: -1}")
         NSLog.d(DEAL_TAG, "活动房666 数据 size : ${room666?.size ?: -1}")
         NSLog.d(DEAL_TAG, "活动房999 数据 size : ${room999?.size ?: -1}")
         NSLog.d(DEAL_TAG, "热门数据 size : ${hotData?.size ?: -1}")*/

        // 0 . 先将卡片数据和其他模块数据都做一次过滤
        if(!cardData.isNullOrEmpty()) {
            filterRecommentExcelAndHotData(recommendExcelData,cardData,"卡片和精选推荐")
            filterRecommentExcelAndHotData(recommendData,cardData,"卡片和推荐")
            filterRecommentExcelAndHotData(room666,cardData,"卡片和666")
            filterRecommentExcelAndHotData(room999,cardData,"卡片和999")
            filterRecommentExcelAndHotData(newData,cardData,"卡片和新人")
            filterRecommentExcelAndHotData(hotData,cardData,"卡片和热门")
        }

        if(recommendExcelData == null) {
            recommendExcelData = mutableListOf()
        }

        // 1. 设置精选推荐数据 ---------- 推荐数据置顶放在第一位 & 卡片数据放在第二位 & 数据不够从热门拉取(热门大于10个)

        // 推荐 -> 精选推荐
        if (!recommendData.isNullOrEmpty()) {
            var indexTemp = -1
            for ((index, info) in recommendData.withIndex()) {
                if (info.isTop == 1) {
                    indexTemp = index
                    break
                }
            }

            if (indexTemp != -1) {
                val info = recommendData.removeAt(indexTemp)
                recommendExcelData.add(0, info)
                NSLog.d(DEAL_TAG, "change : 推荐 -> 精选推荐")
            }
        }

        // 卡片 -> 精选推荐
        if (!cardData.isNullOrEmpty() && recommendExcelData.size > 1) {
            val info = cardData.removeAt(0)
            recommendExcelData.add(1, info)
            NSLog.d(DEAL_TAG, "change : 卡片 -> 精选推荐")
        }

        // 热门补充 -> 精选推荐
        otherCategoryGetDataFromHot(hotData, recommendExcelData, 4, "change : 热门 -> 精选推荐")

        // ==================

        // 过滤精选推荐和推荐数据，防止数据重复
        filterRecommentExcelAndHotData(recommendExcelData,recommendData,"精选推荐和推荐")

        // 2. 设置推荐数据 ---------- 活动房和卡片房共同占据前两个位置 & 数据不够从热门拉取(热门大于10个)

        val needSize = 2

        if (recommendData != null) {
            // 活动房666和999 目前的总size,如果小于needSize,说明要从卡片模块移送数据到推荐模块
            val nowHaveSize = room666?.size ?: 0 + (room999?.size ?: 0)

            // 卡片 -> 推荐
            if (nowHaveSize < needSize && !cardData.isNullOrEmpty()) {
                translateCategoryData(cardData, recommendData, needSize - nowHaveSize, "change : 卡片 -> 推荐")
            }

            // 活动房999 -> 推荐
            if (!room999.isNullOrEmpty()) {
                translateCategoryData(room999, recommendData, needSize, "change : 活动房999 -> 推荐")
            }

            // 活动房666 -> 推荐
            if (!room666.isNullOrEmpty()) {
                translateCategoryData(room666, recommendData, needSize, "change : 活动房666 -> 推荐")
            }

            // 热门补充 -> 推荐
            otherCategoryGetDataFromHot(hotData, recommendData, 6, "change : 热门 -> 推荐")
        }

        // 3. 设置新人数据 ---------- 卡片数据占据前两个位置
        if (newData != null) {
            // 卡片 ->  新人
            if (!cardData.isNullOrEmpty()) {
                translateCategoryData(cardData, newData, needSize, "change : 卡片 -> 新人")
            }

            // 热门补充 -> 新人
            otherCategoryGetDataFromHot(hotData, newData, 6, "change : 热门 -> 新人")
        }

        // 4. 热门和卡片的数据进行整合
        mergeCategoryHotAndCard(hotData, cardData)
        return allCategoryInfo
    }


    // 合并热门和卡片数据  热门是否大于20条数据 : 是(热门前20位置，卡片随机10个，剩余卡片隔两条插入一条) , 否(隔两条插入一条卡片数据)
    private fun mergeCategoryHotAndCard(hotData: MutableList<AnchorInfo>?, cardData: MutableList<AnchorInfo>?) {
        if (hotData.isNullOrEmpty() || cardData.isNullOrEmpty()) {
            return
        }

        val templeList = arrayListOf<AnchorInfo>()

        if (hotData.size > 20) {
            // 热门大于20条数据 : 热门前20位置，卡片随机10个，剩余卡片隔两条插入一条
            translateCategoryData(hotData, templeList, 10, "change : 卡片和热门合并 -> 热门转向临时集合10条数据")
            translateCategoryData(cardData, templeList, 10, "change : 卡片和热门合并 -> 卡片转向临时集合若干条数据")
            templeList.shuffle()
        }

        while (cardData.size > 0 && hotData.size > 0) {
            // 隔两条插入一条数据
            templeList.add(hotData.removeAt(0))
            templeList.add(hotData.removeAt(0))
            templeList.add(cardData.removeAt(0))
        }

        templeList.addAll(hotData)
        templeList.addAll(cardData)

        hotData.clear()

        // 热门小于等于20条数据 : 隔两条插入一条卡片数据
        hotData.addAll(templeList)
    }

    // 数据从一个分类向另一个分类转移
    private fun translateCategoryData(sourceData: MutableList<AnchorInfo>, destData: MutableList<AnchorInfo>, needSize: Int, msg: String): MutableList<AnchorInfo> {
        if (sourceData.isNullOrEmpty()) {
            return destData
        }

        val minSize = needSize.coerceAtMost(sourceData.size)
        for (index in 0 until minSize) {     // 转移数据
            val data = sourceData.removeAt(0)
            destData.add(0, data)
        }

        NSLog.d(DEAL_TAG, "$msg , size = $minSize")

        return destData
    }

    // 热门模块向其他模块补充数据
    private fun otherCategoryGetDataFromHot(hotData: MutableList<AnchorInfo>?, destData: MutableList<AnchorInfo>, maxSize: Int, msg: String): MutableList<AnchorInfo> {
        // 数据过滤 ------------- 过滤推荐和热门中的重复数据
        if (!destData.isNullOrEmpty() && !hotData.isNullOrEmpty()) {
            filterRecommentExcelAndHotData(destData, hotData, msg)
        }

        if (destData.size >= maxSize) {
            return destData
        }

        // 热门模块数量少于10个，不向其他模块补充
        if (hotData.isNullOrEmpty() || hotData.size < 10) {
            NSLog.d(DEAL_TAG, "$msg  : 热门数据不足 10 个")
            return destData
        }

        val needSize = maxSize - destData.size
        val minSize = Math.min(needSize, hotData.size)

        for (index in 0 until minSize) {
            val data = hotData.removeAt(0)
            destData.add(data)
        }

        NSLog.d(DEAL_TAG, "$msg  : 热门数据剩余 ${hotData.size}")
        return destData
    }


    // 过滤热门和其他模块中的重复数据(删除热门中和其他模块重复的数据)
    private fun filterRecommentExcelAndHotData(filterData: MutableList<AnchorInfo>?, hotData: MutableList<AnchorInfo>?, msg: String) {
        if (filterData.isNullOrEmpty() || hotData.isNullOrEmpty()) {
            return
        }
        val tempList = arrayListOf<AnchorInfo>()
        for (recommendAnchor in filterData) {
            for (hotAnchor in hotData) {
                if (TextUtils.equals(hotAnchor.uid, recommendAnchor.uid)) {
                    tempList.add(hotAnchor)
                }
            }
        }

        if (tempList.isNullOrEmpty()) {
            return
        }

        for (removeItem in tempList) {
            NSLog.d(DEAL_TAG, "过滤 : $msg : 移除 -> ${removeItem.uid}")
            hotData.remove(removeItem)
        }
    }

    // 对所有分类数据的随机处理
    fun doRandomAllCategoryData(allCategoryInfo: MoreTypeResultInfo?): MoreTypeResultInfo? {
        if (allCategoryInfo == null || allCategoryInfo.data == null) {
            return null
        }

        val data = allCategoryInfo.data
        // 对分类数据中的 精选，推荐，新人，热门，内容创造营进行随机处理
        with(data) {
            excelRecommend?.shuffle()
            recommend?.shuffle()
            newRecommend?.shuffle()
            hot?.shuffle()
            useCardRoom?.shuffle()
        }
        return allCategoryInfo
    }

    // todo : 将主播数据和标题，标签，banner 进行处理组合
    @SuppressLint("CheckResult")
    fun dealAllHomeInfo(allCategoryInfo: MoreTypeResultInfo?, labelInfos: HomeTagInfo?, bannerInfos: AdvertiseResultInfo?, consumer: (ArrayList<HomeInfo>) -> Unit) {
        var index = 0
        val list = ArrayList<HomeInfo>()
        Observable.create<ArrayList<HomeInfo>> {
            it.onNext(list)
        }.map {
            val data = allCategoryInfo?.data
            val excelRecommendData = data?.excelRecommend
            val hotData = data?.hot
            val recommend = data?.recommend
            val newRecommend = data?.newRecommend
            // 精选不满足,只显示热门数据
            if (excelRecommendData.isNullOrEmpty() || excelRecommendData.size < SIZE_EXCEL_RECOMMEND) {
                if (!hotData.isNullOrEmpty()) {
                    val titleInfoHot = HomeInfo()
                    titleInfoHot.titleInfo = HomeTitleInfo(name = "热门", imgRes = R.drawable.hot_hall_hot_icon)
                    titleInfoHot.dealWithType = HomeInfo.TYPE_HOT
                    it.add(titleInfoHot)

                    hotData.forEach { info ->
                        val anchorInfoHot = HomeInfo()
                        anchorInfoHot.addAnchorInfoByIndex(info, index++)
                        anchorInfoHot.dealWithType = HomeInfo.TYPE_HOT
                        anchorInfoHot.currentType = HomeInfo.TYPE_ANCHOR
                        it.add(anchorInfoHot)
                    }

                }
            } else {
                if (!excelRecommendData.isNullOrEmpty() && excelRecommendData.size >= SIZE_EXCEL_RECOMMEND) {
                    // 添加精选推荐
                    /* val titleInfoExcelRecommend = HomeInfo()
                     titleInfoExcelRecommend.titleInfo = HomeTitleInfo(name = "精选推荐", imgRes = R.drawable.fragment_live_tuijian_icon, arrowShow = false, isExcelRecommend = true)
                     titleInfoExcelRecommend.dealWithType = HomeInfo.TYPE_EXCEL_RECOMMEND
                     it.add(titleInfoExcelRecommend)*/

                    /* val anchorInfoExcelRecommend = HomeInfo()
                     anchorInfoExcelRecommend.anchorExcelRecommend = excelRecommendData.filterIndexed { index, _ -> index < SIZE_EXCEL_RECOMMEND }
                     anchorInfoExcelRecommend.currentType = HomeInfo.TYPE_EXCEL_RECOMMEND
                     anchorInfoExcelRecommend.dealWithType = HomeInfo.TYPE_EXCEL_RECOMMEND
                     it.add(anchorInfoExcelRecommend)*/

                    // 如果后期精选推荐的背景去除，和其他模块保持统一，推荐使用这种写法
                    excelRecommendData.filterIndexed { index, _ -> index < SIZE_EXCEL_RECOMMEND }.forEach { info ->
                        val anchorInfoExcelRecommend = HomeInfo()
                        anchorInfoExcelRecommend.addAnchorInfoByIndex(info, index++)
                        anchorInfoExcelRecommend.currentType = HomeInfo.TYPE_ANCHOR
                        anchorInfoExcelRecommend.dealWithType = HomeInfo.TYPE_EXCEL_RECOMMEND
                        it.add(anchorInfoExcelRecommend)
                    }
                }

                // 添加label数据
                /*if (labelInfos?.data?.size ?: 0 > SIZE_LABEL_MIN) {
                    val labelInfo = HomeInfo()
                    labelInfo.labelInfo = labelInfos?.data?.filterIndexed { index, _ -> index > (SIZE_LABEL_MIN - 1) }
                    labelInfo.currentType = HomeInfo.TYPE_LABEL
                    it.add(labelInfo)
                }*/

                // 添加推荐数据
                if (!recommend.isNullOrEmpty() && recommend.size >= SIZE_RECOMMEND) {
                    /* val titleInfoRecommend = HomeInfo()
                     titleInfoRecommend.titleInfo = HomeTitleInfo(name = "推荐", imgRes = R.drawable.hot_hall_recomend)
                     titleInfoRecommend.dealWithType = HomeInfo.TYPE_RECOMMEND
                     it.add(titleInfoRecommend)*/

                    recommend.filterIndexed { index, _ -> index < SIZE_RECOMMEND }.forEach { info ->
                        val anchorInfoRecommend = HomeInfo()
                        anchorInfoRecommend.addAnchorInfoByIndex(info, index++)
                        anchorInfoRecommend.currentType = HomeInfo.TYPE_ANCHOR
                        anchorInfoRecommend.dealWithType = HomeInfo.TYPE_RECOMMEND
                        it.add(anchorInfoRecommend)
                    }
                }

                // 添加banner数据
                val theBannerInfo = HomeInfo()
                theBannerInfo.bannerInfo = bannerInfos?.data
                theBannerInfo.currentType = HomeInfo.TYPE_BANNER
                it.add(theBannerInfo)


                // 添加新人数据
                if (!newRecommend.isNullOrEmpty() && newRecommend.size >= SIZE_NEW) {
                    /*val titleInfoNew = HomeInfo()
                    titleInfoNew.titleInfo = HomeTitleInfo(name = "新人", imgRes = R.drawable.hot_hall_best_news_icon)
                    titleInfoNew.dealWithType = HomeInfo.TYPE_NEW
                    it.add(titleInfoNew)*/

                    newRecommend.filterIndexed { index, _ -> index < SIZE_NEW }.forEach { info ->
                        val anchorInfoNew = HomeInfo()
                        anchorInfoNew.addAnchorInfoByIndex(info, index++)
                        anchorInfoNew.currentType = HomeInfo.TYPE_ANCHOR
                        anchorInfoNew.dealWithType = HomeInfo.TYPE_NEW
                        it.add(anchorInfoNew)
                    }
                }

                // 添加热门数据
                if (!hotData.isNullOrEmpty()) {
                    /* val titleInfoHot = HomeInfo()
                     titleInfoHot.titleInfo = HomeTitleInfo(name = "热门", imgRes = R.drawable.hot_hall_hot_icon)
                     titleInfoHot.dealWithType = HomeInfo.TYPE_HOT
                     it.add(titleInfoHot)*/

                    hotData.forEach { info ->
                        val anchorInfoHot = HomeInfo()
                        anchorInfoHot.addAnchorInfoByIndex(info, index++)
                        anchorInfoHot.currentType = HomeInfo.TYPE_ANCHOR
                        anchorInfoHot.dealWithType = HomeInfo.TYPE_HOT
                        it.add(anchorInfoHot)
                    }
                }

            }
            return@map it
        }.subscribeOn(Schedulers.io())
                .observeOn(AndroidSchedulers.mainThread())
                .subscribe(object : Observer<ArrayList<HomeInfo>> {
                    override fun onSubscribe(d: Disposable) {
                    }

                    override fun onNext(t: ArrayList<HomeInfo>) {
                        consumer.invoke(t)
                    }

                    override fun onError(e: Throwable) {
                    }

                    override fun onComplete() {
                    }

                })
    }

    // 获取存储的热门标签数据
    fun getSaveLabelData(onSuccess: ((HomeTagInfo) -> Unit)? = null, onError: ((Int, String?) -> Unit)? = null, code: Int, msg: String?) {
        val homeTag = NineShowOtherHttpManager.getInstance().homeTag
        if (!TextUtils.isEmpty(homeTag)) {
            val homeTagInfo = Utils.jsonStrChangeToBean(homeTag, HomeTagInfo::class.java)
            if (homeTagInfo != null) {
                onSuccess?.invoke(homeTagInfo)
            } else {
                onError?.invoke(code, msg)
            }
        } else {
            onError?.invoke(code, msg)
        }
    }

    // 存储热门所有的label数据
    fun saveAllCategoryData(info: MoreTypeResultInfo) {
        val builder = GsonBuilder().create()
        try {
            val data = builder.toJson(info)
            AppCnfSpHelper.getInstance().hotAllCategoryData = data
        } catch (e: Exception) {
            NSLog.d(Tag, "数据解析失败")
        }
    }

    // 获取存储的热门所有label数据
    fun getSaveAllCategoryData(): MoreTypeResultInfo? {
        val data = AppCnfSpHelper.getInstance().hotAllCategoryData
        if (TextUtils.isEmpty(data) || data.isBlank()) {
            return null
        }
        val builder = GsonBuilder().create()
        return try {
            builder.fromJson(data, MoreTypeResultInfo::class.java)
        } catch (e: Exception) {
            NSLog.d(Tag, e.message)
            null
        }
    }

    // FIXME : 辅助打印
    fun helpPrint(allCategoryInfo: MoreTypeResultInfo?, msg: String) {
        if (allCategoryInfo == null || allCategoryInfo.data == null) {
            return
        }
        val data = allCategoryInfo.data

        val recommendExcelData: MutableList<AnchorInfo>? = data.excelRecommend
        val recommendData: MutableList<AnchorInfo>? = data.recommend
        val cardData: MutableList<AnchorInfo>? = data.useCardRoom
        val room666: MutableList<AnchorInfo>? = data.room666
        val room999: MutableList<AnchorInfo>? = data.room999
        val newData: MutableList<AnchorInfo>? = data.newRecommend
        val hotData: MutableList<AnchorInfo>? = data.hot

        NSLog.d(DEAL_TAG, "$msg , 精选推荐数据 size : ${recommendExcelData?.size ?: -1}")
        NSLog.d(DEAL_TAG, "$msg , 推荐数据 size : ${recommendData?.size ?: -1}")
        NSLog.d(DEAL_TAG, "$msg , 卡片数据 size : ${cardData?.size ?: -1}")
        NSLog.d(DEAL_TAG, "$msg , 活动房666 数据 size : ${room666?.size ?: -1}")
        NSLog.d(DEAL_TAG, "$msg , 活动房999 数据 size : ${room999?.size ?: -1}")
        NSLog.d(DEAL_TAG, "$msg , 新人 数据 size : ${newData?.size ?: -1}")
        NSLog.d(DEAL_TAG, "$msg , 热门数据 size : ${hotData?.size ?: -1}")
    }

    private var typeFace: Typeface? = null

    fun getUserName(name: String?): String {
        if (!name.isNullOrBlank() && name.length > 6) {
            return name.substring(0, 6) + "..."
        }

        if (name.isNullOrBlank()) {
            return ""
        }

        return name
    }

    // 转换观众人数
    fun formatViewerCountNew(context: Context, status: Int, userCount: String?, fansCount: Int): Triple<Typeface?, String, String?> {
        if (typeFace == null) {
            typeFace = Typeface.createFromAsset(context.assets, "fonts/BebasNeue_Bold.ttf")
        }
        // status 是否在直播？ 是的话用usercount，不是用fanscount，注意如果fanscount为空还用usercount

        val tempCount: String? = if (status == 1) {
            userCount
        } else {
            if (fansCount == 0) {
                userCount
            } else {
                fansCount.toString()
            }
        }

        if (tempCount.isNullOrBlank()) {
            return Triple(typeFace, "0", null)
        }

        try {
            val number = tempCount.toInt()
            // 转换成w
            if (number < 10000) {
                return Triple(typeFace, tempCount, null)
            }

            val first = number / 10000
            val second = number % 10000 / 1000
            return Triple(typeFace, "${first}.${second}", "万 ")
        } catch (e: java.lang.Exception) {
            return Triple(typeFace, tempCount, null)
        }
    }

    fun getTypeFace(context: Context): Typeface? {
        if (typeFace == null) {
            typeFace = Typeface.createFromAsset(context.assets, "fonts/BebasNeue_Bold.ttf")
        }
        return typeFace
    }
}