package com.ninexiu.sixninexiu.common.util

import android.content.Context
import android.net.Uri
import android.text.TextUtils
import android.util.AttributeSet
import android.view.ViewGroup
import android.widget.FrameLayout
import android.widget.LinearLayout
import android.widget.VideoView
import com.ninexiu.sixninexiu.common.download.DownloadUtil
import com.ninexiu.sixninexiu.common.download.DownloadUtil.OnDownloadListener
import com.ninexiu.sixninexiu.view.CustomVideoView
import com.zhongrun.nineshow_base.utils.NineShowFilePathManager
import java.io.File
import java.io.FileInputStream
import java.io.FileNotFoundException
import java.io.IOException

/**
 * <pre>
 *     @author : gh
 *     time   : 2021/5/12 0012
 *     desc   : 直播间视频背景
 *     version: 1.0
 * </pre>
 */
class MBLiveBgVideoView @JvmOverloads constructor(
        context: Context, attrs: AttributeSet? = null, defStyleAttr: Int = 0
) : FrameLayout(context, attrs, defStyleAttr) {

    private val TAG: String = "MBLiveBgVideoView"

    lateinit var url: String
    var videoView: CustomVideoView = CustomVideoView(context)

    private val deskPath = NineShowFilePathManager.INSTANCE.getExterFileDir(NineShowFilePathManager.LIVE_VIDEO_BG)

    init {
        delOldFile()

        this.videoView.layoutParams = LinearLayout.LayoutParams(ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.MATCH_PARENT, 1.0f)
        this.addView(videoView)
        this.videoView.setOnPreparedListener { mp->
            mp.start()
            mp.isLooping = true
        }

    }

    /**
     * 刷新播放器
     */
    fun setVideoView(url: String){
        this.url = url

//        this.url = "http://ivi.bupt.edu.cn/hls/cctv6hd.m3u8"
//        this.url = "https://img.img.9xiu.com/resource/mobile/backMp4/1.mp4"
//        this.url = "https://img.img.9xiu.com/resource/mobile/backMp4/pk.mp4"
//        this.url = "https://img.img.9xiu.com/resource/mobile/backMp4/1-1.mp4"
//        this.url = "https://img.img.9xiu.com/public/webImg/mobile/background/19.mp4"

        downloadVideo(this.url)

    }

    /**
     * 使用本地视频播放
     */
    fun setVideoViewLocalUrl(url: String){
        this.url = url
        this.videoView.setVideoPath(url)
        this.videoView.requestFocus()
        this.videoView.start()
    }

    /**
     * 播放视频背景
     */
    fun startPlay(file: File){
        if (!file.exists()){
            return
        }
        this.videoView.setVideoURI(Uri.fromFile(file))
        this.videoView.requestFocus()
        this.videoView.start()
    }

    /**
     * 获取当前的本地动画
     */
    fun downloadVideo(url: String) {

        val name = getFileName(url)
        if (TextUtils.isEmpty(url) || TextUtils.isEmpty(name)) {
            return
        }

        try {
            val file = File(deskPath, name)

            if (!file.exists() || getFileSize(file) <= 0) {//如果礼物不存在，重新下载
                //本地下载
                ThreadPoolWrap.getThreadPool().executeTaskLoadLiveRoomBg(url){
                    run {
                        DownloadUtil.get().download(url, deskPath, name,
                                object : OnDownloadListener {
                                    override fun onDownloadSuccess(file: File) {
                                        post {
                                            val localFlie = File(deskPath, name)
                                            startPlay(localFlie)
                                        }

                                    }

                                    override fun onDownloading(progress: Long, total: Long) {
                                    }

                                    override fun onDownloadFailed(e: java.lang.Exception) {
                                        ThreadPoolWrap.getThreadPool().removeTaskUrl(url)
                                        //下载异常进行相关提示操作
                                        NSLog.e(TAG, "message" + e.message.toString())
                                    }
                                })
                    }
                }
            } else {
                val localFlie = File(deskPath, name)
                startPlay(localFlie)
            }

        } catch (e: Exception) {
            e.printStackTrace()
        }

    }

    // 获取文件名字
    fun getFileName(url: String):String{
        if (TextUtils.isEmpty(url)){
            return ""
        }
        return url.substring(url.lastIndexOf("/") + 1)
    }

    /**
     * 获取指定文件大小
     * @param file
     * @return
     * @throws Exception 　　
     */
    fun getFileSize(file: File): Long {
        var size: Long = 0
        try {
            if (file.exists()) {
                var fis: FileInputStream? = null
                fis = FileInputStream(file)
                size = fis.available().toLong()
            } else {
                file.createNewFile()
            }
        } catch (e: FileNotFoundException) {
            e.printStackTrace()
        } catch (e: IOException) {
            e.printStackTrace()
        }

        return size
    }

    /**
     * 删除服务器已下线的文件,最近10天没有使用的文件。
     */
    private fun delOldFile() {
        ThreadPoolWrap.getThreadPool().executeTask{
            val file = File(deskPath)
            if (file.exists()) {
                val childFiles = file.listFiles() ?: return@executeTask
                for (i in childFiles.indices) {
                    val childFile = childFiles[i]
                    NSLog.e(TAG, "childFile = " + childFile.path)
                    val lastUse = System.currentTimeMillis() - childFile.lastModified()
                    if (lastUse / (1000 * 60 * 60 * 24) > 10) { //最近10天没有使用
                        childFile.delete()
                    }
                }
            }
        }
    }

    override fun onDetachedFromWindow() {
        super.onDetachedFromWindow()
        // 外面可以不用线程，里面做了封装
        this.videoView.stopPlayback()

    }

}