package com.ninexiu.sixninexiu.common.util

import android.content.Context
import android.util.DisplayMetrics
import android.view.Window
import android.view.WindowManager
import com.opensource.svgaplayer.SVGAParser
import com.opensource.svgaplayer.SVGAVideoEntity
import java.lang.ref.SoftReference

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/05/07
 *     desc   : s11 活动赛帮助类
 *     version: 1.0
 * </pre>
 */
object S11Helper {
    private const val Tag = "S11Helper : "
    private const val SUFFIX__XINGYAO = "xingyao"
    private const val SUFFIX__WANGZHE = "wangzhe"
    private const val SUFFIX__ZHANSHEN = "zhanshen"

    const val S11_MAKE_CALL = "力挽狂澜"
    const val S11_ACTIVITY_NAME = "pks12"

    var h5Heigght: Int = 0

    // s11 活动是否开启，用来控制打call
    var s11Open: Boolean = false

    // 设置聊天气泡后缀，因为后台放在进房接口了，这里做成全局的
    var chatBgSuffix: String? = null
    var chatBgPath: List<String>? = null

    // 获取s11聊天背景三张图(分开了)
    fun getSuperChatBg(context: Context, suffix: String): Triple<Int, Int, Int>? {
        NSLog.d(Tag, suffix)
        var bg: String? = null
        var left: String? = null
        var right: String? = null

        if (suffix == SUFFIX__XINGYAO || suffix == SUFFIX__ZHANSHEN || suffix == SUFFIX__WANGZHE) {
            bg = "live_msg_bg_${suffix}"
            left = "live_msg_left_${suffix}"
            right = "live_msg_right_${suffix}"
        }

        if (!bg.isNullOrBlank() && !left.isNullOrBlank() && !right.isNullOrBlank()) {
            return Triple(getDrawableResource(context, bg), getDrawableResource(context, left), getDrawableResource(context, right))
        }

        return null
    }


    fun getDrawableResource(context: Context, imgName: String): Int {
        return context.resources.getIdentifier(imgName, "drawable", context.packageName)
    }

    // 获取排位福利 h5 高度
    fun getS11H5Height(context: Context, window: Window, bottom: Int): Int {
        // 获取屏幕总高度
        val screenHeight = getMetricsFull(context)
        if (bottom == -1 || bottom == 0) {
            return screenHeight / 3
        }

        // 判断是否有虚拟键
        if (S11HeightHelper.checkNavigationBarShow(context, window) || S11HeightHelper.checkDeviceHasNavigationBar2(context)) {
            // 获取虚拟键高度
            val navigationHeight = S11HeightHelper.getNavigationHeight(context)
            if (navigationHeight > 0) {
                return screenHeight - bottom - navigationHeight
            }
        }

        return screenHeight - bottom
    }


    private fun getMetricsFull(context: Context): Int {
        val metrics = DisplayMetrics()
        val windowMgr = context.getSystemService(Context.WINDOW_SERVICE) as? WindowManager
        windowMgr?.defaultDisplay?.getRealMetrics(metrics)
        return metrics.heightPixels
    }

    private var mSVGAParser : SVGAParser? = null
    private var svgIceCode : SoftReference<SVGAVideoEntity>? = null

    // 加载冰冻卡svg资源
    fun loadSvgRes(){
        if(svgIceCode?.get() == null || mSVGAParser == null) {
            mSVGAParser = SVGAParser.Companion.shareParser()
            mSVGAParser?.decodeFromAssets("super_open_treasure.svga", object : SVGAParser.ParseCompletion {
                override fun onComplete(videoItem: SVGAVideoEntity) {
                    svgIceCode = SoftReference(videoItem)
                    NSLog.d(S9RankManager.SuperTag, "onComplete")
                }

                override fun onError() {
                    NSLog.d(S9RankManager.SuperTag, "onError")
                }
            },null)
        }
    }

    fun getIceSvgRes() : SoftReference<SVGAVideoEntity>?{
        if(svgIceCode == null || svgIceCode?.get() == null) {
            loadSvgRes()
            return null
        }
        return svgIceCode
    }


}
