package com.ninexiu.sixninexiu.common.util

import android.content.Context
import android.util.TypedValue
import android.view.View
import android.view.animation.Animation
import android.view.animation.ScaleAnimation
import android.widget.TextView
import androidx.core.content.ContextCompat
import com.google.android.material.tabs.TabLayout
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.view.setVisible

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/05/28
 *     desc   : 针对礼物面板 TabLayout 中的一些封装操作
 *              注意 : 这里针对的 Tab 的自定义布局就是按照礼物面板tab的自定义布局来的 R.layout.item_gift_tab_layout
 *     version: 1.0
 * </pre>
 */
object TabLayoutUtil {
    // 礼物面板tab红点显示
    fun showTabRedDot(tabUpdate: TabLayout.Tab?, show: Boolean) {
        tabUpdate?.let {
            val view = it.customView
            val dot = view?.findViewById<View>(R.id.viewDot)
            dot.setVisible(show)
        }
    }

    // 选中某个tab
    fun selectedTab(context : Context,tabLayout: TabLayout?, index: Int) {
        tabLayout ?: return
        if (index < tabLayout.tabCount) {
            val tab = tabLayout.getTabAt(index)
            tab?.select()

            // 选中了 TabLayout 的某个tab , 指示器显示
            tabLayout.postDelayed(Runnable { tabLayout.setSelectedTabIndicator(R.drawable.shape_tablayout_indicator) },200)

            // tab选中和未选中的字体大小和颜色变化
            tabLayoutTextChange(context,tabLayout, index)
        } else {
            // 这时候是选中了包裹
            tabLayout.setSelectedTabIndicator(R.drawable.shape_tablayout_indicator_transparent)
        }
    }

    // tab选中和未选中时的字体大小和颜色变化
    public fun tabTextChange(context : Context,tab: TabLayout.Tab?, selected: Boolean) {
        tab ?: return
        val view = tab.customView
        val tabText = view?.findViewById<TextView>(R.id.tvTab)

        textChange(context,tabText,selected)
    }

    // tab选中和未选中的字体大小和颜色变化
    fun tabLayoutTextChange(context : Context,tabLayout: TabLayout?, index: Int){
        tabLayout?:return
        if(index >= tabLayout.tabCount) {
            return
        }

        for (tabIndex in 0 until  tabLayout.tabCount){
            val tabTemp = tabLayout.getTabAt(tabIndex)
            tabTextChange(context,tabTemp,tabIndex == index)
        }
    }

    // 文字变化
    fun textChange(context : Context,tv: TextView?, selected: Boolean){
        when(selected) {
            true -> {
                tv?.setTextColor(ContextCompat.getColor(context, R.color.white))
                tv?.setTextSize(TypedValue.COMPLEX_UNIT_SP, 15f)
            }
            else -> {
                tv?.setTextColor(ContextCompat.getColor(context, R.color.color_gift_cbcbcb))
                tv?.setTextSize(TypedValue.COMPLEX_UNIT_SP, 14f)
            }
        }
    }

    // 礼物选中以后的图片缩放动画
    fun startScaleAnimation(view : View?) {
        val waveScaleAnimation = ScaleAnimation(1f, 0.9f, 1f, 0.9f, Animation.RELATIVE_TO_SELF, 0.5f, Animation.RELATIVE_TO_SELF, 0.5f)
        waveScaleAnimation.duration = 700
        waveScaleAnimation.fillAfter = false
        waveScaleAnimation.repeatCount = Animation.INFINITE
        waveScaleAnimation.repeatMode = Animation.REVERSE
        view?.startAnimation(waveScaleAnimation)
    }

    // 判断tablayout上是否有红点显示
    fun isHaveDotShow(tabLayout: TabLayout?) : Boolean{
        tabLayout?:return false
        for (tabIndex in 0 until  tabLayout.tabCount){
            val tabTemp = tabLayout.getTabAt(tabIndex)
            tabTemp?.let {
                val view = it.customView
                val dot = view?.findViewById<View>(R.id.viewDot)
                if(dot?.visibility?:View.GONE == View.VISIBLE) {
                    NSLog.d("TheGiftManager : ", "findIndex : $tabIndex")
                    return true
                }
            }
        }
        return false
    }

}