package com.ninexiu.sixninexiu.common.util.gift

import android.content.Context
import android.os.Environment
import android.os.Handler
import android.text.TextUtils
import android.view.View
import android.view.ViewStub
import android.widget.ImageView
import androidx.lifecycle.LifecycleOwner
import com.google.gson.JsonParseException
import com.loopj.android.http.TextHttpResponseHandler
import com.ninexiu.sixninexiu.BuildConfig
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.bean.BaseResultInfo
import com.ninexiu.sixninexiu.bean.ChatMessage
import com.ninexiu.sixninexiu.bean.SvgGiftDownBean
import com.ninexiu.sixninexiu.common.AppCnfSpHelper
import com.ninexiu.sixninexiu.common.net.NSAsyncHttpClient
import com.ninexiu.sixninexiu.common.net.NSGsonObjectNewCallback
import com.ninexiu.sixninexiu.common.net.NsOkHttpClient
import com.ninexiu.sixninexiu.common.util.Constants
import com.ninexiu.sixninexiu.common.util.GsonUtil
import com.ninexiu.sixninexiu.common.util.NSLog
import com.ninexiu.sixninexiu.common.util.svg.down.DownloadCallback
import com.ninexiu.sixninexiu.common.util.svg.down.OkhttpDownload
import com.ninexiu.sixninexiu.view.setVisible
import com.opensource.svgaplayer.SVGACallback
import com.opensource.svgaplayer.SVGAImageView
import com.opensource.svgaplayer.SVGAParser
import com.opensource.svgaplayer.SVGAVideoEntity
import com.zhongrun.nineshow_base.utils.NineShowFilePathManager
import java.io.File
import java.io.FileInputStream
import java.io.FileNotFoundException
import java.io.IOException
import java.net.MalformedURLException
import java.net.URL
import java.util.*

/**
 * <pre>
 *     @author : gh
 *     time   : 2020/12/16 0023
 *     desc   : 直播间Video大动画播放
 *     version: 1.0
 * </pre>
 */
class DressUpVideoManager {

    private val TAG: String = "LiveGiftVideoManager"

    private lateinit var mContext: Context


    var mGiftView: LiveRoomGiftView? = null
    private lateinit var lifecycleOwner: LifecycleOwner


    /**
     * 下载数据
     */
    private var mp4CarList: List<SvgGiftDownBean.DataBean.SvgaListBean> = ArrayList<SvgGiftDownBean.DataBean.SvgaListBean>()

    private val deskPath = NineShowFilePathManager.INSTANCE.getExterFileDir(NineShowFilePathManager.GIFT_DIR)
    private val FILE_SUFFIX = ".mp4"

    private var downloadManager: OkhttpDownload? = null

    companion object {

        val INSTANCE: DressUpVideoManager by lazy(mode = LazyThreadSafetyMode.SYNCHRONIZED) {
            DressUpVideoManager()
        }
    }

    init {
        var result: String = AppCnfSpHelper.getInstance().svgGiftList
        if (!TextUtils.isEmpty(result)) {
            try {
                var bean: SvgGiftDownBean = GsonUtil.fromJson(result, SvgGiftDownBean::class.java)
                if (bean.code == 200) {
                    if (bean.data?.mp4CarList != null) {
                        mp4CarList = bean.data!!.mp4CarList
                    }

                }
            } catch (e: JsonParseException) {
                e.printStackTrace()
            }
        }
    }


    /**
     * 获取指定文件大小
     * @param file
     * @return
     * @throws Exception 　　
     */
    fun getFileSize(file: File): Long {
        var size: Long = 0
        try {
            if (file.exists()) {
                var fis: FileInputStream? = null
                fis = FileInputStream(file)
                size = fis.available().toLong()
            } else {
                file.createNewFile()
            }
        } catch (e: FileNotFoundException) {
            e.printStackTrace()
        } catch (e: IOException) {
            e.printStackTrace()
        }

        return size
    }

    /**
     * 获取当前动画
     */
    fun getVideoData(gid: String): SvgGiftDownBean.DataBean.SvgaListBean? {
        if (mp4CarList?.size > 0) {
            for (bean: SvgGiftDownBean.DataBean.SvgaListBean in mp4CarList) {
                if (TextUtils.equals(gid, bean?.gid)) {
                    return bean
                }
            }
        }
        return null
    }

    fun startPlay(mGiftView: LiveRoomGiftView, gid: String) {

        mGiftView.setVisible(true)
        mGiftView.setOnClickListener {
            mGiftView.release()
            mGiftView.setVisible(false)
        }
        mGiftView.initPlayerController(object : LiveRoomGiftCallBack {
            override fun startAction() {
            }

            override fun endAction() {
                mGiftView.setVisible(false)
            }

            override fun onPrepared() {
            }

            override fun onError() {
            }
        })
        var bean: SvgGiftDownBean.DataBean.SvgaListBean? = getVideoData(gid)
        bean?.let {

            val suffixFileName = it.gid + "_" + it.updatetime
            val file = File(deskPath, suffixFileName)

            /**
             * 删除当前别的动画
             */
            var directory = File(deskPath)
            if (directory?.exists()) {
                var fils = directory?.listFiles()
                fils?.let {
                    for (f in fils) {
                        if (!TextUtils.equals(suffixFileName, f.name) && f.name.contains(bean?.gid)) {
                            if (f.exists()) {
                                f.delete()
                            }
                        }
                    }
                }
            }

            if (!file.exists() || getFileSize(file) <= 0) {//如果礼物不存在，重新下载

                var downloadUrl: String = "https://img.img.9xiu.com/resource/mobile/phoneGiftCar/mgift"
                var path = downloadUrl + bean.gid + FILE_SUFFIX

                netDownLoad(path, it)
            } else {

                // 开始播放
                mGiftView?.startVideoGift("$deskPath/$suffixFileName")
            }
        }

    }


    /**
     * 网络播放、以及下载
     */
    private fun netDownLoad(path: String, bean: SvgGiftDownBean.DataBean.SvgaListBean) {
        //本地下载
        if (downloadManager == null) {
            downloadManager = OkhttpDownload(NineShowApplication.applicationContext)
        }

        downloadManager?.downLoadCallback(path, bean.gid + "_" + bean.updatetime, object : DownloadCallback {
            override fun downloadSuccess() {

                NSLog.d(TAG, "downloadSuccess")
            }

            override fun downloadFailure(errorMsg: String) {

            }
        })
    }

}