package com.ninexiu.sixninexiu.common.util.gift

import android.content.Context
import android.text.style.ImageSpan
import android.util.LruCache
import com.ninexiu.sixninexiu.common.util.GiftVersionManage
import com.ninexiu.sixninexiu.common.util.GlideUtils
import com.ninexiu.sixninexiu.common.util.Utils
import com.ninexiu.sixninexiu.view.VerticalImageSpan
import java.io.File
import java.lang.ref.SoftReference
import java.lang.ref.WeakReference


/**
 * <pre>
 *     @author : gh
 *     time   : 2021/08/25 0023
 *     desc   : 礼物图标资源管理器
 *     version: 1.0
 * </pre>
 */
class GiftResourceBitmapManage {

    var mGiftBitmapCache: LruCache<String, SoftReference<VerticalImageSpan>> = LruCache<String, SoftReference <VerticalImageSpan>>(60);

    companion object {

        private var instance: GiftResourceBitmapManage? = null
            get() {
                if (field == null) {
                    field = GiftResourceBitmapManage()
                }
                return field
            }

        fun get(): GiftResourceBitmapManage {
            return instance!!
        }
    }

    /**
     * 获取缓存的礼物资源图标
     */
    fun getGiftBitmap(context:Context, giftId: String): VerticalImageSpan? {
        var giftImageSpan:VerticalImageSpan? = mGiftBitmapCache?.get(giftId)?.get()

        if (giftImageSpan == null) {
            val v = GiftVersionManage.get().getGiftVersion(giftId)
            var giftFile = Utils.getCachDir()
            giftFile = File(giftFile, "/mgift" + giftId + "_" + v)
            val giftBitmap = GlideUtils.loadBitmapSyncLiveRoom(giftFile)

            giftImageSpan = VerticalImageSpan(context, giftBitmap, ImageSpan.ALIGN_BASELINE)
            if (giftBitmap == null) {
                giftFile.delete()
            } else {
                mGiftBitmapCache.put(giftId,SoftReference(giftImageSpan))
            }

            GiftResourceDownLoadManage.get().checkDownload(giftFile, giftId, v)
        }

        return giftImageSpan
    }

    /**
     * 资源释放
     */
    fun onRelease(){
        mGiftBitmapCache.evictAll()
    }


}