package com.ninexiu.sixninexiu.common.util.gift

import android.content.Context
import android.text.TextUtils
import android.util.AttributeSet
import android.util.Log
import android.view.LayoutInflater
import android.widget.FrameLayout
import android.widget.RelativeLayout
import com.ninexiu.sixninexiu.BuildConfig
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.common.util.NSLog
import com.tencent.qgame.animplayer.AnimConfig
import com.tencent.qgame.animplayer.AnimView
import com.tencent.qgame.animplayer.Constant
import com.tencent.qgame.animplayer.inter.IAnimListener
import com.tencent.qgame.animplayer.util.ALog
import com.tencent.qgame.animplayer.util.IALog
import java.io.*
import java.lang.Exception

/**
 * created by dengzhuoyao on 2020/07/08
 */
class LiveRoomGiftView @JvmOverloads constructor(
        context: Context, attrs: AttributeSet? = null, defStyleAttr: Int = 0
) : FrameLayout(context, attrs, defStyleAttr), IAnimListener {

    val tag:String = "LiveRoomGiftView"

    private var mAnimView: AnimView? = null
    private val mVideoContainer: RelativeLayout

    init {
        LayoutInflater.from(context).inflate(getResourceLayout(), this)
        mVideoContainer = findViewById(R.id.video_view)

    }

    private fun getResourceLayout(): Int {
        return R.layout.ns_live_room_video_gift
    }

    private var callBack: LiveRoomGiftCallBack? = null
    fun initPlayerController(callBack: LiveRoomGiftCallBack? = null) {
        this.callBack = callBack

        createView()
        initLog()
        mAnimView?.setAnimListener(this)
    }


    // 开始播放
    fun startVideoGift(path: String) {
        if (TextUtils.isEmpty(path) || path.indexOf("2000724") != -1) {
            callBack?.endAction()
            return
        }

        try {
            if (mAnimView == null && context != null){
                createView()
            }

            NSLog.d(tag,"path  = $path")
            Thread {
                val file = File(path)
                // 开始播放动画文件
                mAnimView?.startPlay(file)
            }.start()
        } catch (e: Exception){
            callBack?.endAction()
        }

    }

    /**
     * 循环次数
      */
    fun setLoopCount(count: Int){
        mAnimView?.setLoop(count)
    }

    /**
     * 创建视频播放View
     */
    private fun createView(){
        try {
            mAnimView = AnimView(context)
            mVideoContainer.removeAllViews()
            val param = LayoutParams(LayoutParams.MATCH_PARENT, LayoutParams.MATCH_PARENT)
            mAnimView?.layoutParams = param

            mAnimView?.supportMask(true,true)
            mAnimView?.enableAutoTxtColorFill(true)
            mAnimView?.setVideoMode(Constant.VIDEO_MODE_SPLIT_HORIZONTAL)
            mAnimView?.enableVersion1(true)
            mVideoContainer.addView(mAnimView)
        } catch (e:Exception) {
            e.printStackTrace()
        }

    }


    private fun initLog() {
        ALog.isDebug = BuildConfig.DEBUG
        ALog.log = object : IALog {
            override fun i(tag: String, msg: String) {
                Log.i(tag, msg)
            }

            override fun d(tag: String, msg: String) {
                Log.d(tag, msg)
            }

            override fun e(tag: String, msg: String) {
                Log.e(tag, msg)
            }

            override fun e(tag: String, msg: String, tr: Throwable) {
                Log.e(tag, msg, tr)
            }
        }
    }

    /**
     * 视频信息准备好后的回调，用于检查视频准备好后是否继续播放
     * @return true 继续播放 false 停止播放
     */
    override fun onVideoConfigReady(config: AnimConfig): Boolean {
        callBack?.onPrepared()

//        uiHandler.post {
//            val w = dp2px(context,400f).toInt()
//            val lp = mAnimView.layoutParams
//            lp.width = w
//            lp.height = (w * config.height *1f / config.width).toInt()
//            mAnimView.layoutParams = lp
//        }
        return true
    }

    /**
     * 失败回调
     * 一次播放时可能会调用多次，建议onFailed只做错误上报
     * @param errorType 错误类型
     * @param errorMsg 错误消息
     */
    override fun onFailed(errorType: Int, errorMsg: String?) {
        NSLog.d(tag,"errorType  = $errorType     errorMsg = $errorMsg")
    }

    /**
     * 视频播放结束(失败也会回调onComplete)
     */
    override fun onVideoComplete() {
        mVideoContainer?.postDelayed({
            callBack?.endAction()
        }, 100)

        NSLog.d(tag, "onVideoComplete")
    }

    /**
     * 播放器被销毁情况下会调用onVideoDestroy
     */
    override fun onVideoDestroy() {
        callBack?.onError()
        NSLog.d(tag,"onVideoDestroy")
    }

    /**
     * 视频渲染每一帧时的回调
     * @param frameIndex 帧索引
     */
    override fun onVideoRender(frameIndex: Int, config: AnimConfig?) {
        NSLog.d(tag,"frameIndex  = $frameIndex     config = ${config.toString()}")
    }

    /**
     * 视频开始回调
     */
    override fun onVideoStart() {
        callBack?.startAction()
        NSLog.d(tag,"onVideoStart")
    }

    private fun dp2px(context: Context, dp: Float): Float {
        val scale = context.resources.displayMetrics.density
        return dp * scale + 0.5f
    }

    fun release(){
        mVideoContainer?.removeCallbacks(null)
        mVideoContainer?.removeAllViews()
        mAnimView?.stopPlay()
    }

}