package com.ninexiu.sixninexiu.common.util.manager

import android.annotation.SuppressLint
import android.content.Context
import android.util.Log
import android.view.View
import androidx.recyclerview.widget.GridLayoutManager
import com.chad.library.adapter.base.BaseQuickAdapter
import com.chad.library.adapter.base.BaseViewHolder
import com.ninexiu.sixninexiu.adapter.AnchorDialogAdapter
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.bean.*
import com.ninexiu.sixninexiu.common.AppCnfSpHelper
import com.ninexiu.sixninexiu.common.net.NSGsonObjectNewCallback
import com.ninexiu.sixninexiu.common.net.NSRequestParams
import com.ninexiu.sixninexiu.common.net.NsOkHttpClient
import com.ninexiu.sixninexiu.common.statistics.StatisticsEventID
import com.ninexiu.sixninexiu.common.statistics.StatisticsUtil
import com.ninexiu.sixninexiu.common.util.*
import com.ninexiu.sixninexiu.thirdfunc.voice.MoreVoiceManager
import com.ninexiu.sixninexiu.video.ve_gl.EglBase
import com.ninexiu.sixninexiu.view.dialog.LeaveRoomDialog
import com.ninexiu.sixninexiu.view.dialog.LeaveRoomNormalDialog
import kotlinx.android.synthetic.main.dialog_leave_room_normal.*
import org.json.JSONObject

/**
 * @author: lou
 * @date: 2021/8/26
 * desc:用户离开房间的管理类，目前只做810活动相关业务的处理
 */
object LeaveRoomManager {

    //记录Room ID，判断当前房间是否加载过弹窗，弹窗加载是否超过三次
    private var idList = arrayListOf<Int>()

    //每次进入直播间时初始化，记录当前时间
    var createTime = 0L


    //观看时间小于5分钟的dialog
    private var mLeaveRoomNormalDialog: LeaveRoomNormalDialog? = null

    //观看时间大于5分钟的dialog
    private var mLeaveRoomDialog: LeaveRoomDialog? = null

    //判断当前时间距离记录时间的时间间隔
    private fun isGreaterThanMinutes(lastTime: Long, min: Float): Boolean =
        System.currentTimeMillis() - lastTime > 1000 * 60 * min


    /**
     * 当用户离开直播间时弹出该dialog，两种弹窗两个弹出规则
     * 弹窗1：当用户在当前直播间观看小于5分钟时展示，且每30分钟仅展示一次
     * 弹窗2：当用户在当前直播间大于5分钟时且未关注当前主播时展示，每次冷启动只展示3次，每个直播间只展示一次
     */
    fun showLeaveRoomDialog(context: Context, roomInfo: RoomInfo, isToast: Boolean): Boolean {


        //青少年模式不弹
        if (AppCnfSpHelper.getInstance().isChildrenModle) {
            sendCloseLiveRoomBroadCastReceiver(isToast)
            return true
        }

        //大于5富不弹
        if (NineShowApplication.mUserBase?.wealthlevel?:0>=5){
            sendCloseLiveRoomBroadCastReceiver(isToast)
            return true
        }

        //主播不弹
        if (NineShowApplication.mUserBase?.is_anchor?:0==1){
            sendCloseLiveRoomBroadCastReceiver(isToast)
            return true
        }

        //关注不弹
        if (roomInfo.isfollow()) {

            sendCloseLiveRoomBroadCastReceiver(isToast)
            NSLog.d("LeaveRoomManager：关注的主播不弹出")

            return true
        }

        if(roomInfo.is_energy==1){
            sendCloseLiveRoomBroadCastReceiver(isToast)
            NSLog.d("LeaveRoomManager：正能量不弹出")

            return true
        }

        if (roomInfo.status==0){
            sendCloseLiveRoomBroadCastReceiver(isToast)
            NSLog.d("LeaveRoomManager：未开播的不弹出")

            return true
        }

        if (roomInfo.roomType== 18 && MoreVoiceManager.getInstance().currentOptMicNum!=0){

            sendCloseLiveRoomBroadCastReceiver(isToast)
            NSLog.d("LeaveRoomManager：语音房主持未上麦不展示")
            return true

        }

        val lastTime = AppCnfSpHelper.getInstance().lastShowTime

        //判断在当前直播间是否大于5分钟
        val isGreaterThanFiveMin = isGreaterThanMinutes(createTime, 5f)
        //判断弹窗1是否超过30分钟
        val greaterThan30Minutes = isGreaterThanMinutes(lastTime, 30f)




        //用户观看小于5分钟的情况
        if (!isGreaterThanFiveMin) {
            if (!greaterThan30Minutes) {
                NSLog.d("LeaveRoomManager:距离上次弹窗小于30分钟")
                sendCloseLiveRoomBroadCastReceiver(isToast)
                return true
            }

            if (adviseAnchorListResult==null){
                sendCloseLiveRoomBroadCastReceiver(isToast)
            } else {
                adviseAnchorListResult?.let {
                    if (it.code == 200) {
                        val data = it.data
                        if (data.size < 4) {
                            Log.d("LeaveRoomManager", "数量小于4的弹窗不展示")
                            sendCloseLiveRoomBroadCastReceiver(isToast)
                            return true
                        }

                        mLeaveRoomNormalDialog = LeaveRoomNormalDialog(context, data)
                        mLeaveRoomNormalDialog?.show()
                        StatisticsUtil.onEvent(StatisticsEventID.UM_ZBJ_OUT_RECOMMEND)
                        AppCnfSpHelper.getInstance().lastShowTime = System.currentTimeMillis()
                    }
                }
            }

        } else {

            if (idList.size == 3) {
                NSLog.d("LeaveRoomManager:该弹窗已经弹出过三次")
                sendCloseLiveRoomBroadCastReceiver(isToast)
                return true
            }

            if (idList.contains(roomInfo.artistuid)) {
                NSLog.d("LeaveRoomManager:该弹窗已经在该直播间展示过")
                sendCloseLiveRoomBroadCastReceiver(isToast)
                return true
            }

            if (mLeaveRoomDialog == null) {
                mLeaveRoomDialog = LeaveRoomDialog(context, roomInfo.artistuid)
            }
            StatisticsUtil.onEvent(StatisticsEventID.UM_ZBJ_OUT_FOLLOW)
            mLeaveRoomDialog?.show()

            idList.add(roomInfo.artistuid)
        }
        return false
    }


    private var adviseAnchorListResult: AdviseAnchorListResult? = null
    fun loadNormalDialogData(roomType: Int?, rid: String?){

        val okHttpClient = NsOkHttpClient.getNsOkHttpClient()
        val params = NSRequestParams()
        params.put("roomType", roomType)
        params.put("rid",rid)
        params.put("num",4)
        okHttpClient.doGet(
            Constants.GET_LIVE_ROOM_LIST,
            params,
            object : NSGsonObjectNewCallback<AdviseAnchorListResult>() {

                @SuppressLint("LongLogTag")
                override fun onSuccess(
                        statusCode: Int,
                        responseString: String?,
                        message: String?,
                        response: AdviseAnchorListResult?
                ) {
                    adviseAnchorListResult=response
                }

                @SuppressLint("LongLogTag")
                override fun onFailure(statusCode: Int, errorMsg: String?) {
                }

            })


    }

    fun clear() {
        idList?.clear()
        AppCnfSpHelper.getInstance().lastShowTime = 0
    }

    fun dismissDialog() {
        mLeaveRoomDialog?.dismiss()
        mLeaveRoomDialog=null
        mLeaveRoomNormalDialog?.dismiss()
        mLeaveRoomNormalDialog = null
    }

}