package com.ninexiu.sixninexiu.common.util.manager

import android.annotation.SuppressLint
import android.os.Handler
import android.os.Message
import android.text.TextUtils
import com.ninexiu.sixninexiu.bean.BaseResultInfo
import com.ninexiu.sixninexiu.common.net.*
import com.ninexiu.sixninexiu.common.util.Constants
import com.ninexiu.sixninexiu.common.util.NSLog
import org.json.JSONObject
import java.lang.ref.WeakReference

/**
 * <pre>
 *     @author : gh
 *     time   : 2020/7/11 0023
 *     desc   : 多人语聊房送礼管理类
 *     version: 1.0
 * </pre>
 */
class MoreVoiceSendGiftManager {

    private val TAG: String = "MoreVoiceSendGiftManager"

    private var qeque = HashMap<String,NSRequestParams>()
    private var mHandler = SendGiftHandler(this)

    private var onSendGiftInterface: WeakReference<OnSendGiftInterface?>? = null

    private var isReqSendGift = false
    private var time :String = ""

    companion object {

        private var instance: MoreVoiceSendGiftManager? = null
            get() {
                if (field == null) {
                    field = MoreVoiceSendGiftManager()
                }
                return field
            }
        fun get(): MoreVoiceSendGiftManager{
            return instance!!
        }
    }

    /**
     * 送礼成功回调
     */
    fun setOnSendGiftInterface(onSendGiftInterface: OnSendGiftInterface){
        this.onSendGiftInterface = WeakReference(onSendGiftInterface)
    }

    /**
     * 添加礼物
     */
    fun addGift(entry: NSRequestParams) {
        synchronized(this) {
            if (entry != null) {
                var time_key = entry.getValue("time_key")
                if(!TextUtils.isEmpty(time_key)){
                    qeque?.put(time_key,entry)
                }

                //下一条消息
                if (!isReqSendGift) {
                    loadMessage()
                }
            }

        }
    }

    /**
     * 加载消息数据
     */
    private fun loadMessage() {

        synchronized(this) {
            if (qeque?.size > 0) {
                var pollFirst:NSRequestParams? = getFirstOrNull()
                if (pollFirst != null) {
                    sendGift(pollFirst)
                }
            }
        }
    }

    /**
     * 取出第一个
     */
     fun getFirstOrNull() :NSRequestParams? {
        var obj: NSRequestParams? = null
        if (qeque.size > 0) {
            for (value in qeque) {
                obj = value.value
                if (obj != null) {
                    break
                }
            }
        }
        return obj
    }


    /**
     * 移除发送后礼物
     */
    private fun removeMessage(){
        if(qeque.size > 0){
            qeque.remove(time)
        }

    }

    /**
     * 发送礼物请求
     */
    private fun sendGift(params :NSRequestParams?){
        // 临时缓存数据
        this.time = params?.getValue("time_key").toString()
        val asyncHttpClient = NsOkHttpClient.getNsOkHttpClient()
        // 请求链接不进行转码
        asyncHttpClient.doGet(Constants.LIVE_NEW_SEND_GIFT, params, object : NSGsonObjectCallback<BaseResultInfo>() {
            @SuppressLint("LongLogTag")
            override fun onFailure(statusCode: Int, errorMsg: String?) {
                NSLog.e(TAG,"onFailure    statusCode = $statusCode         errorMsg  = $errorMsg")
                if(qeque?.size > 0){
                    qeque?.remove(time)
                }
                mHandler.sendEmptyMessage(1)
            }

            @SuppressLint("LongLogTag")
            override fun onSuccess(statusCode: Int, rawJsonResponse: String?, response: BaseResultInfo?) {
                if(qeque?.size > 0){
                    qeque?.remove(time)
                }
                if (rawJsonResponse != null) {
                    NSLog.e(TAG,"onSuccess      statusCode = $statusCode         rawJsonResponse  = $rawJsonResponse")
                    onSendGiftInterface?.get()?.onSuccess(rawJsonResponse)

                    try {
                        val jsonObject = JSONObject(rawJsonResponse)
                        val code = jsonObject.optInt("code")

                        /**
                         * 库存不能为空，鲜花不能为空
                         */
                        if(code != 4203 && code != 4001){
                            mHandler.sendEmptyMessage(1)
                        } else {
                            isReqSendGift = false
                        }

                    } catch (e: Exception) {
                        e.printStackTrace()
                        mHandler.sendEmptyMessage(1)

                    }

                } else {
                    mHandler.sendEmptyMessage(1)
                }
            }

        })
    }


    /**
     * 送礼Handler
     */
    class SendGiftHandler internal constructor(it: MoreVoiceSendGiftManager) : Handler() {

        var it =  it

        override fun handleMessage(msg: Message) {
            if (msg.what == 1) {
                synchronized(it) {
                    it.isReqSendGift = false
//                    it.removeMessage()
                    it.loadMessage()
                }

            }

        }
    }


    /**
     * 回调是否为空
     */
    fun OnSendGiftInterfaceIsNull() :Boolean{
        onSendGiftInterface?.let {
            return false
        }?:let {
            return true
        }
    }

    public interface OnSendGiftInterface {
        fun onSuccess(responseString: String)
    }

}