package com.ninexiu.sixninexiu.common.util.manager

import android.content.Context
import android.content.Intent
import android.view.View
import android.widget.ImageView
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.activity.LiveRoomWebCenterDialogActivity
import com.ninexiu.sixninexiu.bean.*
import com.ninexiu.sixninexiu.common.net.NSGsonObjectNewCallback
import com.ninexiu.sixninexiu.common.net.NSRequestParams
import com.ninexiu.sixninexiu.common.net.NsOkHttpClient
import com.ninexiu.sixninexiu.common.util.Constants
import com.ninexiu.sixninexiu.common.util.GsonUtil
import com.ninexiu.sixninexiu.common.util.NSLog
import com.ninexiu.sixninexiu.pay.ZhiFuFastCDialog
import com.ninexiu.sixninexiu.view.TrueLoveProgressView
import com.ninexiu.sixninexiu.view.dialog.OnZhiFuFastDialogDismissListener
import com.ninexiu.sixninexiu.view.dialog.TrueLoveGroupBuyDialog
import com.tencent.qcloud.tim.uikit.utils.ToastUtil

/**
 * @author: lou
 * @date: 2021/9/13
 * desc:真爱成团日管理类
 */
object TrueLoveGroupManager {

    var bean: TrueLoveGroupBean? = null
    const val TAG = "TrueLoveGroupManager"

    /**
     * 长连接
     * 根据type值弹出对应的弹窗 ：
     * 2：进度条
     * 3：转盘
     * 4：购买礼包
     */
    fun showTrueLoveGroupDialog(
        context: Context,
        trueLoveGroupBean: TrueLoveGroupBean,
        rootView: View
    ) {
        this.bean = trueLoveGroupBean

        when (bean?.type) {
            2 -> {
                NSLog.d("TrueLove:${bean?.anchorActValue}")

                bean?.nowActValue?.let { showProgress(rootView, it, context) }
            }
            3 -> {
                showTurntableDialog(context)
            }
            4 -> {
                showBuyDialog(context)
            }
        }

    }


    /**
     * 转盘，需要调web页展示转盘
     */
    private fun showTurntableDialog(context: Context) {

        bean?.prizeRewardCount?.let {
            openWebView(
                 context, bean?.rid.toString(),
                it
            )
        }

    }


    /**
     * 购买礼包dialog
     */
    private fun showBuyDialog(context: Context) {
        bean?.rid?.let { TrueLoveGroupBuyDialog(context, it).show() }
    }


    /**
     * 真爱成团日进房需要处理的数据
     * isShowCharm:展示进度条
     * isOpenTrueLoveBag：购买真爱礼包弹框
     * isOpenTrun：转盘
     *
     */
    fun enterRoomLoadData(context: Context, view: View, rid: String) {


        val params = NSRequestParams()
        params.put("rid", rid)
        NsOkHttpClient.getNsOkHttpClient().doGet(
            Constants.GET_TRUE_LOVE_ENTER_ROOM,
            params,
            object : NSGsonObjectNewCallback<BaseResultInfo>() {

                override fun onFailure(statusCode: Int, errorMsg: String?) {
                    NSLog.e(errorMsg)
                }

                override fun onSuccess(
                    statusCode: Int,
                    responseString: String?,
                    message: String?,
                    response: BaseResultInfo?
                ) {
                    if (statusCode == 200) {

                        NSLog.d(TAG + ":${response}")

                        val data = GsonUtil.fromJson(
                            responseString,
                            TrueLoveEnterRoomBean::class.java
                        )?.data

                        data.let { trueLoveEnterRoomChildBean ->

                            //进度条
                            if (trueLoveEnterRoomChildBean?.isShowCharm == 1) {
                                NSLog.d(TAG + "进房进度条")

                                showProgress(view, trueLoveEnterRoomChildBean.nowActValue, context)

                            }

                            //转盘
                            if (trueLoveEnterRoomChildBean?.isOpenTrun == 1) {
                                NSLog.d(TAG + "进房此处应该出转盘")
                                openWebView(
                                    context,
                                    rid,
                                    trueLoveEnterRoomChildBean.prizeRewardCount
                                )
                                return@let
                            }

                            //购买真爱礼包
                            if (trueLoveEnterRoomChildBean?.isOpenTrueLoveBag == 1) {
                                NSLog.d(TAG + "进房购买真爱礼包")
                                showBuyDialog(context)
                            }

                        }


                    }
                }

            })


    }

    /**
     * 打开web页面
     */
    private fun openWebView(context: Context, rid: String, prizeRewardCount: Int) {

        val eggIntent = Intent(
            context,
            LiveRoomWebCenterDialogActivity::class.java
        )
        eggIntent.putExtra("roomId", rid)
        eggIntent.putExtra("url", Constants.WEB_TRUE_LOVE_FULLSCREEN) //H5页面的链接
        eggIntent.putExtra("show_type", 2)
        eggIntent.putExtra("isLoading", false)
        eggIntent.putExtra("prizeRewardCount", prizeRewardCount)
        NSLog.d("TrueLove$prizeRewardCount")
//        eggIntent.flags = Intent.FLAG_ACTIVITY_NEW_TASK

        context.startActivity(eggIntent)
    }


    private fun showProgress(rootView: View, progress: Int, context: Context) {
        val trueLoveProgressView =
            rootView.findViewById<TrueLoveProgressView>(R.id.true_love_progress_view)
        trueLoveProgressView.showProgressView(context, progress)
    }


}