package com.ninexiu.sixninexiu.fragment

import android.annotation.SuppressLint
import android.content.Intent
import android.content.IntentFilter
import android.graphics.Rect
import android.net.Uri
import android.os.Build
import android.os.Bundle
import android.os.Handler
import android.os.Message
import android.provider.Settings
import android.text.TextUtils
import android.view.LayoutInflater
import android.view.View
import androidx.core.app.NotificationManagerCompat
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.blankj.utilcode.util.ToastUtils
import com.ijkplayer.widget.media.IjkVideoView
import com.ijkplayer.widget.media.IjkVideoViewNew
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.adapter.AttentionUserDynamicAdapter
import com.ninexiu.sixninexiu.adapter.DynamicDataAdapter
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.audio.AudioPlayerManager.releasePlayer
import com.ninexiu.sixninexiu.audio.DynamicHelper.addElement
import com.ninexiu.sixninexiu.audio.DynamicHelper.upDynamicDataLoad
import com.ninexiu.sixninexiu.bean.*
import com.ninexiu.sixninexiu.common.AppCacheData
import com.ninexiu.sixninexiu.common.net.NSGsonObjectNewCallback
import com.ninexiu.sixninexiu.common.net.NSRequestParams
import com.ninexiu.sixninexiu.common.net.NsOkHttpClient
import com.ninexiu.sixninexiu.common.statistics.StatisticsEventID
import com.ninexiu.sixninexiu.common.statistics.StatisticsUtil
import com.ninexiu.sixninexiu.common.util.*
import com.ninexiu.sixninexiu.common.util.manager.RequestManager
import com.ninexiu.sixninexiu.view.StateView
import com.ninexiu.sixninexiu.view.dialog.BaseDialog
import com.ninexiu.sixninexiu.view.dialog.CommentListFragmentDialog
import com.ninexiu.sixninexiu.view.dialog.CurrencyBottomDialog
import com.ninexiu.sixninexiu.view.dp2px
import com.ninexiu.sixninexiu.view.getStatusBarHeight
import com.ninexiu.sixninexiu.view.setVisible
import kotlinx.android.synthetic.main.fragment_attenttion_user.*
import kotlinx.android.synthetic.main.layout_for_show_state.*
import tv.danmaku.ijk.media.player.IMediaPlayer

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/07/06
 *     desc   : 交友中的关注页面
 *
 *     页面逻辑 : 主播  &   动态
 *     1. 主播 : 关注主播 & 推荐主播
 *       1> 先取关注主播数据,此接口是分页的,如果主播数据大于等于4条，直接显示关注主播数据
 *       2> 如果关注主播数据小于4条，则再去拉去推荐主播数据(原猜你喜欢)，此接口不是分页的，一次性拉取即可，然后和关注主播数据进行合并
 *
 *     2. 动态 : 关注动态 & 推荐动态
 *       1> 先拉取关注动态，有则显示，无则拉取推荐动态，数据不合并
 *       2> 关注动态(原关注页->动态) , 推荐动态(原发现页面->推荐)
 *     version: 1.0
 * </pre>
 */
class AttentionUserDynamicFragment : BaseFragment(), StateView.OnRefreshViewListener {
    companion object {
        const val Tag = "AttentionUserDynamicFragment : "
    }

    private lateinit var rootView: View

    @SuppressLint("InflateParams")
    override fun inflate(inflater: LayoutInflater): View {
        rootView = inflater.inflate(R.layout.fragment_attenttion_user, null, false)
        return rootView
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        context?.let {
            // 设置padding
            view.setPadding(view.paddingLeft, view.paddingTop + getStatusBarHeight(it) + dp2px(it, 40), view.paddingRight, view.paddingBottom)
        }

        initView()
        initData()

        // refershPushView()
    }

    // 初次加载或刷新 -> 初始化状态
    private fun initData() {
        sv_state_view?.showLoading()

        this.loadAnchorFinish = false
        this.loadDynamicFinish = false
        this.anchorAttention = false
        this.dynamicAttention = false


        anchorPageIndex = 0
        dynamicPageIndex = 0

        anchorData.clear()

        if (NineShowApplication.mUserBase == null) {
            // 未登录获取推荐数据
            getRecommendAnchorData()
            getRecommendDynamicData()
        } else {
            // 获取主播数据
            getAttentionAnchorData()
            // 获取动态数据
            // getRecommendDynamicData()
            getAttentionDynamicData()
        }
    }

    // 这两个字段是为了标识title
    private var anchorAttention = false     // 标识主播数据是关注或推荐
    private var dynamicAttention = false    // 标识推荐数据是关注或推荐

    private var anchorPageIndex = 0     // 主播接口index
    private var dynamicPageIndex = 0    // 动态接口index

    private val dynamicData = arrayListOf<Dynamic>()
    private val anchorData = arrayListOf<AnchorInfo>()
    private val titleList = arrayListOf(anchorAttention, dynamicAttention)

    private lateinit var mLinearLayoutManager: LinearLayoutManager
    private lateinit var adapter: AttentionUserDynamicAdapter
    private fun initView() {
        smartRefreshLayout.setEnableRefresh(true)
        smartRefreshLayout.setOnRefreshListener {
            releaseVideoView()
            releasePlayer()
            hasMoreAnchorData = true
            initData()
        }

        smartRefreshLayout.setOnLoadMoreListener {
            if (dynamicAttention) {
                getAttentionDynamicData()
            } else {
                getRecommendDynamicData()
            }
        }

        sv_state_view?.setOnRefreshListener(this)

        mLinearLayoutManager = LinearLayoutManager(context, LinearLayoutManager.VERTICAL, false)
        adapter = AttentionUserDynamicAdapter(activity, titleList, anchorData, dynamicData, SmileyParser.getInstance())
        // 设置adapter
        recy.layoutManager = mLinearLayoutManager
        recy.adapter = adapter

        // 加载更多主播
        adapter.loadMoreAnchorData = {
            // 推荐主播接口没有分页
            if (dynamicAttention && hasMoreAnchorData) {
                getAttentionAnchorData(regionFefresh = true)
            }
        }

        adapter.setOnClickDynamicCallBack(object : DynamicDataAdapter.OnClickDynamicCallBack {
            override fun onCommentClick(position: Int, dynamic: Dynamic?) {
                activity?.let {
                    if (dynamic != null) {
                        CommentListFragmentDialog.create(dynamic).show(it.supportFragmentManager, "CommentListFragmentDialog")
                    }
                }
            }

            override fun onDeleteClick(position: Int, dynamic: Dynamic?) {
                dynamic ?: return
                showDeleteDialog(position, dynamic)
            }

        })

        // 音频播放时暂停视频的播放
        adapter.isAudioCurrentPlaying = {
            releaseVideoView()
        }

        initRecyScrollVideoPlay()

        messagecenter_tv_openpush.setOnClickListener {
            val intent = Intent()
            when {
                Build.VERSION.SDK_INT >= Build.VERSION_CODES.O -> {
                    intent.action = "android.settings.APP_NOTIFICATION_SETTINGS"
                    intent.putExtra("android.provider.extra.APP_PACKAGE", activity?.packageName)
                }
                Build.VERSION.SDK_INT >= Build.VERSION_CODES.LOLLIPOP -> {  //5.0
                    intent.action = "android.settings.APP_NOTIFICATION_SETTINGS"
                    intent.putExtra("app_package", activity?.packageName)
                    intent.putExtra("app_uid", activity?.applicationInfo?.uid)
                }
                Build.VERSION.SDK_INT == Build.VERSION_CODES.KITKAT -> {  //4.4
                    intent.action = Settings.ACTION_APPLICATION_DETAILS_SETTINGS
                    intent.addCategory(Intent.CATEGORY_DEFAULT)
                    intent.data = Uri.parse("package:" + activity?.packageName)
                }
                Build.VERSION.SDK_INT >= 15 -> {
                    intent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK)
                    intent.action = "android.settings.APPLICATION_DETAILS_SETTINGS"
                    intent.data = Uri.fromParts("package", activity?.packageName, null)
                }
            }
            startActivity(intent)
        }

        messagecenter_tv_close_push.setOnClickListener {
            AppCacheData.instance.attentionPushCloseStatus = 1
            rlPushNotification.setVisible(false)
        }

    }


    private fun showDeleteDialog(position: Int, dynamic: Dynamic) {
        CurrencyBottomDialog.create(context)
                .setFirstText("删除")
                .setFirstTextColor("#E82929")
                .setSecondHideView()
                .setOnClickCallback { type ->
                    if (type == BaseDialog.SELECT_FIRST) {
                        //删除评论
                        RequestManager.create().deleteDynamicTask(dynamic.dynamicid) {
                            adapter.dynamicData.removeAt(position - 1)
                            adapter.notifyItemRemoved(position)
                            ToastUtils.showShort("删除成功")
                        }
                    }
                }
    }

    /**
     * ==========================  播放视频语音 ================================
     */

    private var videoHeight: Int = 0
    fun initRecyScrollVideoPlay() {
        videoHeight = (context!!.resources.displayMetrics.density * 225).toInt() // 多5dp，因为有的手机高度不准确
        if (videoHeight <= 0) {
            return
        }
        recy.addOnScrollListener(object : RecyclerView.OnScrollListener() {
            override fun onScrollStateChanged(recyclerView: RecyclerView, newState: Int) {
                super.onScrollStateChanged(recyclerView, newState)
                handler.removeMessages(DiscoveryDynamicFragment.MSG_PLAY_VIDEO)
                handler.removeMessages(DiscoveryDynamicFragment.MSG_DYNAMIC_RECORD)

                if (newState == RecyclerView.SCROLL_STATE_IDLE) {
                    setRecyScrollVideoPlay()
                }
            }

            override fun onScrolled(recyclerView: RecyclerView, dx: Int, dy: Int) {
                super.onScrolled(recyclerView, dx, dy)
            }
        })
    }

    // 播放视频的view & position
    private var currentPlayVideoView: IjkVideoViewNew? = null
    private var currentPlayVideoPos = 0

    private fun setRecyScrollVideoPlay() {
        handler.removeMessages(DiscoveryDynamicFragment.MSG_PLAY_VIDEO) // 移动时候移除计时的监听
        handler.removeMessages(DiscoveryDynamicFragment.MSG_DYNAMIC_RECORD)
        if (dynamicData.isEmpty()) {
            return
        }
        val top: Int = mLinearLayoutManager.findFirstVisibleItemPosition()
        val bot: Int = mLinearLayoutManager.findLastVisibleItemPosition()
        NSLog.d("theStateChanged : ", "top : $top , bot : $bot")
        val msg = Message.obtain()
        msg.what = DiscoveryDynamicFragment.MSG_DYNAMIC_RECORD
        msg.arg1 = top
        msg.arg2 = bot
        handler.sendMessageDelayed(msg, 2000) // 上报动态id

        // 1. 先判断正在播放的视频，是否应该继续播放
        if (currentPlayVideoView != null && currentPlayVideoPos >= top && currentPlayVideoPos <= bot) {
            // 3. 满足2/3,可继续播放
            if (fitterVideoVisible(currentPlayVideoView)) {
                if (currentPlayVideoView?.isPlaying == true) {
                    releasePlayer() // 停止音频播放
                    NSLog.d("theStateChanged : result : ", "原来的视频还可以正常播放")
                    return
                }
                if (currentPlayVideoPos < 0 || currentPlayVideoPos >= dynamicData.size + 1) {   // 越界判断
                    releaseVideoView()
                    // 寻找下个可以播放的Video
                    findNextCanPlayVideo(top, bot, 1) // msg : 原来的video下标越界
                    return
                }
                NSLog.d("theStateChanged : result : ", "原来的视频还可以正常播放 , stop")
                releasePlayer() // 停止音频播放
                val proxy = NineShowApplication.getProxy()
                currentPlayVideoView?.let {
                    it.setRender(IjkVideoView.RENDER_SURFACE_VIEW)
                    it.videoPath = proxy.getProxyUrl(dynamicData[currentPlayVideoPos - 1]?.getShortvideo()?.getVideoUrl())
                    it.start()
                    it.visibility = View.VISIBLE
                    it.setOnCompletionListener(completionListener) // 设置播放完成监听
                }
            } else {
                // 4. 当前播放的View失效要停止,寻找下一个可以播放的video
                releaseVideoView()
                findNextCanPlayVideo(top, bot, 2) // msg : 原来的video在范围内，但是超过2/3区域
            }
        } else {
            // 5. 重置以前，寻找下一个可以播放的video
            if (currentPlayVideoView != null) {
                releaseVideoView()
            }

            // 6. 寻找新的可以播放的video
            findNextCanPlayVideo(top, bot, 3) // msg : 原来的video失效或不存在
        }
    }

    /**
     * 寻找下一个可以播放的视频
     */
    private fun findNextCanPlayVideo(top: Int, bot: Int, number: Int) {
        NSLog.d("theStateChanged : result : ", "寻找可以播放的视频 , number -> $number")
        if (top >= 0 && top < dynamicData.size + 1 && bot >= 0 && bot < dynamicData.size + 1 && top < bot) {       // 越界判断
            var i = 0

            // 7. 这里遍历进行寻找，寻找到合适的即停止
            i = top
            while (i <= bot) {
                if (i - 1 < 0 || dynamicData[i - 1].type != DynamicDataAdapter.TYPE_DYNAMIC_VIDEO) {                // 非视频类型继续遍历
                    i++
                    continue
                }
                val findIndex = i
                val view = mLinearLayoutManager.findViewByPosition(findIndex) ?: return
                val videoView: IjkVideoViewNew? = view?.findViewById(R.id.ijkPlayerView)
                // 8. 新找到的符合要求的(2/3区域)进行播放
                if (videoView != null && fitterVideoVisible(videoView)) {
                    val msg = Message.obtain()
                    msg.what = DiscoveryDynamicFragment.MSG_PLAY_VIDEO
                    msg.obj = videoView
                    msg.arg1 = findIndex
                    // 9. 延迟1s播放
                    handler.sendMessageDelayed(msg, 1000)
                    NSLog.d("theStateChanged : result : ", "找到可以播放的 video ... pos -> $findIndex ... number -> $number")
                    break
                }
                i++
            }
            if (i == bot + 1) {
                releaseVideoView()
                NSLog.d("theStateChanged : result : ", "未找到可以播放的 video view , number -> $number")
            }
        }
    }

    val MSG_PLAY_VIDEO = 0 // 用于播放视频

    val MSG_DYNAMIC_RECORD = 1 // 用于记录动态

    private val handler = Handler { msg ->
        val what = msg.what
        if (what == MSG_PLAY_VIDEO && dynamicData != null && msg.arg1 < dynamicData.size + 1) {
            val findIndex = msg.arg1
            // 10. 存储记录
            if (dynamicData[findIndex - 1] != null && dynamicData[findIndex - 1].shortvideo != null) {
                releasePlayer() // 停止音频播放
                currentPlayVideoView = msg.obj as? IjkVideoViewNew
                currentPlayVideoPos = findIndex
                currentPlayVideoView?.setRender(IjkVideoView.RENDER_SURFACE_VIEW)
                val proxy = NineShowApplication.getProxy()
                currentPlayVideoView?.setVideoPath(proxy.getProxyUrl(dynamicData[findIndex - 1].shortvideo.videoUrl))
                currentPlayVideoView?.seekTo(0)
                currentPlayVideoView?.start()
                currentPlayVideoView?.setVisibility(View.VISIBLE)
                currentPlayVideoView?.setOnCompletionListener(completionListener) // 设置播放完成监听
            }
        }

        // 上报动态
        if (what == MSG_DYNAMIC_RECORD && dynamicData != null) {
            val start = msg.arg1
            val end = msg.arg2
            if (start >= 1 && start < dynamicData.size + 1 && end >= 1 && end < dynamicData.size + 1) {
                for (i in start..end) {
                    addElement(dynamicData[i - 1].dynamicid)
                }
            }
        }
        true
    }

    private val completionListener = IMediaPlayer.OnCompletionListener {
        currentPlayVideoView?.let {
            it.seekTo(0) // 重新开始播放
            it.start()
        }
    }

    // 释放视频资源
    private fun releaseVideoView() {
        handler.removeMessages(MSG_PLAY_VIDEO)

        if (currentPlayVideoView == null) {
            return
        }

        currentPlayVideoView?.let {
            it.visibility = View.GONE
            it.setOnCompletionListener(null)
            it.stopPlayback()
            it.release(true)
            it.setRender(IjkVideoView.RENDER_NONE)
            it.releaseWithoutStop()
            it.stopBackgroundPlay()
        }


        currentPlayVideoView = null
        currentPlayVideoPos = -1
    }

    /**
     * 计算视频的区域是否满足2/3的显示
     */
    private fun fitterVideoVisible(videoView: IjkVideoViewNew?): Boolean {
        if (videoView == null) {
            return false
        }
        // 2. 判断2/3可见区域  ijkPlayerView
        val rect = Rect()
        videoView.getLocalVisibleRect(rect)
        val botView = rect.bottom
        val topView = rect.top
        val visibleView = (botView - topView) * 1f
        NSLog.d("theStateChanged : rectView : ", "height : $videoHeight , bot : $botView , top : $topView")
        return botView >= 0 && botView <= videoHeight && visibleView / videoHeight > 2f / 3f
    }

    override fun onResume() {
        super.onResume()
        handler.postDelayed({ setRecyScrollVideoPlay() }, 500)
        StatisticsUtil.onEvent(StatisticsEventID.UM_DYNAMIC_TAB_CHANGE)
        refreshPushView()
    }

    override fun onPause() {
        super.onPause()
        releaseVideoView()
        // 上报动态数据
        // 上报动态数据
        upDynamicDataLoad()
        releasePlayer() // 停止音频播放
    }

    override fun setUserVisibleHint(isVisibleToUser: Boolean) {
        super.setUserVisibleHint(isVisibleToUser)
        if (isVisibleToUser) {
            StatisticsUtil.onEvent(StatisticsEventID.UM_DYNAMIC_TAB_CHANGE)
            handler.postDelayed({ setRecyScrollVideoPlay() }, 500)
        } else {
            releaseVideoView()
            releasePlayer()
            // FollowHelper.INSTANCE.clearFollowType();
        }
    }

    override fun onDestroy() {
        super.onDestroy()
        handler.removeCallbacksAndMessages(null)
        recy?.clearOnScrollListeners()
    }

    override fun registerReceiver() = true

    override fun setBroadcastFilter(filter: IntentFilter?) {
        super.setBroadcastFilter(filter)
        filter?.addAction(NSReceiverAction.DYNAMIC_COMMENT)
        filter?.addAction(NSReceiverAction.DYNAMIC_PRAISE)
        filter?.addAction(NSReceiverAction.LOGOUT_ACTION)
        filter?.addAction(NSReceiverAction.LOGIN_ACTION)
    }

    override fun onReceive(action: String?, type: Int, bundle: Bundle?) {
        super.onReceive(action, type, bundle)
        action ?: return
        bundle ?: return

        val uid = bundle.getString("uid")
        val currentUid = adapter.getData()?.info?.uid
        if (TextUtils.equals(uid, currentUid)) {
            when (action) {
                NSReceiverAction.DYNAMIC_COMMENT -> {
                    val isComment = bundle.getBoolean("isComment")
                    val replyNum = if (isComment) {
                        adapter.getData()?.replynum?.let {
                            it + 1
                        }?:let{
                            1
                        }
                    } else {
                        adapter.getData()?.replynum?.let {
                            it - 1
                        }?:let{
                            0
                        }
                    }
                    adapter.getData()?.replynum = replyNum as Long
                    adapter.notifyDataSetChanged()
                }
                NSReceiverAction.DYNAMIC_PRAISE -> {
                    val upNum = adapter.getData()?.upnum ?: 0 + 1
                    adapter.getData()?.upnum = upNum
                    adapter.getData()?.ispraise = 1
                    adapter.notifyDataSetChanged()
                }
            }
        }

        if (action == NSReceiverAction.LOGIN_ACTION || action == NSReceiverAction.LOGOUT_ACTION) {
            initData()
        }
    }

    /**
     * ==========================  播放视频语音 ================================
     */

    // todo : 1 . 获取关注动态数据  // https://api.9xiu.com/dynamic/dynamic/getFollowDynamicList
    private fun getAttentionDynamicData() {
        val params = NSRequestParams()
        params.put("page", dynamicPageIndex)
        val token = NineShowApplication.mUserBase?.token
        token?.let {
            params.put("token", it)
        }

        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_ATTENTION_DYNAMIC_LIST, params, object : NSGsonObjectNewCallback<DynamicResultInfo>() {
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: DynamicResultInfo?) {
                NSLog.d(Tag, "关注-动态数据 : index : $dynamicPageIndex size : ${response?.data?.size ?: -1}")
                if (statusCode == 200 && response != null && response.data != null) {
                    if (dynamicPageIndex == 0) {
                        dynamicData.clear()
                        if (response.data.size > 0) {
                            dynamicData.addAll(response.data)
                            dynamicAttention = true
                            dynamicPageIndex++
                            needNotifyAdapterChanged(loadDynamicFinish = true)
                        } else {
                            getRecommendDynamicData()
                        }
                    } else {
                        dynamicData.addAll(response.data)
                        if (response.data.size > 0) {
                            dynamicPageIndex++
                        }
                        refreshAdapterData()
                    }

                } else {
                    // 获取推荐主播数据
                    if (dynamicPageIndex == 0) {
                        getRecommendDynamicData()
                    }
                }
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                if (dynamicPageIndex == 0) {
                    getRecommendDynamicData()
                    sv_state_view?.showError(context?.resources?.getString(R.string.empty_no_network))
                }
            }

        })
    }

    // todo : 2. 获取推荐动态数据       https://api.9xiu.com/dynamic/dynamic/getHallList
    private fun getRecommendDynamicData() {
        dynamicAttention = false

        val params = NSRequestParams()
        params.put("page", dynamicPageIndex)
        params.put("type", 1)
        val token = NineShowApplication.mUserBase?.token
        token?.let {
            params.put("token", it)
        }
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_DYNAMIC_SQUARE_LIST, params, object : NSGsonObjectNewCallback<DynamicResultInfo>() {
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: DynamicResultInfo?) {
                NSLog.d(Tag, "推荐-动态数据 : index : $dynamicPageIndex , size : ${response?.data?.size ?: -1}")
                if (dynamicPageIndex == 0) {
                    dynamicData.clear()
                }
                response?.data?.let {
                    dynamicData.addAll(it)
                }

                // 刷新
                if (dynamicPageIndex == 0) {
                    needNotifyAdapterChanged(loadDynamicFinish = true)
                } else {
                    refreshAdapterData()
                }

                dynamicPageIndex++
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                if (dynamicPageIndex == 0) {
                    needNotifyAdapterChanged(loadDynamicFinish = true)
                    sv_state_view?.showError(context?.resources?.getString(R.string.empty_no_network))
                }
            }

        })
    }

    private var hasMoreAnchorData = true

    // FIXME : 1. 获取关注主播数据  https://api.9xiu.com/dynamic/videoshort/followList
    private var isLoadingAnchor = false
    private fun getAttentionAnchorData(regionFefresh: Boolean = false) {
        if (isLoadingAnchor) {
            return
        }
        isLoadingAnchor = true
        val params = NSRequestParams()
        params.put("page", anchorPageIndex)
        params.put("type", 1)
        val uid = NineShowApplication.mUserBase?.uid
        uid?.let {
            params.put("uid", it)
        }

        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.USER_PAGE_FOLLOW_LIST, params, object : NSGsonObjectNewCallback<AttentionAnchorNewBean>() {
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: AttentionAnchorNewBean?) {
                NSLog.d(Tag, "关注-主播数据 : index : $anchorPageIndex size : ${response?.data?.size ?: -1}")
                if (statusCode == 200 && response != null && response.data != null) {
                    if (anchorPageIndex == 0) {
                        anchorData.clear()
                        anchorData.addAll(response.data)
                        // 此时是初次加载或刷新
                        if (response.data.size > 3) {
                            anchorPageIndex++
                            anchorAttention = true
                            // 展示关注主播接口数据
                            needNotifyAdapterChanged(loadAnchorFinish = true)
                        } else {
                            // 获取推荐主播数据
                            getRecommendAnchorData()
                        }
                    } else {
                        anchorData.addAll(response.data)
                        if (response.data.size > 0) {
                            anchorPageIndex++
                        }

                        // 区域刷新
                        if (regionFefresh) {
                            if (response.data.size <= 0) {
                                hasMoreAnchorData = false       // 没有更多数据
                            }
                            refreshAdapterDataRegion()
                        } else {
                            refreshAdapterData()
                        }
                    }
                } else {
                    // 获取推荐主播数据
                    if (anchorPageIndex == 0) {
                        getRecommendAnchorData()
                    }
                }
                isLoadingAnchor = false
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                if (anchorPageIndex == 0) {
                    getRecommendAnchorData()
                }
                isLoadingAnchor = false
            }
        })
    }

    private var isLoading = false

    // FIXME : 2. 获取推荐主播数据
    private fun getRecommendAnchorData() {
        if (isLoading) {
            return
        }

        isLoading = true

        anchorAttention = false
        hasMoreAnchorData = false

        val params = NSRequestParams()
        var token = NineShowApplication.mUserBase?.token
        if (TextUtils.isEmpty(token)) {
            token = UserBase().token
        }

        params.put("token", token)          // https://api.9xiu.com/channel/main/openFollow

        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_ONLINEATTENTION_LIST, params, object : NSGsonObjectNewCallback<AttentionRecommendedResultInfo>() {
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: AttentionRecommendedResultInfo?) {
                NSLog.d(Tag, "推荐-主播数据 : index : $anchorPageIndex size : ${response?.data?.recommend?.size ?: -1}")
                // 过滤
                response?.data?.recommend?.let { recommendData ->
                    val data: MutableList<AnchorInfo>? = recommendData as? MutableList<AnchorInfo>
                    if (data.isNullOrEmpty()) {
                        anchorData.addAll(recommendData)
                    } else {
                        filterData(data)
                        data.let {
                            anchorData.addAll(it)
                        }
                    }
                    // 此接口没有分页，不需要处理page
                }
                needNotifyAdapterChanged(loadAnchorFinish = true)

                isLoading = false
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                needNotifyAdapterChanged(loadAnchorFinish = true)
                isLoading = false
            }

        })
    }

    private fun filterData(recommend: MutableList<AnchorInfo>?) {
        if (anchorData.isNullOrEmpty() || recommend.isNullOrEmpty()) {
            return
        }
        val list = arrayListOf<AnchorInfo>()
        for (info in anchorData) {
            for (recomInfo in recommend) {
                if (TextUtils.equals(info.uid, recomInfo.uid)) {
                    list.add(recomInfo)
                }
            }
        }

        if (list.isNullOrEmpty()) {
            return
        }

        for (filerInfo in list) {
            recommend.remove(filerInfo)
        }
    }

    private var loadAnchorFinish = false
    private var loadDynamicFinish = false

    // 两个接口同时请求数据时刷新同步
    private fun needNotifyAdapterChanged(loadAnchorFinish: Boolean? = null, loadDynamicFinish: Boolean? = null) {
        loadAnchorFinish?.let { this.loadAnchorFinish = it }
        loadDynamicFinish?.let { this.loadDynamicFinish = it }

        if (this.loadAnchorFinish && this.loadDynamicFinish) {
            // 刷新adapter
            refreshAdapterData()

            sv_state_view?.showSuccess()

            handler.postDelayed({ setRecyScrollVideoPlay() }, 500)
        }
    }

    private fun refreshAdapterDataRegion() {
        adapter.notifyItemChanged(0, AttentionUserDynamicAdapter.TYPE_REFRESH_REGION)
    }

    private fun refreshAdapterData() {
        titleList.clear()
        titleList.add(anchorAttention)
        titleList.add(dynamicAttention)
        adapter.notifyDataSetChanged()

        endRefreshOrLoadMore()
    }


    private fun endRefreshOrLoadMore() {
        smartRefreshLayout?.finishLoadMore()
        smartRefreshLayout?.finishRefresh()
    }

    // 双击 tab 的刷新
    fun refreshData() {
        recy?.scrollToPosition(0)
        smartRefreshLayout?.autoRefresh()
    }

    override fun onRefreshView() {
        initData()
    }

    private var notification: NotificationManagerCompat? = null
    private fun refreshPushView() {
        val activityTemp = activity
        if (activityTemp == null) {
            rlPushNotification.setVisible(false)
            return
        }

        notification = NotificationManagerCompat.from(activityTemp)
        val enable = notification?.areNotificationsEnabled() ?: true
        if (enable || AppCacheData.instance.attentionPushCloseStatus == 1) {
            rlPushNotification.setVisible(false)
        } else {
            rlPushNotification.setVisible(true)
        }
    }

}