package com.ninexiu.sixninexiu.fragment

import android.app.Dialog
import android.content.Intent
import android.content.IntentFilter
import android.os.Bundle
import android.os.Handler
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import com.google.gson.Gson
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.activity.SubPageActivity
import com.ninexiu.sixninexiu.activity.VideoShowActivity
import com.ninexiu.sixninexiu.adapter.HomeHotAdapter
import com.ninexiu.sixninexiu.bean.*
import com.ninexiu.sixninexiu.common.statistics.StatisticsEventID
import com.ninexiu.sixninexiu.common.statistics.StatisticsUtil
import com.ninexiu.sixninexiu.common.util.*
import com.ninexiu.sixninexiu.common.util.CountTechnology.TDEventMap
import com.ninexiu.sixninexiu.common.util.CountTechnology.TDEventName
import com.ninexiu.sixninexiu.common.util.manager.RequestManager
import com.ninexiu.sixninexiu.common.util.manager.RequestManagerCallBack.MicroVideoCallBack
import com.ninexiu.sixninexiu.values.EnterRoomValue
import com.ninexiu.sixninexiu.view.RecyclerView.XGridLayoutManager
import com.ninexiu.sixninexiu.view.StateView
import com.ninexiu.sixninexiu.view.WrapContentGridLayoutManager
import com.ninexiu.sixninexiu.view.dialog.BanUniversalDialog
import com.selector.picture.ui.StatusBarUtil
import kotlinx.android.synthetic.main.layout_for_show_state.*
import kotlinx.android.synthetic.main.ns_hot_new_fragment.*
import java.io.Serializable
import java.util.*
import kotlin.collections.ArrayList

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/06/23
 *     desc   : 新的热门
 *     version: 1.0
 * </pre>
 */
class HomeHotFragment : BasePagerFragment(), StateView.OnRefreshViewListener {
    companion object {
        const val Tag = "HomeHotFragment"
        const val TAG_PROCESS = "tag_process"
        const val KEY_TAB_PAGE_POSITION = "page_position"
    }

    val pagePosition by lazy {
        arguments?.getInt(KEY_TAB_PAGE_POSITION,0)

    }

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View? {
        return inflater.inflate(R.layout.ns_hot_new_fragment, container, false)
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        initView()
        initData()
        NSLog.d(TAG_PROCESS, "------------  数据初始化")
    }

    private fun initData() {
        sv_state_view?.showLoading()
        // 获取所有分类数据
        getAllCategoryData()
        // 获取内容创造营数据
        getCategoryCardData(allLoad = true)
        // 获取所有标签数据
        // getAllLabelData()
        // 获取banner数据
        getAllBannerData()
    }

    private var bannerInfos: AdvertiseResultInfo? = null

    // 接口 : 获取所有banner数据
    private fun getAllBannerData() {
        HomeHotHelper.getAllBannerData(
                { bannerInfo ->
                    this.bannerInfos = bannerInfo
                    needNotifyAdapterChanged(bannerFinish = true)
                    NSLog.d(Tag, "轮播数据 : ${bannerInfo.data?.size ?: "轮播数据为空"}")
                },
                { code, msg ->
                    needNotifyAdapterChanged(bannerFinish = true)
                    NSLog.d(Tag, "轮播加载 error : $code , ${msg ?: "网络错误"}")
                }
        )
    }

    private var labelInfo: HomeTagInfo? = null

    // 接口 : 加载所有的标签数据 : 音乐，舞蹈，娱乐，视频，校园
    private fun getAllLabelData() {
        HomeHotHelper.getAllLabelData(
                { labelInfo ->
                    this.labelInfo = labelInfo
                    // needNotifyAdapterChanged(labelFinish = true)
                    NSLog.d(Tag, "标签数据 : ${labelInfo.data?.size ?: "标签数据为空"}")
                },
                { code, msg ->
                    // needNotifyAdapterChanged(labelFinish = true)
                    NSLog.d(Tag, "标签加载 error : $code , ${msg ?: "网络错误"}")
                })
    }

    private var allCategoryInfo: MoreTypeResultInfo? = null        // 所有分类数据(原始数据)

    // 接口 : 加载热门fragment所有分类下的数据 :  精选，推荐，新人，热门，内容创建营
    private fun getAllCategoryData() {
        hotPage = 1
        HomeHotHelper.getAllCategoryData(
                // 请求成功
                { allCategoryInfo ->
                    this.allCategoryInfo = allCategoryInfo
                    NSLog.d(Tag, "所有分类数据热门分类 : ${allCategoryInfo.data?.hot?.size ?: "热门数据为空"}")
                    // 因为是刚请求的数据,不需要做随机处理了,数据进行组合处理
                    needNotifyAdapterChanged(categoryFinish = true)
                    endRefreshOrLoadMore()

                    // 记录当前时间,开始刷新倒计时
                    lastRefreshTime = System.currentTimeMillis()
                    handler.removeCallbacks(runnable)
                    handler.postDelayed(runnable, duration)
                },

                // 请求数据失败
                errorLabel@{ code, msg, ban ->
                    NSLog.d(Tag, "所有分类数据 error : $code , ${msg ?: "网络错误"}")
                    needNotifyAdapterChanged(categoryFinish = true)
                    endRefreshOrLoadMore()

                    // 显示封禁dialog
                    if (ban != null) {
                        activity?.runOnUiThread { BanUniversalDialog.create(activity, ban).show() }
                        return@errorLabel
                    }

                    if (NetworkUtil.isNetworkState()) {
                        sv_state_view?.showEmpty(context?.resources?.getString(R.string.sv_show_no_anchor))
                    } else {
                        MyToast.MakeToast(getString(R.string.request_no_network))
                        sv_state_view?.showError(context?.resources?.getString(R.string.empty_no_network))
                    }
                })
    }

    private var hotPage = 1
    private var hotCategoryInfo: MoreTypeResultInfo? = null

    // 接口 : 上拉加载 -> 获取热门的分页数据 -> 添加进原始数据
    private fun getCategoryHotData() {
        HomeHotHelper.getCategoryHotData(hotPage,
                { hotMoreInfos ->
                    this.hotCategoryInfo = hotMoreInfos
                    NSLog.d(Tag, "热门分类分页数据 : $hotPage , ${hotCategoryInfo?.data?.hot?.size ?: "热门分类分页加载为空"}")
                    // 热门数据拼接(临时数据)
                    hotMoreInfos.data?.hot?.let {
                        templeCategoryInfo?.data?.hot?.addAll(it)
                    }
                    if (hotCategoryInfo?.data?.hot?.size ?: 0 > 0) {
                        hotPage++
                    }
                    setAdapterData()
                    endRefreshOrLoadMore()
                },
                { code, msg ->
                    endRefreshOrLoadMore()
                    NSLog.d(Tag, "热门分类分页加载 error : $code , ${msg ?: "网络错误"}")
                }
        )
    }

    private var cardCategoryInfo: MoreTypeResultInfo? = null

    // 接口 : 下拉刷新(未满足刷新间隔要求) -> 获取内容创造营(卡片)数据 -> 替换原始数据
    private fun getCategoryCardData(allLoad: Boolean = false) {
        hotPage = 1
        HomeHotHelper.getCategoryCardData(
                onSuccess = { cardRefreshInfos ->
                    this.cardCategoryInfo = cardRefreshInfos
                    NSLog.d(Tag, "内容创造营刷新 : ${cardCategoryInfo?.data?.useCardRoom?.size ?: "内容创造营刷新加载为空"}")
                    if (allLoad) {
                        needNotifyAdapterChanged(cardFinish = true)
                    } else {
                        // 替换原始数据，并做随机处理，组合处理
                        allCategoryInfo?.data?.useCardRoom = cardRefreshInfos.data?.useCardRoom
                        doRandomAllCategoryData()
                        dealAllCategoryData()

                        setAdapterData()
                        endRefreshOrLoadMore()
                    }
                },
                onFail = { code, msg ->
                    if (allLoad) {
                        needNotifyAdapterChanged(cardFinish = true)
                    }
                    endRefreshOrLoadMore()
                    NSLog.d(Tag, "内容创造营刷新 error : $code , ${msg ?: "网络错误"}")
                }
        )
    }

    private var templeCategoryInfo: MoreTypeResultInfo? = null

    // 组合处理所有的分类数据 && 针对临时数据进行处理 && 符合一系列规则(详见 : HomeHotHelper)
    private fun dealAllCategoryData() {
        if (allCategoryInfo == null || allCategoryInfo?.data == null) {
            return
        }
        // 构建临时数据
        try {
            val builder = Gson()
            templeCategoryInfo = builder.fromJson(builder.toJson(allCategoryInfo), MoreTypeResultInfo::class.java)
        } catch (e: Exception) {
            // todo : 是否需要做一系列处理
            NSLog.d(Tag, "原始数据 -> 临时数据 通过 Gson 序列化失败 : " + e.message)
        }

        if (templeCategoryInfo == null || templeCategoryInfo?.data == null) {
            return
        }

        // 对数据进行处理
        // HomeHotHelper.helpPrint(templeCategoryInfo, "before -> ")
        HomeHotHelper.dealAllCategoryData(templeCategoryInfo)
        // HomeHotHelper.helpPrint(templeCategoryInfo, "after -> ")
    }


    // 将数据进行一个随机处理 && 只针对原始数据 && 刷新时调用(且不满足刷新时间时候)
    private fun doRandomAllCategoryData() {
        if (allCategoryInfo == null || allCategoryInfo?.data == null) {
            return
        }

        /*allCategoryInfo!!.data.hot.forEachIndexed { index, anchorInfo ->
            NSLog.d(Tag,"原始 : index : $index , ${anchorInfo.nickname}")
        }*/

        allCategoryInfo = HomeHotHelper.doRandomAllCategoryData(allCategoryInfo)

        /*allCategoryInfo!!.data.hot.forEachIndexed { index, anchorInfo ->
            NSLog.d(Tag,"随机 : index : $index , ${anchorInfo.nickname}")
        }*/
    }

    /**
     * 接口方法
     * ======================== ======================== ======================== ======================== ========================
     * 工具方法
     */

    // 首次&空界面,adapter要等待三个接口都执行完毕再刷新
    private var loadAllCategoryFinish = false
    private var loadBannerFinish = false
    private var loadCardFinish = false
    private fun needNotifyAdapterChanged(categoryFinish: Boolean? = null, bannerFinish: Boolean? = null,cardFinish : Boolean? = null) {
        NSLog.d(Tag, "categoryFinish : $categoryFinish , bannerFinish : $bannerFinish , cardFinish : $cardFinish")
        categoryFinish?.let { this.loadAllCategoryFinish = it }
        bannerFinish?.let { this.loadBannerFinish = it }
        cardFinish?.let { this.loadCardFinish = it }

        if (loadAllCategoryFinish && loadBannerFinish && loadCardFinish) {
            // 三个接口都执行完毕,如果分类接口数据为空,那么展示空界面
            if (allCategoryInfo != null && allCategoryInfo?.data != null) {

                allCategoryInfo?.data?.useCardRoom = cardCategoryInfo?.data?.useCardRoom
                // 不需要做随机处理
                dealAllCategoryData()

                sv_state_view?.showSuccess()
                setAdapterData()
                NSLog.d(TAG_PROCESS, "------------  数据加载完成,刷新界面")
                // HomeHotHelper.helpPrint(templeCategoryInfo, "刷新界面")
            }
        }
    }

    // 空界面时的刷新操作
    override fun onRefreshView() {
        // 重置参数,保证三个接口执行完毕再进行刷新
        needNotifyAdapterChanged(categoryFinish = false, bannerFinish = false, cardFinish = false)
        initData()
    }

    // 所有的数据汇总在一块 : 精选，标签，推荐，新人，banner，热门，内容创建营
    private var adapter: HomeHotAdapter? = null

    // 初始化view
    private fun initView() {
        hotRecy.layoutManager = WrapContentGridLayoutManager(context, 2)
        adapter = HomeHotAdapter(list)
        adapter?.bindToRecyclerView(hotRecy)

        // 手动刷新
        smartRefreshLayout.setOnRefreshListener {
            // 判断是否到了刷新时间,到了刷新(因为有两分钟自动刷新，基本不可能), 没到(刷新卡片数据，随机处理)
            judgeRefreshNextStep()
        }

        // 上拉加载
        smartRefreshLayout.setOnLoadMoreListener {
            getCategoryHotData()    // 获取热门分类分页数据
        }

        // 标签中打开视频
        adapter?.openVideoAction = {
            openVideo()
        }

        sv_state_view?.setOnRefreshListener(this)

        adapter?.showMoreAnchor = { type ->
            showMoreAnchorFromType(type)
        }
    }

    private val list: ArrayList<HomeInfo> = ArrayList()

    // 设置adapter数据
    private fun setAdapterData() {
        HomeHotHelper.dealAllHomeInfo(templeCategoryInfo, labelInfo, bannerInfos) {
            list.clear()
            list.addAll(it)
            adapter?.notifyDataSetChanged()
        }
    }


    private val handler: Handler = Handler()
    private val runnable: Runnable = Runnable {
        NSLog.d(TAG_PROCESS, "------------  自动刷新 : 倒计时完成,刷新数据")
        doRefresh() // 自动刷新
    }

    private val duration = 2 * 60 * 1000L
    private var lastRefreshTime: Long = System.currentTimeMillis()

    // 手动刷新操作
    private fun judgeRefreshNextStep() {
        if (System.currentTimeMillis() - lastRefreshTime > duration) {
            NSLog.d(TAG_PROCESS, "------------  手动刷新 : 倒计时完成,刷新数据")
            // 真正刷新
            handler.removeCallbacks(runnable)
            doRefresh()
        } else {
            NSLog.d(TAG_PROCESS, "------------  手动刷新 : 倒计时未完成,刷新卡片房数据")
            // 其他数据不刷新 ，只刷新卡片房即可(要保证卡片房实时性)
            getCategoryCardData()
        }
    }

    private fun doRefresh() {
        loadAllCategoryFinish = false
        loadCardFinish = false
        getAllCategoryData()
        getCategoryCardData(allLoad = true)
    }

    /**
     * ------------------------------------------
     *  优化
     */
    // 优化 : setUserVisibleHint , onResume , onPause 是为了优化 : 用户不在当前界面，即使时间到了也不刷新，等用户切换回来再刷新

    // 数数科技统计
    private val liveEventMap: MutableMap<String, Int> = TDEventMap.liveEventMap

    override fun setUserVisibleHint(isVisibleToUser: Boolean) {
        super.setUserVisibleHint(isVisibleToUser)
        judgeRefreshFromPageVisible(visibleToUser = isVisibleToUser)
    }

    override fun onResume() {
        super.onResume()
        judgeRefreshFromPageVisible(resume = true)
    }

    override fun onPause() {
        super.onPause()
        judgeRefreshFromPageVisible(resume = false)
    }

    private var watchDuration: Long = 0L        // 统计观看时长
    private var isVisibleToUser: Boolean = false
    private var isResume: Boolean = false
    private fun judgeRefreshFromPageVisible(visibleToUser: Boolean? = null, resume: Boolean? = null) {
        handler.removeCallbacks(runnable)

        visibleToUser?.let { isVisibleToUser = it }
        resume?.let { isResume = it }

        val current = System.currentTimeMillis() - lastRefreshTime
        if (isVisibleToUser && isResume) {
            if (current > duration) {
                NSLog.d(TAG_PROCESS, "------------  界面切换 : 可以刷新")
                doRefresh()
            } else {
                NSLog.d(TAG_PROCESS, "------------  界面切换 : 重新开始倒计时 -> ${(duration - current) / 1000} , lastRefreshTime : $lastRefreshTime")
                handler.postDelayed(runnable, duration - current)
            }

            watchDuration = System.currentTimeMillis()
        } else {
            // 不可见的时候移除(上面进行了统一移除)
            // handler.removeCallbacks(runnable)
            NSLog.d(TAG_PROCESS, "------------  界面切换 : 移除倒计时 -> ${(duration - current) / 1000} , lastRefreshTime : $lastRefreshTime")

            watchDuration = System.currentTimeMillis() - watchDuration
            if (watchDuration > 1000) {
                val tempDuration = (liveEventMap[TDEventName.LIVE_WARTH_DUATION]
                        ?: 0 + watchDuration / 1000).toInt()
                liveEventMap[TDEventName.LIVE_WARTH_DUATION] = tempDuration
            }

        }
    }

    /**
     * 优化
     * ------------------------------------------
     */

    private fun endRefreshOrLoadMore() {
        smartRefreshLayout?.finishLoadMore()
        smartRefreshLayout?.finishRefresh()
    }

    override fun setBroadcastFilter(filter: IntentFilter?) {
        super.setBroadcastFilter(filter)
        filter?.addAction(NSReceiverAction.ACTION_MAIN_PAGE_DOUBLE_CLICK)
        filter?.addAction(NSReceiverAction.ACTION_TEENS_CONTENTTALENT_USEROOM)
        filter?.addAction(NSReceiverAction.ACTION_RANDOM_OPENLIVEROOM)
        filter?.addAction(NSReceiverAction.ACTION_TDUP_LIVEIPDUATION)
    }

    override fun registerReceiver(): Boolean = true

    override fun onReceive(action: String?, type: Int, bundle: Bundle?) {
        super.onReceive(action, type, bundle)
        when (action) {
            NSReceiverAction.ACTION_MAIN_PAGE_DOUBLE_CLICK -> {     // 双击刷新
                if (!Utils.isNotClickable()) {
                    if (bundle?.getInt("current_index") ?: -1 == pagePosition) {
                        NSLog.d(TAG_PROCESS, " --->   双击刷新")
                        hotRecy.smoothScrollToPosition(0)
                        // 判断是否到了刷新时间,到了刷新(因为有两分钟自动刷新，基本不可能), 没到(刷新卡片数据，随机处理)
                        smartRefreshLayout?.autoRefresh()
                    }
                }
            }
            NSReceiverAction.ACTION_TEENS_CONTENTTALENT_USEROOM -> {    // 使用了卡片，获取所有数据
                handler.removeCallbacks(runnable)
                doRefresh()
            }
            NSReceiverAction.ACTION_RANDOM_OPENLIVEROOM -> {
                // 推送随机打开推荐主播数据
                openRandomAnchorRoom()
            }
            NSReceiverAction.ACTION_TDUP_LIVEIPDUATION -> {     // 统计观看时长
                watchDuration = System.currentTimeMillis() - watchDuration
                if (watchDuration > 1000) {
                    val tempDuration = (liveEventMap[TDEventName.LIVE_WARTH_DUATION]
                            ?: 0 + watchDuration / 1000).toInt()
                    liveEventMap[TDEventName.LIVE_WARTH_DUATION] = tempDuration
                }
            }
        }
    }

    // 推送随机打开推荐主播数据
    private fun openRandomAnchorRoom() {
        var list = allCategoryInfo?.data?.recommend
        if (list?.isNullOrEmpty() != false) {
            list = allCategoryInfo?.data?.hot
        }

        if (list?.isNullOrEmpty() == false) {
            val anchorInfo = list[Random().nextInt(list.size)]
            anchorInfo.enterFrom = EnterRoomValue.ENTER_ROOM_HOMEPAGE_HOT
            Utils.openLiveRoom(context, anchorInfo)
        }
    }

    // 用户点击Title查看更多
    private fun showMoreAnchorFromType(type: Int) {
        NSLog.d(TAG_PROCESS, "clickType : $type")
        var templeList: ArrayList<AnchorInfo>? = ArrayList()
        var jumpToTag = -1
        var liveEventMapKey: String? = null
        when (type) {
            HomeInfo.TYPE_RECOMMEND -> {
                jumpToTag = 0
                templeList = allCategoryInfo?.data?.recommend
                liveEventMapKey = TDEventName.LIVE_MORE_RECOMMEND
                StatisticsUtil.onEvent(StatisticsEventID.MAIN_RECOMEND_MORE)
            }
            HomeInfo.TYPE_NEW -> {
                jumpToTag = 2
                templeList = allCategoryInfo?.data?.newRecommend
                liveEventMapKey = TDEventName.LIVE_MORE_NEWANTHOR
                StatisticsUtil.onEvent(StatisticsEventID.MAIN_BEST_NEW_MORE)
            }
            HomeInfo.TYPE_HOT -> {
                jumpToTag = 4
                liveEventMapKey = TDEventName.LIVE_MORE_HOT
                StatisticsUtil.onEvent(StatisticsEventID.MAIN_HOT_MORE)
            }
        }

        if (liveEventMapKey != null) {
            val count = liveEventMap[liveEventMapKey] ?: 0.plus(1)
            liveEventMap[liveEventMapKey] = count
        }

        if (templeList != null) {
            val intent = Intent(context, SubPageActivity::class.java)
            intent.putExtra(SubPageActivity.CLASSFRAMENT, HotNewTableMoreFragment::class.java)
            val bundle = Bundle()
            bundle.putInt("channelType", jumpToTag)
            val hotData = allCategoryInfo?.data?.hot
            if (hotData?.isNullOrEmpty() == false) {
                bundle.putSerializable("table", hotData)
            }
            if (!templeList.isNullOrEmpty()) {
                bundle.putSerializable("table01", templeList)
            }
            intent.putExtra("bundle", bundle)
            startActivity(intent)
        }
    }

    // 打开标签视频页面
    private fun openVideo() {
        showOrHideDialog(true)
        RequestManager.create().getVideoListData(0, MicroVideoCallBack { response, loadState ->
            showOrHideDialog(false)
            if (response == null || response.data == null) {
                return@MicroVideoCallBack
            }
            if (loadState == RequestManager.LOAD_SUCCESS) {
                VideoShowActivity.start(activity, 0.toString(), 4, true, response.data as Serializable)
            }
        })
    }

    var dialog: Dialog? = null
    private fun showOrHideDialog(show: Boolean) {
        activity ?: return
        if (show) {
            if (dialog == null) {
                dialog = Utils.showProgressDialog(activity, "正在加载...", false)
            }
            dialog?.show()
            return
        }

        val finish = activity?.isFinishing ?: true
        if (!finish && dialog != null && dialog?.isShowing == true) {
            dialog?.dismiss()
        }
    }
}