package com.ninexiu.sixninexiu.fragment

import android.content.IntentFilter
import android.os.Bundle
import android.text.TextUtils
import android.view.LayoutInflater
import android.view.View
import androidx.recyclerview.widget.GridLayoutManager
import com.blankj.utilcode.util.ToastUtils
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.adapter.LiveTabChildAdapter
import com.ninexiu.sixninexiu.bean.AdvertiseResultInfo
import com.ninexiu.sixninexiu.bean.AnchorInfo
import com.ninexiu.sixninexiu.bean.MoreTypeResultInfo
import com.ninexiu.sixninexiu.bean.SingleTypeResultInfo
import com.ninexiu.sixninexiu.common.net.NSGsonObjectNewCallback
import com.ninexiu.sixninexiu.common.net.NSRequestParams
import com.ninexiu.sixninexiu.common.net.NsOkHttpClient
import com.ninexiu.sixninexiu.common.statistics.StatisticsEventID
import com.ninexiu.sixninexiu.common.statistics.StatisticsUtil
import com.ninexiu.sixninexiu.common.util.*
import io.reactivex.Observable
import io.reactivex.android.schedulers.AndroidSchedulers
import io.reactivex.disposables.Disposable
import kotlinx.android.synthetic.main.fragment_live_tab_child.*
import kotlinx.android.synthetic.main.layout_for_show_state.*
import kotlinx.android.synthetic.main.ns_hot_new_fragment.*
import java.util.concurrent.TimeUnit


/**
 * 热门头部点击进入的二级列表
 */
class LiveTabChildFragment : BaseManagerFragment() {
    override fun setLayoutId(): Int {
        return R.layout.fragment_live_tab_child
    }

    companion object {
        const val KEY_TAB_NAME = "tabName"
        const val KEY_TAB_TYPE = "tabType"
        const val KEY_TAB_TYPE_NAME = "tabTypeName"
        const val KEY_TAB_PAGE_POSITION = "page_position"
        fun newInstance(tabName: String, tabType: Int,tabTypeName:String,pagePosition:Int): LiveTabChildFragment {
            val args = Bundle()
            args.putString(KEY_TAB_NAME, tabName)
            args.putInt(KEY_TAB_TYPE, tabType)
            args.putString(KEY_TAB_TYPE_NAME, tabTypeName)
            args.putInt(KEY_TAB_PAGE_POSITION, pagePosition)
            val fragment = LiveTabChildFragment()
            fragment.arguments = args
            return fragment
        }
    }


    private var tabName: String = ""
    private var tabType = 0
    private var tabTypeName: String = ""
    private var pagePosition = 0
    private lateinit var tabChildAdapter: LiveTabChildAdapter
    private var page = 0

    private var haveInit = false

    private val allAnchorList = mutableListOf<AnchorInfo>()
    private val useCardList = mutableListOf<AnchorInfo>()
    private val anchorList = mutableListOf<AnchorInfo>()

    private var haveCardFinish = false
    private var haveAnchorFinish = false


    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        if (!haveInit) {
            haveInit = true
            initData()
            initView()
            initEvent()
        }
    }

    private fun initData() {
        if (arguments != null) {
            tabName = arguments!!.getString(KEY_TAB_NAME, "")
            tabType = arguments!!.getInt(KEY_TAB_TYPE)
            tabTypeName = arguments!!.getString(KEY_TAB_TYPE_NAME,"其他")
            pagePosition = arguments!!.getInt(KEY_TAB_PAGE_POSITION)

        }

        /**
         * 获取初始数据
         */
        getBannerData(tabType)
        getAnchorList(true, tabName)
        getCategoryCardData()
    }

    private fun initView() {

        srl_live_child.setEnableLoadMore(true)

        context?.let {
            tabChildAdapter = LiveTabChildAdapter(it, null, allAnchorList)

            val layoutManager = GridLayoutManager(it, 2, GridLayoutManager.VERTICAL, false)
            layoutManager.spanSizeLookup = object : GridLayoutManager.SpanSizeLookup() {
                override fun getSpanSize(position: Int): Int {
                    val viewType = tabChildAdapter.getItemViewType(position)
                    return if (viewType == LiveTabChildAdapter.VIEW_TYPE_BANNER) {
                        2
                    } else {
                        1
                    }
                }
            }

            rv_live_child.layoutManager = layoutManager
//            rv_live_child.addItemDecoration(CommItemDecoration(it,ContextCompat.getColor(it,R.color.white), dp2px(it,7)))

            rv_live_child.adapter = tabChildAdapter
        }


    }

    private fun initEvent() {
        srl_live_child.setOnRefreshListener {
            getBannerData(tabType)
            getAnchorList(true, tabName)
            getCategoryCardData()
        }

        srl_live_child.setOnLoadMoreListener {
            getAnchorList(false, tabName)
        }

        tabChildAdapter.onAnchorItemClick = label@{ anchorInfo ->

            if (Utils.isNotClickable()) {
                return@label
            }
            if (!RoomUtils.viewLiveRoomNoLogin(activity)) {
                return@label
            }
            anchorInfo.fromSoucre = "首页-${tabTypeName}"
            Utils.openLiveRoom(context, anchorInfo)
            StatisticsUtil.onEvent(StatisticsEventID.MAIN_ATTENTION_ALL_ANCHOR_CK)

        }

        sv_state_view.setOnRefreshListener {
            getBannerData(tabType)
            getAnchorList(true, tabName)
        }
    }

    /**
     * 获取轮播图数据
     */
    private fun getBannerData(tabType: Int) {
        // 请求链接不进行转码
        val okHttpClient = NsOkHttpClient.getNsOkHttpClient()
        val params = NSRequestParams()
        params.put("position", tabType)
        okHttpClient.doGet(Constants.GET_AD_LIST, params, object : NSGsonObjectNewCallback<AdvertiseResultInfo>() {

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: AdvertiseResultInfo?) {
                if (response != null && response.code == 200) {
                    tabChildAdapter.bannerData = response.data
                    tabChildAdapter.notifyDataSetChanged()
                }
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {

            }
        })
    }

    /**
     * 获取主播数据列表
     */
    private fun getAnchorList(isRefresh: Boolean, tabName: String) {
        if (isRefresh) {
            page = 0
        } else {
            page++
        }
        if (tabType == 5) {
            getHotPageData(isRefresh)
        } else {
            getOtherPageData(isRefresh)
        }
    }

    private fun getOtherPageData(isRefresh: Boolean) {
        val okHttpClient = NsOkHttpClient.getNsOkHttpClient()
        val params = NSRequestParams()
        params.put("tag", tabName)
        params.put("page", page)
        okHttpClient.doGet(Constants.GET_MAIN_CHANNEL_TYPE_LIST, params, object : NSGsonObjectNewCallback<SingleTypeResultInfo>() {

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: SingleTypeResultInfo?) {
                anchorList.clear()
                if (response != null && response.code == 200 && !response.data.isNullOrEmpty()) {
                    anchorList.addAll(response.data)
                    if (isRefresh) {
                        formatAnchorData(anchorFinish = true)
                    } else {
                        removeSame()
                        allAnchorList.addAll(anchorList)
                        anchorList.clear()
                        tabChildAdapter.notifyDataSetChanged()
                    }
                    sv_state_view?.showSuccess()
                } else {
                    if (isRefresh) {
                        formatAnchorData(anchorFinish = true)
                        sv_state_view?.showEmpty("当前没有开播的主播")
                    }
                }

                srl_live_child?.finishRefresh()
                srl_live_child?.finishLoadMore(response?.data?.size == 20)
            }

            override fun onFailure(statusCode: Int, errorMsg: String) {
                anchorList.clear()
                formatAnchorData(anchorFinish = true)
            }


        })
    }


    private fun getHotPageData(isRefresh: Boolean) {
        //不可以下拉刷新
        if (!isRefresh) {
            srl_live_child?.finishRefresh()
            srl_live_child?.finishLoadMore(true)
            return
        }
        val okHttpClient = NsOkHttpClient.getNsOkHttpClient()
        val params = NSRequestParams()
        okHttpClient.doGet(Constants.HOT_NEW_CHANNEL, params, object : NSGsonObjectNewCallback<MoreTypeResultInfo>() {
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: MoreTypeResultInfo?) {
                if (response != null && response.code == 200 && !response.data.hot.isNullOrEmpty()) {
                    if (isRefresh) {
                        allAnchorList.clear()
                    }
                    //在推荐中添加置顶数据到列表中
                    val topAnchor: MutableList<AnchorInfo> = ArrayList()
                    for (anchorInfo in response.data.recommend) {
                        if (anchorInfo.tagId == 1) {
                            topAnchor.add(anchorInfo)
                        }
                    }
                    allAnchorList.addAll(topAnchor)
                    allAnchorList.addAll(response.data.hot)
                    tabChildAdapter.notifyDataSetChanged()

                    sv_state_view?.showSuccess()
                } else {
                    if (isRefresh) {
                        sv_state_view?.showEmpty("当前没有开播的主播")
                    }
                }

                srl_live_child?.finishRefresh()
                srl_live_child?.finishLoadMore(response?.data?.hot?.size == 20)
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
            }
        })
    }

    override fun setBroadcastFilter(filter: IntentFilter?) {
        super.setBroadcastFilter(filter)
        filter?.addAction(NSReceiverAction.ACTION_MAIN_PAGE_DOUBLE_CLICK)
    }

    override fun registerReceiver(): Boolean = true

    override fun onReceive(action: String?, type: Int, bundle: Bundle?) {
        super.onReceive(action, type, bundle)
        when (action) {
            NSReceiverAction.ACTION_MAIN_PAGE_DOUBLE_CLICK -> {     // 双击刷新
                if (!Utils.isNotClickable()) {
                    if (bundle?.getInt("current_index") ?: -1 == pagePosition) {
                        rv_live_child.smoothScrollToPosition(0)
                        // 判断是否到了刷新时间,到了刷新(因为有两分钟自动刷新，基本不可能), 没到(刷新卡片数据，随机处理)
                        srl_live_child?.autoRefresh()
                    }
                }
            }
        }
    }
    private fun getCategoryCardData() {
        if (TextUtils.equals("2", tabName) || TextUtils.equals("3", tabName)) {
            HomeHotHelper.getCategoryCardData(tabName, {
                useCardList.clear()
                useCardList.addAll(it.data.useCardRoom)
                formatAnchorData(cardFinsh = true)
            }, { _, message ->
                anchorList.clear()
                formatAnchorData(cardFinsh = true)
                ToastUtils.showShort(message)
            })
        } else {
            formatAnchorData(cardFinsh = true)
        }
    }

    private fun formatAnchorData(cardFinsh: Boolean? = null, anchorFinish: Boolean? = null) {
        cardFinsh?.let {
            haveCardFinish = cardFinsh
        }
        anchorFinish?.let {
            haveAnchorFinish = anchorFinish
        }
        if (haveCardFinish && haveAnchorFinish) {
            removeSame()
            allAnchorList.clear()
            allAnchorList.addAll(anchorList)
            allAnchorList.addAll(getAddIndex(), useCardList)
            tabChildAdapter.notifyDataSetChanged()
            haveCardFinish = false
            haveAnchorFinish = false
        }
    }

    /**
     * 获取添加位置，加在666/999活动房后
     */
    private fun getAddIndex(): Int {
        var index = 0
        for (tempAnchor in anchorList) {
            if (TextUtils.equals("666", tempAnchor.rid) || TextUtils.equals("999", tempAnchor.rid)) {
                index++
                continue
            }
            break
        }
        return index
    }

    /**
     * 去重
     */
    fun removeSame() {
        if (useCardList.isNotEmpty() && anchorList.isNotEmpty()) {
            for (tempAnchor in useCardList) {
                anchorList.remove(tempAnchor)
            }
        }
    }

}