package com.ninexiu.sixninexiu.fragment

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.widget.RadioGroup
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.adapter.RealLoveFansRankAdapter
import com.ninexiu.sixninexiu.bean.LoveFansListResult
import com.ninexiu.sixninexiu.common.inter.UserLoveVisibilityChangeListener
import com.ninexiu.sixninexiu.common.net.NSAsyncHttpClient
import com.ninexiu.sixninexiu.common.net.NSJsonResponseHandler
import com.ninexiu.sixninexiu.common.net.NSRequestParams
import com.ninexiu.sixninexiu.common.util.Constants
import com.ninexiu.sixninexiu.view.PopupWindowHelper
import kotlinx.android.synthetic.main.fragment_reallove_fans_rank.*

/**
 * <pre>
 *     @author : zhangbing
 *     time   : 2020/10/09
 *     desc   : 真爱粉丝榜单
 *     version: 1.0
 * </pre>
 */
class RealLoveFansRankFragment : BaseFragment() {
    override fun inflate(inflater: LayoutInflater?): View? {
        return inflater?.inflate(R.layout.fragment_reallove_fans_rank, null)
    }

    companion object {
        fun newInstance(rid: String): RealLoveFansRankFragment {
            val args = Bundle()
            args.putString("rid", rid)
            val fragment = RealLoveFansRankFragment()
            fragment.arguments = args
            return fragment
        }
    }

    private var loveFansList = ArrayList<LoveFansListResult.DataBean.RankListBean>()
    private lateinit var mbLoveFansListAdapter: RealLoveFansRankAdapter
    private var fansNumber = 0
    private var rankType = R.id.rb_reallove_rank_week
    private lateinit var rid: String

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        rid = arguments?.getString("rid", "")!!
        getAnchorLoveFansRank(rid)

        rv_reallove_fans_rank?.layoutManager = LinearLayoutManager(context, LinearLayoutManager.VERTICAL, false)
        mbLoveFansListAdapter = RealLoveFansRankAdapter(context!!, loveFansList)
        rv_reallove_fans_rank?.adapter = mbLoveFansListAdapter


        tv_reallove_rank_type?.setOnClickListener {
            showPop()
        }


        rv_reallove_fans_rank?.addOnScrollListener(object : RecyclerView.OnScrollListener() {
            override fun onScrollStateChanged(recyclerView: RecyclerView, newState: Int) {
                super.onScrollStateChanged(recyclerView, newState)
                if (visibilityListener != null) {
                    visibilityListener!!.userLoveVisibilityChange(newState == RecyclerView.SCROLL_STATE_IDLE)
                }
            }
        })
    }

    /**
     * 获取真爱粉丝列表
     */
    private fun getAnchorLoveFansRank(rid: String) {
        val params = NSRequestParams()
        params.put("page", 0)
        params.put("pagesize", 50)
        params.put("rid", rid)
        var type = ""
        if (rankType == R.id.rb_reallove_rank_week) {
            type = "week"
        } else if (rankType == R.id.rb_reallove_rank_month) {
            type = "month"
        } else if (rankType == R.id.rb_reallove_rank_total) {
            type = "total"
        }
        params.put("type", type)
        NSAsyncHttpClient.getInstance()[Constants.GET_REAL_LOVE_RANK, params, object : NSJsonResponseHandler<LoveFansListResult?>() {
            override fun onSuccess(statusCode: Int, rawJsonResponse: String, response: LoveFansListResult?) {
                if (response != null && response.data!=null && response.data.rankList.isNotEmpty()) {
                    cl_reallove_fans_empty?.visibility=View.GONE
                    loveFansList.clear()
                    loveFansList.addAll(response.data.rankList)
                    mbLoveFansListAdapter.rankType = type
                    mbLoveFansListAdapter.notifyDataSetChanged()
                    if (loveFansList.size <= 0) {
                    }
                }else{
                    cl_reallove_fans_empty?.visibility=View.VISIBLE
                }
            }

            override fun onFailure(statusCode: Int, errorMsg: String) {
            }

        }]
    }


    private fun showPop() {
        val popupWindowView = LayoutInflater.from(context).inflate(R.layout.popupwindow_reallove_fans_rank, null, false)
        val popupWindowHelper = PopupWindowHelper(popupWindowView)
        popupWindowHelper.showAsDropDown(tv_reallove_rank_type)
        val drawable = resources.getDrawable(R.drawable.icon_arrow_white_down)
        drawable.setBounds(0, 0, drawable.minimumWidth, drawable.minimumHeight)
        tv_reallove_rank_type?.setCompoundDrawables(null, null, drawable, null)
        val rgRealloveRank = popupWindowView.findViewById<RadioGroup>(R.id.rg_reallove_rank_type)
        rgRealloveRank?.check(rankType)
        rgRealloveRank?.setOnCheckedChangeListener { group, checkedId ->
            rankType = checkedId
            when (checkedId) {
                R.id.rb_reallove_rank_week -> {
                    tv_reallove_rank_type?.text = "周榜"
                }
                R.id.rb_reallove_rank_month -> {
                    tv_reallove_rank_type?.text = "月榜"
                }
                R.id.rb_reallove_rank_total -> {
                    tv_reallove_rank_type?.text = "总榜"
                }
            }
            getAnchorLoveFansRank(rid)
            popupWindowHelper.dismiss()
        }

        popupWindowHelper.setPopupWindowDismissListener {
            val drawable = resources.getDrawable(R.drawable.icon_arrow_white_up)
            drawable.setBounds(0, 0, drawable.minimumWidth, drawable.minimumHeight)
            tv_reallove_rank_type?.setCompoundDrawables(null, null, drawable, null)
        }

    }

    public fun setFansNumber(fansNumber: Int) {
        this.fansNumber = fansNumber
        tv_reallove_fans_number?.text = "粉丝人数：${fansNumber}人"
    }

    private var visibilityListener: UserLoveVisibilityChangeListener? = null

    fun setUserLoveVisibilityChangeListener(visibilityListener: UserLoveVisibilityChangeListener?) {
        this.visibilityListener = visibilityListener
    }

}