package com.ninexiu.sixninexiu.fragment

import android.os.Bundle
import android.view.View
import androidx.recyclerview.widget.LinearLayoutManager
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.activity.PersonalInforActivity
import com.ninexiu.sixninexiu.adapter.UserReturnLiveAdapter
import com.ninexiu.sixninexiu.bean.AnchorInfo
import com.ninexiu.sixninexiu.bean.UserReturnLiveBean
import com.ninexiu.sixninexiu.bean.UserReturnLiveItem
import com.ninexiu.sixninexiu.common.net.NSGsonObjectNewCallback
import com.ninexiu.sixninexiu.common.net.NsOkHttpClient
import com.ninexiu.sixninexiu.common.statistics.StatisticsEventID
import com.ninexiu.sixninexiu.common.statistics.StatisticsUtil
import com.ninexiu.sixninexiu.common.util.Constants
import com.ninexiu.sixninexiu.common.util.MyToast
import com.ninexiu.sixninexiu.common.util.NSLog
import com.ninexiu.sixninexiu.common.util.Utils
import com.ninexiu.sixninexiu.view.GallerySnapHelper
import com.ninexiu.sixninexiu.view.fitterViewSize
import kotlinx.android.synthetic.main.fragment_user_return_live.*

/**
 * <pre>
 *     @author : hpf
 *     time   : 2020/11/24
 *     desc   :  聚合页面 : 邂逅主播
 *     version: 1.0
 * </pre>
 */
class UserReturnLiveFragment : BaseManagerFragment() {
    companion object {
        fun getInstance(bundle: Bundle? = null): UserReturnLiveFragment {
            val fragment = UserReturnLiveFragment()
            bundle?.let { fragment.arguments = bundle }
            return fragment
        }

        private const val TAG = "UserReturnLiveFragment >> "
    }

    override fun setLayoutId(): Int = R.layout.fragment_user_return_live

    private val screenWidth: Int by lazy {
        resources.displayMetrics.widthPixels
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        // 适配按钮大小
        fitterViewSize(tvLiveFragment, {
            (screenWidth * 0.575f).toInt()
        }, {
            (it * 0.179f).toInt()
        })

        initFitterView()
    }

    private val data = mutableListOf<UserReturnLiveItem>()
    private val adapter = UserReturnLiveAdapter(data)

    private fun initFitterView() {
        val manager = LinearLayoutManager(context, LinearLayoutManager.HORIZONTAL, false)
        recyLiveFragment.layoutManager = manager
        recyLiveFragment.adapter = adapter
        GallerySnapHelper().attachToRecyclerView(recyLiveFragment)

        adapter.userClick = { item, type ->
            when (type) {
                // 进入个人主页
                UserReturnLiveAdapter.INTO_PROFILE -> {
                    StatisticsUtil.onEvent(StatisticsEventID.UM_USER_RETURN_LIVE_PROFILE)
                    PersonalInforActivity.start(context, true, item.uid)
                }
                // 进入直播间
                UserReturnLiveAdapter.INTO_LIVE_ROOM -> {
                    StatisticsUtil.onEvent(StatisticsEventID.UM_USER_RETURN_LIVE_IN)
                    val anchorInfo = AnchorInfo()
                    anchorInfo.rid = item.rid.toString()
                    Utils.openLiveRoomObjReturn(context, anchorInfo, true)
                }
            }
        }

        tvLiveFragment.setOnClickListener {
            val firstPos = manager.findFirstCompletelyVisibleItemPosition()
            val lastPos = manager.findLastCompletelyVisibleItemPosition()
            // 降临直播间
            if ((firstPos == lastPos) && firstPos >= 0 && firstPos < data.size) {
                NSLog.d(TAG, "visiblePosition : ${manager.findFirstCompletelyVisibleItemPosition()}")
                StatisticsUtil.onEvent(StatisticsEventID.UM_USER_RETURN_LIVE_IN)
                val anchorInfo = AnchorInfo()
                anchorInfo.rid = data[firstPos].rid.toString()
                Utils.openLiveRoomObjReturn(context, anchorInfo, true)
            }
        }
    }

    // 加载主播数据
    override fun initData(savedInstanceState: Bundle?) {
        super.initData(savedInstanceState)

        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.MEET_LIVE, null, object : NSGsonObjectNewCallback<UserReturnLiveBean>() {
            override fun onFailure(statusCode: Int, errorMsg: String?) {
                MyToast.showShort(errorMsg ?: "")
            }

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: UserReturnLiveBean?) {
                MyToast.showShort(message ?: "")
                if (statusCode == 200) {
                    NSLog.d(TAG, "size : ${response?.data?.size ?: " empty "}")
                    response?.data?.let {
                        data.clear()
                        data.addAll(it)
                        adapter.notifyDataSetChanged()
                    }
                }
            }
        })

    }


}