package com.ninexiu.sixninexiu.fragment.auction

import android.content.Intent
import android.os.Bundle
import android.text.TextUtils
import android.view.KeyEvent
import android.view.LayoutInflater
import android.view.View
import androidx.core.content.ContextCompat
import com.blankj.utilcode.util.ToastUtils
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.activity.SubPageActivity
import com.ninexiu.sixninexiu.activity.auction.SelectAddressActivity
import com.ninexiu.sixninexiu.bean.AuctionAddressBean
import com.ninexiu.sixninexiu.bean.AuctionAddressData
import com.ninexiu.sixninexiu.bean.BaseBean
import com.ninexiu.sixninexiu.broadcast.AppBroadcastHelper
import com.ninexiu.sixninexiu.common.net.NSGsonObjectNewCallback
import com.ninexiu.sixninexiu.common.net.NSRequestParams
import com.ninexiu.sixninexiu.common.net.NsOkHttpClient
import com.ninexiu.sixninexiu.common.util.Constants
import com.ninexiu.sixninexiu.common.util.NSReceiverAction
import com.ninexiu.sixninexiu.common.util.UIUtils
import com.ninexiu.sixninexiu.fragment.BaseFragment
import com.ninexiu.sixninexiu.view.dialog.BaseDialog
import com.ninexiu.sixninexiu.view.dialog.CommonRemindDialog
import kotlinx.android.synthetic.main.fragment_order_address_edit.*
import kotlinx.android.synthetic.main.fragment_order_address_edit.tv_order_address_name
import kotlinx.android.synthetic.main.fragment_order_address_edit.tv_order_address_phone
import kotlinx.android.synthetic.main.fragment_order_detail.*
import kotlinx.android.synthetic.main.title_tab_bar.*

class OrderAddressEditFragment : BaseFragment() {
    override fun inflate(inflater: LayoutInflater?): View {
        return inflater?.inflate(R.layout.fragment_order_address_edit, null)!!
    }


    companion object {
        const val REQUEST_CODE_CHOOSE_CITY = 10001
    }


    private var provinceStr: String? = null
    private var cityStr: String? = null
    private var areaStr: String? = null
    private var orderId: String? = null


    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        val address = arguments?.getParcelable<AuctionAddressData>("address")
        if (address == null){
            title.text = "新建收货地址"
        } else {
            title.text = "编辑收货地址"
        }

        orderId = arguments?.getString("order_id")
        initUI(address)
    }

    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        super.onActivityResult(requestCode, resultCode, data)
        if (data != null) {
            provinceStr = data.getStringExtra("province")
            cityStr = data.getStringExtra("city")
            areaStr = data.getStringExtra("area")

            if (context != null && !TextUtils.isEmpty(provinceStr) && !TextUtils.isEmpty(cityStr) && !TextUtils.isEmpty(areaStr)) {
                tv_order_address_city?.setTextColor(ContextCompat.getColor(context!!, R.color.color_333333))
                tv_order_address_city?.text = "$provinceStr $cityStr $areaStr"
            }
        }
    }

    private fun initUI(address: AuctionAddressData?) {
        if (address != null) {
            provinceStr = address.province
            cityStr = address.city
            areaStr = address.county
            tv_order_address_city?.setTextColor(ContextCompat.getColor(context!!, R.color.color_333333))
            tv_order_address_city?.text = "$provinceStr $cityStr $areaStr"

            et_order_address_name?.setText(address.nickname)
            et_order_address_phone?.setText(address.phone)
            et_order_address_details?.setText(address.detail)
        }

        left_btn?.setOnClickListener {
            showClose()
        }

        cl_order_address_choose?.setOnClickListener {
            val intentAddress = Intent(activity, SelectAddressActivity::class.java)
            startActivityForResult(intentAddress, REQUEST_CODE_CHOOSE_CITY)
        }

        tv_order_address_save?.setOnClickListener {
            val nameStr = et_order_address_name?.text.toString().trim()
            if (TextUtils.isEmpty(nameStr)) {
                ToastUtils.showShort("请填写收件人名字！")
                return@setOnClickListener
            }

            val phoneStr = et_order_address_phone?.text.toString().trim()
            if (TextUtils.isEmpty(phoneStr)) {
                ToastUtils.showShort("请填写收件人手机号码！")
                return@setOnClickListener
            }

            if (phoneStr.length < 11) {
                ToastUtils.showShort("手机号码不合法！")
                return@setOnClickListener
            }

            if (TextUtils.isEmpty(provinceStr) || TextUtils.isEmpty(cityStr) || TextUtils.isEmpty(areaStr)) {
                ToastUtils.showShort("请选择收件人省市区!")
                return@setOnClickListener
            }

            val addressStr = et_order_address_details?.text.toString().trim()
            if (TextUtils.isEmpty(addressStr)) {
                ToastUtils.showShort("请填写收件人详细地址!")
                return@setOnClickListener
            }

            saveAddress(nameStr, phoneStr.toLong(), addressStr)

        }
    }


    private fun saveAddress(nameStr: String, phoneStr: Long, addressStr: String) {
        val params = NSRequestParams()
        params.put("province", provinceStr)
        params.put("city", cityStr)
        params.put("county", areaStr)
        params.put("detail", addressStr)
        params.put("nickname", nameStr)
        params.put("phone", phoneStr)
        if (!TextUtils.isEmpty(orderId)) {
            params.put("order_id", orderId)
        }
        NsOkHttpClient.getNsOkHttpClient().doPost(Constants.GET_AUCTION_ADD_ADDRESS, params, object : NSGsonObjectNewCallback<BaseBean<Nothing>>() {

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: BaseBean<Nothing>?) {
                if (response != null && response.code == 200) {
                    ToastUtils.showShort("保存成功！")
                    activity?.finish()
                    val bundle = Bundle()
                    val address = AuctionAddressData(provinceStr, cityStr, areaStr, addressStr, nameStr, phoneStr.toString())
                    bundle.putParcelable("address", address)
                    AppBroadcastHelper.getInstance().sendBroadcast(NSReceiverAction.ACTION_AUCTION_ADDRESS_CHANGE, bundle)
                } else {
                    ToastUtils.showShort(message)
                }
            }

            override fun onFailure(statusCode: Int, errorMsg: String) {
                ToastUtils.showShort(errorMsg)
            }

        })
    }

    /**
     * 关闭提醒
     */
    private fun showClose() {
        CommonRemindDialog.create(context)
                .setText("放弃", "我再想想")
                .setTitleText("是否放弃本次修改")
                .setTitleSize(17)
                .setOnClickCallback { type ->
                    if (type == BaseDialog.SELECT_FIRST) {
                        activity?.finish()
                    }
                }

    }

    override fun onResume() {
        super.onResume()
        getView()?.isFocusableInTouchMode = true
        getView()?.requestFocus()
        getView()?.setOnKeyListener(
                object : View.OnKeyListener {
                    override fun onKey(v: View, keyCode: Int, event: KeyEvent): Boolean {
                        if (event.action == KeyEvent.ACTION_UP
                                && keyCode == KeyEvent.KEYCODE_BACK) {

                            showClose()
                            return true
                        }
                        return false
                    }
                })
    }


}