package com.ninexiu.sixninexiu.fragment.auction

import android.content.ClipboardManager
import android.content.Context
import android.content.Intent
import android.content.IntentFilter
import android.graphics.Typeface
import android.net.Uri
import android.os.Bundle
import android.text.TextUtils
import android.util.TypedValue
import android.view.KeyEvent
import android.view.LayoutInflater
import android.view.View
import android.widget.TextView
import androidx.core.content.ContextCompat
import com.blankj.utilcode.util.ConvertUtils
import com.blankj.utilcode.util.ToastUtils
import com.ninexiu.sixninexiu.BuildConfig
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.activity.SubPageActivity
import com.ninexiu.sixninexiu.activity.TranslucentPayActivity
import com.ninexiu.sixninexiu.bean.*
import com.ninexiu.sixninexiu.common.net.NSGsonObjectNewCallback
import com.ninexiu.sixninexiu.common.net.NSRequestParams
import com.ninexiu.sixninexiu.common.net.NsOkHttpClient
import com.ninexiu.sixninexiu.common.util.*
import com.ninexiu.sixninexiu.fragment.BaseFragment
import com.ninexiu.sixninexiu.pay.PayUtil
import com.ninexiu.sixninexiu.values.Global
import com.ninexiu.sixninexiu.view.dialog.BaseDialog
import com.ninexiu.sixninexiu.view.dialog.CommonRemindDialog
import com.ninexiu.sixninexiu.view.dp2px
import kotlinx.android.synthetic.main.fragment_order_detail.*
import kotlinx.android.synthetic.main.title_tab_bar.*
import org.json.JSONObject
import java.text.DecimalFormat

class OrderDetailsFragment : BaseFragment() {
    override fun inflate(inflater: LayoutInflater?): View {
        return LayoutInflater.from(context).inflate(R.layout.fragment_order_detail, null)
    }

    companion object {
        const val FROM_TYPE_MAKE_ORDER_BUYNOW = 1
        const val FROM_TYPE_MAKE_ORDER_AUCTION = 2
        const val FROM_TYPE_ORDER_LIST = 3
    }

    private var goods: BiddingShopInfo? = null  //下单用，商品信息
    private var address: AuctionAddressData? = null//下单用，收货人信息
    private var order: AuctionOrderData? = null//订单数据
    private var from = 0
    private var payType = -1
    private var orderId = ""
    private var totalPrice = ""
    val df = DecimalFormat("0.00")

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        initData()
        initView()
        initEvent()
    }


    private fun initData() {
        if (arguments != null) {
            goods = arguments!!.getParcelable("goods")
            order = arguments!!.getParcelable("order")
            from = arguments!!.getInt("from_type")
        }

        // 默认微信支付
        payType = if (Global.WEIXIN_CHARGE_TYPE != 0) {
            Global.WEIXIN_CHARGE_TYPE
        } else {
            PayUtil.PAY_TYPE_JX_WXPAY
        }
    }

    private fun initView() {
        if (from == FROM_TYPE_MAKE_ORDER_BUYNOW || from == FROM_TYPE_MAKE_ORDER_AUCTION) {
            title?.text = "确认订单"
            refreshUIGoods()
        } else if (from == FROM_TYPE_ORDER_LIST) {
            title?.text = "订单详情"
            refreshUiOrder()
        }

        if (order != null) {
            orderId = order!!.order_id!!
            getOrderDetails(order!!.order_id)
        }

        UIUtils.showView(iv_right)
        iv_right?.setImageResource(R.drawable.icon_auction_order_service)
    }



    override fun registerReceiver(): Boolean {
        return true
    }

    override fun setBroadcastFilter(filter: IntentFilter) {
        super.setBroadcastFilter(filter)
        filter.addAction(NSReceiverAction.ACTION_AUCTION_ADDRESS_CHANGE)
    }

    override fun onReceive(action: String, type: Int, bundle: Bundle) {
        super.onReceive(action, type, bundle)
        if (NSReceiverAction.ACTION_AUCTION_ADDRESS_CHANGE == action) {
            address = bundle.getParcelable("address")
            order?.province = address?.province
            order?.city = address?.city
            order?.county = address?.county
            order?.detail = address?.detail
            order?.addressee = address?.nickname
            order?.phone = address?.phone

            refreshUIAddress()
        }
    }

    /**
     * 根据商品信息刷新ui
     */
    private fun refreshUIGoods() {
        UIUtils.goneView(tv_order_state)
//        UIUtils.goneView(iv_order_is_auction)
        UIUtils.goneView(iv_order_is_auction_waiting)
        if (from == FROM_TYPE_MAKE_ORDER_BUYNOW) {
            UIUtils.goneView(cl_order_waiting_pay)
        } else {
            UIUtils.showView(cl_order_waiting_pay)
        }
        if (TextUtils.equals(order?.status,"1") && TextUtils.equals(order?.status,"2") && TextUtils.equals(order?.status,"3") && TextUtils.equals(order?.status,"4")){

            UIUtils.showView(cl_order_receiver_address)
        }
        UIUtils.goneView(tv_order_auction_pay_remind)
        UIUtils.showView(cl_order_goods)
        UIUtils.showView(cl_order_note_left)
        UIUtils.showView(cl_order_payway)
        UIUtils.goneView(ll_order_details)
        UIUtils.showView(ll_order_price)
        UIUtils.showView(cl_order_total)
        getAddress()

        if (goods != null) {
            var fixed_price = goods!!.fixed_price
            var express_price = goods!!.express_price
            if(TextUtils.isEmpty(fixed_price)){
                fixed_price = "0.0"
            }
            if(TextUtils.isEmpty(express_price)){
                express_price = "0.0"
            }

            GlideUtils.loadSimpleImgWithRoundCorner(context, goods!!.img1, iv_order_goods_cover, R.drawable.icon_personal_default_bg, ConvertUtils.dp2px(4f))
            tv_order_goods_name?.text = goods!!.goods_name
            tv_order_goods_price?.text = "${df.format(fixed_price?.toFloat())}"

            tv_order_totalprice?.text = "¥${df.format((fixed_price.toFloat() + express_price.toFloat()))}"

            val priceView = LayoutInflater.from(context).inflate(R.layout.layout_auction_order_price_item, ll_order_price, false)
            priceView.findViewById<TextView>(R.id.tv_order_price_item_left).text = "商品总额："
            priceView.findViewById<TextView>(R.id.tv_order_price_item_right).text = "¥${df.format(fixed_price?.toFloat())}"
            ll_order_price?.addView(priceView)

            val expressView = LayoutInflater.from(context).inflate(R.layout.layout_auction_order_price_item, ll_order_price, false)
            expressView.findViewById<TextView>(R.id.tv_order_price_item_left).text = "运费："
            expressView.findViewById<TextView>(R.id.tv_order_price_item_right).text = "+¥${df.format(express_price?.toFloat())}"
            ll_order_price?.addView(expressView)

            val totalView = LayoutInflater.from(context).inflate(R.layout.layout_auction_order_price_item, ll_order_price, false)

            var lable = "应付款："
            if (TextUtils.equals(order?.status,"1")){
                lable = "实付款："
            }
            totalView.findViewById<TextView>(R.id.tv_order_price_item_left).text = lable

            totalView.findViewById<TextView>(R.id.tv_order_price_item_right).text = "¥${df.format((fixed_price.toFloat() + express_price.toFloat()))}"
            totalView.findViewById<TextView>(R.id.tv_order_price_item_right).setTextSize(TypedValue.COMPLEX_UNIT_SP, 16f)
            totalView.setPadding(0, dp2px(context!!, 9), 0, dp2px(context!!, 9))
            ll_order_price?.addView(totalView)
        }
    }

    /**
     * 根据订单信息刷新ui
     */
    private fun refreshUiOrder() {
        if (order == null) {
            return
        }
        if (TextUtils.equals(order?.status,"1") && TextUtils.equals(order?.status,"2") && TextUtils.equals(order?.status,"3") && TextUtils.equals(order?.status,"4")){

            UIUtils.showView(cl_order_receiver_address)
        }
        UIUtils.showView(cl_order_goods)
        UIUtils.showView(ll_order_price)
        //地址相关
        refreshUIAddressOrder()
        //商品相关
        GlideUtils.loadSimpleImgWithRoundCorner(context, order!!.img1, iv_order_goods_cover, R.drawable.icon_personal_default_bg, ConvertUtils.dp2px(4f))
        tv_order_goods_name?.text = order!!.goods_name
        var fixed_price = order!!.fixed_price
        if (TextUtils.isEmpty(fixed_price)){
            fixed_price = "0"
        }

        var amount = order!!.amount
        if (TextUtils.isEmpty(amount)){
            amount = "0"
        }
        tv_order_goods_price?.text = "${df.format(amount?.toFloat())}"

        //商品价格汇总
        addPriceItem()

        if (order != null) {

            if (TextUtils.equals(order!!.sell_type, "1")) {
                UIUtils.showView(iv_order_is_auction)
            } else {
                UIUtils.goneView(iv_order_is_auction)
            }


            when (order!!.status) {
                "0" -> {//0 待支付 1已支付 2已取消 3 已退款 4已发货
                    UIUtils.goneView(tv_order_state)
//                    UIUtils.goneView(iv_order_is_auction)
                    UIUtils.showView(cl_order_waiting_pay)
                    UIUtils.showView(cl_order_note_left)
                    UIUtils.showView(cl_order_payway)
                    UIUtils.goneView(ll_order_details)
                    UIUtils.showView(cl_order_total)

                    if (TextUtils.equals(order!!.sell_type, "1")) {
                        UIUtils.showView(iv_order_is_auction_waiting)
                        UIUtils.showView(tv_order_auction_pay_remind)
                    } else {
                        UIUtils.goneView(iv_order_is_auction_waiting)
                        UIUtils.goneView(tv_order_auction_pay_remind)
                    }
                    var total_price = order!!.total_price
                    if (TextUtils.isEmpty(total_price)){
                        total_price = "0"
                    }
                    var money = "¥${df.format(total_price?.toFloat())}"
                    if(TextUtils.equals(order?.status,"1") && order?.is_show_money == 0){
                        money = "${df.format(order?.total_coin?.toFloat())}九币"
                    }
                    tv_order_totalprice?.text = money
                    //未支付倒计时
                    tv_order_pay_time_remain?.startCutDown(if (TextUtils.equals(order!!.sell_type, "1")) "竞拍订单，支付倒计时：" else "剩余时间：", "", order!!.down_time, "") { time: Long ->
                        val lsTime = time.toInt()
                        val hour = lsTime / 3600
                        val minute = lsTime / 60 % 60  // / :先转换成秒  % : 过滤出小时
                        val second = lsTime % 60
                        return@startCutDown "${tv_order_pay_time_remain.timeToString(hour)}时${tv_order_pay_time_remain.timeToString(minute)}分${tv_order_pay_time_remain.timeToString(second)}秒"
                    }
                    //订单留言
                    if (!TextUtils.isEmpty(order!!.leave_message)) {
                        et_order_note_left?.setText(order!!.leave_message)
                    }

                }
                else -> {
                    UIUtils.showView(tv_order_state)
                    UIUtils.goneView(iv_order_is_auction_waiting)
                    UIUtils.showView(ll_order_details)
                    UIUtils.goneView(cl_order_waiting_pay)
                    UIUtils.goneView(cl_order_note_left)
                    UIUtils.goneView(cl_order_payway)
                    UIUtils.goneView(cl_order_total)
                    UIUtils.goneView(iv_order_address_more)

                    tv_order_state?.text = when (order!!.status) {
                        "1" -> "已支付"
                        "2" -> "已取消"
                        "3" -> "已退款"
                        "4" -> "已发货"
                        else -> "已完成"
                    }

                    addOrderItem()


                }
            }

        }
    }

    /**
     * 刷新收件人信息UI
     */
    private fun refreshUIAddress() {
        if (address != null) {
            UIUtils.showView(tv_order_address_phone)
            UIUtils.showView(tv_order_address)
            tv_order_address_name?.text = address!!.nickname
            if (!TextUtils.isEmpty(address!!.phone)) {
                tv_order_address_phone?.text = "${address!!.phone?.substring(0, 3)}****${address!!.phone?.substring(address!!.phone!!.length - 4, address!!.phone!!.length)}"
            }
            tv_order_address?.text = "${address!!.province}${address!!.city}${address!!.county}${address!!.detail}"
            iv_order_add_address?.setImageResource(R.drawable.icon_auction_receive_address)
        } else {
            tv_order_address_name?.text = "请添加收货地址"
            iv_order_add_address?.setImageResource(R.drawable.icon_auction_add_address)
            UIUtils.goneView(tv_order_address_phone)
            UIUtils.goneView(tv_order_address)
        }
    }

    /**
     * 根据订单里的收件人信息刷新UI
     */
    private fun refreshUIAddressOrder() {
        if (!TextUtils.isEmpty(order!!.province) || !TextUtils.equals(order!!.status, "0")) {
            if (TextUtils.isEmpty(order!!.province)) {
                tv_order_address_name?.text = "【未添加收货信息】"
                UIUtils.goneView(tv_order_address_phone)
                UIUtils.goneView(tv_order_address)
                UIUtils.goneView(iv_order_address_more)
            }
            UIUtils.showView(tv_order_address_phone)
            UIUtils.showView(tv_order_address)
            UIUtils.goneView(iv_order_address_more)
            tv_order_address_name?.text = order!!.addressee
            if (order!!.phone != null && !TextUtils.isEmpty(order!!.phone)) {
                tv_order_address_phone?.text = "${order!!.phone?.substring(0, 3)}****${order!!.phone?.substring(order!!.phone!!.length - 4, order!!.phone!!.length)}"
            }
            tv_order_address?.text = "${order!!.province}${order!!.city}${order!!.county}${order!!.detail}"
            iv_order_add_address?.setImageResource(R.drawable.icon_auction_receive_address)

            if (TextUtils.equals(order!!.sell_type, "1") && TextUtils.equals(order!!.status, "0")) {
                UIUtils.showView(iv_order_address_more)
            }
        } else {
            tv_order_address_name?.text = "请添加收货地址"
            iv_order_add_address?.setImageResource(R.drawable.icon_auction_add_address)
            UIUtils.goneView(tv_order_address_phone)
            UIUtils.goneView(tv_order_address)
            UIUtils.showView(iv_order_address_more)
        }
    }

    /**
     * 商品价格汇总
     */
    private fun addPriceItem() {
        ll_order_price?.removeAllViews()
        val priceView = LayoutInflater.from(context).inflate(R.layout.layout_auction_order_price_item, ll_order_price, false)
        priceView.findViewById<TextView>(R.id.tv_order_price_item_left).text = "商品总额："
        var fixed_price = order!!.fixed_price
        if (TextUtils.isEmpty(fixed_price)){
            fixed_price = "0"
        }
        var amount = order!!.amount
        if (TextUtils.isEmpty(amount)){
            amount = "0"
        }
        var total_price = order!!.total_price
        if (TextUtils.isEmpty(total_price)){
            total_price = "0"
        }

        priceView.findViewById<TextView>(R.id.tv_order_price_item_right).text = "¥${df.format(amount?.toFloat())}"
        ll_order_price?.addView(priceView)

        val expressView = LayoutInflater.from(context).inflate(R.layout.layout_auction_order_price_item, ll_order_price, false)
        expressView.findViewById<TextView>(R.id.tv_order_price_item_left).text = "运费："
        expressView.findViewById<TextView>(R.id.tv_order_price_item_right).text = "+¥${order!!.express_price}"
        ll_order_price?.addView(expressView)

        val totalView = LayoutInflater.from(context).inflate(R.layout.layout_auction_order_price_item, ll_order_price, false)
        var lable = "应付款："
        if (TextUtils.equals(order?.status,"1")){
            lable = "实付款："
        }
        totalView.findViewById<TextView>(R.id.tv_order_price_item_left).text = lable


        var money = "¥${df.format(total_price?.toFloat())}"
        if(TextUtils.equals(lable,"实付款：") && order?.is_show_money == 0){
            money = "${df.format(order?.total_coin?.toFloat())}九币"
        }
        totalView.findViewById<TextView>(R.id.tv_order_price_item_right).text = money
        totalView.findViewById<TextView>(R.id.tv_order_price_item_right).setTextSize(TypedValue.COMPLEX_UNIT_SP, 16f)
        totalView.findViewById<TextView>(R.id.tv_order_price_item_right).setTextColor(ContextCompat.getColor(context!!, R.color.color_fe2b54))
        totalView.findViewById<TextView>(R.id.tv_order_price_item_right).setTypeface(Typeface.defaultFromStyle(Typeface.BOLD))

        totalView.setPadding(0, dp2px(context!!, 9), 0, dp2px(context!!, 9))
        ll_order_price?.addView(totalView)
    }


    /**
     * 订单信息汇总
     */
    private fun addOrderItem() {
        ll_order_details?.removeAllViews()
        //订单编号
        val orderIdView = LayoutInflater.from(context).inflate(R.layout.layout_auction_order_details_item, ll_order_details, false)
        orderIdView.findViewById<TextView>(R.id.tv_order_item_title)?.text = "订单编号："
        orderIdView.findViewById<TextView>(R.id.tv_order_item_content)?.text = "${order!!.order_id}"
        UIUtils.showView(orderIdView.findViewById<TextView>(R.id.tv_order_item_copy))
        orderIdView.findViewById<TextView>(R.id.tv_order_item_copy).setOnClickListener {
            setCopyText("${order!!.order_id}")
        }
        ll_order_details?.addView(orderIdView)

        //下单时间
        val createTimeView = LayoutInflater.from(context).inflate(R.layout.layout_auction_order_details_item, ll_order_details, false)
        createTimeView.findViewById<TextView>(R.id.tv_order_item_title).text = "下单时间："
        if (!TextUtils.isEmpty(order!!.order_time)) {
            createTimeView.findViewById<TextView>(R.id.tv_order_item_content).text = "${order!!.order_time}"
        }
        ll_order_details?.addView(createTimeView)

        if (order!!.status == "1" || order!!.status == "3" || order!!.status == "4") {//已支付
            //支付方式
            val payTypeView = LayoutInflater.from(context).inflate(R.layout.layout_auction_order_details_item, ll_order_details, false)
            payTypeView.findViewById<TextView>(R.id.tv_order_item_title).text = "支付方式："
            payTypeView.findViewById<TextView>(R.id.tv_order_item_content).text = "${order!!.pay_type}"
            ll_order_details?.addView(payTypeView)
            //支付时间
            val payTimeView = LayoutInflater.from(context).inflate(R.layout.layout_auction_order_details_item, ll_order_details, false)
            payTimeView.findViewById<TextView>(R.id.tv_order_item_title).text = "支付时间："
            if (!TextUtils.isEmpty(order!!.pay_time)) {
                payTimeView.findViewById<TextView>(R.id.tv_order_item_content).text = "${order!!.pay_time}"
            }
            ll_order_details?.addView(payTimeView)
        }

        if (order!!.status == "2") {//取消
            //取消时间
            val cancelTimeView = LayoutInflater.from(context).inflate(R.layout.layout_auction_order_details_item, ll_order_details, false)
            cancelTimeView.findViewById<TextView>(R.id.tv_order_item_title).text = "取消时间："
            if (!TextUtils.isEmpty(order!!.cancel_time)) {
                cancelTimeView.findViewById<TextView>(R.id.tv_order_item_content).text = "${order!!.cancel_time}"
            }
            ll_order_details?.addView(cancelTimeView)
        }

        if (order!!.status == "3") {//退款
            //退款时间
            val backTimeView = LayoutInflater.from(context).inflate(R.layout.layout_auction_order_details_item, ll_order_details, false)
            backTimeView.findViewById<TextView>(R.id.tv_order_item_title).text = "退款时间："
            if (!TextUtils.isEmpty(order!!.refund_time)) {
                backTimeView.findViewById<TextView>(R.id.tv_order_item_content).text = "${order!!.refund_time}"
            }
            ll_order_details?.addView(backTimeView)

            //退款金额
            val backMoneyView = LayoutInflater.from(context).inflate(R.layout.layout_auction_order_details_item, ll_order_details, false)
            backMoneyView.findViewById<TextView>(R.id.tv_order_item_title).text = "退款金额："

            var money = "¥ ${order!!.refund_price}"
            if(order?.is_show_money == 0){
                money = "${order!!.refund_coin}九币"
            }
            backMoneyView.findViewById<TextView>(R.id.tv_order_item_content).text = money
            ll_order_details?.addView(backMoneyView)
        }

        if (order!!.status == "4") {//发货
            //取消时间
            val sendView = LayoutInflater.from(context).inflate(R.layout.layout_auction_order_details_item, ll_order_details, false)
            sendView.findViewById<TextView>(R.id.tv_order_item_title).text = "配送单号："
            sendView.findViewById<TextView>(R.id.tv_order_item_content).text = "${order!!.express_order}"
            UIUtils.showView(sendView.findViewById<TextView>(R.id.tv_order_item_copy))
            sendView.findViewById<TextView>(R.id.tv_order_item_copy).setOnClickListener {
                setCopyText("${order!!.express_order}")
            }
            ll_order_details?.addView(sendView)
        }


    }


    private fun initEvent() {
        left_btn?.setOnClickListener {
            showCloseRemind()
        }

        iv_right.setOnClickListener {
            if (!TextUtils.isEmpty(serviceNumber)) {
                callPhone(serviceNumber)
            } else {
                getServiceNumber()
            }
        }

        rg_order_payway?.setOnCheckedChangeListener { group, checkedId ->
            when (checkedId) {
                R.id.rb_order_alipay -> {
                    payType = if (Global.ALIPAY_CHARGE_TYPE != 0) {
                        Global.ALIPAY_CHARGE_TYPE
                    } else {
                        PayUtil.PAY_TYPE_JX_ALIPAY
                    }

                    if (BuildConfig.PAY_MODE == 1) { //百度视频
                        payType = PayUtil.PAY_TYPE_BD_ALIPAY
                    }
                }
                R.id.rb_order_wepay -> {
                    payType = if (Global.WEIXIN_CHARGE_TYPE != 0) {
                        Global.WEIXIN_CHARGE_TYPE
                    } else {
                        PayUtil.PAY_TYPE_JX_WXPAY
                    }

                    if (BuildConfig.PAY_MODE == 1) { //百度视频
                        payType = PayUtil.PAY_TYPE_BD_WXPAY
                    }
                }
            }
        }
        tv_goto_pay?.setOnClickListener {
            if (order == null && goods == null) {
                ToastUtils.showShort("获取商品信息失败！")
                return@setOnClickListener
            }
            if (TextUtils.isEmpty(tv_order_address?.text.toString())) {
                ToastUtils.showShort("还没选择收货地址！")
                return@setOnClickListener
            }
            if (payType == -1) {
                ToastUtils.showShort("请选择支付方式！")
                return@setOnClickListener
            }
            if (order == null) {

                if (address == null){
                    ToastUtils.showShort("还没选择收货地址！")
                    return@setOnClickListener
                }
                createOrder()
            } else {
//                if (TextUtils.equals(order?.sell_type,"2") && TextUtils.equals(order?.status,"0")){
//                    gotoPay(orderId)
//                } else {
                    saveAddress(order!!)
//                }
            }

        }


        cl_order_receiver_address?.setOnClickListener {
            if (TextUtils.equals(order?.status,"1") || TextUtils.equals(order?.status,"2")
                    || TextUtils.equals(order?.status,"3") || TextUtils.equals(order?.status,"4")){

                return@setOnClickListener
            }

            if (from == FROM_TYPE_MAKE_ORDER_BUYNOW) {
                val intent = Intent(context, SubPageActivity::class.java)
                intent.putExtra(SubPageActivity.CLASSFRAMENT, OrderAddressEditFragment::class.java)
                if (address != null) {
                    val bundle = Bundle()
                    bundle.putParcelable("address", address)
                    intent.putExtra("bundle", bundle)
                }
                startActivity(intent)
            } else {
                if (order != null && TextUtils.equals(order!!.sell_type, "1")) {
                    val intent = Intent(context, SubPageActivity::class.java)
                    intent.putExtra(SubPageActivity.CLASSFRAMENT, OrderAddressEditFragment::class.java)

                    val bundle = Bundle()
                    if (!TextUtils.isEmpty(order!!.province) && !TextUtils.isEmpty(order!!.city) && !TextUtils.isEmpty(order!!.county)) {
                        val addressData = AuctionAddressData(order!!.province, order!!.city, order!!.county, order!!.detail, order!!.addressee, order!!.phone)
                        bundle.putParcelable("address", addressData)
                    }
                    bundle.putString("order_id", order!!.order_id)
                    intent.putExtra("bundle", bundle)
                    startActivity(intent)
                }
            }
        }
    }


    /**
     * 获取地址信息
     */
    private fun getAddress() {
        val params = NSRequestParams()
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_AUCTION_ADDRESS, params, object : NSGsonObjectNewCallback<AuctionAddressBean>() {

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: AuctionAddressBean?) {
                if (response != null && response.code == 200) {
                    address = response.data
                    order?.province = address?.province
                    order?.city = address?.city
                    order?.county = address?.county
                    order?.detail = address?.detail
                    order?.addressee = address?.nickname
                    order?.phone = address?.phone
                    refreshUIAddress()
                } else {
                    refreshUIAddress()
                }
            }

            override fun onFailure(statusCode: Int, errorMsg: String) {
                ToastUtils.showShort(errorMsg)
            }

        })
    }

    /**
     * 创建订单
     */
    private fun createOrder() {
        val params = NSRequestParams()
        params.put("goods_id", goods!!.goods_id)
        params.put("province", address?.province)
        params.put("city", address?.city)
        params.put("county", address?.county)
        params.put("detail", address?.detail)
        params.put("nickname", address?.nickname)
        params.put("phone", address?.phone)
        params.put("leave_message", et_order_note_left.text.toString())
        NsOkHttpClient.getNsOkHttpClient().doPost(Constants.GET_AUCTION_BUY_NOW, params, object : NSGsonObjectNewCallback<AuctionCreateOrderBean?>() {

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: AuctionCreateOrderBean?) {
                if (response != null && response.code == 200) {
                    orderId = response.data.order_id
                    totalPrice=(goods!!.fixed_price.toFloat()+goods!!.express_price.toFloat()).toString()
                    getOrderDetails(orderId)
                    gotoPay(response.data.order_id)
                } else {
                    ToastUtils.showShort(message)
                }
            }

            override fun onFailure(statusCode: Int, errorMsg: String) {
                ToastUtils.showShort(errorMsg)
            }

        })
    }

    /**
     * 获取订单详情
     */
    private fun getOrderDetails(orderId: String?) {
        val params = NSRequestParams()
        params.put("order_id", orderId)
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_AUCTION_ORDER_DETAIL, params, object : NSGsonObjectNewCallback<AuctionOrderBean?>() {

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: AuctionOrderBean?) {
                if (response != null && response.code == 200) {
                    order = response.data
                    address = AuctionAddressData(order?.province,order?.city,order?.county,order?.detail,order?.addressee,order?.phone)
                    if (!TextUtils.isEmpty(order!!.total_price)) {
                        totalPrice = order!!.total_price!!
                    }
                    refreshUiOrder()
                } else {
                    ToastUtils.showShort(message)
                }
            }

            override fun onFailure(statusCode: Int, errorMsg: String) {
                ToastUtils.showShort(errorMsg)
            }

        })
    }

    /**
     * 获取订单详情
     */
    private var serviceNumber = ""
    private fun getServiceNumber() {
        var params = NSRequestParams()
        params.put("os", "1")
        params.put("type", "3")
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_SHOP_SERVICEDESC, params, object : NSGsonObjectNewCallback<BaseResultInfo>() {

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: BaseResultInfo?) {
                if (context == null) {
                    return
                }
                if (statusCode == 200) {
                    try {
                        var jsonObject = JSONObject(responseString)
                        var dataBean = jsonObject.optJSONObject("data")
                        var desc = dataBean.optString("desc")
                        serviceNumber = desc
                        if (!TextUtils.isEmpty(serviceNumber)) {
                            callPhone(serviceNumber)
                        }
                    } catch (e: Exception) {
                        e.printStackTrace()
                    }
                }
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {

            }

        })
    }

    /**
     * 调用保存地址
     */
    private fun saveAddress(orderInfo: AuctionOrderData) {
        val params = NSRequestParams()
        params.put("province", orderInfo.province)
        params.put("city", orderInfo.city)
        params.put("county", orderInfo.county)
        params.put("detail", orderInfo.detail)
        params.put("nickname", orderInfo.addressee)
        params.put("phone", orderInfo.phone)
        params.put("order_id", orderInfo.order_id)
        params.put("leave_message", et_order_note_left.text.toString())
        NsOkHttpClient.getNsOkHttpClient().doPost(Constants.GET_AUCTION_UPDATE_ADDRESS, params, object : NSGsonObjectNewCallback<BaseBean<Nothing>>() {

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: BaseBean<Nothing>?) {
                if (response != null && response.code == 200) {
                    gotoPay(orderId)

                } else {
                    MyToast.showShort(message)
                }
            }

            override fun onFailure(statusCode: Int, errorMsg: String) {
                ToastUtils.showShort(errorMsg)
            }

        })
    }


    /**
     * 调用支付
     */
    private fun gotoPay(orderId: String) {
        if (payType == -1) {
            payType = if (Global.ALIPAY_CHARGE_TYPE != 0) {
                Global.ALIPAY_CHARGE_TYPE
            } else {
                PayUtil.PAY_TYPE_JX_ALIPAY
            }

            if (BuildConfig.PAY_MODE === 1) { //百度视频
                payType = PayUtil.PAY_TYPE_BD_ALIPAY
            }
        }

        val intent = Intent(context, TranslucentPayActivity::class.java)
        val bundle = Bundle()
        bundle.putString("count", totalPrice)
        bundle.putInt("type", payType)
        bundle.putInt("rid", 0)
        bundle.putInt("formType", PayUtil.TYPE_FROM_SHOPMALL)
        bundle.putString("subtype", PayUtil.CHARGE_SUB_TYPE_SHOPMALL)      // 修改支付payType后，需要为1元支付添加subType区分类型
        bundle.putString("app_order_id", orderId)      // 竞拍充值订单ID
        intent.putExtras(bundle)
        context!!.startActivity(intent)
    }


    /**
     * 复制文本
     */
    private fun setCopyText(content: String) {
        if (activity == null) {
            return
        }
        val cm = activity!!.getSystemService(Context.CLIPBOARD_SERVICE) as ClipboardManager
        cm.text = content
        ToastUtils.showShort("复制成功")
    }

    override fun onResume() {
        super.onResume()
        if (order != null) {
            orderId = order!!.order_id!!
            getOrderDetails(order!!.order_id)
        }
        getView()?.isFocusableInTouchMode = true
        getView()?.requestFocus()
        getView()?.setOnKeyListener(
                object : View.OnKeyListener {
                    override fun onKey(v: View, keyCode: Int, event: KeyEvent): Boolean {
                        if (event.action == KeyEvent.ACTION_UP
                                && keyCode == KeyEvent.KEYCODE_BACK) {

                            showCloseRemind()
                            return true
                        }
                        return false
                    }
                })
    }

    /**
     * 未支付订单关闭提醒
     */
    private fun showCloseRemind() {
        if (order != null && TextUtils.equals(order!!.status, "0")) {
            CommonRemindDialog.create(context)
                    .setText("放弃", "我再想想")
                    .setTitleText("是否放弃本次购买")
                    .setTitleSize(17)
                    .setOnClickCallback { type ->
                        if (type == BaseDialog.SELECT_FIRST) {
                            activity?.finish()
                        }
                    }

        } else {
            activity?.finish()
        }
    }

    /**
     * 客服电话
     */
    private fun callPhone(phoneNum: String) {
        val intent = Intent(Intent.ACTION_DIAL)
        val data = Uri.parse("tel:$phoneNum")
        intent.data = data
        startActivity(intent)
    }
}