package com.ninexiu.sixninexiu.fragment.discovery

import android.os.Bundle
import androidx.recyclerview.widget.DefaultItemAnimator
import androidx.recyclerview.widget.RecyclerView
import androidx.recyclerview.widget.SimpleItemAnimator
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.fragment.BasePagerFragment
import com.ninexiu.sixninexiu.lib.commonpulltorefresh.PtrClassicFrameLayout

/**
 * @Description:     用于RecyclerView管理页面列表Base类
 * @Author:          liuguangyu
 * @date  :     2019/5/17 12:10
 * @Version:
 */
abstract class BaseViewFragment : BasePagerFragment() {
    /**
     * RootView
     */
    protected var mRootView: View? = null
    /**
     * 核心RecyclerView
     */
    protected lateinit var mRecyclerView: androidx.recyclerview.widget.RecyclerView
    /**
     * 加载视图
     */
    protected lateinit var mLoadingLayout: View
    /**
     * 空视图
     */
    protected lateinit var mEmptyView: View
    /**
     * 加载控件
     */
    protected lateinit var ptrClassicFrameLayout: PtrClassicFrameLayout

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View? {
        if(mRootView == null){
            mRootView = inflater.inflate(inflater(),null)
            prepareView()
            initView()
            initData()
            supportsChangeAnimations()
        }
        return mRootView
    }

    /**
     * close itemAnimator
     */
    private fun supportsChangeAnimations() {
        mRecyclerView.itemAnimator?.let {
            (it as androidx.recyclerview.widget.SimpleItemAnimator).supportsChangeAnimations = false
            (it as androidx.recyclerview.widget.DefaultItemAnimator).supportsChangeAnimations = false
        }
        mRecyclerView.animation?.let {
            (it as androidx.recyclerview.widget.DefaultItemAnimator).supportsChangeAnimations = false
        }
    }

    override fun onActivityCreated(savedInstanceState: Bundle?) {
        super.onActivityCreated(savedInstanceState)
//        prepareView()
//        initView()
//        initData()
    }

    /**
     * 初始化控件
     */
    abstract fun initView()

    /**
     * 初始化数据
     */
    abstract fun initData()

    /**
     * 填充布局
     */
    open fun inflater(): Int {
        return R.layout.fragment_emerging_layout
    }

    /**
     * 刷新结束
     */
    val refreshComplete = fun() {
        ptrClassicFrameLayout?.let {
            ptrClassicFrameLayout.refreshComplete()
            ptrClassicFrameLayout.loadMoreComplete(true)
        }
    }
    /**
     * 没有更多数据
     */
    val setNoMoreData = fun() {
        ptrClassicFrameLayout?.let {
            ptrClassicFrameLayout.loadMoreComplete(false)
            ptrClassicFrameLayout.refreshComplete()
        }
    }
    val loadMoreComplete = fun() {
        ptrClassicFrameLayout.loadMoreComplete(true)
    }


    /**
     * 默认初始化控件
     */
    protected fun prepareView(){
        mLoadingLayout = mRootView?.findViewById<View>(R.id.loading_layout)!!
        mEmptyView = mRootView?.findViewById<View>(R.id.ns_emptyview)!!
        mRecyclerView = mRootView?.findViewById(R.id.rl_child)!!
        ptrClassicFrameLayout = mRootView?.findViewById(R.id.ptrpFrameLayout)!!
//        ptrClassicFrameLayout.rotateView.setImageDrawable(resources.getDrawable(R.drawable.yy_pullrefresh))
//        ptrClassicFrameLayout.setPtrHandler(object : PtrDefaultHandler() {
//            override fun onRefreshBegin(frame: PtrFrameLayout) {
//                initData()
//            }
//        })
    }
}
