package com.ninexiu.sixninexiu.fragment.helper

import android.content.Context
import android.text.TextUtils
import com.google.gson.Gson
import com.google.gson.GsonBuilder
import com.google.gson.JsonSyntaxException
import com.loopj.android.http.BaseJsonHttpResponseHandler
import com.loopj.android.http.TextHttpResponseHandler
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.bean.BaseResultInfo
import com.ninexiu.sixninexiu.bean.DynamicAnchorInfo
import com.ninexiu.sixninexiu.bean.MBUserBaseResult
import com.ninexiu.sixninexiu.bean.ShareInfo
import com.ninexiu.sixninexiu.common.net.*
import com.ninexiu.sixninexiu.common.util.Constants
import com.ninexiu.sixninexiu.common.util.ConstantsVoice
import com.ninexiu.sixninexiu.common.util.MyToast
import com.ninexiu.sixninexiu.common.util.NSLog
import com.qiniu.util.Json
import cz.msebera.android.httpclient.Header
import org.json.JSONObject

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/04/28
 *     desc   : 直播间暂时抽离出来的helper类 : 主要负责接口
 *     version: 1.0
 * </pre>
 */
object MBLiveChatHelper {
    const val Tag = "MBLiveChatHelper"

    // 上报心跳
    fun upLoadUserHeart(uid: Long?, roomId: String?) {
        val params = NSRequestParams()
        uid?.let {
            params.put("uid", it)
        }

        roomId?.let {
            params.put("rid", roomId)
        }

        NSAsyncHttpClient.getInstance().post(Constants.HTTP_POST_GIFT_HEARTLIVE_USERHEART, params, object : TextHttpResponseHandler() {
            override fun onSuccess(statusCode: Int, headers: Array<out Header>?, responseString: String?) {
            }

            override fun onFailure(statusCode: Int, headers: Array<out Header>?, responseString: String?, throwable: Throwable?) {
            }
        })
    }

    // 用户请求上麦
    fun requestUpMic(roomId: String, micNum: Int, callBack: (BaseResultInfo?) -> Unit) {
        val params = NSRequestParams()
        params.put("rid", roomId)
        params.put("micNum", micNum)

        NSAsyncHttpClient.getInstance().post(ConstantsVoice.getInstance().liveAudioRoomSendRequest, params, object : BaseJsonHttpResponseHandler<BaseResultInfo>() {
            override fun onSuccess(statusCode: Int, headers: Array<out Header>?, rawJsonResponse: String?, response: BaseResultInfo?) {
                NSLog.i(Tag, "rawJsonResponse =====$rawJsonResponse")
                callBack.invoke(response)
            }

            override fun onFailure(statusCode: Int, headers: Array<out Header>?, throwable: Throwable?, rawJsonData: String?, errorResponse: BaseResultInfo?) {
            }

            override fun parseResponse(rawJsonData: String?, isFailure: Boolean): BaseResultInfo? {
                var baseResultInfo: BaseResultInfo? = null
                try {
                    val gson = Gson()
                    baseResultInfo = gson.fromJson(rawJsonData, BaseResultInfo::class.java)
                } catch (e: Exception) {
                    NSLog.d(e.message.toString())
                }
                return baseResultInfo
            }

        })
    }

    // 获取观众列表
    fun getViewerList(roomId: String, callBack: (MBUserBaseResult?) -> Unit) {
        val params = NSRequestParams()
        params.put("rid", roomId)
        params.put("os", "1")
        params.put("page", 0)

        NineShowApplication.mUserBase?.token?.let {
            params.put("token", it)
        }

        NSAsyncHttpClient.getInstance().get(Constants.MB_GET_ROOMUSER_LIST_V2, params,
                object : BaseJsonHttpResponseHandler<MBUserBaseResult>() {
                    override fun onSuccess(statusCode: Int, headers: Array<out Header>?, rawJsonResponse: String?, response: MBUserBaseResult?) {
                        callBack.invoke(response)
                    }

                    override fun onFailure(statusCode: Int, headers: Array<out Header>?, throwable: Throwable?, rawJsonData: String?, errorResponse: MBUserBaseResult?) {
                    }

                    override fun parseResponse(rawJsonData: String?, isFailure: Boolean): MBUserBaseResult? {
                        val gson = GsonBuilder().create()
                        var resultInfo: MBUserBaseResult? = null
                        try {
                            resultInfo = gson.fromJson(rawJsonData, MBUserBaseResult::class.java)
                        } catch (e: JsonSyntaxException) {
                            e.printStackTrace()
                        }
                        return resultInfo
                    }
                })
    }

    // pk 主播关注
    fun pkAnchorAttention(context: Context, uid: Long, callBack: (BaseResultInfo?) -> Unit) {
        val params = NSRequestParams()
        params.put("followuid", uid)
        params.put("identify", 1)
        params.put("page", 0)

        val client = NSAsyncHttpClient.getInstance()
        //请求链接不进行转码
        client.setURLEncodingEnabled(false)

        client.get(Constants.PAY_HOST_UNATTE, params, object : BaseJsonHttpResponseHandler<BaseResultInfo>() {
            override fun onSuccess(statusCode: Int, headers: Array<out Header>?, rawJsonResponse: String?, response: BaseResultInfo?) {
                if (response != null) {
                    when (response.code) {
                        200 -> callBack.invoke(response)
                        4403 -> MyToast.MakeToast(context, "不是主播，无法关注！")
                        4404 -> MyToast.MakeToast(context, "用户在您的黑名单列表，无法关注！")
                        4405 -> MyToast.MakeToast(context, "您被对方拉黑了，无法关注！")
                        else -> {
                            MyToast.MakeToast(context, response.message)
                        }
                    }
                }
            }

            override fun onFailure(statusCode: Int, headers: Array<out Header>?, throwable: Throwable?, rawJsonData: String?, errorResponse: BaseResultInfo?) {
            }

            override fun parseResponse(rawJsonData: String?, isFailure: Boolean): BaseResultInfo? {
                val gson = GsonBuilder().create()
                var resultInfo: BaseResultInfo? = null
                try {
                    resultInfo = gson.fromJson(rawJsonData, BaseResultInfo::class.java)
                } catch (e: JsonSyntaxException) {
                    e.printStackTrace()
                }
                return resultInfo
            }

        })
    }

    // fetchAnchorInfo 和 resetAnchorInfo 使用得是同一套接口
    fun fetchAnchorInfo(rid: String?, callBack: (DynamicAnchorInfo?) -> Unit) {
        rid ?: return
        val client = NSAsyncHttpClient.getInstance()
        //请求链接不进行转码
        client.setURLEncodingEnabled(false)

        val params = NSRequestParams()
        params.put("rid", rid)

        client.get(Constants.MBOP_GET_ANTHOR_INFO, params, object : BaseJsonHttpResponseHandler<DynamicAnchorInfo>() {
            override fun onSuccess(statusCode: Int, headers: Array<out Header>?, rawJsonResponse: String?, response: DynamicAnchorInfo?) {
                callBack.invoke(response)
            }

            override fun onFailure(statusCode: Int, headers: Array<out Header>?, throwable: Throwable?, rawJsonData: String?, errorResponse: DynamicAnchorInfo?) {
            }

            override fun parseResponse(rawJsonData: String?, isFailure: Boolean): DynamicAnchorInfo? {
                val gson = GsonBuilder().create()
                var resultInfo: DynamicAnchorInfo? = null
                try {
                    resultInfo = gson.fromJson(rawJsonData, DynamicAnchorInfo::class.java)
                } catch (e: JsonSyntaxException) {
                    e.printStackTrace()
                }
                return resultInfo
            }

        })
    }

    // 获取分享房间的链接
    fun getShareRoomUrl(context: Context, rid: Int, callBack: (ShareInfo?) -> Unit) {
        val params = NSRequestParams()
        params.put("rid", rid)
        NSAsyncHttpClient.getInstance().get(Constants.GET_SHARE_ROOMINTO, params, object : TextHttpResponseHandler() {
            override fun onSuccess(statusCode: Int, headers: Array<out Header>?, responseString: String?) {
                if (responseString != null) {
                    val jsonObject = JSONObject(responseString)
                    val code = jsonObject.optString("code")
                    val message = jsonObject.optString("message")

                    if (TextUtils.equals(code, "200")) {
                        val dataObj = jsonObject.optJSONObject("data")
                        val gson = GsonBuilder().create()

                        try {
                            dataObj?.let {
                                val shareInfo = gson.fromJson(it.toString(), ShareInfo::class.java)
                                callBack.invoke(shareInfo)
                            }

                        } catch (e: Exception) {
                            e.printStackTrace()
                        }
                    } else {
                        MyToast.MakeToast(context, message)
                    }
                }
            }

            override fun onFailure(statusCode: Int, headers: Array<out Header>?, responseString: String?, throwable: Throwable?) {
                callBack.invoke(null)
            }

        })
    }

}