package com.ninexiu.sixninexiu.fragment.liveroom

import android.annotation.SuppressLint
import android.app.Activity
import android.graphics.Bitmap
import android.graphics.BitmapFactory
import android.os.Bundle
import android.text.Spannable
import android.text.SpannableStringBuilder
import android.text.TextUtils
import android.util.TypedValue
import android.view.LayoutInflater
import android.view.View
import android.view.animation.Animation
import android.view.animation.AnimationUtils
import android.widget.ImageView
import androidx.core.content.ContextCompat
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.blankj.utilcode.util.ToastUtils
import com.makeramen.roundedimageview.RoundedImageView
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.adapter.liveroom.LiveRoomUserAdapter
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.bean.*
import com.ninexiu.sixninexiu.broadcast.AppBroadcastHelper
import com.ninexiu.sixninexiu.common.net.NSGsonObjectCallback
import com.ninexiu.sixninexiu.common.net.NSRequestParams
import com.ninexiu.sixninexiu.common.net.NsOkHttpClient
import com.ninexiu.sixninexiu.common.util.*
import com.ninexiu.sixninexiu.fragment.BaseFragment
import com.ninexiu.sixninexiu.view.HeadBoxView
import com.ninexiu.sixninexiu.view.VerticalImageSpan
import com.ninexiu.sixninexiu.view.dp2px
import com.ninexiu.sixninexiu.view.setVisible
import kotlinx.android.synthetic.main.fragment_liveroom_user.*
import kotlinx.android.synthetic.main.layout_for_show_state.*

/**
 * 直播间内的用户列表
 */
class LiveRoomUserFragment : BaseFragment() {
    override fun inflate(inflater: LayoutInflater?): View? {
        return inflater?.inflate(R.layout.fragment_liveroom_user, null)
    }

    companion object {
        const val TYPE_VOICE_HEART = 0  // 语音房心动土豪榜
        const val TYPE_ONLINE_USER = 1//在线用户列表
        const val TYPE_CONTRIBUTION_THIS_TIME = 2//本场贡献
        const val TYPE_CONTRIBUTION_RANK = 3//贡献榜
        fun newInstance(type: Int, roomInfo: RoomInfo?): LiveRoomUserFragment {
            val args = Bundle()
            args.putInt("key_type", type)
            args.putSerializable("key_room", roomInfo)
            val fragment = LiveRoomUserFragment()
            fragment.arguments = args
            return fragment
        }

        fun transformContributeNumber(num: Long): String {
            if (num < 10000) {
                return num.toString()
            }

            val first = num / 10000
            val second = num % 10000 / 1000
            return "${first}.${second}w"
        }
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        initData()
        initView()
    }

    private var type = TYPE_ONLINE_USER
    private var roomInfo: RoomInfo? = null
    private var page = 0
    private lateinit var userAdapter: LiveRoomUserAdapter
    private var haveMyData = false
    private lateinit var inAnim: Animation
    private lateinit var outAnim: Animation

    private fun initData() {
        if (arguments != null) {
            type = arguments!!.getInt("key_type")
            roomInfo = arguments!!.getSerializable("key_room") as RoomInfo?
        }

        inAnim = AnimationUtils.loadAnimation(context, R.anim.anim_view_bottom_in)
        outAnim = AnimationUtils.loadAnimation(context, R.anim.anim_view_bottom_out)

        outAnim.setAnimationListener(object : Animation.AnimationListener {
            override fun onAnimationRepeat(animation: Animation?) {

            }

            override fun onAnimationEnd(animation: Animation?) {
                cl_my_contribution?.visibility = View.GONE
            }

            override fun onAnimationStart(animation: Animation?) {
            }
        })

        if (type == TYPE_ONLINE_USER || type == TYPE_VOICE_HEART) {
            srl_liveroom_user.setEnableLoadMore(true)
            cl_my_contribution.setVisible(false)
        } else {
            srl_liveroom_user.setEnableLoadMore(false)
        }

        getDataByType(true)

        srl_liveroom_user.setOnRefreshListener {
            getDataByType(true)
        }

        srl_liveroom_user.setOnLoadMoreListener {
            getDataByType(false)
        }

        sv_state_view.setOnRefreshListener {
            getDataByType(true)
        }

        rv_liveroom_user.addOnScrollListener(object : RecyclerView.OnScrollListener() {
            override fun onScrollStateChanged(recyclerView: RecyclerView, newState: Int) {
                super.onScrollStateChanged(recyclerView, newState)
                if (haveMyData && type != TYPE_ONLINE_USER && type != TYPE_VOICE_HEART) {
                    if (newState == RecyclerView.SCROLL_STATE_IDLE) {
                        cl_my_contribution.setVisible(true)
                        cl_my_contribution?.startAnimation(inAnim)
                    } else {
                        cl_my_contribution.setVisible(false)
                        cl_my_contribution?.startAnimation(outAnim)
                    }
                }
            }
        })
    }

    /**
     * 根据type调用接口
     */
    private fun getDataByType(isRefresh: Boolean) {
        when (type) {
            TYPE_ONLINE_USER -> {
                getOnlineUserList(isRefresh)
            }
            TYPE_VOICE_HEART -> {
                getVoiceHearList(isRefresh)
            }
            else -> {
                getContributionList()
            }
        }
    }

    private fun initView() {
        if (context == null) return
        rv_liveroom_user.layoutManager = LinearLayoutManager(context, LinearLayoutManager.VERTICAL, false)
        userAdapter = LiveRoomUserAdapter(context!!, if (roomInfo != null) roomInfo!!.artistuid.toLong() else -1L, type, ArrayList())
        rv_liveroom_user.adapter = userAdapter

        // 真爱点击
        userAdapter.realLoveOnClick = {
            AppBroadcastHelper.getInstance().sendBroadcast(NSReceiverAction.ACTION_SHOW_TRUE_LOVE)
        }

        // 去送礼
        tv_send_gift.setOnClickListener {
            AppBroadcastHelper.getInstance().sendBroadcast(NSReceiverAction.ACTION_LIVE_SHOW_GIFT_POP)
        }

        // 显示个人资料页
        userAdapter.showPersonInfoDialog = { userInfo ->
            showUserInfoDialog(userInfo?.uid?.toString(), userInfo?.nickname)
        }


        // 适配阴影影响后的间距   33px   10dp
        cl_my_contribution?.post {
            context?.let {
                val pad = (dp2px(it,10) + 33f/774 * widthScreen).toInt()
                cl_my_contribution.setPadding(pad,pad,pad,pad)
            }
        }
    }

    private val widthScreen: Int by lazy {
        resources?.displayMetrics?.widthPixels ?: 0
    }

    /**
     * 语音房心动现场展示的心动土豪榜
     */
    private fun getVoiceHearList(isRefresh: Boolean) {
        val params = NSRequestParams()
        params.put("rid", roomInfo?.rid)
        params.put("os", "1")
        page = if(isRefresh) {
            1
        } else {
            ++page
        }
        params.put("page", page)
        params.put("count", 15)
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_HEART_FANS, params, object : NSGsonObjectCallback<OnlineUserListBean?>() {

            override fun onSuccess(statusCode: Int, rawJsonResponse: String?, response: OnlineUserListBean?) {
                if (response != null && response.code == 200 && !response.data.list.isNullOrEmpty()) {
                    sv_state_view?.showSuccess()
                    if(isRefresh) {
                        userAdapter.userList.clear()
                    }
                    userAdapter.userList.addAll(response.data.list)
                    userAdapter.notifyDataSetChanged()
                } else {
                    if(isRefresh) {
                        sv_state_view?.showEmpty(context?.getString(R.string.no_current_fans_data))
                    }
                }

                if(isRefresh) {
                    srl_liveroom_user?.finishRefresh()
                }else {
                    srl_liveroom_user?.finishLoadMore()
                }
            }

            override fun onFailure(statusCode: Int, errorMsg: String) {
                ToastUtils.showShort(errorMsg)
                if(isRefresh) {
                    srl_liveroom_user?.finishRefresh()
                }else {
                    srl_liveroom_user?.finishLoadMore()
                }
            }

        })
    }


    /**
     * 在线用户列表
     */
    private fun getOnlineUserList(isRefresh: Boolean) {
        if (isRefresh) {
            page = 0
        } else {
            page++
        }
        val params = NSRequestParams()
        params.put("rid", roomInfo?.rid)
        params.put("os", "1")
        params.put("page", page)
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_LIVEROOM_ONLINE_USER, params, object : NSGsonObjectCallback<OnlineUserListBean?>() {

            override fun onSuccess(statusCode: Int, rawJsonResponse: String?, response: OnlineUserListBean?) {
                if (isRefresh) {
                    userAdapter.userList.clear()
                    srl_liveroom_user?.finishRefresh()
                } else {
                    srl_liveroom_user?.finishLoadMore()
                }
                if (response != null && response.code == 200 && !response.data.user.isNullOrEmpty()) {
                    sv_state_view?.showSuccess()
                    userAdapter.userList.addAll(response.data.user)
                    userAdapter.notifyDataSetChanged()
                } else {
                    if (isRefresh) sv_state_view?.showEmpty("没有在线用户")
                }

            }

            override fun onFailure(statusCode: Int, errorMsg: String) {
                ToastUtils.showShort(errorMsg)
            }

        })
    }


    /**
     * 贡献列表
     */
    private fun getContributionList() {
        val params = NSRequestParams()
        params.put("rid", roomInfo?.rid)
        params.put("os", "1")
        params.put("type", type - 2)
        if (NineShowApplication.mUserBase != null) {
            params.put("uid", NineShowApplication.mUserBase?.uid)
        }
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_LIVEROOM_CONTRIBUTION_USER, params, object : NSGsonObjectCallback<ContributionUserListBean?>() {

            override fun onSuccess(statusCode: Int, rawJsonResponse: String?, response: ContributionUserListBean?) {
                userAdapter.userList.clear()
                if (srl_liveroom_user != null) {
                    srl_liveroom_user.finishRefresh()
                }
                if (response != null && response.code == 200) {
                    if (type == TYPE_CONTRIBUTION_THIS_TIME && !response.data.day.isNullOrEmpty()) {
                        sv_state_view?.showSuccess()
                        userAdapter.userList.addAll(response.data.day)
                        userAdapter.notifyDataSetChanged()

                        if (response.data.user != null) {
                            initMyData(response.data.user)
                        }
                    } else if (type == TYPE_CONTRIBUTION_RANK && !response.data.month.isNullOrEmpty()) {
                        sv_state_view?.showSuccess()
                        userAdapter.userList.addAll(response.data.month)
                        userAdapter.notifyDataSetChanged()

                        if (response.data.user != null) {
                            initMyData(response.data.user)
                        }
                    } else {
                        if (type == TYPE_CONTRIBUTION_THIS_TIME) {
                            sv_state_view?.showEmpty("暂无本场贡献值数据")
                        } else if (type == TYPE_CONTRIBUTION_RANK) {
                            sv_state_view?.showEmpty("暂无月贡献值数据")
                        }
                    }


                }

            }

            override fun onFailure(statusCode: Int, errorMsg: String) {
                ToastUtils.showShort(errorMsg)
            }

        })
    }

    /**
     * 初始化自己的数据
     */
    @SuppressLint("SetTextI18n")
    private fun initMyData(myData: UserBase) {
        if (context == null) return

        haveMyData = true
        cl_my_contribution.setVisible(true)
        //昵称
        tv_my_nickname.text = myData.nickname

        //头像
        var head: View = view.findViewById(R.id.iv_my_avatar)
        var headImg: HeadBoxView? = null
        if (head is ImageView) {
            headImg = HeadBoxView(context!!)
            headImg.setScale(1.4f)
            headImg.bindHead(head)
        } else if (head is HeadBoxView) {
            headImg = head
        }
        if (!TextUtils.isEmpty(myData.headframe)) {
            headImg?.loadBoxImage(myData.headframe)
        }
        GlideUtils.loadCirclePic(context, myData.headimage120, headImg?.iv_head, R.drawable.icon_head_default)

        val spanBuilder = SpannableStringBuilder("")
        var start = 0
        //主播身份
        if (roomInfo != null && roomInfo!!.artistuid.toLong() == myData.uid) {
            spanBuilder.append(LiveRoomUserAdapter.badgeTag)
            val anchorImageSpan = VerticalImageSpan(context, BitmapFactory.decodeResource(context!!.resources, R.drawable.ns_live_chat_anchor_tag))
            spanBuilder.setSpan(anchorImageSpan, start, start + 1, Spannable.SPAN_INCLUSIVE_EXCLUSIVE)
            start += 2
        }

        //管理
        if (myData.managerLevel > 0) {
            spanBuilder.append(LiveRoomUserAdapter.badgeTag)
            val managerImageSpan = VerticalImageSpan(context, BitmapFactory.decodeResource(context!!.resources, R.drawable.ns_live_audience_user_manager))
            spanBuilder.setSpan(managerImageSpan, start, start + 1, Spannable.SPAN_INCLUSIVE_EXCLUSIVE)
            start += 2
        }

        //守护
        if (myData.guardLevel > 0 && Utils.getGuardLevelDrawable(myData.guardId.toLong(), myData.guardLevel) != -1) {
            spanBuilder.append(LiveRoomUserAdapter.badgeTag)
            val managerImageSpan = VerticalImageSpan(context, BitmapFactory.decodeResource(context!!.resources, Utils.getGuardLevelDrawable(myData.guardId.toLong(), myData.guardLevel)))
            spanBuilder.setSpan(managerImageSpan, start, start + 1, Spannable.SPAN_INCLUSIVE_EXCLUSIVE)
            start += 2
        }

        //设置vip
        if (myData.viplevel in 1..4) {
            spanBuilder.append(LiveRoomUserAdapter.badgeTag)
            val vipImageSpan: VerticalImageSpan = when (myData.viplevel) {
                1 -> VerticalImageSpan(context, BitmapFactory.decodeResource(context!!.resources, R.drawable.ns_live_audience_vip_one))
                2 -> VerticalImageSpan(context, BitmapFactory.decodeResource(context!!.resources, R.drawable.ns_live_audience_vip_two))
                3 -> VerticalImageSpan(context, BitmapFactory.decodeResource(context!!.resources, R.drawable.ns_live_audience_vip_three))
                else -> VerticalImageSpan(context, BitmapFactory.decodeResource(context!!.resources, R.drawable.ns_live_audience_vip_four))
            }
            spanBuilder.setSpan(vipImageSpan, start, start + 1, Spannable.SPAN_INCLUSIVE_EXCLUSIVE)
            start += 2
        }

        //等级
        spanBuilder.append(LiveRoomUserAdapter.badgeTag)
        val levelImageSpan = if (myData.is_anchor == 1) {
            VerticalImageSpan(context, BitmapFactory.decodeResource(context!!.resources, Utils.getHostLevelDrawable(myData.creditlevel)))
        } else {
            val bitmap: Bitmap? = Utils.getUserLevelDrawableCommon(context, myData.wealthlevel, myData.uid.toString())
            bitmap?.let { VerticalImageSpan(context, bitmap) }
        }
        spanBuilder.setSpan(levelImageSpan, start, start + 1, Spannable.SPAN_INCLUSIVE_EXCLUSIVE)
        start += 2


        //排位赛
        val res = Utils.getUserRankLevelId(myData.dan, myData.grade, myData.gradeStar)
        if (myData.dan == 0 || myData.grade == 0 || res == -1) {

        } else {
            spanBuilder.append(LiveRoomUserAdapter.badgeTag)
            val rankImageSpan = VerticalImageSpan(context, BitmapFactory.decodeResource(context!!.resources, res))
            spanBuilder.setSpan(rankImageSpan, start, start + 1, Spannable.SPAN_INCLUSIVE_EXCLUSIVE)
            start += 2
        }

        spanBuilder.trim()
        tv_my_badge_container.text = spanBuilder

        //真爱团徽章
        if (myData.loveLevel > 0) {
            tv_my_reallove_badge.setVisible(true)
            tv_my_reallove_badge.text = myData.loveTitle
            val loveLeader = myData.loveRep != 2 && myData.loveFansPointsRank == 1
            tv_my_reallove_badge.background = ContextCompat.getDrawable(context!!, Utils.getTrueLoveFansLeve(myData.loveLevel, 1, loveLeader,myData.loveTagStyle))
            tv_reallove_level?.text = "${myData.loveLevel}"
        } else {
            tv_my_reallove_badge.setVisible(false)
        }

        if (myData.rank > 0) {
            tv_my_rank_count.text = "${myData.rank}"
            tv_my_rank_count.setTextSize(TypedValue.COMPLEX_UNIT_SP, 18f)
        } else {
            tv_my_rank_count.text = "未上榜"
            tv_my_rank_count.setTextSize(TypedValue.COMPLEX_UNIT_SP, 9f)

        }
        if (myData.rank == 1) {
            tv_my_contribution_last.text = "${transformContributeNumber(myData.totalprice)}贡献"
        } else {
            tv_my_contribution_last.text = "距上1名差 ${transformContributeNumber(myData.gapPrice)}贡献"
        }
    }

    private var fragment: LiveBaseInterface? = null
    fun setLiveBaseInterface(fragment: LiveBaseInterface?) {
        this.fragment = fragment
    }


    private fun showUserInfoDialog(uid: String?, name: String?) {
        uid ?: return
        name ?: return
        // 登录用户是主播
        if (NineShowApplication.mUserBase != null) {
            if (NineShowApplication.mUserBase!!.uid == (roomInfo?.artistuid ?: 0).toLong()) {
                // 用户是主播
                if (!TextUtils.isEmpty(uid) && uid == (roomInfo?.artistuid ?: 0).toString() + "") {
                    MBOperationManager.create().showPersonalDialog(context as Activity, fragment,
                            UserBean(null, null, roomInfo, MBOperationManager.MB_LIVE, MBOperationManager.MBOP_ANCHOR,
                                    MBOperationManager.MBOP_ANCHOR_TYPE))
                } else {
                    // 登录人主播 被操作人（观众）不是主播
                    MBOperationManager.create().showPersonalDialog(context as Activity, fragment,
                            UserBean(null, UserBase(Utils.parseLong(uid), name), roomInfo, MBOperationManager.MB_LIVE, MBOperationManager.MBOP_USER,
                                    MBOperationManager.MBOP_ANCHOR_TYPE))
                }
            } else {
                if (!TextUtils.isEmpty(uid) && uid == (roomInfo?.artistuid
                                ?: 0).toString() + "") { // 观众是主播
                    MBOperationManager.create().showPersonalDialog(context as Activity, fragment,
                            UserBean(null, null, roomInfo, MBOperationManager.MB_LIVE, MBOperationManager.MBOP_ANCHOR,
                                    if (NineShowApplication.mUserBase!!.managerLevel > 0) 2 else 3))
                } else { // 观众不是主播
                    MBOperationManager.create().showPersonalDialog(context as Activity, fragment,
                            UserBean(null, UserBase(Utils.parseLong(uid), name), roomInfo, MBOperationManager.MB_LIVE, MBOperationManager.MBOP_USER,
                                    if (NineShowApplication.mUserBase!!.managerLevel > 0) 2 else 3))
                }
            }
        }
    }


}