package com.ninexiu.sixninexiu.fragment.store

import android.app.Dialog
import android.content.Context
import android.content.Intent
import android.os.Bundle
import android.text.TextUtils
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.core.content.ContextCompat
import androidx.recyclerview.widget.GridLayoutManager
import com.blankj.utilcode.util.ToastUtils
import com.loopj.android.http.TextHttpResponseHandler
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.activity.AccountIdentityDialog
import com.ninexiu.sixninexiu.activity.AccountIdentityDialog.Companion.showDialog
import com.ninexiu.sixninexiu.activity.AdvertiseActivity
import com.ninexiu.sixninexiu.adapter.store.GuardBuyPrivilegeAdapter
import com.ninexiu.sixninexiu.adapter.store.StorePriceAdapter
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.bean.BuyTimeList
import com.ninexiu.sixninexiu.bean.GuardBuyInfoDataBean
import com.ninexiu.sixninexiu.bean.GuardList
import com.ninexiu.sixninexiu.bean.IconList
import com.ninexiu.sixninexiu.broadcast.AppBroadcastHelper
import com.ninexiu.sixninexiu.broadcast.NSDataBroadcast
import com.ninexiu.sixninexiu.common.net.NSAsyncHttpClient
import com.ninexiu.sixninexiu.common.net.NSGsonObjectNewCallback
import com.ninexiu.sixninexiu.common.net.NSRequestParams
import com.ninexiu.sixninexiu.common.net.NsOkHttpClient
import com.ninexiu.sixninexiu.common.util.*
import com.ninexiu.sixninexiu.fragment.BasePagerFragment
import com.ninexiu.sixninexiu.pay.ZhiFuFastCDialog.Companion.showBugDialog
import com.ninexiu.sixninexiu.view.dialog.OnZhiFuFastDialogDismissListener
import com.ninexiu.sixninexiu.view.setVisible
import cz.msebera.android.httpclient.Header
import kotlinx.android.synthetic.main.live_guard_buy_layout.*
import org.json.JSONException
import org.json.JSONObject

/**
 * <pre>
 *     @author : hetao
 *     time   : 2021/08/23
 *     desc   : 守护购买页面
 *     version: 1.0
 * </pre>
 */
class GuardBuyFragment : BasePagerFragment(), View.OnClickListener {
    var currentSelect = 0//0白银 1钻石
    var pricePosition = 0//价格选中位置
    var privilegeAdapter: GuardBuyPrivilegeAdapter? = null
    var longTimeAdapter: StorePriceAdapter? = null
    var mbContentFloatManager: MBContentFloatManager? = null

    var privileges = arrayListOf<IconList>()//当前展示的特权列表
    var longTimes = arrayListOf<BuyTimeList>()//当前展示的购买时长

    var anchorHeadUrl: String? = ""//主播头像
    var anchorUid: String? = ""
    var fromPage: Int? = 0//0直播间  1我的守护列表
    var guardBuyInfo: ArrayList<GuardList>? = null//守护列表  白银钻石


    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View? {
        return inflater.inflate(R.layout.live_guard_buy_layout, null)
    }

    override fun onActivityCreated(savedInstanceState: Bundle?) {
        super.onActivityCreated(savedInstanceState)
        initData()
        initView()
    }

    fun initData() {
        anchorHeadUrl = arguments?.getString("anchorHeadUrl")
        anchorUid = arguments?.getString("anchorUid")
        fromPage = arguments?.getInt("fromPage")
        getGuardBuyInfo()
    }

    fun initView() {
        content.setOnClickListener(this)
        guardBack.setOnClickListener(this)
        silver_guard.setOnClickListener(this)
        diamond_guard.setOnClickListener(this)
        guard_buy.setOnClickListener(this)
        guardExplain.setOnClickListener(this)
        if (fromPage == 0) {
            guardBack.visibility = View.VISIBLE
        } else {
            guardBack.visibility = View.GONE
        }
        context?.let {
            privilegeAdapter = GuardBuyPrivilegeAdapter(it, privileges)
            privilege_rv.adapter = privilegeAdapter
            privilege_rv.layoutManager = GridLayoutManager(it, 4)

            longTimeAdapter = StorePriceAdapter(it, false, longTimes, { position, buyPrice ->
                pricePosition = position
                setPageStatus()
            })
            guard_long_time_rv.adapter = longTimeAdapter
            guard_long_time_rv.layoutManager = GridLayoutManager(it, 3)
        }
        //头像
        GlideUtils.loadCirclePic(context, NineShowApplication.mUserBase?.avatarUrl120, guard_buy_head_ic_right, R.drawable.icon_head_default)
        GlideUtils.loadCirclePic(context, anchorHeadUrl, guard_buy_head_ic_left, R.drawable.icon_head_default)

        //余额设置
        NineShowApplication.mUserBase?.let {
            if (it.money > 999999) {
                nine_coin_tv.setText("${Utils.getMoneyFormat(it.money)}九币")
            } else {
                nine_coin_tv.setText("${it.money}九币")
            }
            if (it.tokencoin > 999999) {
                nine_point_tv.setText("${Utils.getMoneyFormat(it.tokencoin)}九点")
            } else {
                nine_point_tv.setText("${it.tokencoin}九点")
            }
        }

    }

    override fun onClick(v: View?) {
        when (v) {
            guardBack -> {//返回键
                AppBroadcastHelper.getInstance().sendBroadcast(NSReceiverAction.ACTION_GUARD_LIST_DIALOG)
            }
            silver_guard -> {//白银守护
                if (guardBuyInfo == null) {
                    return
                }
                currentSelect = 0
                setPageStatus()
            }

            diamond_guard -> {//钻石守护
                if (guardBuyInfo == null) {
                    return
                }
                currentSelect = 1
                setPageStatus()
            }

            guard_buy -> {//购买守护
                longTimeAdapter?.let {
                    buyNobelTask(currentSelect, it.priceList[it.checkedPosition].type)
                }
            }
            guardExplain -> {
                val intent = Intent(activity, AdvertiseActivity::class.java)
                intent.putExtra("url", "https://www.9xiu.com/mobileapp/guard/guardExplain.html")
                intent.putExtra("title", "守护说明")
                intent.putExtra("advertiseMentTitle", "守护说明")
                intent.putExtra("noShare", true)
                startActivity(intent)
            }
        }
    }

    fun setManager(mbContentFloatManager: MBContentFloatManager) {
        this.mbContentFloatManager = mbContentFloatManager
    }

    fun getGuardBuyInfo() {
        val params = NSRequestParams()
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_GUARD_LISTV2, params, object : NSGsonObjectNewCallback<GuardBuyInfoDataBean?>() {
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: GuardBuyInfoDataBean?) {
                if (statusCode == 200) {
                    try {
                        if (response?.code == 200) {
                            guardBuyInfo = response.data
                            //权限条目初始化
                            currentSelect = 0

                            setPageStatus()
                        }
                    } catch (e: Exception) {
                        e.printStackTrace()
                    }
                }
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                ToastUtils.showShort(errorMsg)
            }

        })
    }

    fun setPageStatus() {
        privileges.clear()
        longTimes.clear()
        //时长数据更新
        guardBuyInfo?.get(currentSelect)?.buy_time_list?.let {
            longTimes.addAll(it)
        }
        //是否选择年费
        if (pricePosition == 2) {
            //权益数据更新
            guardBuyInfo?.get(currentSelect)?.year_icon_list?.let {
                privileges.addAll(it)
            }

        } else {
            guardBuyInfo?.get(currentSelect)?.icon_list?.let {
                privileges.addAll(it)
            }
        }
        year_send_tv?.setVisible(!TextUtils.isEmpty(guardBuyInfo?.get(currentSelect)?.buy_time_list?.get(pricePosition)?.message))
        year_send_tv?.text = guardBuyInfo?.get(currentSelect)?.buy_time_list?.get(pricePosition)?.message
        privilegeAdapter?.notifyDataSetChanged()
        //选择白银守护
        if (currentSelect == 0) {
            context?.let {
                silver_guard?.setImageResource(R.drawable.silver_guard_select)
                silver_guard_iv?.setImageResource(R.drawable.silver_guard_select_ic)
                silver_guard_tv?.setTextColor(ContextCompat.getColor(it, R.color.white))

                diamond_guard?.setImageResource(R.drawable.diamond_guard_noselect)
                diamond_guard_iv?.setImageResource(R.drawable.diamond_guard_noselect_ic)
                diamond_guard_tv?.setTextColor(ContextCompat.getColor(it, R.color.color_9b7b47))

                year_send_tv?.setTextColor(ContextCompat.getColor(it, R.color.color_fd638a))


                longTimeAdapter?.isStore = false
                longTimeAdapter?.notifyDataSetChanged()
            }

        } else {//选择钻石守护
            context?.let {
                silver_guard?.setImageResource(R.drawable.silver_guard_noselect)
                silver_guard_iv?.setImageResource(R.drawable.silver_guard_noselect_ic)
                silver_guard_tv?.setTextColor(ContextCompat.getColor(it, R.color.color_fd638a))

                diamond_guard?.setImageResource(R.drawable.diamond_guard_select)
                diamond_guard_iv?.setImageResource(R.drawable.diamond_guard_select_ic)
                diamond_guard_tv?.setTextColor(ContextCompat.getColor(it, R.color.color_3d2600))
                year_send_tv?.setTextColor(ContextCompat.getColor(it, R.color.color_bd8020))
                longTimeAdapter?.isStore = true
                longTimeAdapter?.notifyDataSetChanged()
            }
        }
    }


    private var mDialog: Dialog? = null
    private fun buyNobelTask(serviceType: Int, month: Int) {
        if (NineShowApplication.mUserBase == null) {
            Utils.MakeToast("请登录！")
            return
        }
        val asyncHttpClient = NSAsyncHttpClient.getInstance()
        val params = NSRequestParams()
        var gid = 0
        if (serviceType == 0) {
            //普通守护
            gid = 90001
        } else if (serviceType == 1) {
            //钻石守护
            gid = 90003
        }
        params.put("gid", gid)
        params.put("month", month)
        params.put("anchor_uid", anchorUid)
        asyncHttpClient[Constants.USER_BUY_NOBEL, params, object : TextHttpResponseHandler() {
            override fun onStart() {
                super.onStart()
                mDialog = Utils.showProgressDialog(activity, "购买中...", true)
                mDialog?.show()
            }

            override fun onSuccess(statusCode: Int, headers: Array<Header>, responseString: String) {
                mDialog?.dismiss()
                if (responseString != null) {
                    try {
                        val jsonObject = JSONObject(responseString)
                        val code = jsonObject.optString("code")
                        handleCode(code, jsonObject)
                    } catch (e: java.lang.Exception) {
                        e.printStackTrace()
                        Utils.MakeToast("购买失败，请重试！")
                    }
                }
            }
            override fun onFailure(statusCode: Int, headers: Array<Header>, responseString: String?, throwable: Throwable) {
            }
        }]
    }

    private fun handleCode(code: String, jsonObject: JSONObject) {
        if ("200" == code) {
            Utils.MakeToast("购买成功")
            AppBroadcastHelper.getInstance().sendBroadcast(NSReceiverAction.ACTION_GUARD_PAY_SUCCESS)
            val data = jsonObject.optJSONArray("data")
            if (data != null && data.length() > 0) {
                try {
                    val json = data.getJSONObject(0)
                    if (NineShowApplication.mUserBase != null) {
                        NineShowApplication.mUserBase?.money = json.optLong("money")
                        NineShowApplication.mUserBase?.tokencoin = json.optLong("tokencoin")
                    }
                } catch (e: JSONException) {
                    e.printStackTrace()
                }
            }
            val bundle = Bundle()
            bundle.putString("id", anchorUid)
            AppBroadcastHelper.getInstance().sendBroadcast(NSReceiverAction.ACTION_GUARD_SUCCESS,
                    NSDataBroadcast.TYPE_OPERATION_DEFAULT, bundle)
        } else if ("4305" == code) {
            Utils.MakeToast(jsonObject.optString("message"))
        } else if ("4301" == code) {
            showBuyDialog(activity, jsonObject)
        } else if (AccountIdentityDialog.CODE_BIND_PHONE == code || AccountIdentityDialog.CODE_ACCOUNT_IDENTITY == code) {  // 绑定手机号/实名认证
            activity?.let { showDialog(it, code, jsonObject.optString("message")) }
        } else {
            Utils.MakeToast("购买失败")
        }
    }

    // 快捷支付
    private fun showBuyDialog(context: Context?, jsonObject: JSONObject) {
        MyToast.MakeToast(context?.getString(R.string.yue_not_enough))
        val dataObj = jsonObject.optJSONObject("data") ?: return
        val diffmoney = dataObj.optLong("diffMoney")
        // 调用充值对话框
        if (context != null) {
            showBugDialog(context, 0, diffmoney, object : OnZhiFuFastDialogDismissListener {
                override fun ondismissCallback() {
                }
            })
        }
        activity?.overridePendingTransition(R.anim.slide_in_bottom, R.anim.slide_out_bottom)
    }
}