package com.ninexiu.sixninexiu.fragment.store

import android.os.Bundle
import android.text.TextUtils
import android.view.LayoutInflater
import android.view.View
import androidx.recyclerview.widget.GridLayoutManager
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.adapter.store.MyDressUpAdapter
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.bean.DressUpGoods
import com.ninexiu.sixninexiu.bean.DressUpTab
import com.ninexiu.sixninexiu.common.httphelp.StoreHelper
import com.ninexiu.sixninexiu.common.util.MyToast
import com.ninexiu.sixninexiu.common.util.Utils
import com.ninexiu.sixninexiu.fragment.BaseFragment
import kotlinx.android.synthetic.main.fragment_my_dressup_child.*

/**
 * <pre>
 *     @author : bing
 *     time   : 2021/8/26
 *     desc   :
 *     version: 1.0
 * </pre>
 */
class MyDressUpChildFragment : BaseFragment() {

    companion object {
        const val KEY_DRESSUP_TAB = "dress_up_tab"
        fun newInstance(dressupTab: DressUpTab): MyDressUpChildFragment {
            val args = Bundle()
            args.putParcelable(KEY_DRESSUP_TAB, dressupTab)
            val fragment = MyDressUpChildFragment()
            fragment.arguments = args
            return fragment
        }
    }

    override fun inflate(inflater: LayoutInflater?): View? {
        return inflater?.inflate(R.layout.fragment_my_dressup_child, null)
    }

    private var dressUpTab: DressUpTab? = null
    private lateinit var dressupAdapter: MyDressUpAdapter
    private val goodsList = mutableListOf<DressUpGoods>()
    private var haveViewInit = false
    private var isVisibleUser = false

    /**
     * 已经穿戴的徽章列表
     */
    val dressBadgeList = mutableListOf<DressUpGoods>()

    //获取到数据和修改穿戴的回调
    var onDressChange: ((DressUpTab, List<DressUpGoods>?, Boolean) -> Unit)? = null

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        dressUpTab = arguments?.getParcelable(KEY_DRESSUP_TAB)

        dressUpTab?.let { mTab ->
            context?.let { mContext ->
                rv_my_dressup.layoutManager = GridLayoutManager(mContext, 3, GridLayoutManager.VERTICAL, false)
                dressupAdapter = MyDressUpAdapter(mContext, mTab.id, goodsList)
                rv_my_dressup.adapter = dressupAdapter

                dressupAdapter.onDressUpItemClick = { dressUpGoods, position ->
                    NineShowApplication.mUserBase?.let {
                        if (it.is_anchor == 1 && dressUpTab?.id == 3 && !TextUtils.equals("20200720003", dressUpGoods.badge_id)) {//是主播
                            MyToast.MakeToast("该徽章只能在网页直播间展示，无法在App直播间中展示")
                        } else {
                            MyDressUpDialog.create(mContext, mTab, dressUpGoods, dressBadgeList) { dressupTab, changeGoods, isDress ->
                                if (isDress) {
                                    Utils.MakeToast("穿戴成功")
                                } else {
                                    Utils.MakeToast("取消穿戴成功")
                                }
                                setDressData(position)
                                dressupAdapter.notifyDataSetChanged()
                                formatDressList(changeGoods, isDress)
                                onDressChange?.invoke(dressupTab, dressBadgeList, isDress)
                            }.show()
                        }
                    }
                }
            }
        }

        haveViewInit = true
        if (isVisibleUser) {
            getMyDressUpData()
        }
    }


    /**
     * 对穿戴数据进行预处理，然后回调给父类，结果是穿戴的所有装扮
     */
    private fun formatDressList(changeGoods: DressUpGoods, isDress: Boolean) {
        dressUpTab?.let { tab ->
            if (tab.id != 3) {//不是徽章直接清空，添加进新的
                dressBadgeList.clear()
                if (isDress) {
                    dressBadgeList.add(changeGoods)
                }
            } else {//徽章的，先移除，是穿戴再添加一次
                val iterator = dressBadgeList.iterator()
                while (iterator.hasNext()) {
                    val goods = iterator.next()
                    if (TextUtils.equals(goods.badge_id, changeGoods.badge_id)) {
                        iterator.remove()
                    }
                }
                if (isDress) {
                    dressBadgeList.add(changeGoods)
                }
            }
        }

    }

    /**
     * 刷新穿戴的数据
     */
    private fun setDressData(position: Int) {
        dressUpTab?.let { tab ->
            if (tab.id != 3) {//不是徽章
                for ((index, goods) in goodsList.withIndex()) {
                    if (index != position && goods.isactive == 1) {
                        goods.isactive = 0
                    }
                }
            }
        }

    }

    override fun setUserVisibleHint(isVisibleToUser: Boolean) {
        super.setUserVisibleHint(isVisibleToUser)
        isVisibleUser = isVisibleToUser
        if (haveViewInit && isVisibleToUser) {
            getMyDressUpData()
        }
    }

    /**
     * 获取我的装扮列表
     */
    fun getMyDressUpData() {
        dressUpTab?.let {
            StoreHelper.getMyDressupData(it.id, {
                setupDressChange(it)
                if (it.isNullOrEmpty()) {
                    setUpEmptyRemind()
                } else {
                    sv_state_view?.showSuccess()
                    if (this@MyDressUpChildFragment::dressupAdapter.isInitialized) {
                        goodsList.clear()
                        goodsList.addAll(it)
                        dressupAdapter.notifyDataSetChanged()
                    }
                }
            }, { code, msg ->
                setupDressChange(null)
                setUpEmptyRemind()
            })
        }
    }

    /**
     * 处理回调
     */
    private fun setupDressChange(goodsList: List<DressUpGoods>?) {
        dressUpTab?.let {
            if (goodsList.isNullOrEmpty()) {
                onDressChange?.invoke(it, null, true)
            } else {
                dressBadgeList.clear()
                for (goods in goodsList) {
                    if (goods.isactive == 1) {//佩戴着呢
                        dressBadgeList.add(goods)
                    }
                }
                onDressChange?.invoke(it, dressBadgeList, true)
            }
        }
    }

    /**
     * 没有数据吗，空页面设置
     */
    private fun setUpEmptyRemind() {
        dressUpTab?.let {
            sv_state_view?.showEmpty("您还没有${it.name}哦，快到装扮-${it.name}看看吧~")
        }
    }

}
