package com.ninexiu.sixninexiu.fragment.store

import android.annotation.SuppressLint
import android.content.Context
import android.graphics.drawable.Drawable
import android.text.TextUtils
import androidx.core.content.ContextCompat
import androidx.lifecycle.LifecycleOwner
import com.bumptech.glide.Glide
import com.bumptech.glide.load.engine.DiskCacheStrategy
import com.bumptech.glide.request.RequestOptions
import com.bumptech.glide.request.target.CustomTarget
import com.bumptech.glide.request.target.SimpleTarget
import com.bumptech.glide.request.transition.Transition
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.bean.DressUpGoods
import com.ninexiu.sixninexiu.bean.DressUpTab
import com.ninexiu.sixninexiu.common.httphelp.StoreHelper
import com.ninexiu.sixninexiu.common.util.MyToast
import com.ninexiu.sixninexiu.view.dialog.BaseDialog
import com.ninexiu.sixninexiu.view.dp2px
import com.ninexiu.sixninexiu.view.setVisible
import jp.wasabeef.glide.transformations.RoundedCornersTransformation
import kotlinx.android.synthetic.main.dialog_my_dressup.*

/**
 * 我的道具 - 道具弹窗
 *
 * @author wangyu
 * @date 2020/6/16
 */
class MyDressUpDialog private constructor(val mContext: Context, val dressUpTab: DressUpTab,
                                          val dressUpGoods: DressUpGoods,
                                          val dressBadgeList: MutableList<DressUpGoods>,
                                          var onDressChange: ((dressupTab: DressUpTab, dressupGoods: DressUpGoods, isDress: Boolean) -> Unit)?) : BaseDialog(mContext) {

    companion object {
        const val TENTHOUSAND: Long = 10000
        const val A_HUNDRED_MILLION: Long = 100000000
        fun create(context: Context, dressUpTab: DressUpTab, dressUpGoods: DressUpGoods, dressBadgeList: MutableList<DressUpGoods>,
                   onDressChange: ((dressupTab: DressUpTab, dressupGoods: DressUpGoods, isDress: Boolean) -> Unit)?): MyDressUpDialog {
            return MyDressUpDialog(context, dressUpTab, dressUpGoods, dressBadgeList, onDressChange)
        }
    }

    override fun getContentView(): Int {
        return R.layout.dialog_my_dressup
    }

    override fun setDialogWith(): Float {
        return 1f
    }

    override fun isBottomPop(): Boolean {
        return true
    }


    override fun initView() {
        super.initView()

        setupDressup()
    }

    @SuppressLint("CheckResult")
    private fun setupDressup() {
        tv_dressup_name.text = dressUpGoods.name
        setupDressState()
        tv_dressup_time_remain.text = dressUpGoods.deadLine

        tv_dressup_buy.setVisible(dressUpGoods.state == 4 || dressUpGoods.state == 5)//4购买，5续费

        //背景设置
        if (!TextUtils.isEmpty(dressUpGoods.background)) {
            val options = RequestOptions()
                    .transform(RoundedCornersTransformation(dp2px(context,8),0))
            Glide.with(context).load(dressUpGoods.background).apply(options).into(object : CustomTarget<Drawable>() {
                override fun onResourceReady(resource: Drawable, transition: Transition<in Drawable>?) {
                    cl_dressup_container.background = resource
                }

                override fun onLoadCleared(placeholder: Drawable?) {

                }
            })
        } else {
            cl_dressup_container.background = ContextCompat.getDrawable(context, R.drawable.shape_e9eaeb_corner8)
        }

        cl_dressup_container?.initDressupView(dressUpTab, dressUpGoods, video_dress_up_anim, true)
    }

    /**
     * 设置穿戴状态
     */
    private fun setupDressState() {
        if (dressUpGoods.isactive == 1) {
            tv_dressup_desc?.text = "穿戴中"
            tv_dressup_desc?.setTextColor(ContextCompat.getColor(mContext, R.color.color_ff567b))
            tv_dressup_state?.text = "取消穿戴"
            tv_dressup_state?.setTextColor(ContextCompat.getColor(mContext, R.color.color_ff567b))
            tv_dressup_state?.delegate?.strokeColor = ContextCompat.getColor(mContext, R.color.color_ff567b)
            tv_dressup_state?.delegate?.strokeWidth = 1
            tv_dressup_state?.delegate?.setBackgroundColorStartEnd(ContextCompat.getColor(mContext, R.color.white), ContextCompat.getColor(mContext, R.color.white))
        } else {
            tv_dressup_desc?.text = "未穿戴"
            tv_dressup_desc?.setTextColor(ContextCompat.getColor(mContext, R.color.color_666666))
            tv_dressup_state?.text = "穿戴"
            tv_dressup_state?.setTextColor(ContextCompat.getColor(mContext, R.color.white))
            tv_dressup_state?.delegate?.strokeWidth = 0
            tv_dressup_state?.delegate?.setBackgroundColorStartEnd(ContextCompat.getColor(mContext, R.color.color_ff567b), ContextCompat.getColor(mContext, R.color.color_FFAD9B))
        }
    }

    override fun initDatas() {
        super.initDatas()

        tv_dressup_state.setOnClickListener {
            if (dressUpGoods.isactive == 1) {
                //取消穿戴
                setDressup(0)
            } else {
                //穿戴
                setDressup(1)
            }
        }

        tv_dressup_buy.setOnClickListener {
            dressUpGoods.id = dressUpGoods.gid
            val dressUpDialog = DressUpBuyDialog.create(context, dressUpTab, dressUpGoods, false)
            dressUpDialog.show()
            dressUpDialog.needBackCallBack = {
                show()
            }
            dismiss()
        }

        view_placeholder.setOnClickListener {
            dismiss()
        }
    }

    fun setDressup(newState: Int) {
        var frameBadgeStr = ""
        if (dressUpTab.id == 1) {//头像框参数
            if (newState == 1 && dressUpGoods.frame_id!=null) {
                frameBadgeStr = dressUpGoods.frame_id
            }
        } else if (dressUpTab.id == 3) {//徽章参数设置
            frameBadgeStr = formatBadge(newState)
        }
        StoreHelper.setupDressUp(dressUpTab, dressUpGoods, frameBadgeStr.toString(), newState, {
            dressUpGoods.isactive = newState
            if (newState == 0) {
                onDressChange?.invoke(dressUpTab, dressUpGoods, false)
            } else {
                onDressChange?.invoke(dressUpTab, dressUpGoods, true)
            }
            setupDressState()
            dismiss()
        }, { code, msg ->
            MyToast.MakeToast(msg)
        })
    }


    /**
     * 已穿戴的徽章的数据
     */
    private fun formatBadge(newState: Int): String {
        val badgeBuilder = StringBuilder()
        if (newState == 1) {
            var have = false
            for (badge in dressBadgeList) {
                if (TextUtils.equals(badge.badge_id, dressUpGoods.badge_id)) {
                    have = true
                }
            }
            if (!have) {
                dressBadgeList.add(dressUpGoods)
            }
        } else if (newState != 1) {
            val iterator = dressBadgeList.iterator()
            while (iterator.hasNext()) {
                if (TextUtils.equals(iterator.next().badge_id, dressUpGoods.badge_id)) {
                    iterator.remove()
                }
            }
        }

        for ((index, badge) in dressBadgeList.withIndex()) {
            badgeBuilder.append(badge.badge_id)
            if (index != dressBadgeList.size - 1) {
                badgeBuilder.append(",")
            }
        }
        return badgeBuilder.toString()
    }

}