package com.ninexiu.sixninexiu.fragment.store

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import androidx.recyclerview.widget.GridLayoutManager
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.adapter.store.MyPropsAdapter
import com.ninexiu.sixninexiu.bean.Props
import com.ninexiu.sixninexiu.bean.PropsList
import com.ninexiu.sixninexiu.broadcast.AppBroadcastHelper
import com.ninexiu.sixninexiu.common.util.NSReceiverAction
import com.ninexiu.sixninexiu.common.util.Utils
import com.ninexiu.sixninexiu.fragment.BaseFragment
import kotlinx.android.synthetic.main.fragment_my_props_child.*
import kotlinx.android.synthetic.main.layout_for_show_state.*

/**
 * <pre>
 *     @author : bing
 *     time   : 2021/8/23
 *     desc   : 我的道具 子列表类
 *     version: 1.0
 * </pre>
 */
class MyPropsChildFragment : BaseFragment() {
    companion object {
        const val KEY_PROP_LIST = "prop_list"

        const val PROP_TYPE_ALL = 1//全部
        const val PROP_TYPE_VIP = 2//vip
        const val PROP_TYPE_GIFT = 3//礼物
        const val PROP_TYPE_BEAUTY_NUMBER = 4//靓号
        const val PROP_TYPE_PROP = 5//道具

        fun newInstance(propsList: PropsList): MyPropsChildFragment {
            val args = Bundle()
            if (!propsList.list.isNullOrEmpty()) {
                args.putParcelable(KEY_PROP_LIST, propsList)
            }
            val fragment = MyPropsChildFragment()
            fragment.arguments = args
            return fragment
        }
    }

    override fun inflate(inflater: LayoutInflater?): View? {
        return inflater?.inflate(R.layout.fragment_my_props_child, null)
    }

    private val propsList = mutableListOf<Props>()
    private lateinit var propsAdapter: MyPropsAdapter

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        arguments?.let {
            val propsData = it.getParcelable<PropsList>(KEY_PROP_LIST)
            if (propsData != null && !propsData.list.isNullOrEmpty()) {
                propsList.addAll(propsData.list)
            }
        }

        context?.let {
            rv_my_prop?.layoutManager = GridLayoutManager(it, 3, GridLayoutManager.VERTICAL, false)
            propsAdapter = MyPropsAdapter(it, propsList)
            rv_my_prop?.adapter = propsAdapter

            propsAdapter.onPropsClick = { props, position ->
                if (!Utils.isNotClickable()) {
                    context?.let {
                        if (props.stocktype == 4 || props.stocktype == 11 || props.stocktype == 12) { //VIP  //隐身卡   //靓号
                            val propsDialog = MyPropsDialog.create(it, props)
                            propsDialog.show()
                            propsDialog.onPropsStateChange = {
                                AppBroadcastHelper.getInstance().sendBroadcast(NSReceiverAction.ACTION_MY_PROPS_CHANGE)
//                            propsAdapter.notifyItemChanged(position)
                            }
                        } else if (props.stocktype == 13) { //置顶卡逻辑
                            val topCardDialog = MyPropsTopCardDialog.create(it, props)
                            topCardDialog.show()
                            topCardDialog.userTopCardSucceed = {
                                AppBroadcastHelper.getInstance().sendBroadcast(NSReceiverAction.ACTION_MY_PROPS_CHANGE)
                            }
                        }
                    }
                }
            }
        }

        if (propsList.isEmpty()) {
            sv_state_view?.showEmpty("暂无数据！")
        }
    }

    /**
     * 更新数据
     */
    fun setNewData(newData: List<Props>?) {
        if (!newData.isNullOrEmpty()) {
            propsList.clear()
            propsList.addAll(newData)
            propsAdapter.notifyDataSetChanged()
        }
    }
}