package com.ninexiu.sixninexiu.fragment.store

import android.content.Context
import android.text.TextUtils
import androidx.core.content.ContextCompat
import com.contrarywind.adapter.WheelAdapter
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.bean.Props
import com.ninexiu.sixninexiu.bean.TimePeriod
import com.ninexiu.sixninexiu.common.httphelp.StoreHelper
import com.ninexiu.sixninexiu.common.util.MyToast
import com.ninexiu.sixninexiu.view.dialog.BaseDialog
import kotlinx.android.synthetic.main.dialog_my_props_topcard.*

/**
 * 我的道具 置顶卡操作弹窗
 *
 * @author wangyu
 * @date 2020/6/16
 */
class MyPropsTopCardDialog private constructor(val mContext: Context, val props: Props) : BaseDialog(mContext) {

    companion object {
        const val TENTHOUSAND: Long = 10000
        const val A_HUNDRED_MILLION: Long = 100000000
        fun create(context: Context, props: Props): MyPropsTopCardDialog {
            return MyPropsTopCardDialog(context, props)
        }
    }

    var userTopCardSucceed:(() ->Unit)?=null

    override fun getContentView(): Int {
        return R.layout.dialog_my_props_topcard
    }

    override fun setDialogWith(): Float {
        return 1f
    }

    override fun isBottomPop(): Boolean {
        return true
    }


    override fun initView() {
        super.initView()

        tv_props_title.text = props.name
    }

    private var date: String? = null
    private var time: String? = null
    private var timeList = mutableListOf<TimePeriod>()

    override fun initDatas() {
        super.initDatas()

        tv_props_day.setOnClickListener {
            val dayDialog = MyPropsSelectTimeDialog.create(context = mContext, props = props)
            dayDialog.show()

            dayDialog.onSelectResult = {
                getTimeList(it)
                date = it
                tv_props_day.text = date
                tv_props_day.setTextColor(ContextCompat.getColor(mContext, R.color.color_333333))
            }
        }

        tv_props_time.setOnClickListener {
            date?.let {
                val timeDialog = MyPropsSelectTimeDialog.create(context = mContext, timeList = timeList, props = props)
                timeDialog.show()

                timeDialog.onSelectResult = {
                    time = it
                    tv_props_time.text = time
                    tv_props_time.setTextColor(ContextCompat.getColor(mContext, R.color.color_333333))
                }
            }
        }


        tv_props_use.setOnClickListener {
            val rid = et_props_roomid.text.toString().trim()
            if (TextUtils.isEmpty(rid)) {
                MyToast.MakeToast("还没有输入房间id")
                return@setOnClickListener
            }

            if (TextUtils.isEmpty(date)) {
                MyToast.MakeToast("还没有选择日期")
                return@setOnClickListener
            }

            if (TextUtils.isEmpty(time)) {
                MyToast.MakeToast("还没有选择时间")
                return@setOnClickListener
            }
            date?.let { date ->
                time?.let { time ->
                    props.gid?.let { gid ->
                        StoreHelper.userTopcard(rid, date, time, gid, {
                            userTopCardSucceed?.invoke()
                            MyToast.MakeToast("启用成功")
                            dismiss()
                        }, { code, msg ->
                            MyToast.MakeToast(msg)
                        })
                    }
                }
            }
        }

        iv_props_back.setOnClickListener {
            dismiss()
        }
    }


    //获取可选日期，根据系统时间获取
    private fun getTimeList(selectDete: String) {
        if (!TextUtils.isEmpty(props.gid)) {
            StoreHelper.getTimeList(selectDete, props.gid!!, { result ->
                timeList.clear()
                if (!result.data.timelist.isNullOrEmpty()) {
                    for (time in result.data.timelist) {
                        if (time.status != 1) {
                            timeList.add(time)
                        }
                    }

                    time = timeList[0].time
                }
            }, { code, msg ->
                MyToast.MakeToast(msg)
            })
        }
    }

}