package com.ninexiu.sixninexiu.fragment.store

import android.animation.ObjectAnimator
import android.content.Context
import android.text.TextUtils
import android.view.LayoutInflater
import androidx.core.content.ContextCompat
import androidx.recyclerview.widget.LinearLayoutManager
import com.ninexiu.sixninexiu.CommonApplication
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.activity.AccountIdentityDialog
import com.ninexiu.sixninexiu.activity.store.StoreGiveActivity
import com.ninexiu.sixninexiu.adapter.store.StorePriceAdapter
import com.ninexiu.sixninexiu.bean.*
import com.ninexiu.sixninexiu.common.httphelp.StoreHelper
import com.ninexiu.sixninexiu.common.util.MyToast
import com.ninexiu.sixninexiu.common.util.Utils
import com.ninexiu.sixninexiu.im.NewsRemindManager
import com.ninexiu.sixninexiu.pay.ZhiFuFastCDialog
import com.ninexiu.sixninexiu.view.PopupWindowHelper
import com.ninexiu.sixninexiu.view.dialog.BaseDialog
import com.ninexiu.sixninexiu.view.dialog.CommonRemindDialog
import com.ninexiu.sixninexiu.view.dialog.OnZhiFuFastDialogDismissListener
import com.ninexiu.sixninexiu.view.dp2px
import com.ninexiu.sixninexiu.view.setVisible
import kotlinx.android.synthetic.main.dialog_store_buy.*
import kotlinx.android.synthetic.main.dialog_store_buy.rv_price
import kotlinx.android.synthetic.main.dialog_store_buy.view_placeholder
import kotlinx.android.synthetic.main.popwindow_store_prop_yinshen.view.*
import org.json.JSONObject

/**
 * <pre>
 *     @author : bing
 *     time   : 2021/8/19
 *     desc   : 新版商城购买弹窗
 *     version: 1.0
 * </pre>
 */
class StoreBuyDialog : BaseDialog {

    override fun getContentView(): Int {
        return R.layout.dialog_store_buy
    }

    private lateinit var mContext: Context
    private var beautyNumber: Account? = null
    private var props: StoreProps? = null
    private var vipInfo: VipPrivilege? = null


    private var type = StoreHelper.TYPE_BEAUTY_NUMBER
    private var needGive = true

    //选中的价格
    private var selectedPrice: BuyTimeList? = null

    var buySucceed: ((BuyTimeList) -> Unit)? = null
    var buyFailed: (() -> Unit)? = null

    /**
     * 购买成功回调
     */
    private val onSucceed: ((StoreBuyResult?) -> Unit) = { result ->
        selectedPrice?.let { price ->
            buySucceed?.invoke(price)
        }
        result?.let { res ->
            CommonApplication.mUserBase?.let {
                it.money = res.money
                it.tokencoin = res.tokencoin
            }
        }

        setupBalance()
        MyToast.MakeToast("购买成功")
        dismiss()
    }

    /**
     * 购买失败回调
     */
    private val onFiled: ((Int, String?, String?) -> Unit) = { code, msg, responseStr ->
        if (4301 == code) {
            // 调用充值对话框
            showBuyDialog(JSONObject(responseStr))
            dismiss()
        } else if (4302 == code) {
            Utils.MakeToast("用户未登录")
        } else if (409 == code) {// 409被占用
            buyFailed?.invoke()
            dismiss()
            Utils.MakeToast("该靓号已被占用")
        } else if (AccountIdentityDialog.CODE_BIND_PHONE == code.toString() || AccountIdentityDialog.CODE_ACCOUNT_IDENTITY == code.toString()) {  // 绑定手机号/实名认证
            AccountIdentityDialog.showDialog(mContext, code.toString(), msg)
        } else {// 400请求参数有误
            MyToast.MakeToast(msg)
        }
    }

    constructor(context: Context, beautyNumber: Account, needGive: Boolean) : super(context) {
        mContext = context
        this.beautyNumber = beautyNumber
        type = StoreHelper.TYPE_BEAUTY_NUMBER
        this.needGive = needGive
    }

    constructor(context: Context, props: StoreProps, needGive: Boolean) : super(context) {
        mContext = context
        this.props = props
        type = StoreHelper.TYPE_BEAUTY_PROPS
        this.needGive = needGive
    }

    constructor(context: Context, vipInfo: VipPrivilege, needGive: Boolean) : super(context) {
        mContext = context
        this.vipInfo = vipInfo
        type = StoreHelper.TYPE_BEAUTY_VIP
        this.needGive = needGive
    }

    companion object {

        fun create(context: Context, beautyNumber: Account, needGive: Boolean = true): StoreBuyDialog {
            val dialog = StoreBuyDialog(context, beautyNumber, needGive)
            return dialog
        }

        fun create(context: Context, props: StoreProps, needGive: Boolean = true): StoreBuyDialog {
            val dialog = StoreBuyDialog(context, props, needGive)
            return dialog
        }

        fun create(context: Context, vipInfo: VipPrivilege, needGive: Boolean = true): StoreBuyDialog {
            val dialog = StoreBuyDialog(context, vipInfo, needGive)
            return dialog
        }
    }


    override fun initView() {
        super.initView()

        tv_give_other.setVisible(needGive)
        setupBalance()
        setupGoods()

    }

    private fun setupGoods() {
        if (type == StoreHelper.TYPE_BEAUTY_NUMBER) {
            beautyNumber?.let {
                tv_beauty_number.setVisible(true)
                tv_beauty_number.text = it.accountid
                tv_store_goods_name.text = "靓号${it.accountid}"

                formatPriceSetAdapter(it.priceInfo)
                when (it.bit) {
                    "3" -> {
                        iv_store_goods_cover.setImageResource(R.drawable.icon_store_beauty_number_bg_3)
                        tv_beauty_number.setTextColor(ContextCompat.getColor(mContext, R.color.color_ffda9e))
                    }
                    "4" -> {
                        iv_store_goods_cover.setImageResource(R.drawable.icon_store_beauty_number_bg_4)
                        tv_beauty_number.setTextColor(ContextCompat.getColor(mContext, R.color.color_232222))
                    }
                    "5" -> {
                        iv_store_goods_cover.setImageResource(R.drawable.icon_store_beauty_number_bg_5)
                        tv_beauty_number.setTextColor(ContextCompat.getColor(mContext, R.color.white))
                    }
                    "6" -> {
                        iv_store_goods_cover.setImageResource(R.drawable.icon_store_beauty_number_bg_6)
                        tv_beauty_number.setTextColor(ContextCompat.getColor(mContext, R.color.white))
                    }
                    "7" -> {
                        iv_store_goods_cover.setImageResource(R.drawable.icon_store_beauty_number_bg_7)
                        tv_beauty_number.setTextColor(ContextCompat.getColor(mContext, R.color.white))
                    }
                }
            }
        } else if (type == StoreHelper.TYPE_BEAUTY_PROPS) {
            props?.let {
                tv_store_goods_name.text = "隐身卡"
                iv_store_goods_cover.setImageResource(R.drawable.icon_store_prop_yinshen)
                tv_store_prop_help.setVisible(true)
                if (!it.priceInfo.isNullOrEmpty()) {
                    tv_props_preprice.text = "${it.priceInfo[0].money}九币/月"
                }

                if (!TextUtils.isEmpty(it.tips)) {
                    tv_props_remind.text = it.tips
                    tv_props_remind.setVisible(true)
                } else {
                    tv_props_remind.setVisible(false)
                }
                formatPriceSetAdapter(it.priceInfo)
            }
        } else if (type == StoreHelper.TYPE_BEAUTY_VIP) {
            vipInfo?.let {
                tv_store_goods_name.text = it.name
                val vipDrawable = when (it.gid) {
                    "800001" -> {
                        R.drawable.icon_store_vip_1
                    }
                    "800002" -> {
                        R.drawable.icon_store_vip_2
                    }
                    "800003" -> {
                        R.drawable.icon_store_vip_3
                    }
                    "800004" -> {
                        R.drawable.icon_store_vip_4
                    }
                    else -> {
                        0
                    }
                }

                if (vipDrawable != 0) {
                    iv_store_goods_cover.setImageResource(vipDrawable)
                }
                if (!it.price_info.isNullOrEmpty()) {
                    tv_props_preprice.text = "${it.price_info[0].money}九币/月"
                }
                formatPriceSetAdapter(it.price_info)
            }
        }
    }

    /**
     * 设置价格列表
     */
    private fun formatPriceSetAdapter(prices: List<BuyTimeList>?) {
        if (!prices.isNullOrEmpty()) {
            val formatPriceList = mutableListOf<BuyTimeList>()
            formatPriceList.addAll(prices)
            selectedPrice = formatPriceList[0]
            selectedPrice?.message?.let {
                tv_store_goods_price_desc.text = it
            }
            rv_price.layoutManager = LinearLayoutManager(mContext, LinearLayoutManager.HORIZONTAL, false)
            val priceAdapter = StorePriceAdapter(mContext, true, formatPriceList)

            priceAdapter.onPriceClick = { position, buyPrice ->
                selectedPrice = buyPrice
                priceAdapter.notifyDataSetChanged()
                tv_store_goods_price_desc.text = buyPrice.message
            }

            rv_price.adapter = priceAdapter
        }
    }

    override fun initDatas() {
        super.initDatas()
    }

    override fun initEvents() {
        super.initEvents()

        tv_store_prop_help.setOnClickListener {
            showHelperPop()
        }

        view_placeholder.setOnClickListener {
            dismiss()
        }

        tv_store_goods_buy.setOnClickListener {
            if (type == StoreHelper.TYPE_BEAUTY_NUMBER) {
                buyBeautyNumber()
            } else if (type == StoreHelper.TYPE_BEAUTY_PROPS) {
                buyPropsYinshen()
            } else if (type == StoreHelper.TYPE_BEAUTY_VIP) {
                buyVip()
            }
        }

        tv_give_other.setOnClickListener {
            if (type == StoreHelper.TYPE_BEAUTY_NUMBER) {
                beautyNumber?.let { number ->
                    selectedPrice?.let { price ->
                        StoreGiveActivity.start(mContext, number, price) {
                            if (it) {
                                startTransAnim(false)
                            } else {
                                dismiss()
                                buySucceed?.invoke(price)
                            }
                        }
                        startTransAnim(true)
                    }
                }
            } else if (type == StoreHelper.TYPE_BEAUTY_PROPS) {
                props?.let { mProps ->
                    selectedPrice?.let { mPrice ->
                        StoreGiveActivity.start(mContext, mProps, mPrice) {
                            if (it) {
                                startTransAnim(false)
                            } else {
                                dismiss()
                            }
                        }
                        startTransAnim(true)
                    }
                }
            } else if (type == StoreHelper.TYPE_BEAUTY_VIP) {
                vipInfo?.let { vip ->
                    selectedPrice?.let { mPrice ->
                        StoreGiveActivity.start(mContext, vip, mPrice) {
                            if (it) {
                                startTransAnim(false)
                            } else {
                                dismiss()
                            }
                        }
                        startTransAnim(true)
                    }
                }
            }
        }
    }


    /**
     * 购买VIP
     */
    private fun buyVip() {
        if (Utils.isNotClickable()) {
            return
        }

        if (vipInfo == null) {
            MyToast.MakeToast("未获取到商品信息，请重试！")
            dismiss()
            return
        }

        if (selectedPrice == null) {
            MyToast.MakeToast("请选择购买时长！")
            dismiss()
            return
        }
        vipInfo?.let { vip ->
            selectedPrice?.let { price ->
                StoreHelper.buyVipBefore(vip, price, null, {
                    //校验成功，去购买
                    StoreHelper.buyVip(vip, price, null, onSucceed, onFiled)
                }, { code, msg ->
                    if (code == 4304) {
                        CommonRemindDialog.create(mContext).setTitleText(msg).setText("确定", "取消").setOnClickCallback {
                            if (it == BaseDialog.SELECT_FIRST) {
                                //校验成功，去购买
                                StoreHelper.buyVip(vip, price, null, onSucceed, onFiled)
                            }
                        }
                    } else {
                        MyToast.MakeToast(msg)
                    }
                })

            }
        }
    }

    /**
     * 购买隐身卡
     */
    private fun buyPropsYinshen() {
        if (Utils.isNotClickable()) {
            return
        }

        if (props == null) {
            MyToast.MakeToast("未获取到商品信息，请重试！")
            dismiss()
            return
        }

        if (selectedPrice == null) {
            MyToast.MakeToast("请选择购买时长！")
            dismiss()
            return
        }
        props?.let { mProps ->
            selectedPrice?.let {
                NewsRemindManager.getInstans().delete(NewsRemindManager.KEY_STEALTHCARD_EXPIRED)
                StoreHelper.buyPropsYinshen(mProps, it, null, onSucceed, onFiled)
            }
        }

    }

    /**
     * 余额设置
     */
    private fun setupBalance() {
        var nineCoin: String? = ""
        var nineDot: String? = ""
        CommonApplication.mUserBase?.let {
            if (it.money >= 0 || it.tokencoin >= 0) {
                nineCoin = when {
                    it.money in StoreHelper.TENTHOUSAND..StoreHelper.A_HUNDRED_MILLION -> {
                        Utils.convertToTenThousand((it.money / (StoreHelper.TENTHOUSAND * 1.0)))
                    }
                    it.money > StoreHelper.A_HUNDRED_MILLION -> {
                        val double2 = it.money / (StoreHelper.A_HUNDRED_MILLION * 1.0)
                        Utils.convertToAHundredMillion(double2)
                    }
                    else -> {
                        it.money.toString() + ""
                    }
                }
                nineDot = when {
                    it.tokencoin in StoreHelper.TENTHOUSAND..StoreHelper.A_HUNDRED_MILLION -> {
                        Utils.convertToTenThousand((it.tokencoin / (StoreHelper.TENTHOUSAND * 1.0)))
                    }
                    it.tokencoin > StoreHelper.A_HUNDRED_MILLION -> {
                        Utils.convertToAHundredMillion((it.tokencoin / (StoreHelper.A_HUNDRED_MILLION * 1.0)))
                    }
                    else -> {
                        it.tokencoin.toString() + ""
                    }
                }
            }
            tv_blance_9bi?.text = "${nineCoin}九币"
            tv_blance_9dian?.text = "${nineDot}九点"
        }
    }

    /**
     * 购买靓号
     */
    private fun buyBeautyNumber() {
        if (Utils.isNotClickable()) {
            return
        }

        if (beautyNumber == null) {
            MyToast.MakeToast("未获取到商品信息，请重试！")
            dismiss()
            return
        }

        if (selectedPrice == null) {
            MyToast.MakeToast("请选择购买时长！")
            dismiss()
            return
        }
        beautyNumber?.let { goods ->
            selectedPrice?.let { price ->
                NewsRemindManager.getInstans().delete(NewsRemindManager.KEY_ACCOUNTID_EXPIRED)
                StoreHelper.buyBeautyNumber(beautyNumber = goods, price = price, onSuccess = onSucceed, onFail = onFiled)
            }
        }

    }


    // 快捷支付
    private fun showBuyDialog(jsonObject: JSONObject) {
        MyToast.MakeToast(context.getString(R.string.balance_not_enough))
        val dataObj = jsonObject.optJSONObject("data") ?: return
        val diffmoney = dataObj.optLong("diffMoney")
        // 调用充值对话框
        ZhiFuFastCDialog.showBugDialog(mContext, 0, diffmoney, object : OnZhiFuFastDialogDismissListener {
            override fun ondismissCallback() {
                this@StoreBuyDialog.show()
            }
        })
    }

    /**
     * 隐身卡介绍的popupwindow
     */
    private fun showHelperPop() {
        val popupWindowView = LayoutInflater.from(context).inflate(R.layout.popwindow_store_prop_yinshen, null, false)
        val popupWindowHelper = PopupWindowHelper(popupWindowView)
        popupWindowHelper.showAsPopUp(tv_store_prop_help, dp2px(context, 11.5f), -dp2px(context, 16))

        popupWindowView.iv_close.setOnClickListener {
            popupWindowHelper.dismiss()
        }
    }

    private fun startTransAnim(isDismiss: Boolean) {
        if (isDismiss) {
            val mTranslationOut = ObjectAnimator.ofFloat(cl_buy_container, "translationY", 0f, cl_buy_container.height.toFloat())
            mTranslationOut.duration = 200
            mTranslationOut.repeatMode=ObjectAnimator.REVERSE
            mTranslationOut.start()
        }else{
            val mTranslationIn = ObjectAnimator.ofFloat(cl_buy_container, "translationY", cl_buy_container.height.toFloat(), 0f)
            mTranslationIn.duration = 200
            mTranslationIn.start()
        }
    }

    override fun isBottomPop(): Boolean {
        return true
    }


}