package com.ninexiu.sixninexiu.fragment.store

import android.animation.Animator
import android.animation.TimeInterpolator
import android.animation.ValueAnimator
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.animation.AccelerateDecelerateInterpolator
import androidx.recyclerview.widget.GridLayoutManager
import androidx.recyclerview.widget.RecyclerView
import androidx.viewpager2.widget.CompositePageTransformer
import androidx.viewpager2.widget.ViewPager2
import androidx.viewpager2.widget.ViewPager2.OnPageChangeCallback
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.adapter.store.StoreVipAdapter
import com.ninexiu.sixninexiu.adapter.store.VipPrivilegeAdapter
import com.ninexiu.sixninexiu.bean.VipPrivilege
import com.ninexiu.sixninexiu.bean.VipPrivilegeIcon
import com.ninexiu.sixninexiu.common.AppCnfSpHelper
import com.ninexiu.sixninexiu.common.ScaleInTransformer
import com.ninexiu.sixninexiu.common.httphelp.StoreHelper
import com.ninexiu.sixninexiu.common.util.MyToast
import com.ninexiu.sixninexiu.fragment.BaseFragment
import com.ninexiu.sixninexiu.view.dp2px
import kotlinx.android.synthetic.main.fragment_store_parent.*
import kotlinx.android.synthetic.main.fragment_store_vip.*

/**
 * <pre>
 *     @author : bing
 *     time   : 2021/8/18
 *     desc   : 商城-VIP
 *     version: 1.0
 * </pre>
 */
class StoreVipFragment : BaseFragment() {
    companion object {
        fun newInstance(): StoreVipFragment {
            val args = Bundle()

            val fragment = StoreVipFragment()
            fragment.arguments = args
            return fragment
        }
    }

    //vip数据与adapter
    private var vipInfoList = mutableListOf<VipPrivilege>()
    private var vipAdapter: StoreVipAdapter? = null

    //权益数据与adapter
    private val privileges = mutableListOf<VipPrivilegeIcon>()
    private var privilegeAdapter: VipPrivilegeAdapter? = null

    //当选选中的vip
    private var currentPosition: Int = 0

    override fun inflate(inflater: LayoutInflater?): View? {
        return inflater?.inflate(R.layout.fragment_store_vip, null)
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        initView()
        initData()

        initEvent()
    }

    private fun initEvent() {
        vip_buy_tv.setOnClickListener {
            context?.let {
                if (vipInfoList.size >= currentPosition + 1) {
                    val buyDialog = StoreBuyDialog.create(it, vipInfoList[currentPosition])
                    buyDialog.show()
                }
            }

        }
    }

    private fun initView() {
        context?.let {
            vipAdapter = StoreVipAdapter(it, vipInfoList)
            setRecyclerviewPadding()
            val compositePageTransformer = CompositePageTransformer()
            compositePageTransformer.addTransformer(ScaleInTransformer(0.743f))
            banner_store_vip?.setPageTransformer(compositePageTransformer)
            banner_store_vip?.adapter = vipAdapter


            banner_store_vip?.registerOnPageChangeCallback(object : OnPageChangeCallback() {
                override fun onPageScrollStateChanged(state: Int) {
                }

                override fun onPageSelected(position: Int) {
                    if (have_privilege == null){
                        return
                    }
                    //更新vip权益数据
                    privileges.clear()
                    currentPosition = position % vipInfoList.size
                    //更新特权文字
                    have_privilege.text = "拥有特权${vipInfoList[currentPosition].show_num}/${vipInfoList[currentPosition].icon_list?.size}"
                    vipInfoList[currentPosition].icon_list?.let { it1 -> privileges.addAll(it1) }
                    privilegeAdapter?.showNum = vipInfoList[currentPosition].show_num ?: 0
                    privilegeAdapter?.notifyDataSetChanged()
                }
            })

            vip_privilege_rv.layoutManager = GridLayoutManager(it, 4)
            privilegeAdapter = VipPrivilegeAdapter(it, privileges)
            vip_privilege_rv.adapter = privilegeAdapter
        }
    }

    private fun initData() {
        StoreHelper.getVipList({
            currentPosition = 0
            //更新vip数据
            vipInfoList.clear()
            vipInfoList.addAll(it)
            vipAdapter?.notifyDataSetChanged()

            banner_store_vip?.setCurrentItem(vipInfoList.size * 1000, false)

            doGuideAnim()

            have_privilege?.text = "拥有特权${it[currentPosition].show_num}/${it[currentPosition].icon_list?.size}"

            it[currentPosition].icon_list?.let { it1 ->
                //更新vip权限数据
                privileges.clear()
                privileges.addAll(it1)
                privilegeAdapter?.showNum = it[currentPosition].show_num ?: 0
                privilegeAdapter?.notifyDataSetChanged()
            }
        }, { statusCode, errorMsg ->
            MyToast.MakeToast(errorMsg)
        })
    }

    private fun doGuideAnim() {
        if (!AppCnfSpHelper.getInstance().vipScrollGuide) {
            context?.let { context ->
                banner_store_vip?.let {
                    it.postDelayed({
                        it?.setCurrentItem(vipInfoList.size * 1000 + 1, 800, AccelerateDecelerateInterpolator(), it.width - dp2px(context, 44))
                    }, 200)

                    it.postDelayed({
                        it?.setCurrentItem(vipInfoList.size * 1000, 800, AccelerateDecelerateInterpolator(), it.width - dp2px(context, 44))
                    }, 1500)
                }
            }
            AppCnfSpHelper.getInstance().vipScrollGuide = true
        }
    }

    private fun setRecyclerviewPadding() {
        val rv = banner_store_vip?.getChildAt(0) as? RecyclerView
        rv?.let {
            it.setPadding(dp2px(context!!, 15), 0, dp2px(context!!, 15), 0)
            it.clipToPadding = false
        }
    }


    fun ViewPager2.setCurrentItem(
            item: Int,
            duration: Long,
            interpolator: TimeInterpolator = AccelerateDecelerateInterpolator(),
            pagePxWidth: Int = width // 使用viewpager2.getWidth()获取
    ) {
        val pxToDrag: Int = pagePxWidth * (item - currentItem)
        val animator = ValueAnimator.ofInt(0, pxToDrag)
        var previousValue = 0
        animator.addUpdateListener { valueAnimator ->
            val currentValue = valueAnimator.animatedValue as Int
            val currentPxToDrag = (currentValue - previousValue).toFloat()
            fakeDragBy(-currentPxToDrag)
            previousValue = currentValue
        }
        animator.addListener(object : Animator.AnimatorListener {
            override fun onAnimationStart(animation: Animator?) {
                beginFakeDrag()
            }

            override fun onAnimationEnd(animation: Animator?) {
                endFakeDrag()
            }

            override fun onAnimationCancel(animation: Animator?) {}
            override fun onAnimationRepeat(animation: Animator?) {}
        })
        animator.interpolator = interpolator
        animator.duration = duration
        animator.start()
    }

}