package com.ninexiu.sixninexiu.fragment.topic

import android.Manifest
import android.content.IntentFilter
import android.graphics.Color
import android.os.Bundle
import android.text.Spannable
import android.text.SpannableStringBuilder
import android.text.TextPaint
import android.text.TextUtils
import android.text.method.LinkMovementMethod
import android.text.style.ClickableSpan
import android.view.LayoutInflater
import android.view.View
import android.widget.FrameLayout
import androidx.core.content.ContextCompat
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.blankj.utilcode.util.ToastUtils
import com.google.android.material.appbar.AppBarLayout
import com.google.android.material.appbar.AppBarLayout.OnOffsetChangedListener
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.activity.AdvertiseActivity
import com.ninexiu.sixninexiu.adapter.DynamicDataAdapter
import com.ninexiu.sixninexiu.adapter.TopicDynamicDataAdapter
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.bean.Dynamic
import com.ninexiu.sixninexiu.bean.Topic
import com.ninexiu.sixninexiu.broadcast.AppBroadcastHelper
import com.ninexiu.sixninexiu.common.statistics.Statistics
import com.ninexiu.sixninexiu.common.httphelp.DynamicTopicHelper
import com.ninexiu.sixninexiu.common.net.NSRequestParams
import com.ninexiu.sixninexiu.common.statistics.StatisticsEventID
import com.ninexiu.sixninexiu.common.statistics.StatisticsUtil
import com.ninexiu.sixninexiu.common.util.*
import com.ninexiu.sixninexiu.common.util.manager.PermissionManager
import com.ninexiu.sixninexiu.common.util.manager.RequestManager
import com.ninexiu.sixninexiu.fragment.BaseFragment
import com.ninexiu.sixninexiu.view.ViewUtils
import com.ninexiu.sixninexiu.view.dialog.BaseDialog
import com.ninexiu.sixninexiu.view.dialog.CommentListFragmentDialog
import com.ninexiu.sixninexiu.view.dialog.CommonRemindDialog
import com.ninexiu.sixninexiu.view.dialog.CurrencyBottomDialog
import com.ninexiu.sixninexiu.view.dp2px
import com.ninexiu.sixninexiu.view.setVisible
import com.ninexiu.sixninexiu.view.shape.RoundTextView
import kotlinx.android.synthetic.main.fragment_dynamic_topic_details.*
import kotlinx.android.synthetic.main.layout_for_show_state.*
import kotlinx.android.synthetic.main.title_tab_bar_tra.*
import java.util.HashMap
import kotlin.math.abs
import kotlin.reflect.jvm.internal.impl.load.kotlin.JvmType

/**
 * <pre>
 *     @author : bing
 *     time   : 2021/7/13
 *     desc   :  动态详情页
 *     version: 1.0
 * </pre>
 */
class DynamicTopicDetailsFragment : BaseFragment(), View.OnClickListener {

    override fun inflate(inflater: LayoutInflater?): View? {
        return inflater?.inflate(R.layout.fragment_dynamic_topic_details, null)
    }

    companion object {
        const val KEY_TOPIC = "key_topic"
    }

    //话题
    private var topic: Topic? = null

    //状态栏高度
    private var statusBarHeight = 0

    //标题栏高度
    private var titleBarHeight = 0
    //底部被覆盖高度

    //底部预留高度
    private var bottomHeight = 0

    //可滑动的高度
    private var height: Int = 0

    private var page = 0

    private var isFollow = false

    private lateinit var dynamicAdapter: TopicDynamicDataAdapter
    private val dynamicList = ArrayList<Dynamic>()

    private val sdPermission = arrayOf(
            Manifest.permission.WRITE_EXTERNAL_STORAGE
    )

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        arguments?.let {
            topic = it.getParcelable<Topic>(KEY_TOPIC)
        }
        initView()
        initData()
        initEvent()
    }


    private fun initView() {
        setViewHeight()
        left_btn.setImageResource(R.drawable.tab_back_second_white)
        app_cover.addOnOffsetChangedListener(onOffListener)
        activity?.let {
            title.setTextColor(ContextCompat.getColor(it, R.color.white))
        }

        title.visibility = View.INVISIBLE
    }

    private fun initData() {
        arguments?.let {
            topic = it.getParcelable(KEY_TOPIC)
        }
        setTopic(topic)
        context?.let {
            dynamicAdapter = TopicDynamicDataAdapter(it, dynamicList, isEnterAnchorPagehome = false, currentTopic = topic, isShowAtten = false)
            topic_details_rv?.layoutManager = LinearLayoutManager(it, LinearLayoutManager.VERTICAL, false)
            topic_details_rv?.adapter = dynamicAdapter

            dynamicAdapter.setOnClickDynamicCallBack(object :DynamicDataAdapter.OnClickDynamicCallBack{
                override fun onCommentClick(position: Int, dynamic: Dynamic?) {
                    if (activity == null) {
                        return
                    }
                    CommentListFragmentDialog.create(dynamic)
                            .show(activity!!.supportFragmentManager, "CommentListFragmentDialog")
                }

                override fun onDeleteClick(position: Int, dynamic: Dynamic?) {
                    if (dynamic != null) {
                        showDeleteDialog(position, dynamic)
                    }
                }
            })
        }


        getTopicDynamic(true)
    }

    private fun initEvent() {
        rl_right_tv?.setOnClickListener(this)
        attention_tv?.setOnClickListener(this)
        ll_join_topic?.setOnClickListener(this)

        srl_topic_dynamic.setOnLoadMoreListener {
            getTopicDynamic(false)
        }

        srl_topic_dynamic.setOnRefreshListener {
            getTopicDynamic(true)
        }

        app_cover?.addOnOffsetChangedListener(OnOffsetChangedListener { appBarLayout, p1 ->
            appBarLayout?.let {
                dynamic_topic_content_tv.alpha = 1 - abs(p1).toFloat() / it.totalScrollRange
            }
        })

        topic_details_rv?.addOnScrollListener(object :RecyclerView.OnScrollListener(){
            override fun onScrollStateChanged(recyclerView: RecyclerView, newState: Int) {
                super.onScrollStateChanged(recyclerView, newState)
                ll_join_topic?.setVisible(newState == RecyclerView.SCROLL_STATE_IDLE)
            }
        })
    }

    override fun registerReceiver(): Boolean {
        return true
    }

    override fun setBroadcastFilter(filter: IntentFilter?) {
        filter!!.addAction(NSReceiverAction.DYNAMIC_SQUARE_REFERSH_ACTION)
        filter.addAction(NSReceiverAction.DYNAMIC_COMMENT)
        filter.addAction(NSReceiverAction.DYNAMIC_PRAISE)
    }

    override fun onReceive(action:String , type:Int , bundle:Bundle ) {
        //接受数据并做处理
        if (bundle == null) {
            return
        }
        if (dynamicAdapter != null) {
            val uid = bundle.getString ("uid")
            dynamicAdapter.getData()?.let {
                if (it.info != null && TextUtils.equals(uid, it.info.uid)) {
                    if (action == NSReceiverAction.DYNAMIC_COMMENT) {
                        val isComment = bundle.getBoolean("isComment")
                        it.replynum = if (isComment) it.replynum + 1 else it.replynum - 1;
                        dynamicAdapter.notifyDataSetChanged()
                    } else if (action == NSReceiverAction.DYNAMIC_PRAISE) {
                        NSLog.e("onReceive", "点赞刷新数据")
                        it.upnum = it.upnum + 1
                        it.ispraise = 1
                        dynamicAdapter.notifyDataSetChanged()
                    } else if (action == NSReceiverAction.DYNAMIC_SQUARE_REFERSH_ACTION) {
                        if (dynamicAdapter != null) {
                            dynamicList.remove(it)
                            dynamicAdapter.notifyDataSetChanged()
                        }
                    }
                }
            }
        }
    }


    private fun getTopicDynamic(isRefresh: Boolean) {
        if (isRefresh) {
            page = 0
        } else {
            page++
        }
        topic?.let { topic->
            val params = NSRequestParams()
            params.put("id",topic.topicid)
            params.put("page",page)
            if(page >0){
                if (dynamicList.size>0){
                    val dynamic = dynamicList[dynamicList.size -1]
                    params.put("report_time",dynamic.report_time)
                    params.put("dynamicId",dynamic.dynamicid)
                }
            }
            DynamicTopicHelper.getTopicDetails(params, {
//                sv_state_view?.showSuccess()
                it.data?.let { dynamicTopicList ->
                    setTopic(dynamicTopicList.topicData)
                    setDynamic(isRefresh, dynamicTopicList.dynamicData)
                }

            }, { _, message ->
                if (!TextUtils.isEmpty(message)) {
                    ToastUtils.showShort(message)
                }
//                showStateView(null)
            })
        }
    }

    private fun setDynamic(refresh: Boolean, dynamicData: List<Dynamic>?) {
        srl_topic_dynamic?.finishRefresh()
        srl_topic_dynamic?.finishLoadMore()
        if (refresh && dynamicData.isNullOrEmpty()) {
            sv_state_view?.showEmpty("暂无动态")
            return
        } else if (!dynamicData.isNullOrEmpty()) {
            sv_state_view?.showSuccess()
            if (refresh) {
                dynamicList.clear()
            }
            dynamicList.addAll(dynamicData)
            dynamicAdapter.notifyDataSetChanged()
        }
    }

    private fun setTopic(topicData: Topic?) {
        context?.let { mContext ->
            topicData?.let { mTopicData ->
                mTopicData.topicid = topic!!.topicid
                topic = mTopicData
                GlideUtils.loadSimpleImgWithRoundCorner(context, mTopicData.url, dynamic_topic_user_iv, R.drawable.anthor_moren, dp2px(mContext, 8))
                GlideUtils.loadBlurImage(context, mTopicData.url, back_btn)
                dynamic_topic_title_tv?.text = mTopicData.title
                title?.text = mTopicData.title
                topic_dynamic_num_tv?.text = "${topicData.total} 动态"
                dynamic_topic_content_tv?.text = if (mTopicData.introduce.isNullOrEmpty()) "快来参与话题讨论吧~" else mTopicData.introduce
                isFollow = mTopicData.isfollow == 1
                setFollowState(attention_tv)
                setFollowState(rl_right_tv)

                if(mTopicData.is_activity == 1) {
                    setLinkText(mTopicData)
                }

                if (mTopicData.is_activity == 1) {
                    val drawable = ContextCompat.getDrawable(mContext, R.drawable.icon_dynamic_topic_action)
                    drawable?.setBounds(0, 0, drawable.minimumWidth, drawable.minimumHeight)
                    topic_dynamic_num_tv?.setCompoundDrawables(drawable, null, null, null)
                } else {
                    topic_dynamic_num_tv?.setCompoundDrawables(null, null, null, null)
                }
            }
        }
    }

    /**
     * 关注状态
     */
    private fun setFollowState(view: RoundTextView?) {
        context?.let {
            if (isFollow) {
                //已关注
                view?.text = "已关注"
                view?.setTextColor(ContextCompat.getColor(it, R.color.color_white_4dffffff))
                view?.delegate?.backgroundColor = ContextCompat.getColor(it, R.color.transparent)
                view?.delegate?.setBackgroundColorStartEnd(ContextCompat.getColor(it, R.color.transparent), ContextCompat.getColor(it, R.color.transparent))
                view?.delegate?.strokeWidth = 1
                view?.delegate?.strokeColor = ContextCompat.getColor(it, R.color.color_white_4dffffff)
            } else {
                //未关注
                view?.text = "关注"
                view?.setTextColor(ContextCompat.getColor(it, R.color.white))
                view?.delegate?.backgroundColor = ContextCompat.getColor(it,R.color.color_ff567b)
                view?.delegate?.strokeWidth = 0
            }
        }
    }

    /**
     * 设置超链接样式
     */
    private fun setLinkText(topic: Topic) {
        if (!topic.ac_title.isNullOrEmpty()) {
            dynamic_topic_content_tv?.movementMethod = LinkMovementMethod.getInstance()
            val content = if (topic.introduce.isNullOrEmpty()) "快来参与话题讨论吧~" else topic.introduce
            val builder = SpannableStringBuilder("${content}${topic.ac_title}>")
            builder.setSpan(object : ClickableSpan() {
                override fun onClick(widget: View) {
                    AdvertiseActivity.start(context, false, topic.ac_url, topic.ac_title)
                }

                override fun updateDrawState(ds: TextPaint) {
                    super.updateDrawState(ds)
                    activity?.let {
                        ds.color = ContextCompat.getColor(it, R.color.color_fabc0a)
                    }
                    ds.isUnderlineText = true
                }
            }, if (topic.introduce==null) 0 else topic.introduce.length, builder.length, Spannable.SPAN_INCLUSIVE_EXCLUSIVE)
            dynamic_topic_content_tv?.text = builder
        }
    }


    private val onOffListener by lazy {
        AppBarLayout.OnOffsetChangedListener { appBarLayout, verticalOffset ->
            setViewHeight()

            val verticalHeight = -verticalOffset

            when {
                verticalHeight <= 0 -> isShowEdit(0)
                verticalHeight < height -> {
                    val scale = verticalHeight.toFloat() / height
                    val alpha = (255 * scale).toInt()
                    isShowEdit(alpha)
                }
                else -> isShowEdit(255)
            }
        }
    }

    /**
     * Tab显示状态
     */
    private fun isShowEdit(alpha: Int) {
        if (activity == null) {
            return
        }
        if (alpha >= 150) {
            if (alpha > 155) {
                ViewUtils.hideView(dynamic_topic_top_layout)
            }
            ViewUtils.showView(title)
            ViewUtils.showView(rl_right_tv)
        } else {
            ViewUtils.showView(dynamic_topic_user_iv)
            ViewUtils.showView(dynamic_topic_top_layout)
            if (alpha < 145) {
                ViewUtils.hideView(title)
                ViewUtils.hideView(rl_right_tv)
            }
        }
        dynamic_topic_user_iv.alpha = (255 - alpha).toFloat()
        attention_tv.setTextColor(Color.argb(255 - alpha, 255, 255, 255))
        topic_dynamic_num_tv.setTextColor(Color.argb(255 - alpha, 204, 204, 204))
        dynamic_topic_title_tv.setTextColor(Color.argb(255 - alpha, 255, 255, 255))
        topic_dynamic_num_tv.setTextColor(Color.argb(255 - alpha, 204, 204, 204))
        dynamic_topic_content_tv.setTextColor(Color.argb(255 - alpha, 204, 204, 204))
        title.setTextColor(Color.argb(alpha, 255, 255, 255))
    }

    private fun setViewHeight() {
        if (statusBarHeight == 0 || titleBarHeight == 0) {
            activity?.let { it ->
                layout_title.setBackgroundColor(ContextCompat.getColor(it, R.color.transparent))
                statusBarHeight = SystemUtil.getStatusBarHeight(it)
                titleBarHeight = DensityUtil.dp2px(it, 40f)
                bottomHeight = DensityUtil.dp2px(it, 20f)
                val matchHeight = DensityUtil.dp2px(it, 210f)
                //设置CollapsingToolbarLayout最小高度
                ct_layout.minimumHeight = titleBarHeight + bottomHeight + statusBarHeight
                height = matchHeight - statusBarHeight - titleBarHeight - bottomHeight
                //向下偏移 statusBarHeight
                title_layout.layoutParams = (title_layout.layoutParams as FrameLayout.LayoutParams).also { layoutParams ->
                    layoutParams.topMargin = statusBarHeight
                }
                dynamic_topic_top_layout.layoutParams = (dynamic_topic_top_layout.layoutParams as FrameLayout.LayoutParams).also { layoutParams ->
                    layoutParams.topMargin = statusBarHeight + layoutParams.topMargin
                }
                dynamic_topic_content_tv.layoutParams = (dynamic_topic_content_tv.layoutParams as FrameLayout.LayoutParams).also { layoutParams ->
                    layoutParams.topMargin = statusBarHeight + layoutParams.topMargin
                }
            }
        }
    }

    override fun onDestroyView() {
        app_cover.removeOnOffsetChangedListener(onOffListener)
        super.onDestroyView()
    }

    override fun onClick(v: View?) {
        when (v?.id) {
            R.id.rl_right_tv, R.id.attention_tv -> {
                if (Utils.isNotClickable()){
                    return
                }
                topic?.let {
                    if (isFollow) {
                       showCancelFollowDialog(it.topicid)
                    } else {
                        DynamicTopicHelper.followTopic(it.topicid, { message ->
                            StatisticsUtil.onEvent(StatisticsEventID.UM_TOPIC_FOLLOW)
                            isFollow = true
                            setFollowState(attention_tv)
                            setFollowState(rl_right_tv)
                            ToastUtils.showShort(message)
                            AppBroadcastHelper.getInstance().sendBroadcast(NSReceiverAction.ACTION_TOPIC_FOLLOW_CHANGE)
                        }, { _, msg ->
                            ToastUtils.showShort(msg)
                        })
                    }
                }
            }
            R.id.ll_join_topic -> {
                StatisticsUtil.onEvent(StatisticsEventID.UM_TOPIC_JOIN)
                if (NineShowApplication.mUserBase == null) {
                    Utils.startLogin(activity, getString(R.string.live_login_audience))
                    return
                }
                if (!PermissionManager.create().haveSdPermission(activity)) {
                    PermissionManager.create().showPermission(activity, sdPermission) { allGranted, grantedList, deniedList ->
                        if (allGranted) {
                            MBOperationManager.create().showDynamicDialog(activity, topic)
                        }
                    }
                } else {
                    MBOperationManager.create().showDynamicDialog(activity, topic)
                }
            }
        }
    }

    /**
     * 取消关注弹窗
     */
    private fun showCancelFollowDialog(topicId: Int) {
        CommonRemindDialog.create(context)
                .setText("确定", "取消")
                .setTitleText("确定取消关注吗？")
                .setOnClickCallback {
                    if (it == BaseDialog.SELECT_FIRST) {
                        DynamicTopicHelper.cancelFollowTopic(topicId, { message ->
                            StatisticsUtil.onEvent(StatisticsEventID.UM_TOPIC_CANCEL_FOLLOW)
                            isFollow = false
                            setFollowState(attention_tv)
                            setFollowState(rl_right_tv)
                            ToastUtils.showShort(message)
                            AppBroadcastHelper.getInstance().sendBroadcast(NSReceiverAction.ACTION_TOPIC_FOLLOW_CHANGE)
                        }, { _, msg ->
                            ToastUtils.showShort(msg)
                        })
                    }
                }
    }


    private fun showDeleteDialog(position: Int, dynamic: Dynamic) {
        CurrencyBottomDialog.create(context)
                .setFirstText("删除")
                .setFirstTextColor("#E82929")
                .setSecondHideView()
                .setOnClickCallback { type ->
                    if (type == BaseDialog.SELECT_FIRST) {
                        //删除评论
                        RequestManager.create().deleteDynamicTask(dynamic.dynamicid) {
                            dynamicAdapter.dynamicList.removeAt(position)
                            dynamicAdapter.notifyItemRemoved(position)
                            ToastUtils.showShort("删除成功")
                        }
                    }
                }
    }

    override fun getFragmentTag(): String {
        return Statistics.STATISTIC_DISCOVERY_DYNAMIC
    }

    private var showStartTime: Long = 0//开始显示的时间

    override fun onResume() {
        super.onResume()
        showStartTime = System.currentTimeMillis()

    }

    override fun onPause() {
        super.onPause()

        if(showStartTime > 0){
            val hashMap = HashMap<String, Any>()
            val time = System.currentTimeMillis() / 1000 - showStartTime / 1000
            hashMap["话题详情停留时长"] = time
            StatisticsUtil.onEventObject(StatisticsEventID.UM_DYNAMIC_TOPIC_DETAILS_TIME,hashMap)
        }
        showStartTime = System.currentTimeMillis()
    }
}