package com.ninexiu.sixninexiu.fragment.topic

import android.content.Intent
import android.content.IntentFilter
import android.os.Bundle
import android.text.TextUtils
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.recyclerview.widget.GridLayoutManager
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.viewpager.widget.ViewPager
import com.blankj.utilcode.util.ToastUtils
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.activity.TranslucentSubPageActivity
import com.ninexiu.sixninexiu.adapter.FacePagerAdapter
import com.ninexiu.sixninexiu.adapter.topic.DynamicTopicListAdapter
import com.ninexiu.sixninexiu.adapter.topic.DynamicTopicPageAdapter
import com.ninexiu.sixninexiu.bean.Topic
import com.ninexiu.sixninexiu.bean.TopicTab
import com.ninexiu.sixninexiu.broadcast.AppBroadcastHelper
import com.ninexiu.sixninexiu.common.statistics.StatisticsEventID
import com.ninexiu.sixninexiu.common.statistics.StatisticsUtil
import com.ninexiu.sixninexiu.common.httphelp.DynamicTopicHelper
import com.ninexiu.sixninexiu.common.util.NSReceiverAction
import com.ninexiu.sixninexiu.fragment.BaseFragment
import com.ninexiu.sixninexiu.view.dp2px
import com.ninexiu.sixninexiu.view.setVisible
import kotlinx.android.synthetic.main.fragment_dynamic_topic_list.*
import kotlinx.android.synthetic.main.layout_for_show_state.*
import kotlinx.android.synthetic.main.page_dynamic.view.*
import kotlin.math.min

/**
 * <pre>
 *     @author : bing
 *     time   : 2021/7/12
 *     desc   :  话题列表页
 *     version: 1.0
 * </pre>
 */
class DynamicTopicListFragment : BaseFragment() {
    override fun inflate(inflater: LayoutInflater?): View? {
        return inflater?.inflate(R.layout.fragment_dynamic_topic_list, null)
    }

    companion object {
        const val KEY_TOPIC_TAB = "key_topic_tab"
        fun newInstance(topicTab: TopicTab): DynamicTopicListFragment {
            val args = Bundle()
            args.putParcelable(KEY_TOPIC_TAB, topicTab)
            val fragment = DynamicTopicListFragment()
            fragment.arguments = args
            return fragment
        }
    }

    private lateinit var topicListAdapter: DynamicTopicListAdapter
    private val topicList = mutableListOf<Topic>()
    private var recommendGroup = mutableListOf<Topic>()
    private var page = 0
    private var topicTab: TopicTab? = null
    private var isFollowChange = false
    private var isFollowEmpty = false
    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        initView()
        initData()
        initListener()
    }

    private fun initListener() {
        srl_topic_list.setOnRefreshListener {
            getTopicList(true)
        }

        srl_topic_list.setOnLoadMoreListener {
            getTopicList(false)
        }

        sv_state_view.setOnRefreshListener {
            getTopicList(true)
        }
    }

    override fun registerReceiver(): Boolean {
        return true
    }

    override fun setBroadcastFilter(filter: IntentFilter) {
        filter.addAction(NSReceiverAction.ACTION_TOPIC_FOLLOW_CHANGE)
    }

    override fun onReceive(action: String, type: Int, bundle: Bundle) {
        if (NSReceiverAction.ACTION_TOPIC_FOLLOW_CHANGE == action) {
            isFollowChange = true
        }
    }

    override fun setUserVisibleHint(isVisibleToUser: Boolean) {
        super.setUserVisibleHint(isVisibleToUser)
        if (isVisibleToUser && isFollowChange && topicTab?.tab_id == 1){
            isFollowChange = false
            getTopicList(true)
        }
    }

    override fun onResume() {
        super.onResume()
        if (topicTab?.tab_id == 1 && isFollowChange) {
            isFollowChange = false
            getTopicList(true)
        }
    }

    private fun initView() {
        arguments?.let {
            topicTab = it.getParcelable(KEY_TOPIC_TAB)
        }

        context?.let {
            rv_topic_list.layoutManager = LinearLayoutManager(it, LinearLayoutManager.VERTICAL, false)
            topicListAdapter = DynamicTopicListAdapter(it, topicTab?.tab_id == 1, topicList)
            rv_topic_list.adapter = topicListAdapter

            topicListAdapter.onTopicFollowClick = { position, topic ->
                DynamicTopicHelper.followTopic(topic.topicid, {
                    StatisticsUtil.onEvent(StatisticsEventID.UM_TOPIC_FOLLOW)
                    topicList[position].isfollow = 1
                    topicListAdapter.notifyItemChanged(position)
                    ToastUtils.showShort(it)
                    AppBroadcastHelper.getInstance().sendBroadcast(NSReceiverAction.ACTION_TOPIC_FOLLOW_CHANGE)
                }, { code, msg ->
                    ToastUtils.showShort(msg)
                })

            }
        }

    }


    private fun initData() {
        getTopicList(true)
        if (topicTab?.tab_id == 1) {
            getRecommendGroup()
        }
    }

    private fun getRecommendGroup() {
        DynamicTopicHelper.getTopicTopList({
            it.data?.let { result ->
                recommendGroup.addAll(result)
                if (isFollowEmpty){
                    setupFollowEmptyRecommend()
                }
            }
        }, { _, _ ->

        })
    }

    private fun getTopicList(isRefresh: Boolean) {
        if (isRefresh) {
            page = 0
        } else {
            page++
        }
        DynamicTopicHelper.getTopicListByTab(page, topicTab?.tab_id, {
            if (isRefresh) {
                srl_topic_list?.finishRefresh()
                topicList.clear()
            } else {
                srl_topic_list?.finishLoadMore()
            }
            topicList.addAll(it.data!!)
            topicListAdapter.notifyDataSetChanged()
            sv_state_view?.showSuccess()
            cl_recommend_topic?.setVisible(false)

        }, { _, message ->
            if (isRefresh) {
                srl_topic_list?.finishRefresh()
                if (topicTab?.tab_id == 1) {
                    if (recommendGroup.isEmpty()){
                        isFollowEmpty = true
                    }else {
                        setupFollowEmptyRecommend()
                    }
                    sv_state_view?.showEmpty("没有关注的话题啦 \n 快去看看其他喜欢的话题吧")
                } else {
                    cl_recommend_topic?.setVisible(false)
                    sv_state_view?.showEmpty("暂无话题")
                }
            } else {
                srl_topic_list?.finishLoadMore()
            }
            if (!TextUtils.isEmpty(message)) {
                ToastUtils.showShort(message)
            }
        })
    }

    private fun setupFollowEmptyRecommend() {
        isFollowEmpty = false
        context?.let { mContext ->
            cl_recommend_topic?.setVisible(true)
            val views = mutableListOf<View>()
            for (index in recommendGroup.indices step 4) {
                val pageView = LayoutInflater.from(context).inflate(R.layout.page_dynamic, vp_dynamic_topic, false)
                pageView.rv_dynamic_topic_page.layoutManager = GridLayoutManager(mContext, 2, GridLayoutManager.VERTICAL, false)
                val tabAdapter = DynamicTopicPageAdapter(mContext, recommendGroup.subList(index, min(index + 4, recommendGroup.size)))
                pageView.rv_dynamic_topic_page.adapter = tabAdapter
                (pageView.rv_dynamic_topic_page.layoutParams as ViewGroup.MarginLayoutParams).topMargin = dp2px(mContext, 6)
                views.add(pageView)
                tabAdapter.onTabClick = {
                    if (it.tab_id > 0) {
                        //跳列表
                        if (it.tab_id==1){
                            srl_topic_list?.autoRefresh()
                        }else{
                            vp_dynamic_topic?.currentItem = if (recommendGroup.indexOf(it) > 0) recommendGroup.indexOf(it) else 0
                        }
                    } else {
                        //跳详情
                        val intent = Intent(context, TranslucentSubPageActivity::class.java)
                        intent.putExtra(TranslucentSubPageActivity.CLASSFRAMENT, DynamicTopicDetailsFragment::class.java)
                        val bundle = Bundle()
                        bundle.putParcelable(DynamicTopicDetailsFragment.KEY_TOPIC, it)
                        intent.putExtra("bundle", bundle)
                        context?.startActivity(intent)
                    }
                }
            }
            vp_dynamic_topic?.adapter = FacePagerAdapter(views)
            if (views.isNullOrEmpty() || views.size <= 1) {
                view_index?.setVisible(false)
            } else {
                view_index?.setVisible(true)
                view_index?.max = views.size
            }

            vp_dynamic_topic?.setOnPageChangeListener(object : ViewPager.OnPageChangeListener {
                override fun onPageScrollStateChanged(state: Int) {
                }

                override fun onPageScrolled(position: Int, positionOffset: Float, positionOffsetPixels: Int) {
                }

                override fun onPageSelected(position: Int) {
                    view_index?.setSelectIndex(position)
                }

            })
        }
    }
}