package com.ninexiu.sixninexiu.fragment.topic

import android.graphics.Typeface
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import androidx.fragment.app.Fragment
import com.blankj.utilcode.util.ConvertUtils
import com.blankj.utilcode.util.ToastUtils
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.adapter.CommonPagerAdapter
import com.ninexiu.sixninexiu.common.httphelp.DynamicTopicHelper
import com.ninexiu.sixninexiu.fragment.BaseFragment
import kotlinx.android.synthetic.main.fragment_dynamic_topic_list_parent.*
import kotlinx.android.synthetic.main.title_tab_bar.*

/**
 * <pre>
 *     @author : bing
 *     time   : 2021/7/13
 *     desc   :
 *     version: 1.0
 * </pre>
 */
class DynamicTopicListParentFragment : BaseFragment() {
    override fun inflate(inflater: LayoutInflater?): View? {
        return inflater?.inflate(R.layout.fragment_dynamic_topic_list_parent, null)
    }

    private val tabId: Int by lazy {
        if (arguments != null) {
            arguments!!.getInt(KEY_TOPIC_GROUP_ID)
        } else {
            0
        }
    }

    companion object {
        const val KEY_TOPIC_GROUP_ID = "key_topic_group_id"
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        initViews()
        initDatas()
    }

    private fun initViews() {
        title.text = "话题"
        left_btn.setOnClickListener {
            activity?.finish()
        }
        context?.let {
            tab_topic_list.setTextSelectSize(ConvertUtils.sp2px(18f))
            tab_topic_list.textSize = ConvertUtils.sp2px(14f)
            tab_topic_list.setTextColorResource(R.color.color_333333, R.color.color_666666)
            tab_topic_list.setTypeface(Typeface.DEFAULT_BOLD,0)
        }

    }

    private fun initDatas() {

        DynamicTopicHelper.getTopicTabList({
            if (it.data.isNotEmpty()) {
                var tabIndex = 0
                val titles = Array<String?>(it.data.size) { index -> it.data[index].tab_name }
                val fragments = ArrayList<Fragment>()
                for ((index, topicTab) in it.data.withIndex()) {
                    fragments.add(DynamicTopicListFragment.newInstance(topicTab))
                    if (topicTab.tab_id == tabId) {
                        tabIndex = index
                    }
                }
                vp_topic_list?.offscreenPageLimit = fragments.size
                vp_topic_list?.adapter = CommonPagerAdapter(fragmentManager, titles, fragments)
                tab_topic_list?.setViewPager(vp_topic_list)
                vp_topic_list?.currentItem = tabIndex
            }
        }, { _, message ->
            ToastUtils.showShort(message)
        })
    }


}