package com.ninexiu.sixninexiu.pay

import android.annotation.SuppressLint
import android.app.Activity
import android.app.AlertDialog
import android.app.Dialog
import android.content.Context
import android.content.Intent
import android.graphics.Bitmap
import android.graphics.Rect
import android.net.ConnectivityManager
import android.net.Uri
import android.net.http.SslError
import android.os.Build
import android.os.Handler
import android.os.Message
import android.provider.Settings
import android.text.TextUtils
import android.util.Log
import android.view.View
import android.view.ViewGroup
import android.webkit.SslErrorHandler
import android.webkit.WebSettings
import android.webkit.WebView
import android.webkit.WebViewClient
import android.widget.ImageView
import android.widget.Toast
import androidx.recyclerview.widget.GridLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.alipay.sdk.app.PayTask
import com.ninexiu.sixninexiu.BuildConfig
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.activity.AccountIdentityDialog
import com.ninexiu.sixninexiu.activity.AdvertiseActivity
import com.ninexiu.sixninexiu.activity.BaseActivity
import com.ninexiu.sixninexiu.adapter.ZhiFuAdapter
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.bean.*
import com.ninexiu.sixninexiu.common.net.*
import com.ninexiu.sixninexiu.common.statistics.StatisticsEventID
import com.ninexiu.sixninexiu.common.statistics.StatisticsUtil
import com.ninexiu.sixninexiu.common.util.*
import com.ninexiu.sixninexiu.im.NewsRemindManager
import com.ninexiu.sixninexiu.pay.PayUtil.*
import com.ninexiu.sixninexiu.pay.WXPay.WXPayResultCallBack
import com.ninexiu.sixninexiu.values.Global
import com.ninexiu.sixninexiu.view.*
import com.ninexiu.sixninexiu.view.banner.BGABanner
import com.ninexiu.sixninexiu.view.dialog.AutumnChargeDialog
import com.ninexiu.sixninexiu.view.dialog.ParentsModleHintDialog
import com.thirdparty.utils.StatusBarUtil
import kotlinx.android.synthetic.main.activity_zhifu.*
import org.json.JSONException
import org.json.JSONObject
import java.util.*
import kotlin.concurrent.thread

/**
 * <pre>
 *     @author : hpf
 *     time   : 2020/12/25
 *     desc   : 充值界面
 *     version: 1.0
 * </pre>
 */
class ZhiFuActivity : BaseActivity() {
    companion object {
        const val Tag = "ZhiFuActivity >> "
        const val ITEM_PERCENT = 0.0125
        const val HEAD_SHORT_PERCENT = 0.504
        const val HEAD_LONG_PERCENT = 0.657
        const val HEAD_BANNER_WIDTH_PERCENT = 0.936
        const val HEAD_BANNER_SELF_PERCENT = 0.228

        const val PAY_WECHAT = 0
        const val PAY_ALI = 1

        fun startActivity(context: Context) {
            val intent = Intent(context, ZhiFuActivity::class.java)
            context.startActivity(intent)
        }
    }

    private val payUtil = PayUtil()

    private val chargeNum: Int by lazy {
        intent?.getIntExtra("num", -1) ?: -1
    }

    private val chargeRid: Int by lazy {
        intent?.getIntExtra("rid", 0) ?: 0
    }

    // 余额️不足进来 ： -1
    private val source: Int by lazy {
        intent?.getIntExtra("source", 0) ?: 0
    }

    private val widthScreen: Int by lazy {
        resources?.displayMetrics?.widthPixels ?: 0
    }

    private val datas = mutableListOf<Option>()
    private val adapter = ZhiFuAdapter(datas, ZhiFuAdapter.ZHIFU_TYPE)

    // 动态设置 : 顶部title的margin,头部的高度随背景适配
    override fun initViews() {
        StatisticsUtil.onEvent(StatisticsEventID.ZHIFU_ETR)
        // 设置标题topMargin
        val params = rlTitle.layoutParams as? ViewGroup.MarginLayoutParams
        params?.topMargin = statusBarHeight
        rlTitle.layoutParams = params

        tvTitle.text = getString(R.string.zhifu_title)

        // recy : 充值选项
        recy.layoutManager = GridLayoutManager(this, 3)
        recy.addItemDecoration(decoration)
        recy.adapter = adapter

        // 用户输入自定义金额后的回调
        adapter.userInputMoney = {
            NSLog.d(Tag, "自定义金额 : $it")
            customMoney = it
            if (!TextUtils.isEmpty(customMoney)) {
                btConfirm.text = getString(R.string.zhifu_confirm, customMoney.toString().toInt())
            } else {
                btConfirm.text = getString(R.string.zhifu_confirm_custom)
            }
        }

        // 适配
        fitterViewSize(zhifuTypeWechat, { (widthScreen - dp2px(this, 32)) / 2 }, { (it * 0.256).toInt() })
        fitterViewSize(zhifuTypeAli, { (widthScreen - dp2px(this, 32)) / 2 }, { (it * 0.256).toInt() })

        // 设置透明度的变化
        setTitleAlpha()

        // 设置充值类型 ： 支付宝或微信
        zhifuTypeWechat.setPayType(ZhiFuItemTypeView.WECHAT).setPaySelected(true)
        zhifuTypeAli.setPayType(ZhiFuItemTypeView.ALIPAY)

        // 记录支付方式
        zhifuTypeWechat.setOnClickListener {
            payType = PAY_WECHAT
            zhifuTypeWechat.setPaySelected(true)
            zhifuTypeAli.setPaySelected(false)
        }

        zhifuTypeAli.setOnClickListener {
            payType = PAY_ALI
            zhifuTypeWechat.setPaySelected(false)
            zhifuTypeAli.setPaySelected(true)
        }

        // 用户选择不同的支付item
        adapter.onSelected = { pos, type ->
            datas.forEach {
                it.selected = false
            }
            datas[pos].selected = true
            adapter.notifyDataSetChanged()

            customMoney = null   // 清除
            payItemType = type

            // 设置埋点
            setStatisticsEvent(pos)

            // 设置按钮数字
            when (type) {
                ZhiFuItemView.CUSTOM -> {
                    payItemPosition = -1
                    btConfirm.post {
                        btConfirm.text = getString(R.string.zhifu_confirm_custom)
                    }
                }
                else -> {
                    payItemPosition = pos
                    btConfirm.post {
                        btConfirm.text = getString(R.string.zhifu_confirm, datas[pos].amount)
                    }
                }
            }
        }

        btConfirm.setOnClickListener {
            userPayConfirm()
        }

        // 快付微信支付 初始化webview
        initKuaiFuPay()

        // 更新系统配置的支付信息
        getRoomSystemMessage()

        // refershRemind()

        // ProgressDialogUtil.show(this)

        if (chargeNum >= 1) { //如果传递的有金额进来就直接调起。
            mHandler.postDelayed({
                val type = if (Global.ALIPAY_CHARGE_TYPE != 0) {
                    Global.ALIPAY_CHARGE_TYPE
                } else {
                    PayUtil.PAY_TYPE_JX_ALIPAY
                }
                getOrderdate(chargeNum, type)
            }, 800)
        }
    }

    private fun setStatisticsEvent(pos: Int) {
        if (!datas.isNullOrEmpty() && pos >= 0 && pos < datas.size) {
            when (datas[pos].amount) {
                10 -> StatisticsUtil.onEvent(StatisticsEventID.ZHIFU_NUMBER_10)
                50 -> StatisticsUtil.onEvent(StatisticsEventID.ZHIFU_NUMBER_50)
                100 -> StatisticsUtil.onEvent(StatisticsEventID.ZHIFU_NUMBER_100)
                500 -> StatisticsUtil.onEvent(StatisticsEventID.ZHIFU_NUMBER_500)
                1000 -> StatisticsUtil.onEvent(StatisticsEventID.ZHIFU_NUMBER_1000)
            }
        }
    }

    private var titleMargin: Int = 0
    private fun setTitleAlpha() {
        constraintHead.post {
            titleMargin = constraintHead.height / 2 - tvMoney.height / 2 - rlTitle.height - statusBarHeight
            NSLog.d("setTitleAlpha : ", "$titleMargin")
        }

        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
            nestedScrollView.setOnScrollChangeListener { v: View?, scrollX: Int, scrollY: Int, oldScrollX: Int, oldScrollY: Int ->
                NSLog.d("setTitleAlpha : ", "scrollY : $scrollY , oldScrollY : $oldScrollY")
                if (titleMargin > 0) {
                    val alpha = 1f - scrollY * 1f / titleMargin
                    val alphaT = if (alpha < 0f) {
                        0f
                    } else {
                        alpha
                    }

                    tvMoney.alpha = alphaT
                    tvAmount.alpha = alphaT
                }

            }
        }
    }

    /**
     * 整个支付模块
     */
    // 支付item选择(下标)
    private var payItemPosition = 0

    // 支付item方式 : 固定或自定义
    private var payItemType = ZhiFuItemView.NORMAL

    // 支付类型 : 支付宝或微信
    var payType = PAY_WECHAT

    // 自定义金额
    private var customMoney: CharSequence? = null

    private var chargeType: Int = 0// 110：支付宝官方;126：微信官方;114：手机银联(android); 146：快付微信 163 银联闪付宝

    /**
     * 充值流程 : 充值 $1 $2 ...
     */
    private fun userPayConfirm() {
        StatisticsUtil.onEvent(StatisticsEventID.ZHIFU_BTN_GOZHIFU)
        // 处于家长模式
        if (NineShowApplication.mUserBase != null && NineShowApplication.mUserBase?.family_module ?: 2 == 1) {
            ParentsModleHintDialog(this).show()
            return
        }

        // 充值 : 1. 判断是否绑定手机号
        val userBase = NineShowApplication.mUserBase ?: return

       /* if (userBase.request_bind == 1) {
            showPhoneAuthDialog()
            return
        }*/

        // 从余额不足进来
        if (source == 1) {
            StatisticsUtil.onEvent(StatisticsEventID.UM_PAY_CLICK_INSUFFICIENT_BALANCE_PAY)
        }

        var money = 0
        // 固定选项支付
        if (payItemType == ZhiFuItemView.NORMAL && payItemPosition >= 0 && payItemPosition < datas.size - 1) { // 这里去除自定义选项
            money = datas[payItemPosition].amount
        } else if (payItemType == ZhiFuItemView.CUSTOM && !TextUtils.isEmpty(customMoney)) {
            money = customMoney.toString().toInt()
        }

        NSLog.d(Tag, "确认支付 : $money")

        // 充值 : 2. 判断金额是否满足条件  return & 提示信息
        if (money < 10) {
            MyToast.showShort("充值金额过低")
            return
        }

        if (money.toString().length > 6) {
            MyToast.showShort("充值金额过大")
            return
        }


        // 充值 : 3. 统一调用
        if (!Utils.isLongPeriodNotClickable()) {
            when (payType) {
                PAY_WECHAT -> {  // 微信支付
                    StatisticsUtil.onEvent(StatisticsEventID.ZHIFU_TYPE_WEIXIN)
                    chargeType = if (Global.WEIXIN_CHARGE_TYPE != 0) {
                        Global.WEIXIN_CHARGE_TYPE
                    } else {
                        PayUtil.PAY_TYPE_JX_WXPAY
                    }

                    if (BuildConfig.PAY_MODE == 1) { //百度视频
                        chargeType = PAY_TYPE_BD_WXPAY
                    }
                }
                PAY_ALI -> {      // 阿里(支付宝)支付
                    StatisticsUtil.onEvent(StatisticsEventID.ZHIFU_TYPE_ZHIFUBAO)
                    chargeType = if (Global.ALIPAY_CHARGE_TYPE != 0) {
                        Global.ALIPAY_CHARGE_TYPE
                    } else {
                        PayUtil.PAY_TYPE_JX_ALIPAY
                    }

                    if (BuildConfig.PAY_MODE == 1) { //百度视频
                        chargeType = PAY_TYPE_BD_ALIPAY
                    }
                }
            }


            // 充值 : 4. 根据对应的支付方式生成订单
            getOrderdate(money, chargeType)
        }
    }

    // 生成订单
    private fun getOrderdate(money: Int, type: Int) {
        isClikcPayBtn = true
        showOrDismissDialog(true, "请稍候...")
        PayUtil.createOrderRequest(money.toString(), type.toString(), NineShowApplication.mUserBase, chargeRid, applicationContext, object : PayUtil.CreateOrderListener {
            override fun success(result: String?) {
                if (isFinishing) {
                    return
                }

                showOrDismissDialog(false)

                result?.let {
                    generateOrderResult(type, it)
                }
            }

            override fun failure() {
                if (isFinishing) {
                    return
                }
                showOrDismissDialog(false)
                MyToast.MakeToast("服务器连接超时，请重试")
            }

        })
    }

    // 服务端返回的签名数据
    private var orderId: String? = null
    private var param: String? = null

    // 充值 : 5. 生成订单结果
    private fun generateOrderResult(type: Int, result: String) {
        NSLog.d("generateOrderResult : ", "type : $type , result : $result")

        try {
            val jsonObject = JSONObject(result)
            val code: String? = jsonObject.optString("code")
            val msg: String? = jsonObject.optString("message")

            when {
                TextUtils.equals(code, "200") -> {
                    val jsonObject2 = jsonObject.optJSONObject("data")
                    orderId = jsonObject2?.optString("orderid") // 后台生成的订单号

                    var realChargeType = jsonObject2?.optInt("type", -1) ?: -1
                    if (realChargeType == -1) {
                        realChargeType = type
                    }
                    NSLog.e("pay type  = $realChargeType")
                    param = if (realChargeType == PayUtil.PAY_TYPE_JX_ALIPAY) { //支付宝(支付宝官方)
                        jsonObject2?.optString("sign")
                    } else {
                        jsonObject2?.optString("transid") //签名数据
                    }

                    when (realChargeType) {
                        // 支付宝(官方)
                        PayUtil.PAY_TYPE_JX_ALIPAY -> {
                            aliPayTask()
                        }

                        // 快付支付通道app支付 , 微信支付(官方)
                        PayUtil.PAY_TYPE_KF_APP_WXPAY, PayUtil.PAY_TYPE_JX_WXPAY -> {
                            jsonObject2?.optJSONObject("params")?.let { doPayWeixinTask(it) }
                        }

                        // 云更新支付宝 , 云更新微信支付（微信官方h5) , 微信支付（快付）,
                        PayUtil.PAY_TYPE_YGX_ALIPAY, PayUtil.PAY_TYPE_YGX_WXPAY, PayUtil.PAY_TYPE_JX_WX_KUAIPAY,
                            // 百度微信 , 百度支付宝 , 九秀官方h5
                        PayUtil.PAY_TYPE_BD_WXPAY, PayUtil.PAY_TYPE_BD_ALIPAY, PayUtil.PAY_TYPE_JX_WXPAY_H5 -> {
                            jsonObject2?.optString("url")?.let { kuaiFuWXPay(it, realChargeType) }
                        }

                    }

                }
                TextUtils.equals(code, "4001") -> {
                    MyToast.MakeToast("第三方生成订单失败")
                }
                TextUtils.equals(code, "9002") || TextUtils.equals(code, "9003") -> {
                    code?.let{
                        AccountIdentityDialog.showDialog(this,it,msg)
                    }
                }
                else -> {
                    MyToast.MakeToast(msg)
                }
            }
        } catch (e: JSONException) {
            e.printStackTrace()
        }
    }

    private var isNoCallBackPay = false //是不是没有回调的支付方式
    private var pay_webview: WebView? = null

    private fun kuaiFuWXPay(payinfo: String, realChargeType: Int) {
        StatisticsUtil.onEvent(StatisticsEventID.UM_PAY_SHOW_THREAD_PAY)
        isNoCallBackPay = true
        if (pay_webview == null) {
            initKuaiFuPay()
        }
        if (TextUtils.isEmpty(payinfo)) {
            MyToast.MakeToast(this, "支付参数错误，请重新下单")
            return
        }

        when (realChargeType) {
            PayUtil.PAY_TYPE_YGX_WXPAY -> { //云更新微信支付
                val map: MutableMap<String, String> = HashMap()
                map["Referer"] = "https://www.feihuo.com"
                pay_webview?.loadUrl(payinfo, map)
            }
            PayUtil.PAY_TYPE_BD_WXPAY -> { //百度微信支付
                val map: MutableMap<String, String> = HashMap()
                map["Referer"] = "https://v.xiaodutv.com"
                pay_webview?.loadUrl(payinfo, map)
            }
            PayUtil.PAY_TYPE_JX_WX_KUAIPAY -> { //快付
                pay_webview?.loadUrl(payinfo)
            }
            else -> {
                pay_webview?.loadUrl(payinfo)
            }
        }
    }


    private var isClikcPayBtn = true //一次点击支付对应一次调起

    /**
     * 快付微信支付 初始化webview
     */
    @SuppressLint("SetJavaScriptEnabled")
    private fun initKuaiFuPay() {
        pay_webview = WebView(this)
        pay_webview?.visibility = View.VISIBLE
        pay_webview?.let {
            val webSettings = it.settings

            with(webSettings) {
                javaScriptEnabled = true
                defaultTextEncodingName = "UTF-8"
                // 设置可以访问文件
                allowFileAccess = true
                // 设置支持缩放
                // 设置支持缩放
                builtInZoomControls = true
                cacheMode = WebSettings.LOAD_NO_CACHE
                // 使用localStorage则必须打开
                // 使用localStorage则必须打开
                domStorageEnabled = true
                setGeolocationEnabled(true)
            }
        }

        pay_webview?.webViewClient = object : WebViewClient() {
            override fun onPageStarted(view: WebView?, url: String, favicon: Bitmap?) {
                NSLog.i("KuaiFu", "onPageStarted url:$url")
                showOrDismissDialog(true, "正在启动微信...")
            }

            override fun onReceivedSslError(view: WebView?, handler: SslErrorHandler?, error: SslError?) {
                handler?.proceed()
            }

            override fun onPageFinished(view: WebView?, url: String?) {
                super.onPageFinished(view, url)
                showOrDismissDialog(false)
            }

            override fun shouldOverrideUrlLoading(view: WebView?, url: String?): Boolean {
                url ?: return false
                NSLog.i("KuaiFu", "支付 url:$url")
                // 如下方案可在非微信内部WebView的H5页面中调出微信支付
                if (url.startsWith("weixin://wap/pay?") || url.startsWith("alipays://platformapi/startApp?")) {
                    if (!isClikcPayBtn) {
                        return false
                    }
                    isClikcPayBtn = false
                    if (url.startsWith("alipays://platformapi/startApp?")) {
                        if (!checkAliPayInstalled()) { //支付宝未安装
                            isNoCallBackPay = false
                            MyToast.MakeSysToast(NineShowApplication.applicationContext, "支付失败!支付宝未安装!")
                            return true
                        }
                    } else if (url.startsWith("weixin://wap/pay?")) {
                        if (!checkWxInstalled()) { //微信未安装
                            isNoCallBackPay = false
                            MyToast.MakeSysToast(NineShowApplication.applicationContext, "支付失败!微信未安装!")
                            return true
                        }
                    }
                    val intent = Intent()
                    intent.action = Intent.ACTION_VIEW
                    intent.data = Uri.parse(url)
                    startActivity(intent)
                    return true
                } else if (parseScheme(url)) {
                    try {
                        val intent: Intent = Intent.parseUri(url, Intent.URI_INTENT_SCHEME)
                        intent.addCategory("android.intent.category.BROWSABLE")
                        intent.component = null
                        startActivity(intent)
                        return true
                    } catch (e: java.lang.Exception) {
                        e.printStackTrace()
                    }
                }
                return false
            }
        }
    }

    private fun parseScheme(url: String): Boolean {
        return if (url.contains("platformapi/startapp")) {
            true
        } else Build.VERSION.SDK_INT > Build.VERSION_CODES.M && url.contains("platformapi") && url.contains("startapp")
    }

    // 检测支付宝是否已安装
    private fun checkAliPayInstalled(): Boolean {
        val uri = Uri.parse("alipays://platformapi/startApp")
        val intent = Intent(Intent.ACTION_VIEW, uri)
        val componentName = intent.resolveActivity(NineShowApplication.applicationContext.packageManager)
        return componentName != null
    }

    // 检测微信是否安装
    private fun checkWxInstalled(): Boolean {
        val uri = Uri.parse("weixin://wap/pay?")
        val intent = Intent(Intent.ACTION_VIEW, uri)
        val componentName = intent.resolveActivity(NineShowApplication.applicationContext.packageManager)
        return componentName != null
    }

    private val mWXPayCallBack: WXPayResultCallBack = object : WXPayResultCallBack {
        override fun onSuccess() {
            NineShowApplication.setCharged(true)
            checkOrder()
        }

        override fun onError(error_code: Int) {
            when (error_code) {
                WXPay.NO_OR_LOW_WX -> Toast.makeText(this@ZhiFuActivity, "未安装微信或微信版本过低", Toast.LENGTH_SHORT).show()
                WXPay.ERROR_PAY_PARAM -> Toast.makeText(this@ZhiFuActivity, "参数错误", Toast.LENGTH_SHORT).show()
                WXPay.ERROR_PAY -> Toast.makeText(this@ZhiFuActivity, "支付失败", Toast.LENGTH_SHORT).show()
            }
        }

        override fun onCancel() {
            Toast.makeText(this@ZhiFuActivity, "支付取消", Toast.LENGTH_SHORT).show()
        }
    }


    // 调用微信支付(官方)
    private fun doPayWeixinTask(param: JSONObject) {    // 包含签名数据的参数
        StatisticsUtil.onEvent(StatisticsEventID.UM_PAY_SHOW_THREAD_PAY)
        val appid: String? = param.optString("appid")
        if (null == appid) {
            mWXPayCallBack.onError(WXPay.ERROR_PAY_PARAM)
            return
        }
        WXPay.init(this, appid)
        val manager: ConnectivityManager? = getSystemService(Context.CONNECTIVITY_SERVICE) as? ConnectivityManager
        val networkinfo = manager?.activeNetworkInfo
        if (networkinfo != null && networkinfo.isConnected) {
            WXPay.getInstance().doPay(param, mWXPayCallBack)
        } else { //若无网，则应用原来逻辑
            val builder = AlertDialog.Builder(this, R.style.CustomBgTransparentDialog)
            builder.setIcon(R.drawable.logo)
            builder.setTitle("网络状态")
            builder.setMessage("没有可用网络,是否进入设置面板")
            builder.setPositiveButton("是") { _, _ -> startActivity(Intent(Settings.ACTION_WIRELESS_SETTINGS)) }
            builder.setNegativeButton("否") { _, _ -> Toast.makeText(this, "联网失败", Toast.LENGTH_SHORT).show() }
            builder.create().show()
        }

    }

    // 调用支付宝支付(支付宝官方)
    private fun aliPayTask() {
        StatisticsUtil.onEvent(StatisticsEventID.UM_PAY_SHOW_THREAD_PAY)
        thread {
            val alipay = PayTask(this)
            // 构造PayTask对象，调用支付接口，获取支付结果
            val result = alipay.pay(param)

            val msg = Message.obtain()
            msg.what = PayUtil.MSG_ZHIFUBAO
            msg.obj = result
            mHandler.sendMessage(msg)
        }
    }

    @SuppressLint("HandlerLeak")
    private val mHandler = object : Handler() {
        override fun handleMessage(msg: Message) {
            try {
                val strRet = msg.obj as? String
                when (msg.what) {
                    PayUtil.MSG_ZHIFUBAO -> {       //支付宝支付成功的结果处理（支付宝官方）
                        // 处理交易结果
                        try {
                            strRet ?: return
                            var tradeStatus = "resultStatus={"
                            val imemoStart = strRet.indexOf("resultStatus=") + tradeStatus.length
                            val imemoEnd = strRet.indexOf("};memo=")
                            tradeStatus = strRet.substring(imemoStart, imemoEnd)
                            // 先验签通知
                            val resultChecker = ResultChecker(strRet)
                            val retVal = resultChecker.checkSign()
                            // 验签失败
                            if (retVal == ResultChecker.RESULT_CHECK_SIGN_FAILED) {
                                BaseHelper.showDialog(this@ZhiFuActivity, "提示", getResources().getString(R.string.check_sign_failed), android.R.drawable.ic_dialog_alert)
                            } else {
                                // 验签成功。验签成功后再判断交易状态码 -> 判断交易状态码，只有9000表示交易成功
                                if (TextUtils.equals(tradeStatus, "9000")) {
                                    NineShowApplication.setCharged(true)
                                    checkOrder()
                                } else {
                                    BaseHelper.showDialog(this@ZhiFuActivity, "提示", "支付失败.", R.drawable.infoicon)
                                }
                            }
                        } catch (e: Exception) {
                            e.printStackTrace()
                            BaseHelper.showDialog(this@ZhiFuActivity, "提示", strRet, R.drawable.infoicon)
                        }
                    }
                    PayUtil.TRUE_LOVE_POWDER -> {
                        showOrDismissDialog(false)
                        NineShowApplication.setFirstPayGiftTips(false)
                        MyToast.MakeToast("充值成功！已经到账。")
                        /* if (isChargeGuide) {
                             StatisticsUtil.onEvent(StatisticsEventID.PAYED_FROM_GUIDE)
                         }*/
                    }
                    PayUtil.MSG_CHECK_FAILURE -> {
                        showOrDismissDialog(false)
                        MyToast.MakeToast("充值失败,请检查网络后重试！")
                    }
                    PayUtil.MSG_PAY_THIRD -> {   //充值轮询未查询到
                        MyToast.MakeSysToast(NineShowApplication.applicationContext, "确认充值成功后在三十分钟内到账,如未到账请联系客服处理!")
                    }
                }

            } catch (e: Exception) {
                NSLog.d(Tag, e.message)
            }
        }
    }

    // 轮询服务器，检查是否支付成功
    private fun checkOrder() {
        showOrDismissDialog(true, "正在充值……")
        payUtil.checkOrder(object : PayUtil.OrderRequest {
            override fun checkOrder() {
                PayUtil.checkOrderRequest(orderId, NineShowApplication.mUserBase, object : PayUtil.PayEndListener {
                    override fun success(firstchargeType: Int, gainNumber: Int) {
                        showOrDismissDialog(false)
                        checkOrderSuccess(firstchargeType)
                    }

                    override fun failure() {
                        showOrDismissDialog(false)
                        mHandler.sendEmptyMessage(PayUtil.MSG_CHECK_FAILURE)
                    }

                })
            }

            override fun failure() {
                showOrDismissDialog(false)
                mHandler.sendEmptyMessage(PayUtil.MSG_CHECK_FAILURE)
            }

        }, PayUtil.PERIOD_ZHIFUBAO, 1000, PayUtil.COUNT, mHandler)
    }

    private fun checkOrderSuccess(firstchargeType: Int) {
        Log.e("checkCount:  ", "checkOrderSuccess--")
        val msg = mHandler.obtainMessage()
        msg.what = PayUtil.TRUE_LOVE_POWDER
        msg.arg1 = firstchargeType
        mHandler.sendMessage(msg)
        notifyUserInfo()
        payUtil.stopCheck()
    }

    private fun notifyUserInfo() {
        if (source == 1) {
            StatisticsUtil.onEvent(StatisticsEventID.UM_PAY_CLICK_INSUFFICIENT_BALANCE_SUCCESS)
        }
        StatisticsUtil.onEvent(StatisticsEventID.UM_PAY_SUCCESS)
        // 这里可以整个替换用户信息的
        PayUtil.notifyUserInfoRequest(NineShowApplication.mUserBase, object : NotifyUserInfoListener {
            override fun success(result: String?) {
                if (result != null) {
                    val jsonObject: JSONObject
                    try {
                        jsonObject = JSONObject(result)
                        val code: String? = jsonObject.optString("code")
                        if (TextUtils.equals("200", code)) {
                            val data: JSONObject? = jsonObject.optJSONObject("data")
                            data?.optInt("money")?.toLong()?.let { NineShowApplication.mUserBase?.money = it }
                            data?.optInt("tokencoin")?.toLong()?.let { NineShowApplication.mUserBase?.tokencoin = it }
                            data?.optInt("wealthlevel")?.let { NineShowApplication.mUserBase?.wealthlevel = it }
                            NineShowApplication.getManager().notifyState() //若从个人中心跳转过来的 则更改个人中心的 金额显示
                            // getUserMoney() // 刷新余额
                            tvMoney.text = NineShowApplication.mUserBase?.money?.toString() ?: "--"
                        }

                        // 修改用户是否支付
                        val userBase = NineShowApplication.mUserBase
                        if (userBase != null) {
                            userBase.isCharge = 1
                        }

                    } catch (e: java.lang.Exception) {
                        e.printStackTrace()
                    }
                }
            }

            override fun failure() {
                MyToast.MakeToast("更新金币信息失败！ 请重新登录")
            }
        })
    }

    // 等候弹窗
    private var dialog: Dialog? = null
    private fun showOrDismissDialog(show: Boolean, msg: String? = null) {
        if (!this.isFinishing) {
            when (show) {
                true -> {
                    dialog = Utils.showProgressDialog(this, msg, true)
                    dialog?.show()
                }
                false -> {
                    dialog?.dismiss()
                }
            }
        }
    }

    // 绑定手机号弹窗
    private fun showPhoneAuthDialog() {
        /*CommonRemindDialog.create(this)
                .setCurrencyText("去认证")
                .setTitleText(Html.fromHtml("由于相关法律法规<br/>想要进行此操作<br/>您需要进行<b>实名手机号</b>认证"))
                .setOnClickCallback { type ->
                    if (type == BaseDialog.SELECT_SECOND) {
                        val intent = Intent(this, RegisterActivity::class.java).also { it.putExtra("type", 3) }
                        startActivity(intent)
                    }
                }*/
        AccountIdentityDialog.showDialog(this,AccountIdentityDialog.CODE_BIND_PHONE)
    }

    // 轮询服务器，检查是否支付成功
    private fun checkOrderThird() {
        // 1.显示弹出窗口
        showOrDismissDialog(true, "正在查询充值状态……")
        payUtil.checkOrder(object : OrderRequest {
            override fun checkOrder() {
                checkOrderRequest(orderId, NineShowApplication.mUserBase, object : PayEndListener {
                    override fun success(firstchargeType: Int, number: Int) {
                        showOrDismissDialog(false)
                        checkOrderSuccess(firstchargeType)
                    }

                    override fun failure() {
                        showOrDismissDialog(false)
                        mHandler.sendEmptyMessage(MSG_PAY_THIRD)
                    }
                })
            }

            override fun failure() {
                showOrDismissDialog(false)
                mHandler.sendEmptyMessage(MSG_PAY_THIRD)
            }
        }, PERIOD_THIRE, 1000, MSG_MOBILE_CARD_FAILURE, mHandler)
    }

    override fun onResume() {
        super.onResume()
        if (!TextUtils.isEmpty(orderId) && NineShowApplication.mUserBase != null && isNoCallBackPay) {
            isNoCallBackPay = false
            checkOrderThird()
        }
        // getUserMoney()
        // refershRemind()
        super.onResume()
    }


    override fun initDatas() {
        // 如果获取到的支付存储数据为空，则从接口自己拉取
        getPayData()
    }

    // 获取支付界面整体数据 : 支付选项 & 提示信息
    private fun getPayData() {
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.ZHIFU_PAY_DETAIL, null, object : NSGsonObjectNewCallback<ZhiFuResult>() {
            override fun onFailure(statusCode: Int, errorMsg: String?) {
                NSLog.d(Tag, "status 0 : $statusCode")
                MyToast.showShort(errorMsg ?: "")
                // ProgressDialogUtil.dismiss()
            }

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: ZhiFuResult?) {
                NSLog.d(Tag, "status : $statusCode")
                if (statusCode == 200) {

                    UserZhiFuGsonHelper.saveUserZhiFuData(response)

                    response?.data?.let {
                        setData(it)
                        showAutumnChargeDialog(it)
                    }

                    setBanner(response?.data?.banners)
                }
            }
        })
    }

    // 显示金秋充值弹窗
    private var autumnChargeDialog: AutumnChargeDialog? = null
    private fun showAutumnChargeDialog(result: Data) {
        if (NineShowApplication.mUserBase != null && result.goldenFall == 1 && UserReturnGsonHelper.getNewAutumnActiveStatus()) {
            autumnChargeDialog = AutumnChargeDialog(this, 0)
            autumnChargeDialog!!.show()
        }
    }


    /**
     * 更新系统配置的支付信息
     */
    private fun getRoomSystemMessage() {
        val asyncHttpClient = NSAsyncHttpClient.getInstance()
        val params = NSRequestParams()
        params.put("channel", NineShowApplication.UMENG_CHANNEL)
        asyncHttpClient[Constants.NS_ROOM_APPCONF, params, object : NSJsonResponseHandler<RoomSystemMsgResultInfo?>() {
            override fun onSuccess(statusCode: Int, rawJsonResponse: String?, response: RoomSystemMsgResultInfo?) {
                if (response != null) {
                    if (response.data != null && response.data.priv != null && response.data.priv.size > 0) { //房间系统消息有配置
                        NineShowApplication.setRoomSystemMessageList(response.data.priv)
                    }
                    if (response.data != null && response.data.chatWord != null && response.data.chatWord.size > 0) { //房间系统消息有配置
                        NineShowApplication.setHotWordList(response.data.chatWord)
                    }
                    if (response.data != null) {
                        NineShowApplication.isShowDouTu = response.data.isDoupic
                    }
                    if (response.data != null && response.data.payType != null) { //支付方式
                        Global.ALIPAY_CHARGE_TYPE = response.data.payType.ali_pay
                        Global.WEIXIN_CHARGE_TYPE = response.data.payType.wx_pay
                    }
                    if (response.data != null && response.data.showwwj == 1) {
                        NineShowApplication.isShowHotGame = true
                    }
                    if (response.data != null && response.data.topUserLevel != null && response.data.topUserLevel.size > 0) { //自定义的等级图标
                        NineShowApplication.setUserCustomLevelList(response.data.topUserLevel)
                    }
                }
            }

            override fun onFailure(statusCode: Int, errorMsg: String) {}
        }]
    }

    // 设置Banner数据 & 适配头部高度
    private fun setBanner(bannerTempDatas: MutableList<Banner>?) {
        val bannerDatas = bannerTempDatas?.filter {
            !TextUtils.isEmpty(it.banner)
        }

        val userInfo = NineShowApplication.mUserBase
        if (null != userInfo && userInfo.isCharge == 0 && null != bannerDatas) { // 用户信息没有充值过并且返回信息也没有充值过才显示
            if (bannerDatas.size > 1) {
                bgaBanner.setAutoPlayAble(true)
            } else {
                bgaBanner.setAutoPlayAble(false)
            }

            constraintHead.setBackgroundResource(R.drawable.bg_zhifu_top_long)
            fitterViewSize(constraintHead, { widthScreen }, { (it * HEAD_LONG_PERCENT).toInt() })

            fitterViewSize(bgaBanner, { (widthScreen * HEAD_BANNER_WIDTH_PERCENT).toInt() }, { width -> (width * HEAD_BANNER_SELF_PERCENT).toInt() })
            bgaBanner.setData(bannerDatas, null)
            bgaBanner.setAdapter(object : BGABanner.Adapter<ImageView, Banner> {
                override fun fillBannerItem(banner: BGABanner?, itemView: ImageView?, model: Banner?, position: Int) {
                    NSLog.d(Tag, "展示 : ${model?.banner}")
                    itemView?.let {
                        GlideUtils.loadBannerPic(this@ZhiFuActivity, model?.banner, itemView)
                    }
                }
            })
            bgaBanner.setDelegate(object : BGABanner.Delegate<ImageView, Banner> {
                override fun onBannerItemClick(banner: BGABanner?, itemView: ImageView?, model: Banner?, position: Int) {
                    NSLog.d(Tag, "点击 ${model?.act_url}")
                    model?.act_url?.let {
                        AdvertiseActivity.start(this@ZhiFuActivity, false, it)
                    }
                }
            })
            bgaBanner.setVisible(true)
            return
        } else {
            bgaBanner.setVisible(false)
            constraintHead.setBackgroundResource(R.drawable.bg_zhifu_top_short)
            fitterViewSize(constraintHead, { widthScreen }, { (it * HEAD_SHORT_PERCENT).toInt() })
        }
    }


    // 设置数据
    @SuppressLint("SetTextI18n")
    private fun setData(data: Data) {
        tvInfoContent.text = data.tips
        tvMoney.text = data.user_info?.money ?: "--"
        tvForbid.text = data.forbid_tip ?: "--"
        llPolicy.setVisible(data.show_agreement == 1)

        // 过滤
        val list = data.options?.filter {
            TextUtils.equals(it.type, "index")
        }

        list?.let {
            datas.clear()
            datas.addAll(it)
            datas[0].selected = true
            datas.add(Option(0, 0, "index", ZhiFuItemView.CUSTOM, false))
            adapter.notifyDataSetChanged()

            // 设置确认充值
            btConfirm.text = getString(R.string.zhifu_confirm, datas[0].amount)
        }


        /*btConfirm.postDelayed({
            ProgressDialogUtil.dismiss()
        }, 500)*/

        // 设置协议文字和跳转链接
        data.agreement_name?.let {
            tvPolicy.text = "《$it》"
        }

        tvPolicy.setOnClickListener {
            data.recharge_agreement?.let {
                AdvertiseActivity.start(this, false, true,it,getString(R.string.zhifu_h5_title))
            }
        }
    }

    val decoration = object : RecyclerView.ItemDecoration() {
        override fun getItemOffsets(outRect: Rect, view: View, parent: RecyclerView, state: RecyclerView.State) {
            super.getItemOffsets(outRect, view, parent, state)
            val index = parent.getChildAdapterPosition(view)

            when {
                index % 3 == 0 -> {
                    outRect.right = (ITEM_PERCENT * widthScreen).toInt()
                }
                index % 3 == 1 -> {
                    outRect.right = (ITEM_PERCENT * widthScreen).toInt()
                    outRect.left = (ITEM_PERCENT * widthScreen).toInt()
                }
                else -> {
                    outRect.left = (ITEM_PERCENT * widthScreen).toInt()
                }
            }

            if (index > 2) {
                outRect.top = (resources.displayMetrics.density * 13).toInt()
            }
        }
    }

    override fun initEvents() {
        llBack.setOnClickListener {
            mHandler.removeCallbacksAndMessages(null)
            finish()
        }
        llList.setOnClickListener {
            if (Utils.isLongPeriodNotClickable()) {
                return@setOnClickListener
            }
            NewsRemindManager.getInstans().delete(NewsRemindManager.KEY_MINE_RECHARGE_RECORD)
            // 跳转广告页
            val intent = Intent(this, AdvertiseActivity::class.java)
            intent.putExtra("url", Constants.LINK_ACCOUNT_LIST_H5)
            intent.putExtra("title", "我的账单")
            intent.putExtra("desc", "我的账单") //
            intent.putExtra("noShare", true) //不可分享
            startActivity(intent)
//            ZhiFuFastCDialog.showBugDialog(this,0,1000,null)
        }
    }

    override fun onBackPressed() {
        mHandler.removeCallbacksAndMessages(null)
        super.onBackPressed()
    }

    override fun setContentView() {
        setContentView(R.layout.activity_zhifu)
    }

    override fun setStatusBar() {
        StatusBarUtil.setTranslucentForImageViewInFragment(this, null)
    }

    private val statusBarHeight: Int
        get() = getStatusBarHeight(this)

    // 获得状态栏高度
    private fun getStatusBarHeight(context: Context): Int {
        val resourceId = context.resources.getIdentifier("status_bar_height", "dimen", "android")
        return context.resources.getDimensionPixelSize(resourceId)
    }

}
