package com.ninexiu.sixninexiu.tencentim

import android.os.Bundle
import android.text.TextUtils
import com.google.gson.JsonObject
import com.loopj.android.http.TextHttpResponseHandler
import com.ninexiu.sixninexiu.broadcast.AppBroadcastHelper
import com.ninexiu.sixninexiu.common.net.NSAsyncHttpClient
import com.ninexiu.sixninexiu.common.net.NSRequestParams
import com.ninexiu.sixninexiu.common.util.Constants
import com.ninexiu.sixninexiu.common.util.NSReceiverAction
import com.ninexiu.sixninexiu.common.util.TextUtil
import com.ninexiu.sixninexiu.im.NewsRemindManager
import com.tencent.imsdk.TIMCallBack
import com.tencent.imsdk.TIMConversation
import com.tencent.imsdk.TIMConversationType
import com.tencent.imsdk.TIMManager
import com.tencent.qcloud.tim.uikit.PushContants
import com.tencent.qcloud.tim.uikit.bean.SysAndAnchorBean
import com.tencent.qcloud.tim.uikit.modules.conversation.ConversationManagerKit
import cz.msebera.android.httpclient.Header
import org.json.JSONException
import org.json.JSONObject


/**
 * <pre>
 *     @author : zhangbing
 *     time   : 2021/01/27
 *     desc   :
 *     version: 1.0
 * </pre>
 */
class UnreadMsgCountManager {

    companion object {
        val INSTANCE: UnreadMsgCountManager by lazy(mode = LazyThreadSafetyMode.SYNCHRONIZED) {
            UnreadMsgCountManager()
        }
    }


    private var msgUnreadCount = 0
    private var systemMsgUnreadCount = 0
    var lastSystemBean: SysAndAnchorBean? = null


    /**
     * 消息  所有的未读数
     */
    public fun getMessageCenterUnReadCount(): Int {
        return msgUnreadCount + getDynamicMessageUnreadNum() + systemMsgUnreadCount
    }

    /**
     * 消息  直播间未读数
     */
    public fun getMessageLiveroomUnReadCount(): Int {
        return msgUnreadCount + systemMsgUnreadCount
    }


    /**
     * IM消息未读数
     * 添加未读消息监视器，  收到未读消息时发送广播    并设置  msgUnreadCount 为   消息未读消息数
     */
    public fun initImUnReadListener() {
        ConversationManagerKit.getInstance().removeAllUnreadWatchers()
        ConversationManagerKit.getInstance().addUnreadWatcher { count ->
            msgUnreadCount = count
            AppBroadcastHelper.getInstance().sendBroadcast(NSReceiverAction.ACTION_CHAT_MESSAGE_UNREAD)
        }
    }

    /**
     * 互动消息未读数获取
     */
    public fun getDynamicMessageUnreadNum(conversation : TIMConversation? = null): Int {
        var attentionRemind = NewsRemindManager.getInstans().getNewsRemind(NewsRemindManager.INTERACTION_ATTENTION_MESSAGE)
        var commentRemind = NewsRemindManager.getInstans().getNewsRemind(NewsRemindManager.KEY_INTERACTION_COMMENT_MESSAGE)
        var likeRemind = NewsRemindManager.getInstans().getNewsRemind(NewsRemindManager.KEY_INTERACTION_LIKE_MESSAGE)
        if ((attentionRemind != null && attentionRemind.status == 1) || (commentRemind != null && commentRemind.status == 1) || (likeRemind != null && likeRemind.status == 1)) {
            var unreadNum = 0
            if (attentionRemind != null) {
                unreadNum += attentionRemind.num
            }
            if (commentRemind != null) {
                unreadNum += commentRemind.num
            }
            if (likeRemind != null) {
                unreadNum += likeRemind.num
            }

            if(unreadNum == 0 && conversation != null) {
                return conversation.unreadMessageNum.toInt()
            }

            return unreadNum
        }

         if(conversation != null) {
            return conversation.unreadMessageNum.toInt()
        }

        return 0
    }

    /**
     * 设置互动消息已读
     */
    public fun setDynamicMessageRead() {
        NewsRemindManager.getInstans().delete(NewsRemindManager.INTERACTION_ATTENTION_MESSAGE)
        NewsRemindManager.getInstans().delete(NewsRemindManager.KEY_INTERACTION_COMMENT_MESSAGE)
        NewsRemindManager.getInstans().delete(NewsRemindManager.KEY_INTERACTION_LIKE_MESSAGE)
        AppBroadcastHelper.getInstance()
                .sendBroadcast(NSReceiverAction.ACTION_DYNAMIC_MESSAGE_UNREAD)
    }

    /**
     * 系统消息最后一条和未读数
     */
    public fun getLastSystemPushMessage() {
        val asyncHttpClient = NSAsyncHttpClient.getInstance()
        var params = NSRequestParams()
        params.put("msgtype", "1")
        asyncHttpClient?.get(Constants.GETPUSH_LASTMESSAGEINFO, params, object : TextHttpResponseHandler() {
            override fun onSuccess(statusCode: Int, headers: Array<out Header>?, responseString: String?) {
                if (responseString != null) {
                    try {
                        val jsonObject = JSONObject(responseString)
                        val code = jsonObject.optInt("code")
                        if (code == 200) {
                            var data = jsonObject.optJSONObject("data")
                            var title = data.optString("title")
                            var contentObj = JSONObject(data.optString("content"))
                            var time = contentObj.optLong("send_time")
                            var contentStr = contentObj.optString("content")
                            var tm_id = data.optLong("tm_id")



                            systemMsgUnreadCount = data.optInt("unreadCount")

                            val systemBean = SysAndAnchorBean()
                            systemBean.title = title
                            systemBean.content = contentStr
                            systemBean.unReadCount = systemMsgUnreadCount
                            systemBean.lastMessageTime = time
                            systemBean.tm_id=tm_id

                            PushContants.systemBean = systemBean
                            lastSystemBean = systemBean

                            val bundle = Bundle()
                            bundle.putSerializable("last_system_msg", systemBean)
                            AppBroadcastHelper.getInstance().sendBroadcast(NSReceiverAction.ACTION_SYSTEMMESSAGE_REFRESH, bundle)
                            ConversationManagerKit.getInstance().onRefresh() //刷新直播间系统消息为读数
                        }else{
                            PushContants.systemBean = null
                            AppBroadcastHelper.getInstance().sendBroadcast(NSReceiverAction.ACTION_SYSTEMMESSAGE_REFRESH, Bundle())
                        }
                    } catch (e: JSONException) {
                        e.printStackTrace()

                    } catch (e: Exception) {
                        e.printStackTrace()

                    }

                }
            }

            override fun onFailure(statusCode: Int, headers: Array<out Header>?, responseString: String?, throwable: Throwable?) {

            }

        })
    }

    /**
     * 设置系统消息已读
     */
    public fun setSystemMsgRead(tm_id: String) {
        val asyncHttpClient = NSAsyncHttpClient.getInstance()
        var params = NSRequestParams()
        params.put("is_read", "1")
        params.put("msgtype", "1")
        params.put("tm_id", tm_id)
        asyncHttpClient?.get(Constants.GETPUSH_SETReadPushMessage, params, object : TextHttpResponseHandler() {
            override fun onSuccess(statusCode: Int, headers: Array<out Header>?, responseString: String?) {
                try {
                    var jsonObject = JSONObject(responseString)
                    var responceCode = jsonObject.optInt("code")
                    if (responceCode == 200) {
                        getLastSystemPushMessage()
                    }
                } catch (e: Exception) {
                    e.printStackTrace()
                }
            }

            override fun onFailure(statusCode: Int, headers: Array<out Header>?, responseString: String?, throwable: Throwable?) {

            }

        })
        //上报系统消息已读
        TIMManager.getInstance().getConversation(TIMConversationType.C2C, //会话类型：单聊
                "100000").setReadMessage(null, object : TIMCallBack {
            override fun onSuccess() {

            }

            override fun onError(p0: Int, p1: String?) {

            }
        })
    }


    public fun clearUnread() {
        systemMsgUnreadCount = 0
        lastSystemBean = null
        msgUnreadCount = 0
    }

}