package com.ninexiu.sixninexiu.view

import android.content.Context
import android.util.AttributeSet
import android.view.LayoutInflater
import androidx.constraintlayout.widget.ConstraintLayout
import com.ninexiu.sixninexiu.R
import kotlinx.android.synthetic.main.view_account_set_status.view.*

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/03/03
 *     desc   : 用户设置后的状态统一界面
 *     version: 1.0
 * </pre>
 */
class AccountSetStatusView @JvmOverloads constructor(context: Context, attrs: AttributeSet? = null, defStyleAttr: Int = 0) : ConstraintLayout(context, attrs, defStyleAttr) {
    private val screenWidth: Int by lazy {
        context.resources.displayMetrics.widthPixels
    }

    init {
        LayoutInflater.from(context).inflate(R.layout.view_account_set_status, this)

        // 适配
        post {
            fitterViewSize(ivTop, { screenWidth }, { (it * 0.443).toInt() })
            fitterViewPosition(ivStatus, ORIENTATION_TOP, { (screenWidth * 0.24).toInt() })
        }

        btConfirm.setOnClickListener {
            // 用户主动点击
            removeCallbacks(runnable)
            userConfirm?.invoke()
        }
    }

    private var userConfirm: (() -> Unit)? = null

    // 设置 isSuc : 成功/失败 , status : 状态信息 , info : 提示信息 , confirm : 按钮文字
    fun setStatus(isSuc: Boolean, status: String?, confirm: String, info: String? = null, selfFinish: Boolean = true, userConfirm: (() -> Unit)? = null) {
        if (isSuc) {
            ivStatus.setImageResource(R.drawable.ic_account_status_suc)
        } else {
            ivStatus.setImageResource(R.drawable.ic_account_status_err)
        }

        tvStatus.text = status
        tvInfo.text = info
        btConfirm.text = confirm

        this.userConfirm = userConfirm

        // 倒计时3s,用户如果没有其他操作，自动返回
        if (selfFinish) {
            postRunnableSelf()
        }
    }

    var time = 3
    private val runnable = Runnable {
        if (--time == 0) {
            doNextAction()
        } else {
            postRunnableSelf()
        }
    }

    private fun postRunnableSelf() {
        postDelayed(runnable, 1000)
    }

    private fun doNextAction() {
        removeCallbacks(runnable)
        userConfirm?.invoke()
    }

    override fun onDetachedFromWindow() {
        super.onDetachedFromWindow()
        removeCallbacks(runnable)
    }

}
