package com.ninexiu.sixninexiu.view

import android.annotation.SuppressLint
import android.content.Context
import android.text.InputType
import android.text.method.HideReturnsTransformationMethod
import android.text.method.PasswordTransformationMethod
import android.util.AttributeSet
import android.view.LayoutInflater
import androidx.constraintlayout.widget.ConstraintLayout
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.common.util.listener.EditTextWatcher
import kotlinx.android.synthetic.main.activity_account_bind_phone.*
import kotlinx.android.synthetic.main.view_account_setting_edit.view.*

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/03/05
 *     desc   : 封装下用户输入框 EditText(输入密码) + 可见/不可见
 *     version: 1.0
 * </pre>
 */
@SuppressLint("Recycle")
class AccountSettingEditView @JvmOverloads constructor(context: Context, attrs: AttributeSet? = null, defStyleAttr: Int = 0) : ConstraintLayout(context, attrs, defStyleAttr) {
    init {
        LayoutInflater.from(context).inflate(R.layout.view_account_setting_edit, this)
        val att = context.obtainStyledAttributes(attrs, R.styleable.AccountSettingEditView)
        val hint = att.getString(R.styleable.AccountSettingEditView_android_hint)
        val selected = att.getBoolean(R.styleable.AccountSettingEditView_selected,false)

        if(!hint.isNullOrBlank()){
            etPwd.hint = hint
        }

        if(selected) {
            setBackgroundResource(R.drawable.bg_account_selected)
        }else {
            setBackgroundResource(R.drawable.bg_account_normal)
        }

        // editText获取到焦点
        etPwd.getFocus = {
            onEditGetFocus?.invoke()
        }


        etPwd.addTextChangedListener(object : EditTextWatcher(){
            override fun onTextChanged(s: CharSequence?, start: Int, before: Int, count: Int) {
                super.onTextChanged(s, start, before, count)
                if(!etPwd.text.isNullOrBlank()) {
                    llHideSee.setVisible(true)
                }else {
                    llHideSee.setVisible(false)
                }
            }
        })


        // 显示获隐藏editText内容
        llHideSee.setOnClickListener {
            if(isHide) {
                etPwd.inputType = (InputType.TYPE_TEXT_VARIATION_VISIBLE_PASSWORD)
                etPwd.transformationMethod = HideReturnsTransformationMethod.getInstance()
                ivHideSee.setImageResource(R.drawable.ic_edit_see)
            }else {
                etPwd.inputType = InputType.TYPE_TEXT_VARIATION_PASSWORD
                etPwd.transformationMethod = PasswordTransformationMethod.getInstance()
                ivHideSee.setImageResource(R.drawable.ic_edit_hide)
            }
            etPwd.setSelection(etPwd.length())
            isHide = !isHide
        }
    }

    private var isHide : Boolean = true

    // editText获取到焦点,外界需要设置整体的背景
    var onEditGetFocus: (() -> Unit)? = null

    // 切换背景
    fun setEditSelected(selected : Boolean) {
        if(selected) {
            setBackgroundResource(R.drawable.bg_account_selected)
            etPwd.setTextColor(resources.getColor(R.color.color_333333))
        }else {
            setBackgroundResource(R.drawable.bg_account_normal)
            etPwd.setTextColor(resources.getColor(R.color.color_cccccc))
        }
    }

    // 获取输入的密码
    fun getEditTextPwd() : String?{
        if(etPwd != null && !etPwd.text.isNullOrBlank()) {
            return etPwd.text.toString()
        }
        return null
    }
}