package com.ninexiu.sixninexiu.view

import android.annotation.SuppressLint
import android.content.Context
import android.util.AttributeSet
import android.view.LayoutInflater
import androidx.constraintlayout.widget.ConstraintLayout
import com.ninexiu.sixninexiu.R
import kotlinx.android.synthetic.main.view_setting.view.*

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/03/02
 *     desc   : 账户安全通用item
 *     version: 1.0
 * </pre>
 */
@SuppressLint("Recycle")
class AccountSettingItemView @JvmOverloads constructor(context: Context, attrs: AttributeSet? = null, defStyleAttr: Int = 0) : ConstraintLayout(context, attrs, defStyleAttr) {
    companion object {
        const val STATUS_ARROW = 0
        const val STATUS_UNIDENTITY = 1
        const val STATUS_IDENTITY = 2
        const val STATUS_BIND = 3
        const val STATUS_UNBIND = 4
    }

    init {
        LayoutInflater.from(context).inflate(R.layout.view_setting, this)
        val att = context.obtainStyledAttributes(attrs, R.styleable.SettingItemView)

        // 设置背景
        when (att.getInt(R.styleable.SettingItemView_item_bg_level, 0)) {
            0 -> setBackgroundResource(R.drawable.bg_item_full)
            1 -> setBackgroundResource(R.drawable.bg_item_top)
            2 -> setBackgroundResource(R.drawable.bg_item_middle)
            3 -> setBackgroundResource(R.drawable.bg_item_bottom)
        }

        tvTitle.text = att.getString(R.styleable.SettingItemView_item_title)
        att.recycle()
        setPadding(dp2px(context, 14), 0, dp2px(context, 14), 0)
    }

    // 主要是设置标题
    fun setTitleInfo(status: Int = STATUS_ARROW, title: String? = null, showDot: Boolean = false) {
        setStatusVisible(status)
        tvTitle.text = title
        setDotVisible(showDot)
    }


    // 设置每种状态的信息  status : 状态信息    unComplete : 未完成状态时的提示   complete : 完成时的提示    bind : 要求绑定时提示     unbind : 解绑时提示   thirdInfo : 三方信息
    fun setStatusInfo(status: Int = STATUS_ARROW, unComplete: String? = null, complete: String? = null, bind: String? = null, unBind: String? = null, thirdInfo: String? = null, showDot: Boolean = false) {
        setStatusVisible(status)
        tvUnIdentification.text = unComplete
        tvIdentification.text = complete
        btBind.text = bind
        btUnBind.text = unBind
        // todo : 需要添加一个转换规则，*号
        tvThirdNickName.text = thirdInfo
        setDotVisible(showDot)
    }

    // 设置红点可见
    private fun setDotVisible(visible: Boolean): AccountSettingItemView {
        viewDot.setVisible(visible)
        return this
    }

    // 设置状态和文字
    /**
     * 这里将item右边分为5种状态
     * 1. 只有箭头
     * 2. 红字和箭头(未完成提示)
     * 3. 灰字(表示完成)
     * 4. 按钮 -> 去绑定
     * 5. 灰字和按钮 -> 已经绑定,可解绑或更换
     */
    private fun setStatusVisible(status: Int) {
        ivArrow.setVisible(false)
        tvUnIdentification.setVisible(false)    // 未认证
        tvIdentification.setVisible(false)      // 已认证
        btBind.setVisible(false)                // 去绑定
        btUnBind.setVisible(false)                // 解绑/更换[手机号]
        tvThirdNickName.setVisible(false)          // 三方

        btBind.isClickable = false
        btUnBind.isClickable = false

        when (status) {
            // 未认证
            STATUS_UNIDENTITY -> {
                ivArrow.setVisible(true)
                tvUnIdentification.setVisible(true)
            }
            // 已认证
            STATUS_IDENTITY -> {
                tvIdentification.setVisible(true)
            }
            // 去绑定
            STATUS_BIND -> {
                btBind.setVisible(true)
            }
            // 解绑
            STATUS_UNBIND -> {
                btUnBind.setVisible(true)
                tvThirdNickName.setVisible(true)
            }
            else -> {
                ivArrow.setVisible(true)
            }
        }
    }

}

