package com.ninexiu.sixninexiu.view

import android.content.Context
import android.util.AttributeSet
import android.view.LayoutInflater
import android.view.animation.AccelerateDecelerateInterpolator
import android.view.animation.Animation
import android.view.animation.ScaleAnimation
import androidx.constraintlayout.widget.ConstraintLayout
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.bean.AnchorInfo
import com.ninexiu.sixninexiu.common.util.GlideUtils
import com.ninexiu.sixninexiu.common.util.NSLog
import com.opensource.svgaplayer.SVGAParser
import com.opensource.svgaplayer.SVGAVideoEntity
import kotlinx.android.synthetic.main.view_anchor_head.view.*
import kotlinx.android.synthetic.main.view_audio_record.view.*

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/07/15
 *     desc   :
 *     version: 1.0
 * </pre>
 */
class AnchorHeadView @JvmOverloads constructor(context: Context, attrs: AttributeSet? = null, defStyleAttr: Int = 0) : ConstraintLayout(context, attrs, defStyleAttr) {


    init {
        LayoutInflater.from(context).inflate(R.layout.view_anchor_head, this)
    }


    fun setAnchorInfo(head : String?) {
        GlideUtils.loadCirclePic(context, head, ivAnchor, R.drawable.icon_head_default)
    }

    private var svgEntry: SVGAVideoEntity? = null
    fun startAnchorAnimation(entry: SVGAVideoEntity?) {
        this.svgEntry = entry
        stopAnchorAnimation()
        postDelayed(run, 500)
    }

    fun stopAnchorAnimation() {
        removeCallbacks(run)
        svgImageView.setVisible(false)
        animationContainer?.clearAnimation()
        svgImageView?.stopAnimation()
    }

    private val run = Runnable {
        startIvScaleAnimation()
    }

    private fun startIvScaleAnimation() {
        svgEntry ?: return
        svgImageView.setVisible(true)
        svgImageView?.setVideoItem(svgEntry)

        val animation = ScaleAnimation(1f, 0.88f, 1f, 0.88f, Animation.RELATIVE_TO_SELF, 0.5f, Animation.RELATIVE_TO_SELF, 0.5f)
        animation.duration = 500
        animation.fillAfter = false
        animation.repeatMode = Animation.REVERSE
        animation.repeatCount = 1
        animation.interpolator = AccelerateDecelerateInterpolator()

        // 同时开始动画
        animationContainer?.startAnimation(animation)
        svgImageView?.startAnimation()

        animation.setAnimationListener(object : Animation.AnimationListener {
            override fun onAnimationStart(animation: Animation?) {
            }

            override fun onAnimationEnd(animation: Animation?) {
                animationContainer?.clearAnimation()
                svgImageView?.stopAnimation()
                postDelayed(run, 500)
            }

            override fun onAnimationRepeat(animation: Animation?) {
            }

        })
    }

    override fun onDetachedFromWindow() {
        super.onDetachedFromWindow()
        stopAnchorAnimation()
    }
}