package com.ninexiu.sixninexiu.view

import android.content.Context
import android.util.AttributeSet
import androidx.core.widget.NestedScrollView
import com.ninexiu.sixninexiu.common.util.NSLog

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/05/17
 *     desc   : 自定义 NestScrollView 为了解决 设置 minHeight , maxHeight 不起作用
 *     version: 1.0
 * </pre>
 */
class AnnounceNestScrollView @JvmOverloads constructor(context: Context, attrs: AttributeSet? = null, defStyleAttr: Int = 0) : NestedScrollView(context, attrs, defStyleAttr) {
    override fun onMeasure(widthMeasureSpec: Int, heightMeasureSpec: Int) {
        // super.onMeasure(widthMeasureSpec, heightMeasureSpec)
        measureChildren(widthMeasureSpec,heightMeasureSpec)

        var height = getScrollViewHeight(context)
        if(height == 0) {
           height = MeasureSpec.getSize(heightMeasureSpec)
        }

        setMeasuredDimension(MeasureSpec.getSize(widthMeasureSpec),height)
    }

    private fun getScrollViewHeight(context: Context) : Int {
        if(childCount > 0) {
            var sumH = 0
            for(index in 0 until childCount) {
                sumH += getChildAt(index).measuredHeight
            }

            val min = dp2px(context,129)
            val max = dp2px(context,219)

            NSLog.d("AnnounceNestScrollView : ","min = $min , max = $max , sumH = $sumH")

            if(sumH < min) {
                return min
            }

            if(sumH > max) {
                return max
            }
            return sumH
        }

        return 0
    }
}