package com.ninexiu.sixninexiu.audio

import android.app.Activity
import android.app.Dialog
import android.content.DialogInterface
import android.text.TextUtils
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.bean.UploadTokenResult
import com.ninexiu.sixninexiu.common.net.NSGsonObjectNewCallback
import com.ninexiu.sixninexiu.common.net.NSRequestParams
import com.ninexiu.sixninexiu.common.net.NsOkHttpClient
import com.ninexiu.sixninexiu.common.util.Constants
import com.ninexiu.sixninexiu.common.util.MyToast
import com.ninexiu.sixninexiu.common.util.NSLog
import com.ninexiu.sixninexiu.common.util.Utils
import com.ninexiu.sixninexiu.view.dialog.BaseDialog
import com.ninexiu.sixninexiu.view.fitterViewSize
import com.qiniu.android.storage.UpCompletionHandler
import com.qiniu.android.storage.UploadOptions
import kotlinx.android.synthetic.main.dialog_audio_record.*
import org.json.JSONException
import java.io.File
import java.util.*

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/04/22
 *     desc   : 录音对话框
 *     version: 1.0
 * </pre>
 */
class AudioRecordDialog(val context: Activity) : BaseDialog(context) {
    override fun getContentView() = R.layout.dialog_audio_record

    private val widthScreen: Int by lazy {
        context.resources?.displayMetrics?.widthPixels ?: 0
    }


    private var audioPath: String = ""
    private var audioDuration = 0
    var onRecordVoiceSucceed: ((voiceUrl: String, voiceDuration: Int) -> Unit)? = null
    override fun initView() {
        super.initView()

        audioRecordViewCopy.setActivity(context)

        // 适配
        llContainer.post {
            fitterViewSize(llContainer, { (widthScreen * 0.83).toInt() })
        }

        // 录音初始化
        audioRecordViewCopy.setStatus(AudioRecordViewCopy.STATUS_INIT)

        // 录音完成回调
        audioRecordViewCopy.audioComplete = { audioFilePath, duration ->
            NSLog.d("AudioRecordDialog : ", "path : $audioFilePath , duration : $duration")
            audioPath = audioFilePath
            audioDuration = duration
            getUploadAudioToken()
        }

        iv_record_close?.setOnClickListener {
            dismissDialog()
            dismiss()
        }
    }


    /**
     * 发表语音动态 1. 获取token
     */
    private fun getUploadAudioToken() {
        showDialog()
        val params = NSRequestParams()
        params.put("suffix", "mp3")
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_SAY_HI_UPLOAD_VOICE_TOKEN, params, object : NSGsonObjectNewCallback<UploadTokenResult?>() {
            override fun onSuccess(statusCode: Int, responseString: String, message: String, response: UploadTokenResult?) {
                if (statusCode == 200 && response != null && response.data != null && response.data.size > 0) {
                    val uploadToken = response.data[0]
                    if (!TextUtils.isEmpty(uploadToken.key) && !TextUtils.isEmpty(uploadToken.token)) {
                        upLoadAudioQINiu(uploadToken.key, uploadToken.token)
                    } else {
                        MyToast.MakeToast("音频上传失败，请重试")
                        dismissDialog()
                    }
                } else {
                    MyToast.MakeToast("音频上传失败，请重试")
                    dismissDialog()
                }
            }

            override fun onFailure(statusCode: Int, errorMsg: String) {
                MyToast.MakeToast("音频上传失败，请重试")
                dismissDialog()
            }
        })
    }


    /**
     * 发表语音动态 2. 上传到七牛
     */
    private fun upLoadAudioQINiu(key: String, token: String) {
        NSLog.d("upLoadAudio : ", "key : $key , token : $token")
        if (TextUtils.isEmpty(audioPath) || audioDuration <= 0) {
            dismissDialog()
            MyToast.MakeToast("音频上传失败，请重试")
            return
        }
        val audioFile = File(audioPath)
        if (!audioFile.exists()) {
            dismissDialog()
            MyToast.MakeToast("音频上传失败，请重试")
            return
        }
        val params: MutableMap<String, String> = HashMap()
        params["x:cat"] = "0"
        val options = UploadOptions(params, null, false, null, null)
        NineShowApplication.getQiNiuUpLoadManager()
                .put(audioFile, key, token, UpCompletionHandler { key, info, response ->
                    try {
                        if (response != null) {
                            if (response.optBoolean("success")) {
                                val audioQiNiuUrl = response.getString("photourl")
                                if (!TextUtils.isEmpty(audioQiNiuUrl)) {
                                    onRecordVoiceSucceed?.invoke(audioQiNiuUrl,audioDuration)
                                    dismissDialog()
                                    dismiss()
                                }
                            } else {
                                dismissDialog()
                                MyToast.MakeToast("音频上传失败，请重试")
                            }
                        }
                    } catch (e: JSONException) {
                        dismissDialog()
                        MyToast.MakeToast("音频上传失败，请重试")
                        e.printStackTrace()
                    }
                }, options)
    }


    /**
     * 显示loading
     */
    private var mDilaog: Dialog? = null
    private fun showDialog() {
        if (context == null) {
            return
        }
        if (mDilaog == null) {
            mDilaog = Utils.showProgressDialog(context, "正在上传...", false)
            mDilaog!!.show()
        } else {
            mDilaog!!.show()
        }
    }

    /**
     * 关闭loading
     */
    private fun dismissDialog() {
        if (context == null) {
            return
        }
        if (!context.isFinishing && mDilaog != null && mDilaog!!.isShowing) {
            mDilaog!!.dismiss()
        }
    }

    override fun setOnBackgroundDismiss(): Boolean {
        return false
    }


    override fun onDismiss(dialog: DialogInterface?) {
        super.onDismiss(dialog)

        // 释放
        audioRecordViewCopy.releaseAudioRecorder()
    }


}