package com.ninexiu.sixninexiu.view

import android.annotation.SuppressLint
import android.content.Context
import android.util.AttributeSet
import android.view.View
import com.ninexiu.sixninexiu.common.util.NSLog

/**
 * <pre>
 *     @author : hpf
 *     time   : 2020/12/01
 *     desc   : 通用倒计时
 *     version: 1.0
 * </pre>
 */
class CountDownTextView @JvmOverloads constructor(context: Context, attrs: AttributeSet? = null, defStyleAttr: Int = 0) : androidx.appcompat.widget.AppCompatTextView(context, attrs, defStyleAttr) {
    private var prefix: String? = null                      // 计时前缀
    private var postfix: String? = null                     // 计时后缀
    private var endText: String? = null                     // 计时结束后显示文字
    private var cutDownRule: ((Long) -> String)? = null     // 计时规则
    private var time: Long = 0L                             // 倒计时时长

    var timeOver: (() -> Unit)? = null                      // 计时结束后回调

    var runnable = Runnable {
        --time
        setTime()
    }

    // 开始倒计时，设置前缀和后缀
    fun startCutDown(pre: String? = null, post: String? = null, timeCut: Long? = null, endT: String? = null, rule: ((Long) -> String)? = ::formatTimeMinute) {
        // 用户传入数据为空
        if (timeCut == null) {
            removeCallbacks(runnable)
            visibility = View.GONE
            return
        }

        removeCallbacks(runnable)       // 移除之前的倒计时消息

        this.prefix = pre
        this.postfix = post
        this.endText = endT
        this.time = timeCut
        this.cutDownRule = rule

        setTime()
    }

    @SuppressLint("SetTextI18n")
    private fun setTime() {
        // 正常计时结束
        if (time <= 0L) {
            removeCallbacks(runnable)
            timeOver?.invoke()              // 计时结束回调
            text = endText ?: ""
            return
        }

        visibility = View.VISIBLE

        // 设置倒计时 [可以自定义计时规则 cutDownRule]
        text = "${prefix ?: ""}${cutDownRule?.invoke(time)}${postfix ?: ""}"

        postDelayed(runnable, 1000L)
    }

    private val oneHour = 60 * 60

    // 默认时间转换规则[自己可以添加] : 格式化时间 (小于1天情况)
    private fun formatTime(time: Long): String {
        val lsTime = time.toInt()
        val hour = lsTime / oneHour
        val minute = lsTime / 60 % 60  // / :先转换成秒  % : 过滤出小时
        val second = lsTime % 60

        return "${timeToString(hour)}:${timeToString(minute)}:${timeToString(second)}"
    }

    // 分钟的转换
    private fun formatTimeMinute(time: Long) : String {
        val lsTime = time.toInt()
        val minute = lsTime / 60 % 60
        val second = lsTime % 60

        return "${timeToString(minute)} : ${timeToString(second)}"
    }

    public fun timeToString(time: Int): String {
        return if (time < 10) {
            "0${time}"
        } else {
            time.toString()
        }
    }


    override fun onDetachedFromWindow() {
        super.onDetachedFromWindow()
        removeCallbacks(runnable)
    }
}