package com.ninexiu.sixninexiu.view

import android.app.Dialog
import android.text.TextUtils
import com.ninexiu.sixninexiu.common.util.NSLog

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/08/20
 *     desc   :
 *     1. 需要控制显示的dialog提前创建好，加入进来
 *     2. 正在显示的dialog消失的时候,需要调用dialogDismissAndShowNext
 *     3. 扩展
 *     version: 1.0
 * </pre>
 */
object DialogOrderHelper {
    private const val Tag = "DilaogOrderHelper : "

    // 是否开始按顺序显示所有的对话框 (允许用户中断)
    private var isStart: Boolean = true

    // 控制集合
    private val list = mutableListOf<DialogSingle>()

    // 创建需要控制的dialog
    fun createDialog(dialog: Dialog, identity: String): DialogSingle {
        val single = DialogSingle(dialog, identity)
        addDialog(single)
        return single
    }

    // 添加控制的dialog
    fun addDialog(dialogSingle: DialogSingle) {
        val findIndex = list.indexOfFirst { it.identity == dialogSingle.identity }   // 防止dialog重复创建，重复添加进入集合
        if(findIndex == -1) {
            list.add(dialogSingle)
        }else {
            list.removeAt(findIndex)
            list.add(findIndex,dialogSingle)
        }
    }

    /**
     * @param preIdentity : 当前显示的dialog的标识
     * 先将当前显示的dialog的alreadyShow修改，然后显示下一个dialog
     */
    fun dialogDismissAndShowNext(preIdentity: String, showNext: Boolean? = true) {
        next {
            var preDialog = list.find { it.identity == preIdentity }
            // 修改当前dialog状态(不一定能找寻到,所以后面采取轮询方式，不再使用index)
            preDialog?.run {
                dialog = null
            }

            list.remove(preDialog)
            preDialog = null

            showNext?.let {
                // 显示下一个dialog
                if (it) showNext() else isStart = false
            }
        }
    }

    private fun showNext() {
        next {
            val currentShowDialog = list.find { it.dialog != null}
            currentShowDialog?.dialog?.show()
        }
    }

    // 显示某一个对话框(不继续向下显示)
    fun showDialog(identity: String) {
        dialogDismissAndShowNext(identity,showNext = null)
    }

    private fun next(nextAction: (() -> Unit)? = null): Boolean {
        if (!isStart || list.isNullOrEmpty()) {
            NSLog.d(Tag, "dialog cannot show reason : isStart : $isStart , list : ${list.isNullOrEmpty()}")
            return false
        }

        nextAction?.invoke()

        return true
    }

}

data class DialogSingle(
        // 需要用户提供的字段 : delay & map
        var dialog: Dialog? = null,    // 当前dialog的引用
        val identity: String,         // dialog 标识
)