package com.ninexiu.sixninexiu.view

import android.annotation.SuppressLint
import android.content.Context
import android.graphics.Canvas
import android.graphics.Paint
import android.util.AttributeSet
import androidx.appcompat.widget.AppCompatTextView
import androidx.core.content.ContextCompat
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.common.util.NSLog

/**
 * <pre>
 *     @author : bing
 *     time   : 2021/7/12
 *     desc   :
 *     version: 1.0
 * </pre>
 */
class DynamicTopicIndexView @JvmOverloads constructor(context: Context, attrs: AttributeSet? = null, defStyleAttr: Int = 0) : AppCompatTextView(context, attrs, defStyleAttr) {
    private var mPaint: Paint = Paint()

    private var currentSelect = 0
    private var moveRadio = 0f
    var max = 0
    private var selectWidth = 0

    init {
        val typedArray = context.obtainStyledAttributes(attrs, R.styleable.DynamicTopicIndexView)
        max = typedArray.getInt(R.styleable.DynamicTopicIndexView_max_step, 4)
        selectWidth = typedArray.getDimensionPixelSize(R.styleable.DynamicTopicIndexView_select_width, dp2px(context, 15))
        typedArray.recycle()
    }

    open fun setSelectIndex(index: Int) {
        if (index > max - 1) {
            currentSelect = max - 1
        } else {
            currentSelect = index
        }
        moveRadio=0f
        firstMove=true
        moveright=true
        invalidate()
    }

    private var firstMove = true
    private var moveright = true
    fun updateIndexMove(move:Float){
        if (firstMove) {
            firstMove = false
            moveright = move < 0.5f
        }

        moveRadio = if (moveright) {
            move
        }else{
            move-1
        }
        NSLog.e("DynamicTopicHolder moveRadio"+moveRadio)
        invalidate()
    }


    override fun onMeasure(widthMeasureSpec: Int, heightMeasureSpec: Int) {
        super.onMeasure(widthMeasureSpec, heightMeasureSpec)
    }

    override fun onLayout(changed: Boolean, left: Int, top: Int, right: Int, bottom: Int) {
        super.onLayout(changed, left, top, right, bottom)
    }

    override fun onDraw(canvas: Canvas?) {
        super.onDraw(canvas)

        val stepSize = (measuredWidth - selectWidth) / (max - 1)

        context?.let {
            //画背景
            mPaint.color = ContextCompat.getColor(context, R.color.color_eeeeee)
            canvas?.drawRoundRect(0f, 0f, measuredWidth.toFloat(), measuredHeight.toFloat(), dp2px(context, 2).toFloat(), dp2px(context, 2).toFloat(), mPaint)
            //画选中
            mPaint.color = ContextCompat.getColor(it, R.color.color_ff567b)
            canvas?.drawRoundRect(stepSize * currentSelect.toFloat()+moveRadio*stepSize, 0f, stepSize * currentSelect.toFloat()+selectWidth+moveRadio*stepSize, measuredHeight.toFloat(), dp2px(context, 2).toFloat(), dp2px(context, 2).toFloat(), mPaint)
        }
    }
}