package com.ninexiu.sixninexiu.view

import android.annotation.SuppressLint
import android.content.Context
import android.graphics.*
import android.util.AttributeSet
import android.widget.LinearLayout
import androidx.appcompat.widget.AppCompatTextView
import com.ninexiu.sixninexiu.R

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/06/17
 *     desc   : 渐变 TextView
 *     version: 1.0
 * </pre>
 */
@SuppressLint("Recycle")
class GradientTextView @JvmOverloads constructor(context: Context, attrs: AttributeSet? = null, defStyleAttr: Int = 0) : AppCompatTextView(context, attrs, defStyleAttr) {
    private var startColor: Int
    private var endColor: Int
    private var origination: Int

    init {
        val attrs = context.obtainStyledAttributes(attrs, R.styleable.GradientTextView)
        startColor = attrs.getColor(R.styleable.GradientTextView_start_color, -1)
        endColor = attrs.getColor(R.styleable.GradientTextView_end_color, -1)

        origination = attrs.getInt(R.styleable.GradientTextView_android_orientation, 0)
        attrs.recycle()
    }

    @SuppressLint("DrawAllocation")
    override fun onDraw(canvas: Canvas?) {
        val str: String? = text?.toString()
        if (startColor == -1 || endColor == -1 || str == null) {
            super.onDraw(canvas)
            return
        }

        // val rect = Rect()

       /* val myPaint = paint
        myPaint.getTextBounds(str, 0, str.length, rect)
*/

        val position = floatArrayOf(0f,1.0f)

        // 设置渐变，方向
        val gradient = LinearGradient(0f,
                0f,
                if (origination == LinearLayout.HORIZONTAL) measuredWidth.toFloat() else 0f,
                if (origination == LinearLayout.VERTICAL) measuredHeight.toFloat() else 0f,
                intArrayOf(startColor, endColor),
                //intArrayOf(Color.RED, Color.GREEN, Color.BLUE),
                position,
                Shader.TileMode.CLAMP)
        paint.shader = gradient

        super.onDraw(canvas)
       // canvas?.drawText(str, (measuredWidth - rect.width()) / 2f, (measuredHeight + rect.height()) / 2f, myPaint)
    }
}