package com.ninexiu.sixninexiu.view

import android.app.Activity
import android.content.Context
import android.text.TextUtils
import android.util.AttributeSet
import android.view.LayoutInflater
import android.view.View
import android.widget.FrameLayout
import android.widget.RelativeLayout
import androidx.recyclerview.widget.LinearLayoutManager
import com.blankj.utilcode.util.ToastUtils
import com.google.gson.GsonBuilder
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.adapter.HotWordAdapter
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.bean.ChatMessageConstants
import com.ninexiu.sixninexiu.bean.HotWord
import com.ninexiu.sixninexiu.bean.HotWordListBean
import com.ninexiu.sixninexiu.common.ConfigSpHelper
import com.ninexiu.sixninexiu.common.net.NSGsonObjectNewCallback
import com.ninexiu.sixninexiu.common.net.NSRequestParams
import com.ninexiu.sixninexiu.common.net.NsOkHttpClient
import com.ninexiu.sixninexiu.common.statistics.StatisticsEventID
import com.ninexiu.sixninexiu.common.statistics.StatisticsUtil
import com.ninexiu.sixninexiu.common.util.Constants
import com.ninexiu.sixninexiu.common.util.CountTechnology.TDEventMap
import com.ninexiu.sixninexiu.common.util.CountTechnology.TDEventName
import com.ninexiu.sixninexiu.common.util.LiveBaseInterface
import com.ninexiu.sixninexiu.common.util.NSLog
import com.ninexiu.sixninexiu.common.util.Utils
import com.ninexiu.sixninexiu.fragment.MBLiveChatFragment
import com.ninexiu.sixninexiu.login.LoginEntryActivity
import kotlinx.android.synthetic.main.view_hot_word_room.view.*
import java.util.*

class HotWordRoomView(context: Context, attrs: AttributeSet?, defStyleAttr: Int) : FrameLayout(context, attrs, defStyleAttr) {
    constructor(context: Context) : this(context, null)
    constructor(context: Context, attrs: AttributeSet?) : this(context, attrs, 0)

    companion object {
        const val Tag = "HotWord"
        const val TYPE_LIVE_ROOM = 1//直播间底部，每次进入房间时显示，打开过一次输入框后，隐藏快捷消息
        const val TYPE_LIVE_ROOM_INPUT = 2//输入框dialog，每次都有


        /**
         * 存储或清除底部热词数据
         * 1. 用户每进入一个直播间，存储一次(防止后期热词随房间而变化)
         * 2. 用离开房间清除数据
         */
        fun saveOrCleanHotWordData(isClear : Boolean = false , data : HotWordListBean? = null){
            NSLog.d(Tag, "是否清除房间数据 : $isClear")
            if(isClear) {
                ConfigSpHelper.getInstance().hotWordData = null
                return
            }

            data?:return

            val builder = GsonBuilder().create()
            try {
                val hotData = builder.toJson(data)
                ConfigSpHelper.getInstance().hotWordData = hotData
            } catch (e: Exception) {
                NSLog.d(Tag, "用户热词数据解析失败")
            }
        }

        /**
         * 获取热词数据
         */
        fun getHotWordData() : HotWordListBean? {
            val data = ConfigSpHelper.getInstance().hotWordData
            if (TextUtils.isEmpty(data) || data.isBlank()) {
                return null
            }

            val builder = GsonBuilder().create()
            return try {
                return builder.fromJson(data, HotWordListBean::class.java)
            } catch (e: Exception) {
                null
            }
        }
    }

    init {
        LayoutInflater.from(getContext()).inflate(R.layout.view_hot_word_room, this)
    }

    private var type = TYPE_LIVE_ROOM_INPUT
    private var fragment: LiveBaseInterface? = null
    private lateinit var hotWordAdapter: HotWordAdapter
    private var listHeight = 0
    fun initOnce(type: Int, fragment: LiveBaseInterface) {
        this.type = type
        this.fragment = fragment

        hotWordAdapter = HotWordAdapter(context, type, ArrayList())
        rv_hot_word.layoutManager = LinearLayoutManager(context, LinearLayoutManager.HORIZONTAL, false)
        rv_hot_word.adapter = hotWordAdapter

        hotWordAdapter.onHotWordClick = { _, hotWord ->
            var roomSendFast = TDEventMap.getLiveRoomEventMapIntValue(TDEventName.LIVE_ROOM_SEND_FAST)
            roomSendFast++
            TDEventMap.putLiveRoomEventMapIntValue(TDEventName.LIVE_ROOM_SEND_FAST,roomSendFast)
            sendChatMsgLive(hotWord)

        }
        getHotWordList()
    }


    // 用于直播间发送消息
    fun sendChatMsgLive(word : HotWord) {
        val content = word.chatWord
        // 聊天
        if (NineShowApplication.mUserBase == null) {
            Utils.startLogin(context as Activity, LoginEntryActivity.FROM_LIVEROOM)
            return
        }

        if (TextUtils.isEmpty(content)) {
            return
        }

        if (null != fragment && null != fragment!!.talkUtil && null != NineShowApplication.mUserBase) {
            StatisticsUtil.onEvent(StatisticsEventID.UM_LIVEROOM_PUBLIC_CHAT_GUIDE_HOTWORD)
            if(word.id != null) {
                // 将热词id带上，用户svg动画
                fragment!!.talkUtil.sendMessage(NineShowApplication.mUserBase, content, hashMapOf(ChatMessageConstants.HOT_WORD_ID to word.id))
            }else {
                fragment!!.talkUtil.sendMessage(content,NineShowApplication.mUserBase)
            }
        }
    }

    fun setViewShowState(show: Boolean) {
        if(isStop) {
            return
        }
        resetChatListHeight(show)
        setVisible(show)
    }

    // 此view是否在直播间内不再显示
    var isStop = false

    fun resetChatListHeight(show: Boolean){
        if (type == TYPE_LIVE_ROOM && fragment != null && fragment is MBLiveChatFragment) {
            val mbLiveChatFragment = fragment as MBLiveChatFragment
            if (mbLiveChatFragment.mChatListLv != null) {
                if (show) {
                    val lp = mbLiveChatFragment.mChatListLv?.layoutParams as RelativeLayout.LayoutParams
                    lp.addRule(RelativeLayout.ABOVE, R.id.hotword_view)
                    NSLog.e("ns_live_video ${lp.height}")
                    if (lp.height > 0) {
                        listHeight = lp.height
                        lp.height -= dp2px(context, 38)
                        mbLiveChatFragment.mChatListLv?.layoutParams = lp
                        postDelayed({
                            mbLiveChatFragment.smoothToBottom()
                        }, 500)
                    } else {
                        postDelayed({
                            resetChatListHeight(show)
                        }, 200)

                    }
                } else {
                    if (visibility == View.VISIBLE) {
                        val lp = mbLiveChatFragment.mChatListLv?.layoutParams as RelativeLayout.LayoutParams
                        lp.addRule(RelativeLayout.ABOVE, R.id.footer_view)
                        lp.height = listHeight
                        mbLiveChatFragment.mChatListLv?.layoutParams = lp
                        postDelayed({
                            mbLiveChatFragment.smoothToBottom()
                        }, 500)
                    }
                }
            }
        }
    }


    /**
     * 获取热词列表
     */
    private fun getHotWordList() {
        val dataStore = getHotWordData()

        // 先从存储数据中获取
        if(dataStore?.data != null && dataStore.data.isNotEmpty()) {
            NSLog.d(Tag, "热词 --> 缓存数据")
            hotWordAdapter.hotwordList.clear()
            hotWordAdapter.hotwordList.addAll(dataStore.data)
            hotWordAdapter.notifyDataSetChanged()
            setViewShowState(true)
            return
        }

        if (fragment == null) {
            return
        }
        val params = NSRequestParams()
        params.put("rid", fragment!!.roomId)
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_ROOM_HOT_WORD_LIST, params, object : NSGsonObjectNewCallback<HotWordListBean>() {
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: HotWordListBean?) {
                if (response != null && response.code == 200) {
                    NSLog.d(Tag, "热词 --> 接口数据")
                    hotWordAdapter.hotwordList.clear()
                    hotWordAdapter.hotwordList.addAll(response.data)
                    hotWordAdapter.notifyDataSetChanged()
                    setViewShowState(true)
                    // 存储更新数据
                    saveOrCleanHotWordData(data = response)
                } else {
                    setViewShowState(false)
                }
            }

            override fun onFailure(statusCode: Int, errorMsg: String) {
                ToastUtils.showShort(errorMsg)
            }
        })
    }

    // 用户退出房间清除数据
    override fun onDetachedFromWindow() {
        NSLog.d(Tag, "onDetachedFromWindow")
        super.onDetachedFromWindow()
        saveOrCleanHotWordData(isClear = true)
    }

    /*override fun onAttachedToWindow() {
        NSLog.d(Tag, "onAttachedToWindow")
        super.onAttachedToWindow()
    }

    override fun onSaveInstanceState(): Parcelable? {
        NSLog.d(Tag, "onSaveInstanceState")
        return super.onSaveInstanceState()
    }

    override fun onRestoreInstanceState(state: Parcelable?) {
        NSLog.d(Tag, "onRestoreInstanceState")
        super.onRestoreInstanceState(state)
    }*/
}