package com.ninexiu.sixninexiu.view

import android.animation.ArgbEvaluator
import android.animation.ValueAnimator
import android.annotation.SuppressLint
import android.content.Context
import android.graphics.Canvas
import android.graphics.Paint
import android.graphics.Rect
import android.os.Build
import android.util.AttributeSet
import android.util.Log
import android.view.View
import android.view.animation.AccelerateDecelerateInterpolator
import androidx.annotation.RequiresApi
import com.ninexiu.sixninexiu.common.util.NSLog
import java.util.*

/**
 * <pre>
 *     @author : hpf
 *     time   : 2020/12/26
 *     desc   : 声音动画 : 这里先不做成动态的
 *     version: 1.0
 * </pre>
 */
@RequiresApi(Build.VERSION_CODES.LOLLIPOP)
class InputVoiceWaveView @JvmOverloads constructor(context: Context, attrs: AttributeSet? = null, defStyleAttr: Int = 0) : View(context, attrs, defStyleAttr) {
    companion object {
        const val Tag = "InputVoiceWaveView >> "

        // 设置基础缩放比例 & 增量缩放比例 : 可通过控制两者实现不同波形
        const val BASE_RATIO = 2
        const val STEP_RATIO = 2

        // 设置基础值
         val baseValue = arrayOf(5, 6, 6, 8)
        // val baseValue = arrayOf(5, 6, 6, 8, 8, 9)

        // 设置增量值
        val stepValue = arrayOf(2, 6, 10, 14)
        //val stepValue = arrayOf(3, 5, 6, 6, 7, 7)

        // 矩形条目个数
        const val COUNT = 40

        // 基础数组，增量数组size
        const val SIZE = 4

        // 设置矩形绘制间距
        const val DIVIDER = 14

        // 设置矩形宽度
        const val ITEM_RECT_WIDTH = 3

        // 刷新时间
        const val TIME = 150L
    }

    private val paint = Paint()

    init {
        paint.isAntiAlias = true
        paint.isDither = true
        paint.style = Paint.Style.FILL
        paint.strokeCap = Paint.Cap.ROUND
        paint.strokeWidth = 5f
    }

    // 最小宽度
    private val minViewWidth = COUNT * (DIVIDER + ITEM_RECT_WIDTH) - DIVIDER

    // 最小高度
    private val minHeight = baseValue[baseValue.size - 1] + stepValue[stepValue.size - 1] * (SIZE - 1)

    override fun onMeasure(widthMeasureSpec: Int, heightMeasureSpec: Int) {
        val specModeW = MeasureSpec.getMode(widthMeasureSpec)
        var specSizeW = MeasureSpec.getSize(widthMeasureSpec)

        val specModeH = MeasureSpec.getMode(heightMeasureSpec)
        var specSizeH = MeasureSpec.getSize(heightMeasureSpec)

        if (specModeW == MeasureSpec.AT_MOST && specModeH == MeasureSpec.AT_MOST) {
            specSizeH = minHeight
            specSizeW = minViewWidth
        } else if (specModeW == MeasureSpec.AT_MOST) {
            specSizeW = minViewWidth
        } else if (specModeH == MeasureSpec.AT_MOST) {
            specSizeH = minHeight
        }

        setMeasuredDimension(specSizeW, specSizeH)
    }


    private val colorList = mutableListOf<Int>()
    override fun onFinishInflate() {
        super.onFinishInflate()
        // 设置颜色
        val animator = ValueAnimator.ofArgb(-0x1b68f, -0x6f85)
        animator.interpolator = AccelerateDecelerateInterpolator()
        animator.setEvaluator(ArgbEvaluator())
        animator.addUpdateListener {
            Log.d(Tag, "valueAnimator : ${it.animatedValue}")
            colorList.add(it.animatedValue as? Int ?: 0)
        }
        animator.start()

    }

    @SuppressLint("DrawAllocation")
    override fun onDraw(canvas: Canvas?) {
        super.onDraw(canvas)
        if (allWaveValues.size < COUNT) {
            return
        }

        // 找到25个中最大的高度的矩形
        val maxRectHeight = allWaveValues.maxOrNull()

        maxRectHeight ?: return

        // 颜色补充
        if (colorList.size in 1 until COUNT) {
            setColorList()
        }

        NSLog.d("color_list_size : ","${colorList.size} -> $COUNT")

        // 计算开始位置 left
        val start = (width - minViewWidth) / 2

        // 绘制矩形
        for (index in 0 until COUNT) {
            val itemTop = (height - allWaveValues[index]) / 2
            val rect = Rect(start + index * (DIVIDER + ITEM_RECT_WIDTH), itemTop, start + index * (DIVIDER + ITEM_RECT_WIDTH) + ITEM_RECT_WIDTH, itemTop + allWaveValues[index])

            // 设置颜色
            if (index >= colorList.size) {
                paint.color = colorList[colorList.size - 1]
            } else {
                paint.color = colorList[index]
            }
            canvas?.drawRect(rect, paint)
        }
    }

    // 存储最小值到最大值(一个5个数量级)
    private val values = mutableListOf<Int>()

    // 所有的条目(做动画的矩形共25个)
    private val allWaveValues = mutableListOf<Int>()

    private fun choseBase(index: Int) {
        if (index > SIZE - 1) {
            return
        }
        // 1. 选取一个基础值和一个增量值
        val base = baseValue[index] * BASE_RATIO
        val step = stepValue[index] * STEP_RATIO

        // 2. 得到一个范围数组，里面有5个数值，变化从这个5个选择
        values.clear()
        for (index in 0 until SIZE) {
            // Log.d(Tag, "values : ${base + step * index}")
            values.add(base + step * index)
        }

        // 3. todo : 删除 获取最大和最小值
        val min = values[0]
        val max = values[SIZE - 1]

        // 4. 为中间的条目选取一个起始值(这里得到的是范围数组中的index),然后依次向两边递加或递减
        val middleIndex = Random().nextInt(SIZE)

        // 5. 为25个条目全部赋值(分为 : 中间向两边递加/递减)
        /**
         * 1. 区分递加或递减方式
         * 2. 如果index最大，只能递减，如果index为最小，只能递加
         */
        var isAdd = middleIndex == 0 || Random().nextInt(2) == 0
        val tempAdd = isAdd

        val currentIndex = COUNT / 2  // 当前25个矩形中的中间下标

        allWaveValues.clear()
        // todo : test
        for (i in 0 until COUNT) {
            allWaveValues.add(i, 0)
        }

        var tempIndex = middleIndex
        allWaveValues[COUNT / 2] = values[middleIndex]  // 设置中间值
        for (step in 1..COUNT / 2) {
            val preIndex = currentIndex - step
            val postIndex = currentIndex + step

            // 当前应该设置的范围数组的下标
            val indexTest = if (isAdd) {
                if (tempIndex + 1 == SIZE) {
                    tempIndex -= 1
                    isAdd = false
                } else {
                    tempIndex += 1
                }
                tempIndex
            } else {
                if (tempIndex - 1 < 0) {
                    tempIndex += 1
                    isAdd = true
                } else {
                    tempIndex -= 1
                }
                tempIndex
            }

            Log.d("TestWaveView >> ", "$isAdd , index 取值范围 : $indexTest")

            val shouldValue = values[indexTest]

            if (preIndex < 0 || postIndex > COUNT - 1) {
                break
            }
            /**
             * 递增
            D/InputVoiceWaveView >>: 取值范围 : choseIndex : 3 ,  base : 5 , step : 3 , values : [5, 8, 11, 14, 17]
            D/InputVoiceWaveView >>: 中间取值 : randomIndex : index : 2 , value : 11
            D/InputVoiceWaveView >>: 所有数组 : isAdd : true , allValues : [11, 14, 17, 14, 11, 8, 5, 8, 11, 14, 17, 14, 11(中间), 14, 17, 14, 11, 8, 5, 8, 11, 14, 17, 14, 11]

             * 递减
            取值范围 : choseIndex : 2 ,  base : 4 , step : 3 , values : [4, 7, 10, 13, 16]
            中间取值 : randomIndex : index : 1 , value : 7
            所有数组 : isAdd : false , allValues : [13, 10, 7, 4, 7, 10, 13, 16, 13, 10, 7, 4, 7(中间), 4, 7, 10, 13, 16, 13, 10, 7, 4, 7, 10, 13]
             */
            allWaveValues[preIndex] = shouldValue
            allWaveValues[postIndex] = shouldValue
        }

        // test : 打印所有数值
        /*Log.d(Tag, "取值范围 : choseIndex : $index ,  base : $base , step : $step , values : $values")
        Log.d(Tag, "中间取值 : randomIndex : index : $middleIndex , value : ${values[middleIndex]}")
        Log.d(Tag, "所有数组 : isAdd : $tempAdd , allValues : $allWaveValues")*/

        // 6. 刷新
        invalidate()
        // postDelayed(runnable, TIME)
    }

    // 补全颜色集合 (选取原颜色集合中的1/3作为补全标准)
    private fun setColorList() {

        while (colorList.size in 1 .. COUNT) {
            colorList.add(0,colorList[0])
        }
        /*val size = colorList.size
        if (size == 0) {
            return
        }

        val dis = COUNT - size

        // 选取1/3作为颜色补充
        val supplyColorSize = size / 3

        if (supplyColorSize <= 0) {
            return
        }

        // 计算一种颜色应该补充多少
        val supplyEverySize = dis / supplyColorSize + 1

        if (supplyEverySize <= 0) {
            return
        }

        val startIndex = (size - supplyColorSize) / 2
        val endIndex = startIndex + supplyColorSize - 1

        val tempList = mutableListOf<Int>()
        for (index in 0 until colorList.size) {
            if (index in startIndex..endIndex) {
                for (addIndex in 0 until supplyEverySize) {
                    tempList.add(colorList[index])
                }
            }
            tempList.add(colorList[index])
        }
        colorList.clear()
        colorList.addAll(tempList)
        tempList.clear()*/
        /* Log.d(Tag,"colorApply >> 颜色集合大小 : ${colorList.size}")
         Log.d(Tag,"colorApply >> 差距 : $dis , 1/3多少 : $supplyColorSize , 一种颜色补多少 : $supplyEverySize")
         Log.d(Tag,"colorApply >> size : ${tempList.size} $tempList")*/
    }

    private val runnable: Runnable = Runnable {
        choseBase(Random().nextInt(SIZE))
    }

    // 结束
    fun endVoiceInput() {
        removeCallbacks(runnable)
    }

    private var start = System.currentTimeMillis()

    // 开始
    fun startVoiceInput(volume: Int) {
        val upDateMillis = System.currentTimeMillis()
        if(upDateMillis - start >= 80) {
            choseBase(volumeTranslate(volume))
            start = upDateMillis
        }
    }

    private fun volumeTranslate(volume: Int): Int {
        return when (volume) {
            in 0..3 -> {
                0
            }
            in 4..7 -> {
                1
            }
            in 8..11 -> {
                2
            }
            else -> {
                SIZE - 1
            }
        }
    }


}
