package com.ninexiu.sixninexiu.view

import android.app.Activity
import android.content.Context
import android.text.TextUtils
import android.util.AttributeSet
import android.view.LayoutInflater
import android.widget.FrameLayout
import androidx.recyclerview.widget.LinearLayoutManager
import com.blankj.utilcode.util.ToastUtils
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.adapter.liveroom.ContributionTopUserAdapter
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.bean.*
import com.ninexiu.sixninexiu.common.net.NSGsonObjectCallback
import com.ninexiu.sixninexiu.common.net.NSRequestParams
import com.ninexiu.sixninexiu.common.net.NsOkHttpClient
import com.ninexiu.sixninexiu.common.util.*
import com.ninexiu.sixninexiu.common.util.Constants
import com.ninexiu.sixninexiu.common.util.LiveBaseInterface
import com.ninexiu.sixninexiu.common.util.MBOperationManager
import com.ninexiu.sixninexiu.common.util.Utils
import com.ninexiu.sixninexiu.login.LoginEntryActivity
import kotlinx.android.synthetic.main.view_liveroom_contribution_users.view.*

/**
 * 颜色上下渐变的textview
 */
class LiveRoomContributionUsersView @JvmOverloads constructor(context: Context, attrs: AttributeSet? = null, defStyleAttr: Int = 0) : FrameLayout(context, attrs, defStyleAttr) {


    private val userList = mutableListOf<ContributionTopUser>()
    private lateinit var roomInfo: RoomInfo
    private lateinit var fragment: LiveBaseInterface
    private var contributionUserAdapter: ContributionTopUserAdapter

    init {
        LayoutInflater.from(getContext()).inflate(R.layout.view_liveroom_contribution_users, this)

        rv_contribution_user.layoutManager = LinearLayoutManager(context, LinearLayoutManager.HORIZONTAL, false)
        contributionUserAdapter = ContributionTopUserAdapter(context, userList)
        rv_contribution_user.adapter = contributionUserAdapter

        contributionUserAdapter.onUserClick = { user ->
            if (NineShowApplication.mUserBase == null) {
                Utils.startLogin(context as Activity, LoginEntryActivity.FROM_LIVEROOM)
            } else {
                showUserInfoDialog(user.uid, "")
            }
        }
    }

    fun setRoomInfo(roomInfo: RoomInfo, fragment: LiveBaseInterface) {
        this.roomInfo = roomInfo
        this.fragment = fragment
        getContributionUserList(roomInfo.rid.toLong())
    }

    /**
     * 获取贡献用户列表
     */
    fun getContributionUserList(rid: Long) {
        val params = NSRequestParams()
        params.put("rid", rid)
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_LIVEROOM_TOP_CONTRIBUTION_USER, params, object : NSGsonObjectCallback<ContributionTopUserListBean?>() {

            override fun onSuccess(statusCode: Int, rawJsonResponse: String?, response: ContributionTopUserListBean?) {
                if (response != null && response.code == 200) {
                    if (response.data.count > 0) {
                        tv_contribution_user_count.setVisible(true)
                        tv_contribution_user_count.text = Utils.formatViewerNum(response.data.count.toDouble())
                    }

                    if (!response.data.data.isNullOrEmpty()) {
                        refreshContributionUsers(response.data)
                    }

                }

            }

            override fun onFailure(statusCode: Int, errorMsg: String) {
                ToastUtils.showShort(errorMsg)
            }

        })
    }


    fun refreshContributionUsers(users: ContributionTopUserList) {
        /*if (users.size<4){
            rv_contribution_user.layoutParams.width = dp2px(context,42)*users.size
        }else{
            rv_contribution_user.layoutParams.width = dp2px(context,200)-tv_contribution_user_count.width
        }*/
        tv_contribution_user_count.setVisible(true)
        tv_contribution_user_count.text = Utils.formatViewerNum(users.count.toDouble())
        userList.clear()
        users.data?.let { userList.addAll(it) }
        contributionUserAdapter.notifyDataSetChanged()
    }


    fun showUserInfoDialog(uid: String, name: String?) {
        // 登录用户是主播
        if (NineShowApplication.mUserBase != null) {
            if (NineShowApplication.mUserBase!!.uid == roomInfo.artistuid.toLong()) {
                // 用户是主播
                if (!TextUtils.isEmpty(uid) && uid == roomInfo.artistuid.toString() + "") {
                    MBOperationManager.create().showPersonalDialog(context as Activity, fragment,
                            UserBean(null, null, roomInfo, MBOperationManager.MB_LIVE, MBOperationManager.MBOP_ANCHOR,
                                    MBOperationManager.MBOP_ANCHOR_TYPE))
                } else {
                    // 登录人主播 被操作人（观众）不是主播
                    MBOperationManager.create().showPersonalDialog(context as Activity, fragment,
                            UserBean(null, UserBase(Utils.parseLong(uid), name), roomInfo, MBOperationManager.MB_LIVE, MBOperationManager.MBOP_USER,
                                    MBOperationManager.MBOP_ANCHOR_TYPE))
                }
            } else {
                if (!TextUtils.isEmpty(uid) && uid == roomInfo.artistuid.toString() + "") { // 观众是主播
                    MBOperationManager.create().showPersonalDialog(context as Activity, fragment,
                            UserBean(null, null, roomInfo, MBOperationManager.MB_LIVE, MBOperationManager.MBOP_ANCHOR,
                                    if (NineShowApplication.mUserBase!!.managerLevel > 0) 2 else 3))
                } else { // 观众不是主播
                    MBOperationManager.create().showPersonalDialog(context as Activity, fragment,
                            UserBean(null, UserBase(Utils.parseLong(uid), name), roomInfo, MBOperationManager.MB_LIVE, MBOperationManager.MBOP_USER,
                                    if (NineShowApplication.mUserBase!!.managerLevel > 0) 2 else 3))
                }
            }
        }
    }


}