package com.ninexiu.sixninexiu.view

import android.content.Context
import android.graphics.drawable.Drawable
import android.text.TextUtils
import android.util.AttributeSet
import android.view.LayoutInflater
import android.view.View
import android.widget.FrameLayout
import android.widget.ImageView
import android.widget.TextView
import androidx.constraintlayout.widget.ConstraintSet
import androidx.vectordrawable.graphics.drawable.Animatable2Compat
import com.bumptech.glide.Glide
import com.bumptech.glide.load.DataSource
import com.bumptech.glide.load.engine.GlideException
import com.bumptech.glide.load.resource.gif.GifDrawable
import com.bumptech.glide.request.RequestListener
import com.bumptech.glide.request.target.Target
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.bean.RoomInfo
import com.ninexiu.sixninexiu.common.util.NSLog
import com.ninexiu.sixninexiu.common.util.RoomUtils
import com.ninexiu.sixninexiu.view.shape.RoundRelativeLayout
import com.opensource.svgaplayer.SVGACallback
import com.opensource.svgaplayer.SVGAParser
import com.opensource.svgaplayer.SVGAVideoEntity
import kotlinx.android.synthetic.main.view_mb_liveroom_footer.view.*

/**
 * 引导用户吹大哥牛逼
 */
class MBLiveRoomFooterView(context: Context, attrs: AttributeSet?, defStyleAttr: Int) : FrameLayout(context, attrs, defStyleAttr), View.OnClickListener {
    constructor(context: Context) : this(context, null)
    constructor(context: Context, attrs: AttributeSet?) : this(context, attrs, 0)

    var isFirst = true   //是否第一次播放动画
    private lateinit var roomInfo: RoomInfo
//    private var gifDrawableResource: GifDrawable? = null
    private val mSVGAParser: SVGAParser by lazy {
        SVGAParser(context)
    }

    init {
        LayoutInflater.from(getContext()).inflate(R.layout.view_mb_liveroom_footer, this)
    }

    public fun initByRoomType(roomInfo: RoomInfo) {
        this.roomInfo = roomInfo
        if (roomInfo.roomType == RoomUtils.ROOM_TYPE_MORE_AUDIO || roomInfo.roomType == RoomUtils.ROOM_TYPE_SINGLE_AUDIO) {//语音房
            iv_voiceroom_public_chat.setVisible(true)
            rl_voiceroom_mic.setVisible(true)
            tv_liveroom_public_chat.setVisible(false)


        } else {
            val constraintSet = ConstraintSet()
            constraintSet.clone(cl_footer_container)
            constraintSet.clear(R.id.iv_liveroom_more, 6)
            constraintSet.clear(R.id.iv_liveroom_private_chat, 6)

            constraintSet.connect(R.id.iv_liveroom_more, ConstraintSet.END, R.id.liveroom_svga_rl, ConstraintSet.START, dp2px(context, 10))
            constraintSet.connect(R.id.iv_liveroom_private_chat, ConstraintSet.END, R.id.iv_liveroom_more, ConstraintSet.START, dp2px(context, 10))
            constraintSet.applyTo(cl_footer_container)

            iv_liveroom_more.setVisible(true)
            iv_liveroom_private_chat.setVisible(true)
        }

        if (!TextUtils.isEmpty(NineShowApplication.liveroom_public_chat_hint)) {
            getPublicChatTv().text = NineShowApplication.liveroom_public_chat_hint
        }

        //公聊
        iv_voiceroom_public_chat.setOnClickListener(this)
        tv_liveroom_public_chat.setOnClickListener(this)
        //私聊
        iv_liveroom_private_chat.setOnClickListener(this)
        //更多
        iv_liveroom_more.setOnClickListener(this)
        //语音房表情
        iv_voiceroom_phiz.setOnClickListener(this)
        //语音房心动
        iv_voiceroom_heart_stage.setOnClickListener(this)
        //语音房pk
        iv_voiceroom_teampk.setOnClickListener(this)
        //语音房麦位
        rl_voiceroom_mic.setOnClickListener(this)
        //竞拍
        iv_liveroom_bidding.setOnClickListener(this)
        //送礼
        liveroom_svga_rl.setOnClickListener(this)

        iv_liveroom_svga.callback = object:SVGACallback{
            override fun onPause() {
            }

            override fun onRepeat() {
            }

            override fun onStep(frame: Int, percentage: Double) {
//                if(View.VISIBLE == iv_liveroom_gift.visibility){
//                    iv_liveroom_gift.visibility = View.INVISIBLE
//                }
//                if(View.INVISIBLE == iv_liveroom_svga.visibility){
//                    iv_liveroom_svga.visibility = View.VISIBLE
//                }
            }

            override fun onFinished() {
//                iv_liveroom_gift.postDelayed({ iv_liveroom_gift.visibility = View.VISIBLE
//                    iv_liveroom_svga.visibility = View.INVISIBLE },800)


//                iv_liveroom_svga.setImageResource(R.drawable.icon_live_room_gift_normal)
            }

        }
    }

    public fun show(view: View?) {
        view.setVisible(true)
    }

    public fun gone(view: View?) {
        view.setVisible(false)
    }

    //表情view
    fun getPhizView(): View {
        return iv_voiceroom_phiz
    }

    //表情view
    fun getMoreView(): ImageView {
        return iv_liveroom_more
    }

    //公聊
    fun getPublicChatIv(): ImageView {
        return iv_voiceroom_public_chat
    }

    fun getPublicChatTv(): TextView {
        return tv_liveroom_public_chat
    }

    //私聊未读数
    fun getPrivateChatUnread(): TextView {
        return tv_liveroom_private_chat_unread
    }

    //更多红点
    fun getMoreRedPoint(): TextView {
        return tv_liveroom_more_red
    }

    //礼物
    fun getGiftView(): ImageView {
        return iv_liveroom_svga
    }

    //礼物
    fun getGiftViewLayout(): RoundRelativeLayout {
        return liveroom_svga_rl
    }

    //礼物未读数
    fun getGiftUnread(): View {
        return tv_liveroom_gift_unread
    }

    //麦位容器
    fun getMicContainer(): View {
        return rl_voiceroom_mic
    }

    //麦位 有新申请
    fun getMicTag(): ImageView {
        return iv_voiceroom_mic_tag
    }

    //语音 心动
    fun getVoiceHeartIcon(): ImageView {
        return iv_voiceroom_heart_stage
    }

    // 语音  pk
    fun getVoicePkIcon(): ImageView {
        return iv_voiceroom_teampk
    }

    //语音 拍卖
    fun getBiddingView(): ImageView {
        return iv_liveroom_bidding
    }

    //设置
    fun startAnimator() {

        if(isFirst){
            mSVGAParser.decodeFromAssets("icon_live_room_gift" + ".svga", callback)
        }else{
//            iv_liveroom_svga.visibility = View.VISIBLE
            iv_liveroom_svga.startAnimation()
//            iv_liveroom_gift.visibility = View.INVISIBLE
        }
//        Glide.with(this).asGif().load(R.drawable.icon_liveroom_gift).listener(object : RequestListener<GifDrawable> {
//            override fun onLoadFailed(e: GlideException?, model: Any?, target:  Target<GifDrawable>?, isFirstResource: Boolean): Boolean {
//                iv_liveroom_gift.setImageResource(R.drawable.icon_liveroom_gift_normal)
//                return false
//            }
//
//            override fun onResourceReady(resource: GifDrawable, model: Any?, target:  Target<GifDrawable>?, dataSource: DataSource?, isFirstResource: Boolean): Boolean {
//                resource.setLoopCount(1)//设置循环次数
//                resource.registerAnimationCallback(object : Animatable2Compat.AnimationCallback() {
//                    override fun onAnimationEnd(drawable: Drawable?) {
//                        //gif播放完毕回调
//                        iv_liveroom_gift.setImageResource(R.drawable.icon_liveroom_gift_normal)
//                    }
//
//                    override fun onAnimationStart(drawable: Drawable?) {
//                        //gif播放开始回调
//                    }
//                })
//                resource.start()
//                return false
//            }
//        }).into(iv_liveroom_gift)
    }

    override fun onClick(v: View?) {
        onFooterClick?.invoke(v)
    }

    var onFooterClick: ((view: View?) -> Unit)? = null

    private val callback = object : SVGAParser.ParseCompletion {
        override fun onComplete(videoItem: SVGAVideoEntity) {
            iv_liveroom_svga.setVideoItem(videoItem)
            iv_liveroom_svga.visibility = View.VISIBLE
            iv_liveroom_svga.startAnimation()
            iv_liveroom_gift.visibility = View.INVISIBLE
            isFirst = false
        }

        override fun onError() {
            iv_liveroom_svga.visibility = View.INVISIBLE
            iv_liveroom_gift.visibility = View.VISIBLE
        }

    }
}