package com.ninexiu.sixninexiu.view

import android.content.Context
import android.text.TextUtils
import android.util.AttributeSet
import android.view.LayoutInflater
import android.view.MotionEvent
import android.view.View
import android.view.ViewConfiguration
import androidx.constraintlayout.widget.ConstraintLayout
import com.blankj.utilcode.util.ScreenUtils
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.bean.MidAutumnReunionBean
import com.ninexiu.sixninexiu.common.net.NSGsonObjectNewCallback
import com.ninexiu.sixninexiu.common.net.NSRequestParams
import com.ninexiu.sixninexiu.common.net.NsOkHttpClient
import com.ninexiu.sixninexiu.common.util.Constants
import com.ninexiu.sixninexiu.common.util.GlideUtils
import kotlinx.android.synthetic.main.view_mid_autumn_reunion.view.*

/**
 * <pre>
 *     @author : hetao
 *     time   : 2021/08/30
 *     desc   : 中秋团圆照view
 *     version: 1.0
 * </pre>
 */
class MidAutumnReunionView @JvmOverloads constructor(context: Context, attrs: AttributeSet? = null, defStyleAttr: Int = 0) : ConstraintLayout(context, attrs, defStyleAttr) {

    private var margin = 0
    var lastY = 0
    private var downY = 0f
    private var slop = 0
    private var screenHeight = 0

    init {
        LayoutInflater.from(context).inflate(R.layout.view_mid_autumn_reunion, this)
        margin = NineShowApplication.applicationContext.resources.getDimension(R.dimen.mb_live_video_margin_top).toInt()
        slop = ViewConfiguration.get(getContext()).scaledTouchSlop
        screenHeight = ScreenUtils.getScreenHeight()
    }


    fun requestData(rid: String) {
        val params = NSRequestParams()
        params.put("rid", rid)
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_AUTUMN_REUNION, params, object : NSGsonObjectNewCallback<MidAutumnReunionBean?>() {
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: MidAutumnReunionBean?) {
                try {
                    if (statusCode == 200) {
                        if (response?.code == 200) {
                            visibility = View.VISIBLE
                            if (TextUtils.equals(response.data?.userNcikName, "神秘人")) {
                                user_avatar.setImageResource(R.drawable.sendgift_mystery_head_icon_new)
                            } else {
                                GlideUtils.loadCirclePic(context, response.data?.userImg, user_avatar)
                            }
                            GlideUtils.loadCirclePic(context, response.data?.anchorImg, anchor_avatar)
                        } else {
                            visibility = View.GONE
                        }

                    } else {
                        visibility = View.GONE
                    }
                } catch (e: Exception) {
                    e.printStackTrace()
                }
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                try {
                    visibility = View.GONE
                } catch (e: Exception) {
                    e.printStackTrace()
                }
            }

        })
    }


    override fun dispatchTouchEvent(event: MotionEvent?): Boolean {
        parent.requestDisallowInterceptTouchEvent(true)
        return super.dispatchTouchEvent(event)
    }

    override fun onTouchEvent(event: MotionEvent?): Boolean {
        val y = event?.rawY?.toInt()
        when (event?.action) {
            MotionEvent.ACTION_DOWN -> downY = event.rawY
            MotionEvent.ACTION_MOVE -> {
                //计算y坐标上的差值
                //要平移的y值
                if (event.rawY < lastY && event.rawY - margin < event.y) {
                    return false
                }
                if (event.rawY > lastY && event.rawY + height - event.y + margin > screenHeight) {
                    return false
                }
                val max: Float = screenHeight - event.rawY - height + event.y + translationY - margin
                val min: Float = event.y - event.rawY + translationY + margin
                val deltaY: Int = y?.minus(lastY) ?: 0
                val tranY = translationY + deltaY
                translationY = if (tranY > max) {
                    max
                } else if (tranY < min) {
                    min
                } else {
                    tranY
                }
            }
            MotionEvent.ACTION_UP -> {
                val v1 = event.rawY - downY
                if (Math.abs(v1) < slop) {
                    performClick()
                }
            }
            else -> {
            }
        }
        if (y != null) {
            lastY = y
        }
        return true
    }


}