package com.ninexiu.sixninexiu.view

import android.animation.Animator
import android.animation.AnimatorSet
import android.animation.ObjectAnimator
import android.animation.ValueAnimator
import android.content.Context
import android.graphics.Bitmap
import android.graphics.BitmapFactory
import android.graphics.NinePatch
import android.graphics.Rect
import android.graphics.drawable.Drawable
import android.graphics.drawable.NinePatchDrawable
import android.os.Build
import android.text.Spannable
import android.text.SpannableStringBuilder
import android.text.TextUtils
import android.util.AttributeSet
import android.util.TypedValue
import android.view.Gravity
import android.view.LayoutInflater
import android.view.View
import android.view.animation.LinearInterpolator
import android.widget.FrameLayout
import android.widget.ImageView
import android.widget.TextView
import androidx.annotation.RequiresApi
import androidx.core.content.ContextCompat
import androidx.lifecycle.LifecycleOwner
import com.bumptech.glide.Glide
import com.bumptech.glide.request.target.CustomTarget
import com.bumptech.glide.request.target.SimpleTarget
import com.bumptech.glide.request.target.Target
import com.bumptech.glide.request.transition.Transition
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.bean.ChatMessage
import com.ninexiu.sixninexiu.bean.DressUpGoods
import com.ninexiu.sixninexiu.bean.DressUpTab
import com.ninexiu.sixninexiu.common.httphelp.StoreHelper
import com.ninexiu.sixninexiu.common.util.*
import com.ninexiu.sixninexiu.common.util.gift.DressUpVideoManager
import com.ninexiu.sixninexiu.common.util.gift.LiveRoomGiftView
import com.ninexiu.sixninexiu.view.shape.RoundFrameLayout
import kotlinx.android.synthetic.main.layout_my_dressup_badge.view.*
import kotlinx.android.synthetic.main.layout_my_dressup_bubble.view.*
import kotlinx.android.synthetic.main.layout_my_dressup_car.view.*
import kotlinx.android.synthetic.main.layout_my_dressup_enterroom.view.*
import kotlinx.android.synthetic.main.layout_my_dressup_enterroom.view.iv_light
import kotlinx.android.synthetic.main.layout_my_dressup_enterroom.view.tv_enter_content
import kotlinx.android.synthetic.main.layout_my_dressup_enterroom.view.tv_enter_level
import kotlinx.android.synthetic.main.layout_my_dressup_frame.view.*
import kotlinx.android.synthetic.main.layout_my_dressup_infocard.view.*
import kotlinx.android.synthetic.main.layout_my_dressup_mic_circle.view.*
import java.io.File
import java.io.FileInputStream

/**
 * <pre>
 *     @author : bing
 *     time   : 2021/8/31
 *     desc   :
 *     version: 1.0
 * </pre>
 */
class MyDressUpFrameView @JvmOverloads constructor(context: Context, attrs: AttributeSet? = null) : RoundFrameLayout(context, attrs) {


    //    private lateinit var liveGiftVideoManager: LiveGiftVideoManager

    //头像框装扮的view
    private val frameDressupView: View by lazy {
        LayoutInflater.from(context).inflate(R.layout.layout_my_dressup_frame, this, false)
    }

    //座驾装扮的view
    private val carDressupView: View by lazy {
        LayoutInflater.from(context).inflate(R.layout.layout_my_dressup_car, this, false)
    }

    //徽章装扮的view
    private val badgeDressupView: View by lazy {
        LayoutInflater.from(context).inflate(R.layout.layout_my_dressup_badge_2, this, false)
    }

    //发言气泡的view
    private val bubbleDressupView: View by lazy {
        LayoutInflater.from(context).inflate(R.layout.layout_my_dressup_bubble, this, false)
    }

    //资料卡的view
    private val infoCardDressupView: View by lazy {
        LayoutInflater.from(context).inflate(R.layout.layout_my_dressup_infocard, this, false)
    }

    //麦位光圈的view
    private val micCircleDressupView: View by lazy {
        LayoutInflater.from(context).inflate(R.layout.layout_my_dressup_mic_circle, this, false)
    }


    //进房特效的view
    private val enterRoomDressupView: View by lazy {
        LayoutInflater.from(context).inflate(R.layout.layout_my_dressup_enterroom, this, false)
    }

    /**
     * 根据类型添加不同的view
     */
    fun initDressupView(dressUpTab: DressUpTab, dressUpGoods: List<DressUpGoods>?, video_dress_up_anim: LiveRoomGiftView, isDress: Boolean) {
        animSet?.let {
            animSet?.removeAllListeners()
            animSet?.cancel()
            animSet = null
        }
        removeAllViews()
        when (dressUpTab.id) {
            1 -> {//头像框
                addView(frameDressupView)
                NineShowApplication.mUserBase?.let {
                    GlideUtils.loadCirclePic(context, it.avatarUrl120, frameDressupView.iv_dressup_avatar)
                }
                if (!dressUpGoods.isNullOrEmpty()) {
                    NewSvgaFrameUtil.getInstance().startAnimator(frameDressupView.svga_dressup_frame, dressUpGoods[0].frame_id)
                } else {
                    frameDressupView.svga_dressup_frame?.stopAnimation(true)
//                    frameDressupView.svga_dressup_frame?.clearAnimation()
                }

            }
            2 -> {//座驾
                addView(carDressupView)
                if (!dressUpGoods.isNullOrEmpty()) {
                    GlideUtils.loadNormalPic(context, dressUpGoods[0].imgurl, carDressupView.iv_my_dressup_car, R.drawable.icon_my_dressup_car_default)

                    dressUpGoods[0].gid?.let { carId ->
                        carDressupView.iv_my_dressup_car_play?.setVisible(dressUpGoods[0].is_resources == 1 || !TextUtils.isEmpty(AppInitDownloadResHelper.getVersion(carId, AppInitDownloadResHelper.CAR_MP4_TYPE)))
                        carDressupView.iv_my_dressup_car_play?.setOnClickListener {
                            DressUpVideoManager.INSTANCE.startPlay(video_dress_up_anim, carId)
                        }
                    }

                } else {
                    carDressupView.iv_my_dressup_car?.setImageResource(R.drawable.icon_my_dressup_car_default)
                    carDressupView.iv_my_dressup_car_play?.visibility = View.GONE
                }
            }
            3 -> {//徽章
                addView(badgeDressupView)
                badgeDressupView.tv_my_dressup_badge?.let {
                    if (!dressUpGoods.isNullOrEmpty()) {
                        setBadgeData(it, dressUpGoods, isDress)
                    } else {
                        setBadgeData(it, null, false)
                    }
                }

            }
            4 -> {//聊天气泡
                addView(bubbleDressupView)

                NineShowApplication.mUserBase?.let {
                    bubbleDressupView.tv_nickname.text = it.nickname
                    setBadgeData(bubbleDressupView.tv_nickname, null, false)
                }

                if (!dressUpGoods.isNullOrEmpty()) {
                    dressUpGoods[0].chat_path?.let { paths ->
                        if (paths.size >= 5) {
                            for ((index, path) in paths.withIndex()) {
                                if (!TextUtils.isEmpty(path)) {
                                    if (cl_bubble_container.getChildAt(index) is ImageView) {
                                        val bubbleImg = bubbleDressupView.cl_bubble_container.getChildAt(index) as ImageView
                                        if (index != 0) {
                                            Glide.with(context).asBitmap().load(path).into(object : CustomTarget<Bitmap?>() {
                                                override fun onLoadCleared(placeholder: Drawable?) {}
                                                override fun onResourceReady(resource: Bitmap, transition: Transition<in Bitmap?>?) {
                                                    val radio = dp2px(context, 1) / 2.0
                                                    bubbleImg.layoutParams.width = (resource.width * radio).toInt()
                                                    bubbleImg.layoutParams.height = (resource.height * radio).toInt()
                                                    bubbleImg.setImageBitmap(resource)
                                                }
                                            })
                                        } else {
                                            Glide.with(context).asFile().load(path).into(object : CustomTarget<File>() {

                                                override fun onLoadCleared(placeholder: Drawable?) {
                                                }

                                                override fun onResourceReady(resource: File, transition: Transition<in File>?) {
                                                    val bitmap = BitmapFactory.decodeStream(FileInputStream(resource))
                                                    if (bitmap.ninePatchChunk != null && NinePatch.isNinePatchChunk(bitmap.ninePatchChunk)) {
                                                        val npf = NinePatchDrawable(context.resources, bitmap, bitmap.ninePatchChunk, Rect(), null)
                                                        bubbleImg.background = npf
                                                    } else {
                                                        bubbleImg.setImageBitmap(bitmap)
                                                    }
                                                }

                                            })
                                        }
                                    }
                                }
                            }
                        }
                    }
                } else {
                    bubbleDressupView.cl_chat_container.setBackgroundResource(R.drawable.shape_chat_bg)
                    bubbleDressupView.iv_bubble_bg.background = null
                    bubbleDressupView.iv_bubble_bl.setImageDrawable(null)
                    bubbleDressupView.iv_bubble_br.setImageDrawable(null)
                    bubbleDressupView.iv_bubble_tl.setImageDrawable(null)
                    bubbleDressupView.iv_bubble_tr.setImageDrawable(null)
                }
            }
            5 -> {//资料卡
                addView(infoCardDressupView)

                (infoCardDressupView.layoutParams as MarginLayoutParams).leftMargin = dp2px(context, 10)
                (infoCardDressupView.layoutParams as MarginLayoutParams).rightMargin = dp2px(context, 10)
                NineShowApplication.mUserBase?.let {
                    infoCardDressupView.tv_infocard_nickname.text = it.nickname
                    GlideUtils.loadCirclePic(context, it.avatarUrl120, infoCardDressupView.iv_infocard_avatar)
                }

                if (!dressUpGoods.isNullOrEmpty()) {
                    GlideUtils.loadNormalImg(context, dressUpGoods[0].nameplate_img, infoCardDressupView.iv_infocard_bg)
                    GlideUtils.loadCirclePic(context, dressUpGoods[0].nameplate_frame, infoCardDressupView.iv_infocard_frame)
                } else {
                    infoCardDressupView.iv_infocard_frame.setImageDrawable(null)
                    infoCardDressupView.iv_infocard_bg.setImageDrawable(null)
                }
            }
            6 -> {//麦位光圈
                addView(micCircleDressupView)

                NineShowApplication.mUserBase?.let {
                    GlideUtils.loadCirclePic(context, it.avatarUrl120, micCircleDressupView.iv_miccircle_avatar)
                }
                if (!dressUpGoods.isNullOrEmpty()) {
                    SvgaCommonUtil.getInstance().initView(context).startAnimator(micCircleDressupView.svga_miccircle, dressUpGoods[0].imgurl)
                } else {
                    micCircleDressupView.svga_miccircle.clearAnimation()
                }
            }
            7 -> {//进房特效
                addView(enterRoomDressupView)

                NineShowApplication.mUserBase?.let {
                    enterRoomDressupView.tv_enter_content.text = "${it.nickname} 进入直播间"
                }
                (enterRoomDressupView.tv_enter_content.layoutParams as MarginLayoutParams).marginStart = dp2px(context, 20)
                if (!dressUpGoods.isNullOrEmpty()) {
                    enterRoomDressupView.tv_enter_level.text = ""
                    Glide.with(context).load(dressUpGoods[0].imgurl).into(enterRoomDressupView.iv_enterroom_bg)
                    if (TextUtils.isEmpty(dressUpGoods[0].special_sao) || TextUtils.isEmpty(dressUpGoods[0].special_icon)) {
                        startEnterAnim(enterRoomDressupView.cl_enterroom_container, true)
                    } else {
                        Glide.with(context).load(dressUpGoods[0].special_icon).into(enterRoomDressupView.iv_star)
                        Glide.with(context).load(dressUpGoods[0].special_sao).into(enterRoomDressupView.iv_light)

                        startEnterAnimMax(enterRoomDressupView.cl_enterroom_container, iv_star, iv_light, true)
                    }
                } else {
                    NineShowApplication.mUserBase?.let {
                        if (it.isVipSeat == 1) {
                            enterRoomDressupView.iv_light.setImageResource(R.drawable.ic_enter_room_light03)
                            enterRoomDressupView.iv_enterroom_bg.setImageResource(R.drawable.bg_rich_man_come_guest)
                            enterRoomDressupView.tv_enter_level.text = "贵宾"
                            startEnterAnimMax(enterRoomDressupView.cl_enterroom_container, iv_star, iv_light, true)
                        } else {
                            enterRoomDressupView.tv_enter_level.text = getLevelName(it.uid, it.wealthlevel)
                            if (it.wealthlevel in 11..22) {//男爵11
                                enterRoomDressupView.iv_light.setImageResource(R.drawable.ic_enter_room_light)
                                enterRoomDressupView.iv_enterroom_bg.setImageResource(R.drawable.bg_rich_man_come_momal)
                                startEnterAnim(enterRoomDressupView.cl_enterroom_container, true)
                            } else if (it.wealthlevel >= 23) {//国王23
                                enterRoomDressupView.iv_light.setImageResource(R.drawable.ic_enter_room_light02)
                                enterRoomDressupView.iv_enterroom_bg.setImageResource(R.drawable.bg_rich_man_come_higher)
                                startEnterAnimMax(enterRoomDressupView.cl_enterroom_container, iv_star, iv_light, true)
                            } else {
                                (enterRoomDressupView.tv_enter_content.layoutParams as MarginLayoutParams).marginStart = dp2px(context, 0)
                                enterRoomDressupView.tv_enter_content.background = ContextCompat.getDrawable(context, R.drawable.shape_5c000000_corner8)
                                enterRoomDressupView.tv_enter_level.text = ""

                            }
                        }
                    }
                }
            }

            else -> {
                context?.let {
                    val textView = TextView(it)
                    textView.setTextColor(ContextCompat.getColor(it, R.color.white))
                    textView.setTextSize(TypedValue.COMPLEX_UNIT_SP, 14f)
                    textView.text = "应用版本过低，请升级版本后查看！"
                    addView(textView)

                    val layoutParams = textView.layoutParams as FrameLayout.LayoutParams
                    // 设置里面的控件的布局和父布局的高度相同
                    layoutParams.height = FrameLayout.LayoutParams.MATCH_PARENT
                    layoutParams.width = FrameLayout.LayoutParams.MATCH_PARENT
                    textView.layoutParams = layoutParams
                    // 设置控件自身的内容居中
                    textView.gravity = Gravity.CENTER
                }
            }
        }
    }

    var animSet: AnimatorSet? = null
    private fun startEnterAnim(view: View, isNew: Boolean) {
        if (animSet != null && !isNew) {
             animSet = animSet?.clone()
        } else {
            animSet = AnimatorSet()
            val screenWidth = NineShowApplication.getScreenWidth(context)
            val mTranslationIn = ObjectAnimator.ofFloat(view, "translationX", screenWidth.toFloat(), 0f)
            mTranslationIn.duration = 500
            val mTranslationOut = ObjectAnimator.ofFloat(view, "translationX", 0f, -screenWidth.toFloat())
            mTranslationOut.duration = 500
            mTranslationOut.startDelay = 1500

            addAnimListener(view)
            animSet?.playSequentially(mTranslationIn, mTranslationOut)
        }
        animSet?.start()
    }

    private fun addAnimListener(view: View) {
        animSet?.addListener(object : Animator.AnimatorListener {
            override fun onAnimationRepeat(animation: Animator?) {
            }

            override fun onAnimationEnd(animation: Animator?) {
//                animSet?.removeAllListeners()
                startEnterAnim(view, false)
            }

            override fun onAnimationCancel(animation: Animator?) {
            }

            override fun onAnimationStart(animation: Animator?) {
            }

        })
    }

    private fun startEnterAnimMax(animRoot: View, starView: View, lightView: View, isNew: Boolean) {
        animRoot.clearAnimation()
        starView.clearAnimation()
        lightView.clearAnimation()
        starView.visibility = View.INVISIBLE
        val screenWidth = NineShowApplication.getScreenWidth(context)
        if (!isNew && animSet != null) {
            animSet = animSet?.clone()
        } else {
            animSet = AnimatorSet()
            val mXLeveIn = ObjectAnimator.ofFloat(animRoot, "translationX", screenWidth.toFloat(), 0f)
            mXLeveIn.duration = 600
            mXLeveIn.addListener(object : Animator.AnimatorListener {
                override fun onAnimationStart(animation: Animator) {}
                override fun onAnimationEnd(animation: Animator) {
                    starView.visibility = View.VISIBLE
                    lightView.visibility = View.VISIBLE
                }

                override fun onAnimationCancel(animation: Animator) {}
                override fun onAnimationRepeat(animation: Animator) {}
            })
            val mXLeveOut = ObjectAnimator.ofFloat(animRoot, "translationX", 0f, -screenWidth.toFloat())
            mXLeveOut.startDelay = 3000
            mXLeveOut.duration = 600
            val fristAnim01 = ObjectAnimator.ofFloat(starView, "scaleX", 0.2f, 1f)
            fristAnim01.duration = 800
            val fristAnim02 = ObjectAnimator.ofFloat(starView, "scaleY", 0.2f, 1f)
            fristAnim02.duration = 800
            val fristAnim11 = ObjectAnimator.ofFloat(starView, "scaleX", 1f, 0.2f)
            fristAnim11.duration = 800
            val fristAnim12 = ObjectAnimator.ofFloat(starView, "scaleY", 1f, 0.2f)
            fristAnim12.duration = 800
            val fristAnim21 = ObjectAnimator.ofFloat(starView, "scaleX", 0.2f, 1.1f)
            fristAnim11.duration = 1400
            val fristAnim22 = ObjectAnimator.ofFloat(starView, "scaleY", 0.2f, 1.1f)
            fristAnim12.duration = 1400
            val mStarAnmSet = AnimatorSet()
            mStarAnmSet.interpolator = LinearInterpolator()
            mStarAnmSet.play(fristAnim01).with(fristAnim02).before(fristAnim11)
            mStarAnmSet.play(fristAnim11).with(fristAnim12).before(fristAnim21)
            mStarAnmSet.play(fristAnim21).with(fristAnim22)
            mStarAnmSet.startDelay = 600
            val mLightOut = ObjectAnimator.ofFloat(lightView, "translationX", 0f, Utils.dip2px(context, 145f).toFloat())
            mLightOut.duration = 1500
            mLightOut.startDelay = 600
            mLightOut.repeatCount = 2
            mLightOut.addListener(object : Animator.AnimatorListener {
                override fun onAnimationStart(animation: Animator) {}
                override fun onAnimationEnd(animation: Animator) {
                    lightView.x = Utils.dip2px(context, 50f).toFloat()
                    lightView.visibility = View.GONE
                    starView.visibility = View.INVISIBLE
                }

                override fun onAnimationCancel(animation: Animator) {}
                override fun onAnimationRepeat(animation: Animator) {}
            })
            animSet?.play(mXLeveIn)?.with(mStarAnmSet)?.with(mLightOut)?.before(mXLeveOut)
            addMaxAnimListener(animRoot, starView, lightView)
        }
        animSet?.start()
    }

    private fun addMaxAnimListener(animRoot: View, starView: View, lightView: View) {
        animSet?.addListener(object : Animator.AnimatorListener {
            override fun onAnimationStart(animation: Animator) {
            }

            override fun onAnimationRepeat(animation: Animator) {}
            override fun onAnimationEnd(animation: Animator) {
//                animSet?.removeAllListeners()
                startEnterAnimMax(animRoot, starView, lightView, false)
            }

            override fun onAnimationCancel(animation: Animator) {
            }
        })
    }


    /**
     * 设置徽章 内容
     */
    private fun setBadgeData(textView: TextView, dressUpGoods: List<DressUpGoods>?, isDress: Boolean) {

        NineShowApplication.mUserBase?.let {
            val badgeSpan = SpannableStringBuilder(it.nickname)

            val levelBitmap = if (it.is_anchor == 1) {
                BitmapFactory.decodeResource(resources, Utils.getHostLevelDrawable(it.creditlevel))
            } else {
                Utils.getUserLevelDrawableCommon(context, it.wealthlevel, it.uid.toString())
            }

            if (levelBitmap != null) {
                badgeSpan.append(" [levelbadge]")
                val userLevelSpan = VerticalImageSpan(context, levelBitmap)
                val start = badgeSpan.indexOf("[levelbadge]")
                val end = start + "[levelbadge]".length
                badgeSpan.setSpan(userLevelSpan, start, end, Spannable.SPAN_INCLUSIVE_EXCLUSIVE)
            }

            if (dressUpGoods.isNullOrEmpty()) {
                textView.text = badgeSpan
            } else {
                for (badge in dressUpGoods) {
                    val drawableId: Int
                    val bitmap: Bitmap?
                    if (TextUtils.equals(badge.badge_id, "20200720003")) {
                        if (TextUtils.isEmpty(badge.url) && badge.dan != null) {
                            drawableId = Utils.getUserRankLevelId(badge.dan.dan, badge.dan.grade, 0)
                            bitmap = BitmapFactory.decodeResource(resources, drawableId)
                        } else {
                            bitmap = GlideUtils.loadBitmapSync(context, badge.url)
                        }
                    } else {
                        drawableId = Utils.getFirstChargeResId(badge.badge_id)
                        bitmap = BitmapFactory.decodeResource(resources, drawableId)
                    }

                    if (bitmap == null) {
                        textView.text = badgeSpan
                        return
                    }

                    badge.badge_id?.let { badgeId ->
                        badgeSpan.append(" ${badgeId}")
                        val badgeBitmapSpan = VerticalImageSpan(context, bitmap)
                        val start = badgeSpan.indexOf(badgeId)
                        badgeSpan.setSpan(badgeBitmapSpan, start, start + badgeId.length, Spannable.SPAN_INCLUSIVE_EXCLUSIVE)
                    }
                }

                textView.text = badgeSpan
            }
        }
    }


    fun getLevelName(uid: Long, level: Int): String? {
        val levelNameDts = context.resources.getStringArray(R.array.user_level_name)
        return if (level < levelNameDts.size) {
            levelNameDts[level]
        } else {
            val userCustomLevels = NineShowApplication.getUserCustomLevelList()
            if (userCustomLevels != null && userCustomLevels.size > 0) {
                for (userCustomLevel in userCustomLevels) {
                    if (userCustomLevel != null && userCustomLevel.uid != 0L && TextUtils.equals("" + uid, userCustomLevel.uid.toString() + "")) {
                        return userCustomLevel.levelName
                    }
                }
            }
            "自封神"
        }
    }

    override fun onDetachedFromWindow() {
        super.onDetachedFromWindow()
//        if (this::liveGiftVideoManager.isInitialized) {
//            liveGiftVideoManager.release()
//        }
    }
}