package com.ninexiu.sixninexiu.view

import android.content.Context
import android.text.TextUtils
import android.util.AttributeSet
import android.widget.ImageView
import android.widget.LinearLayout
import android.widget.RelativeLayout
import android.widget.TextView
import androidx.recyclerview.widget.GridLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.bumptech.glide.Glide
import com.bumptech.glide.Priority
import com.bumptech.glide.request.RequestOptions
import com.chad.library.adapter.base.BaseMultiItemQuickAdapter
import com.chad.library.adapter.base.BaseViewHolder
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.activity.PersonalInforActivity
import com.ninexiu.sixninexiu.audio.AudioVoiceWaveView
import com.ninexiu.sixninexiu.bean.ReadAnchorInfo
import com.ninexiu.sixninexiu.common.util.GlideUtils
import com.ninexiu.sixninexiu.common.util.Utils
import kotlinx.android.synthetic.main.fragment_dynamic_detail_new.*

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/07/13
 *     desc   :
 *     version: 1.0
 * </pre>
 */
class PersonRecentItemView @JvmOverloads constructor(context: Context, attrs: AttributeSet? = null, defStyleAttr: Int = 0) : RecyclerView(context, attrs, defStyleAttr) {
    private val list: MutableList<ReadAnchorInfo> = mutableListOf()
    private val theAdapter = PersonRecentItemAdapter(list)

    init {
        this.layoutManager = GridLayoutManager(context, 4)
        this.adapter = theAdapter
        this.setHasFixedSize(true)
    }

    fun setData(data: List<ReadAnchorInfo>?) {
        if (data.isNullOrEmpty()) {
            return
        }
        val min = 4.coerceAtMost(data.size)     // 最长需要4个item
        this.list.clear()
        this.list.addAll(data.filterIndexed { index, _ -> index < min })
        this.theAdapter.notifyDataSetChanged()
    }
}

class PersonRecentItemAdapter(list: List<ReadAnchorInfo>) : BaseMultiItemQuickAdapter<ReadAnchorInfo, BaseViewHolder>(list) {
    init {
        addItemType(0, R.layout.item_person_recent)
    }

    override fun convert(helper: BaseViewHolder?, item: ReadAnchorInfo?) {
        helper ?: return
        item ?: return
        GlideUtils.loadCirclePic(helper.itemView.context, item.headimage, helper.getView(R.id.ivAnchor), R.drawable.icon_head_default)
        helper.getView<TextView>(R.id.tvName).text = getUserNameRecent(item.nickname)

        val llWave = helper.getView<RelativeLayout>(R.id.llWave)
        val audioVoiceWaveView = helper.getView<ImageView>(R.id.audioVoiceWave)
        if(TextUtils.equals(item.opentime,"")) {    // 未开播
            llWave.setVisible(false)
        }else {
            llWave.setVisible(true)
            GlideUtils.loadCirclePic(helper.itemView.context,R.drawable.ic_personal_living,0,audioVoiceWaveView)
        }

        helper.itemView.setOnClickListener {
            if (Utils.isNotClickable()) { // 处理频繁点击
                return@setOnClickListener
            }

            val roomType = if (!item.roomType.isNullOrBlank()) {
                item.roomType.toInt()
            } else {
                0
            }

            if (!TextUtils.equals(item.opentime,"") || roomType == 4) {
                Utils.openLiveRoom(helper.itemView.context, roomType, item.rid.toString(), if (item.opentime.isNullOrBlank()) 0 else 1, item.nickname)
            } else {
                // 跳转到主播个人主页
                PersonalInforActivity.start(helper.itemView.context, true, item.artistuid.toLong())
            }
        }
    }

    private fun getUserNameRecent(name: String?): String {
        if (!name.isNullOrBlank() && name.length > 5) {
            return name.substring(0, 5) + "..."
        }

        if (name.isNullOrBlank()) {
            return ""
        }

        return name
    }

}