package com.ninexiu.sixninexiu.view

import android.app.Activity
import android.content.Context
import android.graphics.Paint
import android.os.Message
import android.text.TextUtils
import android.util.AttributeSet
import android.util.DisplayMetrics
import android.util.Log
import android.util.TypedValue
import android.view.View
import android.view.ViewGroup
import android.widget.*
import androidx.core.content.ContextCompat
import com.blankj.utilcode.util.ConvertUtils
import com.ninexiu.sixninexiu.BuildConfig
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.bean.ChatMessage
import com.ninexiu.sixninexiu.common.statistics.StatisticsEventID
import com.ninexiu.sixninexiu.common.statistics.StatisticsUtil
import com.ninexiu.sixninexiu.common.util.LiveBaseInterface
import com.ninexiu.sixninexiu.common.util.SafeHandler
import com.ninexiu.sixninexiu.common.util.SafeHandler.IHandlerHost
import com.ninexiu.sixninexiu.common.util.ScreenUtils
import com.ninexiu.sixninexiu.common.util.Utils
import com.ninexiu.sixninexiu.game.GameCenterHelper
import com.ninexiu.sixninexiu.game.Version
import com.ninexiu.sixninexiu.thirdfunc.nextjoy.NjGameSdkUtils
import kotlin.math.max

class RunwayTextView @JvmOverloads constructor(context: Context, attrs: AttributeSet? = null, defStyleAttr: Int = 0) : RelativeLayout(context, attrs, defStyleAttr), IHandlerHost {
    private var mScrollX = 0
    var type = 0
    private var scrollAble = true
    private var mRunwayHandler: SafeHandler? = null
    private var mCurrentRoomType = 0
    private var screenWidth: Int
    private var runwayWidth = 0
    private var currentTextView: TextView? = null
    private var currentTextWidth = 0
    private var isLand = false

    private val paint: Paint by lazy {
        Paint()
    }

    //内容滚动完毕的回调
    var runwayFinish: (() -> Unit)? = null

    override fun handleMessage(msg: Message) {
        when (msg.what) {
            0 -> {
                currentTextView?.scrollTo(mScrollX, 0)
                val distance = currentTextWidth - runwayWidth
                mScrollX += 3
                if (mScrollX > distance) {
                    runwayFinish?.invoke()
                    return
                }
                if (scrollAble) {
                    mRunwayHandler!!.removeMessages(0)
                    mRunwayHandler!!.sendEmptyMessageDelayed(0, 30)
                }
            }
        }
    }

    init {
        screenWidth = getScreenWidth(getContext() as Activity)
    }


    fun setIsScrollable(scrollable: Boolean) {
        scrollAble = scrollable
    }

    /**
     * 开始滚动
     */
    fun startRoll() {
        this.scrollBarStyle = View.SCROLLBARS_INSIDE_OVERLAY
        setIsScrollable(true)
        postDelayed({
            move()
        }, 200)
    }

    /**
     * 滚动位置恢复
     */
    private fun realReset() {
        setIsScrollable(false)
        mScrollX = 0
        type = 0
        removeAllViews()
    }

    fun setLandState(isLand: Boolean) {
        this.isLand = isLand
    }


    /**
     * 创建TextView
     */
    fun createText(add: CharSequence, msg: ChatMessage, runwayWidth: Int) {
        this.runwayWidth = runwayWidth
        realReset()
        paint.textSize = ConvertUtils.sp2px(12f).toFloat()
        currentTextWidth = paint.measureText(add, 0, add.length).toInt() + dp2px(context, 4)
        currentTextView = TextView(context)

        if (isLand) {
            layoutParams.width = ScreenUtils.getScreenWidth(context) / 2
            this.runwayWidth = ScreenUtils.getScreenWidth(context) / 2 - dp2px(context, 20)
        }
        val layoutParams = RelativeLayout.LayoutParams(currentTextWidth, ViewGroup.LayoutParams.WRAP_CONTENT)
        if (isLand || currentTextWidth <= runwayWidth) {
            layoutParams.addRule(RelativeLayout.CENTER_IN_PARENT)
        } else {
            layoutParams.addRule(RelativeLayout.ALIGN_PARENT_LEFT)
            layoutParams.addRule(RelativeLayout.CENTER_VERTICAL)
        }

        currentTextView?.isSingleLine = true
        currentTextView?.layoutParams = layoutParams
        currentTextView?.text = add
        currentTextView?.setTextColor(ContextCompat.getColor(context,R.color.white))
        currentTextView?.setTextSize(TypedValue.COMPLEX_UNIT_SP, 12f)
        currentTextView?.setOnClickListener(TextListenner(msg))
        addView(currentTextView)
    }

    private fun move() {
        if (mRunwayHandler == null) {
            mRunwayHandler = SafeHandler(this)
        }
        mRunwayHandler!!.sendEmptyMessage(0)
    }


    private inner class TextListenner(private val chatMessage: ChatMessage) : OnClickListener {
        private val rid: String = chatMessage.rid
        private val roomType: Int = chatMessage.roomType
        private val gameName: String = chatMessage.gameName
        override fun onClick(view: View) {
            baseInterface?.let {
                if (NineShowApplication.mUserBase == null) {
                    Utils.startLogin(view.context as Activity, resources.getString(R.string.live_login_game))
                    return
                }
                StatisticsUtil.onEvent(StatisticsEventID.LIVEROOM_RUNWAY_CLICK)
                if (BuildConfig.DEBUG && TextUtils.equals(chatMessage.type, "30")) { //明日捕鱼的强制跳转
                    NjGameSdkUtils.startGameActivity(context as Activity?, "https://mtest.game.nextjoy.com/gameCenter/index.html#/gameMain?gid=38&pid=520&screenType=0")
                    return
                }
                if ("99001" == chatMessage.rid) { //只有这个地方做了这样的处理。
                    if (Utils.enterZodiaRoom(view.context)) {
                        it.finish()
                    }
                } else if (TextUtils.equals("明日捕鱼", chatMessage.gameName) || TextUtils.equals("捕鱼达人", chatMessage.gameName)) {
                    // 20 - 多彩九点，明日捕鱼，九秀捕鱼;2 - 砸金蛋; 18 - 动感足球; 26 - 大航海; 29 - 蓄力飞镖
                    Log.d("msgid", "getGameName = " + chatMessage.gameName)
                    onActionGame(view, chatMessage.gameName)
                } else {
                    if (TextUtils.isEmpty(rid) || "0" == rid || TextUtils.equals(it.roomId, rid)) {
                        return
                    }
                    Utils.openLiveRoom(context, mCurrentRoomType, roomType, rid, 1, "")
                }
            }
        }

    }

    /**
     * 游戏跳转
     * @param view
     * @param gameName
     */
    private fun onActionGame(view: View, gameName: String) {
        if (NineShowApplication.mUserBase == null) {
            Utils.startLogin(view.context as Activity, resources.getString(R.string.live_login_game))
        } else {
            val gameVersionList = GameCenterHelper.getRoomVersionListData()
            var currentGame: Version? = null
            for (i in gameVersionList.indices) {
                val version = gameVersionList[i]
                if (TextUtils.equals(version.game_name, gameName)) {
                    currentGame = version
                    break
                }
            }
            if (null != currentGame && null != baseInterface && null != baseInterface!!.roomInfo) {
                GameCenterHelper.onClick(view.context as Activity, currentGame, baseInterface!!.roomInfo, GameCenterHelper.GAME_TYPE_LIVE, true)
            }
        }
    }

    private var baseInterface: LiveBaseInterface? = null

    fun setBaseInterface(baseInterface: LiveBaseInterface?, roomType: Int) {
        mCurrentRoomType = roomType
        this.baseInterface = baseInterface
    }


    fun release() {
        if (mRunwayHandler != null) {
            mRunwayHandler!!.removeCallbacksAndMessages(null)
        }
    }

    companion object {
        private const val TAG = "TextViewRunway"
        fun getScreenWidth(activity: Activity): Int {
            val metrics = DisplayMetrics()
            activity.windowManager.defaultDisplay.getMetrics(metrics)
            return metrics.widthPixels
        }
    }
}