package com.ninexiu.sixninexiu.view

import android.annotation.SuppressLint
import android.content.Context
import android.util.AttributeSet
import android.view.MotionEvent
import android.view.VelocityTracker
import android.widget.FrameLayout
import com.ninexiu.sixninexiu.common.util.NSLog
import com.ninexiu.sixninexiu.lib.magicindicator.buildins.UIUtil
import kotlin.math.abs

/**
 * <pre>
 *     @author : hpf
 *     time   : 2020/12/01
 *     desc   : 可全局滑动的View
 *     version: 1.0
 * </pre>
 */
class SlideUserReturnFrameLayout @JvmOverloads constructor(context: Context, attrs: AttributeSet? = null, defStyleAttr: Int = 0) : FrameLayout(context, attrs, defStyleAttr) {
    private val mScreenWidth: Int by lazy {
        context.resources.displayMetrics.widthPixels
    }

    private val mScreenHeight: Int by lazy {
        context.resources.displayMetrics.heightPixels
    }

    private var start = 0L
    private var downX = 0
    private var downY = 0

    // measureHeight和measureWidth == 0 ？？
    override fun onFinishInflate() {
        super.onFinishInflate()
        // 设置初始化位置
        y = (mScreenHeight - measuredHeight - UIUtil.dip2px(context, 160.0)).toFloat()  // 99+49+19
        x = ((mScreenWidth - measuredWidth - UIUtil.dip2px(context, 85.0)).toFloat())  //72+10
    }

    var onUserReturnClick: (() -> Unit)? = null

    private var velocityTracker: VelocityTracker? = null


    private var trackerX: Int = 0
    private var trackerY: Int = 0


    @SuppressLint("ClickableViewAccessibility")
    override fun onTouchEvent(event: MotionEvent?): Boolean {
        if (velocityTracker == null) {
            velocityTracker = VelocityTracker.obtain()
        }
        // velocityTracker ?: VelocityTracker.obtain()

        velocityTracker?.addMovement(event)

        val actionX = event?.x?.toInt() ?: 0
        val actionY = event?.y?.toInt() ?: 0

        when (event?.action) {
            MotionEvent.ACTION_DOWN -> {
                start = System.currentTimeMillis()
                downX = event.x.toInt()
                downY = event.y.toInt()
            }

            MotionEvent.ACTION_MOVE -> {
                val disX = actionX - downX
                val disY = actionY - downY

                val resultX = x + disX
                val resultY = y + disY

                if (resultX <= 0 || resultX >= (mScreenWidth - measuredWidth)) {
                    return false
                }

                if (resultY <= 0 || resultY >= (mScreenHeight - measuredHeight)) {
                    return false
                }

                translationX = x + disX
                translationY = y + disY

                velocityTracker?.computeCurrentVelocity(500)

                trackerX = velocityTracker?.xVelocity?.toInt() ?: 0
                trackerY = velocityTracker?.yVelocity?.toInt() ?: 0
            }

            MotionEvent.ACTION_UP -> {
                NSLog.d("SlideUserReturnFrameLayout >> ", "trackerX : $trackerX , trackerY : $trackerY")

                if (abs(trackerX) < 50 && abs(trackerY) < 50 && System.currentTimeMillis() - start < 500) {
                    NSLog.d("SlideUserReturnFrameLayout >> ", "onclick")
                    onUserReturnClick?.invoke()
                } else {
                    NSLog.d("SlideUserReturnFrameLayout >> ", "move")
                }

                trackerX = 0
                trackerY = 0
                velocityTracker?.recycle()
                velocityTracker = null
            }
        }
        return true
    }

    override fun onDetachedFromWindow() {
        super.onDetachedFromWindow()
        velocityTracker?.recycle()
        velocityTracker = null
    }

}