package com.ninexiu.sixninexiu.view

import android.content.Context
import android.content.Intent
import android.os.Bundle
import android.text.Spannable
import android.text.SpannableStringBuilder
import android.text.TextPaint
import android.text.TextUtils
import android.text.method.LinkMovementMethod
import android.text.style.ClickableSpan
import android.util.AttributeSet
import android.view.View
import androidx.appcompat.widget.AppCompatTextView
import androidx.core.content.ContextCompat
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.activity.TranslucentSubPageActivity
import com.ninexiu.sixninexiu.bean.Topic
import com.ninexiu.sixninexiu.common.util.SmileyParser
import com.ninexiu.sixninexiu.common.util.Utils
import com.ninexiu.sixninexiu.fragment.topic.DynamicTopicDetailsFragment
import kotlin.math.max
import kotlin.math.min

/**
 * <pre>
 *     @author : bing
 *     time   : 2021/7/16
 *     desc   :
 *     version: 1.0
 * </pre>
 */
class TopicTextView @JvmOverloads constructor(context: Context, attrs: AttributeSet? = null, defStyleAttr: Int = 0) : AppCompatTextView(context, attrs, defStyleAttr) {
    val TAG = "TopicTextView"

    private val mParser: SmileyParser by lazy {
        SmileyParser.getInstance()
    }


    /**
     * 设置输入内容 话题颜色
     * @param content
     * @return
     */
    fun buildClickableTopicText(content: String?, currentTopic: Topic?, topics: List<Topic>?) {
        if (content.isNullOrEmpty()){
            return
        }

        val builder: SpannableStringBuilder = mParser.addSmileySpans1(content) as SpannableStringBuilder
        if (topics.isNullOrEmpty()) {//没有话题
            text = builder
            return
        }

        movementMethod = LinkMovementMethod.getInstance()

        var lastIndex = 0
        while (content.indexOf("#", lastIndex) >= 0) {
            lastIndex = content.indexOf("#", lastIndex)

            var nextIndex = 0
            val nextIndexTemp1 = content.indexOf("#", lastIndex + 1)
            var nextIndexTemp2 = content.indexOf(" ", lastIndex)
            val nextIndexTemp3 = content.indexOf("[", max(0, lastIndex - 1))
            val nextIndexTemp4 = content.indexOf("]", lastIndex)
            val nextIndexTemp5 = content.indexOf("\n", lastIndex)
            if (nextIndexTemp3 >= 0 && nextIndexTemp4 > 0 && nextIndexTemp3 == lastIndex - 1 && nextIndexTemp4 - nextIndexTemp3 < 15 && content.substring(nextIndexTemp3, nextIndexTemp4).contains("#img")) {
                lastIndex = nextIndexTemp4
                continue
            }
            if (nextIndexTemp2 >= 0 && nextIndexTemp5 >= 0) {
                nextIndexTemp2 = min(nextIndexTemp2, nextIndexTemp5)
            } else if (nextIndexTemp2 < 0 && nextIndexTemp5 >= 0) {
                nextIndexTemp2 = nextIndexTemp5
            }
            //前两种情况有大于0
            if (nextIndexTemp1 > 0 && nextIndexTemp2 > 0) {
                if (lastIndex == nextIndexTemp2 - 1) {
                    //输入# 直接输入空格
                    lastIndex = nextIndexTemp2
                    continue
                }
                nextIndex = min(nextIndexTemp1, nextIndexTemp2)
            } else if (nextIndexTemp1 > 0) {
                nextIndex = nextIndexTemp1
            } else if (nextIndexTemp2 > 0) {
                if (lastIndex == nextIndexTemp2 - 1) {
                    //输入# 直接输入空格
                    lastIndex = nextIndexTemp2
                    continue
                }
                nextIndex = nextIndexTemp2
            }
            //处理第三种情况
            if (nextIndex > 0 && nextIndexTemp3 > 0) {
                nextIndex = min(nextIndex, nextIndexTemp3)
            } else if (nextIndexTemp3 > 0) {
                nextIndex = nextIndexTemp3
            }
            //三种情况都不大于0
            if (nextIndex == 0) {
//                nextIndex = min(lastIndex + 13, content.length)
                nextIndex = content.length
            }

//            nextIndex = min(nextIndex, lastIndex + 36)

            val topicStr = content.substring(lastIndex + 1, nextIndex).trim()
            for (topic in topics) {
                if (TextUtils.equals(topicStr, topic.title)) {
                    builder.setSpan(TopicClickSpan(context, topic, currentTopic,
                            ContextCompat.getColor(context, R.color.color_ff567b)),
                            lastIndex, nextIndex, Spannable.SPAN_INCLUSIVE_EXCLUSIVE)
                }
            }

            lastIndex = nextIndex
        }

        text = builder
    }


    // 默认提示语的链接
    internal class TopicClickSpan(val context: Context, val topic: Topic, private val currentTopic: Topic?, private val txtColor: Int) : ClickableSpan() {
        override fun onClick(widget: View) {
            if (Utils.isNotClickable()) {
                return
            }
            if (currentTopic != null && currentTopic == topic) {
                return
            }
            val intent = Intent(context, TranslucentSubPageActivity::class.java)
            intent.putExtra(TranslucentSubPageActivity.CLASSFRAMENT, DynamicTopicDetailsFragment::class.java)
            val bundle = Bundle()
            bundle.putParcelable(DynamicTopicDetailsFragment.KEY_TOPIC, topic)
            intent.putExtra("bundle", bundle)
            context.startActivity(intent)
        }

        override fun updateDrawState(ds: TextPaint) {
            super.updateDrawState(ds)
            ds.color = txtColor
            ds.isUnderlineText = false
        }

    }
}