package com.ninexiu.sixninexiu.view

import android.content.Context
import android.os.Environment
import android.text.TextUtils
import com.google.gson.GsonBuilder
import com.ninexiu.sixninexiu.bean.UserReturnData
import com.ninexiu.sixninexiu.bean.UserReturnPayTaskBean
import com.ninexiu.sixninexiu.common.ConfigSpHelper
import com.ninexiu.sixninexiu.common.util.NSLog
import com.ninexiu.sixninexiu.common.util.TimeUtil

/**
 * <pre>
 *     @author : hpf
 *     time   : 2020/11/26
 *     desc   : 用户回头辅助类 : 时间间隔判断，json转换
 *     version: 1.0
 * </pre>
 */
object UserReturnGsonHelper {
    private const val Tag = "UserReturnGsonHelper : "
    const val TestTag = "UserReturnTestTag >> "
    var USERRETURN_OVER = false

    private const val STORE_TAG = "NineShow_Store_Tag"

    // 获取金秋状态，判断是否要弹窗(一天弹出一次)
    fun getNewAutumnActiveStatus() : Boolean {
        val preTime = ConfigSpHelper.getInstance().newAutumnBuyTime


        if (TextUtils.isEmpty(preTime)) {
            // 时间更新
            // ConfigSpHelper.getInstance().newAutumnBuyTime = currentTime
            return true
        }

        val currentTime = TimeUtil.getUserReturnDayTime(System.currentTimeMillis())

        NSLog.d(Tag, "pre : $preTime , cur : $currentTime")
        if (preTime != currentTime) {
            // 时间更新
            // ConfigSpHelper.getInstance().newAutumnBuyTime = currentTime
            return true
        }
        return false
    }


    fun setNewAutumnActiveStatus(){
        val currentTime = TimeUtil.getUserReturnDayTime(System.currentTimeMillis())
        ConfigSpHelper.getInstance().newAutumnBuyTime = currentTime
    }


    // 是否请求用户状态接口
    fun getUserReturnAuthorStatus(): Boolean {
        val preTime = ConfigSpHelper.getInstance().userReturnAuthorTime

        val currentTime = TimeUtil.getUserReturnDayTime(System.currentTimeMillis())

        if (TextUtils.isEmpty(preTime)) {
            // 时间更新
            ConfigSpHelper.getInstance().userReturnAuthorTime = currentTime
            return true
        }

        NSLog.d(Tag, "pre : $preTime , cur : $currentTime")
        if (preTime != currentTime) {
            // 时间更新
            ConfigSpHelper.getInstance().userReturnAuthorTime = currentTime
            return true
        }
        return false
    }

    // 存储用户回归状态数据
    fun saveJsonData(response: UserReturnPayTaskBean?) {
        USERRETURN_OVER = (response?.data?.old_user_v3 == 0)
        response ?: return
        val gson = GsonBuilder().create()
        try {
            val data = gson.toJson(response)
            ConfigSpHelper.getInstance().userReturnAuthorStatus = data
        } catch (e: Exception) {
            NSLog.d(Tag, "用户回归数据解析失败")
        }
    }

    // 用户回归活动过期后重新写入数据
    fun saveJsonDataOver() {
        saveJsonData(UserReturnPayTaskBean(UserReturnData(0,0,0)))
    }

    // 判断用户是否可以领取回归礼包 -> 存储的数据为空的情况也是要走接口的
    fun isCanReceiveFreeBag(): Boolean {
        val data = ConfigSpHelper.getInstance().userReturnAuthorStatus
        if (TextUtils.isEmpty(data) || data.isBlank()) {
            return true
        }
        val gson = GsonBuilder().create()
        return try {
            val result = gson.fromJson(data, UserReturnPayTaskBean::class.java)
            NSLog.d(Tag, result.toString())
            result.data?.old_user_v3 == 1 && result.data.is_come == 0
        } catch (e: Exception) {
            NSLog.d(Tag, e.message)
            false
        }
    }

    // 获取存储的用户回归数据 | 用户是否可以半价购买 -> 若存储数据为空或者未领取回归特权的情况下是不让半价购买的
    fun isHomeShowUserReturnIV(): Boolean {
        val data = ConfigSpHelper.getInstance().userReturnAuthorStatus
        if (TextUtils.isEmpty(data) || data.isBlank()) {
            return false
        }
        val gson = GsonBuilder().create()
        return try {
            val result = gson.fromJson(data, UserReturnPayTaskBean::class.java)
            NSLog.d(Tag, result.toString())
            result.data?.old_user_v3 == 1 && result.data.is_come == 1
        } catch (e: Exception) {
            NSLog.d(Tag, e.message)
            false
        }
    }


    private const val oneday = 60 * 60 * 24
    private const val onehour = 60 * 60

    // 判断倒计时是否超过一天  true : 天    false : h : m : s
    fun overOneDay(time: Long): Boolean {
        return time.toInt() > oneday
    }

    // 返回天数(大于1天情况)
    fun formatDay(time: Long): Int {
        val day = time / oneday
        return day.toInt()
    }

    // 格式化时间 (小于1天情况)
    fun formatTime(time: Long): String {
        if(time <= 0) {
            return "该活动已结束"
        }

        if (overOneDay(time)) {
            return "--"
        }

        val lsTime = time.toInt()

        val hour = lsTime / onehour
        val minute = lsTime / 60 % 60  // / :先转换成秒  % : 过滤出小时
        val second = lsTime % 60

        return "${timeToString(hour)} : ${timeToString(minute)} : ${timeToString(second)}"
    }

    private fun timeToString(time: Int): String {
        return if (time < 10) {
            "0${time}"
        } else {
            time.toString()
        }
    }
}