package com.ninexiu.sixninexiu.view

import android.content.Context
import android.util.AttributeSet
import android.view.LayoutInflater
import android.widget.TextView
import androidx.constraintlayout.widget.ConstraintLayout
import com.ninexiu.sixninexiu.R
import kotlinx.android.synthetic.main.view_return_tablayout.view.*

/**
 * <pre>
 *     @author : hpf
 *     time   : 2020/11/23
 *     desc   : 用户按钮切换  : 回归福利 / 邂逅主播
 *     version: 1.0
 * </pre>
 */
class UserReturnTabLayout @JvmOverloads constructor(context: Context, attrs: AttributeSet? = null, defStyleAttr: Int = 0) : ConstraintLayout(context, attrs, defStyleAttr) {
    companion object {
       const val TAB_WELFARE = 0
       const val TAB_LIVE = 1
    }

    // 默认选中
    private var currentTab = TAB_WELFARE

    // 选中回调
    var onUserSelected: ((Int) -> Unit)? = null

    init {
        LayoutInflater.from(context).inflate(R.layout.view_return_tablayout, this)
        val attrs = context.obtainStyledAttributes(attrs, R.styleable.UserReturnTabLayout)

        val leftText = attrs.getString(R.styleable.UserReturnTabLayout_tab_left_text)
        val rightText = attrs.getString(R.styleable.UserReturnTabLayout_tab_right_text)

        tvUserReturnWelfare.text = leftText ?: ""
        tvUserReturnLive.text = rightText ?: ""

        attrs.recycle()
    }

    override fun onFinishInflate() {
        super.onFinishInflate()

        // 初始化默认选中回归福利
        setTabStatus(tvUserReturnWelfare, tvUserReturnLive)

        tvUserReturnWelfare.setOnClickListener {
            if (currentTab != TAB_WELFARE) {
                currentTab = TAB_WELFARE

                onUserSelected?.invoke(currentTab)

                // 切换回归福利
                setTabStatus(tvUserReturnWelfare, tvUserReturnLive)
            }
        }

        tvUserReturnLive.setOnClickListener {
            if (currentTab != TAB_LIVE) {
                currentTab = TAB_LIVE

                onUserSelected?.invoke(currentTab)

                // 切换邂逅主播
                setTabStatus(tvUserReturnLive, tvUserReturnWelfare)
            }
        }
    }

    // 切换按钮状态
    private fun setTabStatus(viewSelected: TextView, unViewSelected: TextView) {
        viewSelected.setBackgroundResource(R.drawable.bg_user_return_chose_tab)
        viewSelected.setTextColor(resources.getColor(R.color.white))

        unViewSelected.background = null
        unViewSelected.setTextColor(resources.getColor(R.color.color_6A0094))
    }

}

