package com.ninexiu.sixninexiu.view

import android.text.TextUtils
import com.google.gson.GsonBuilder
import com.ninexiu.sixninexiu.bean.ZhiFuResult
import com.ninexiu.sixninexiu.common.ConfigSpHelper
import com.ninexiu.sixninexiu.common.util.NSLog
import java.lang.Exception

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/01/06
 *     desc   : 用户支付帮助类
 *     version: 1.0
 * </pre>
 */
object UserZhiFuGsonHelper {
    const val Tag = "UserZhiFuGsonHelper : "

    // 判断是否含有banner数据 : 如果不含有说明用户已经是首充，不再拉取接口
    fun needRetryZhiFuData(): Boolean {
        val result = getUserZhiFuData()
        result ?: return true // 没有存储过数据

        // 如果banner存储的数据为空，则不再拉取接口了，因为支付选项一般不会变化
        if(result.data != null && result.data.banners == null && result.data.banners?.size?:0 >0) {
            return false
        }

        return true
    }


    // 存储支付数据
    fun saveUserZhiFuData(response: ZhiFuResult?) {
        response ?: return
        val gson = GsonBuilder().create()
        try {
            ConfigSpHelper.getInstance().userZhiFuInfo = gson.toJson(response)
        } catch (e: Exception) {
            NSLog.d(Tag, "用户支付数据解析失败")
        }
    }


    // 获取支付数据
    fun getUserZhiFuData(): ZhiFuResult? {
        val data = ConfigSpHelper.getInstance().userZhiFuInfo
        if (TextUtils.isEmpty(data) || data.isBlank()) {
            return null
        }

        val gson = GsonBuilder().create()
        return try {
            val result = gson.fromJson(data, ZhiFuResult::class.java)
            NSLog.d(Tag, result.toString())
            result
        } catch (e: Exception) {
            NSLog.d(Tag, e.message)
            null
        }

    }

    // 修改支付数据 : 用户支付完成以后修改banner数据
}