package com.ninexiu.sixninexiu.view

import android.animation.Animator
import android.animation.AnimatorSet
import android.animation.ObjectAnimator
import android.content.Context
import android.util.AttributeSet
import android.view.LayoutInflater
import android.view.animation.Animation
import android.view.animation.AnimationSet
import android.view.animation.TranslateAnimation
import androidx.constraintlayout.widget.ConstraintLayout
import com.ninexiu.sixninexiu.R
import kotlinx.android.synthetic.main.view_voice_game_animation.view.*

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/09/10
 *     desc   : 心动现场 & 团战pk的动画封装
 *     version: 1.0
 * </pre>
 */
class VoiceGameAnimationView @JvmOverloads constructor(context: Context, attrs: AttributeSet? = null, defStyleAttr: Int = 0) : ConstraintLayout(context, attrs, defStyleAttr) {
    companion object {
        const val VOICE_GAME_LOVE = 0       // 心动现场
        const val VOICE_GAME_PK = 1         // 团战pk
    }

    init {
        LayoutInflater.from(context).inflate(R.layout.view_voice_game_animation, this)
    }

    private var currentType = VOICE_GAME_LOVE

    private val screenW: Int by lazy {
        getScreenWidth(context)
    }

    fun showVoiceGame(type: Int) {
        currentType = type

        when (currentType) {
            VOICE_GAME_LOVE -> {
                fitterViewPosition(this, ORIENTATION_TOP, { dp2px(context, 26) })

                fitterViewSize(ivVoiceGameAnimationLeft, { (screenW * 0.4853).toInt() }, { (it * 1.071).toInt() })
                fitterViewSize(ivVoiceGameAnimationRight, { (screenW * 0.4853).toInt() }, { (it * 1.071).toInt() })

                fitterViewSingleMargin(ivVoiceGameAnimationLeft, ORIENTATION_LEFT, setLeftMargin = { 0 })
                fitterViewSingleMargin(ivVoiceGameAnimationRight, ORIENTATION_RIGHT, setRightMargin = { 0 })

                ivVoiceGameAnimationLeft.setBackgroundResource(R.drawable.icon_liveroom_micbg_left)
                ivVoiceGameAnimationRight.setBackgroundResource(R.drawable.icon_liveroom_micbg_right)

                setViewsVisible(false, tvRed, tvBlue)

                this.setVisible(true)
            }

            /**
             * 团战适配 : svg整体宽为750
             * 左右间距屏幕 : 12px
             * 两个svg间隔 : 20px
             * svg宽高 : 353 * 433
             */
            VOICE_GAME_PK -> {
                fitterViewPosition(this, ORIENTATION_TOP, { (screenW * 0.04).toInt() })

                fitterViewSize(ivVoiceGameAnimationLeft, { (screenW * 0.471).toInt() }, { (it * 1.23).toInt() })
                fitterViewSize(ivVoiceGameAnimationRight, { (screenW * 0.471).toInt() }, { (it * 1.23).toInt() })

                fitterViewSingleMargin(ivVoiceGameAnimationLeft, ORIENTATION_LEFT, setLeftMargin = { (screenW * 0.016).toInt() })
                fitterViewSingleMargin(ivVoiceGameAnimationRight, ORIENTATION_RIGHT, setRightMargin = { (screenW * 0.016).toInt() })

                // todo : 高度需要去计算
                ivVoiceGameAnimationLeft.setBackgroundResource(R.drawable.ic_voice_game_pk_left_bg)
                ivVoiceGameAnimationRight.setBackgroundResource(R.drawable.ic_voice_game_pk_right_bg)

                setViewsVisible(true, tvRed, tvBlue)

                this.setVisible(true)
            }
        }
    }

    // 移除动画监听等
    fun clear() {
        this.setVisible(false)
    }
}