package com.ninexiu.sixninexiu.view

import android.content.Context
import android.graphics.Bitmap
import android.graphics.BitmapFactory
import android.graphics.Color
import android.graphics.Paint
import android.text.BoringLayout
import android.text.Layout
import android.text.TextPaint
import android.util.AttributeSet
import android.view.LayoutInflater
import android.view.ViewGroup
import android.widget.ImageView
import androidx.constraintlayout.widget.ConstraintLayout
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.common.util.NSLog
import com.ninexiu.sixninexiu.common.util.VoiceGameSvgHelper
import com.opensource.svgaplayer.SVGADrawable
import com.opensource.svgaplayer.SVGADynamicEntity
import com.opensource.svgaplayer.SVGAVideoEntity
import kotlinx.android.synthetic.main.view_voice_game_svg.view.*


/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/09/13
 *     desc   : 语音房svg管理类(因为团战svg太大的原因，将其svg布局写在了直播间层次，心动团战的层次还是在语音房层次 VoiceGameSvgBottomManagerView & VoiceGameSvgTopManagerView)
 *     version: 1.0
 * </pre>
 */
class VoiceGameSvgManagerView @JvmOverloads constructor(context: Context, attrs: AttributeSet? = null, defStyleAttr: Int = 0) : ConstraintLayout(context, attrs, defStyleAttr) {
    companion object {
        const val Tag = "VoiceGameSvgManagerView : "
    }

    private val screenW: Int by lazy {
        getScreenWidth(context)
    }

    init {
        LayoutInflater.from(context).inflate(R.layout.view_voice_game_svg, this)
    }

    // 心动消失动画
    fun disappearLoveBg(context: Context,onFinish: ((Boolean) -> Unit)? = null) {
        val svgDisAppear : SVGAVideoEntity? = VoiceGameSvgHelper.svgLoveDisAppear
        if(svgDisAppear == null) {
            VoiceGameSvgHelper.initLoveSvg()
            onFinish?.invoke(false)
            return
        }
        // 适配
        fitterViewSize(voiceGameSvg, { screenW }, { (it * 0.52).toInt() })

        fitterViewPosition(this, ORIENTATION_TOP, { dp2px(context, 82 + 10 + 26) })

        if (svgDisAppear != null) {
            voiceGameSvg.callback = object : SVGACallbackImpl() {
                override fun onFinished() {
                    onFinish?.invoke(true)
                }
            }
            this.setVisible(true)
            voiceGameSvg.setVisible(true)
            voiceGameSvg.setVideoItem(svgDisAppear)
            voiceGameSvg.startAnimation()
        }
    }

    // 心动背景动画
    fun showLoveBg(context: Context, onTeamPkSvgFinish: ((Boolean) -> Unit)? = null) {
        val svgLovePkBg: SVGAVideoEntity? = VoiceGameSvgHelper.svgLovePkBg

        if (svgLovePkBg == null) {
            VoiceGameSvgHelper.initLoveSvg()
            onTeamPkSvgFinish?.invoke(false)
            return
        }

        // 适配
        fitterViewSize(voiceGameSvg, { screenW }, { (it * 0.52).toInt() })

        fitterViewPosition(this, ORIENTATION_TOP, { dp2px(context, 82 + 10 + 26) })

        if (svgLovePkBg != null) {
            voiceGameSvg.callback = object : SVGACallbackImpl() {
                override fun onFinished() {
                    // voiceGameSvg.setVisible(false)
                    onTeamPkSvgFinish?.invoke(true)
                }
            }
            this.setVisible(true)
            voiceGameSvg.setVisible(true)
            voiceGameSvg.setVideoItem(svgLovePkBg)
            voiceGameSvg.startAnimation()
        }
    }

    // 心动倒计时动画
    fun showLoveCutDown(context: Context, onTeamPkSvgFinish: ((Boolean) -> Unit)? = null) {
        val svgLoveCutDownBg: SVGAVideoEntity? = VoiceGameSvgHelper.svgLoveCutDownBg

        if (svgLoveCutDownBg == null) {
            VoiceGameSvgHelper.initLoveSvg()
            onTeamPkSvgFinish?.invoke(false)
            return
        }


        // 适配
        fitterViewSize(voiceGameSvg, { screenW / 3 }, { it })

        /**
         * 状态栏 : top1
         * 直播间头部 : 43.5 + 26
         * 头部 : 62 + 4 + 14 + 2(paddingBottom)
         */
        fitterViewPosition(this, ORIENTATION_TOP, { dp2px(context, 82 + 10 + 40) })

        if (svgLoveCutDownBg != null) {
            voiceGameSvg.callback = object : SVGACallbackImpl() {
                override fun onFinished() {
                    onTeamPkSvgFinish?.invoke(true)
                }
            }
            this.setVisible(true)
            voiceGameSvg.setVisible(true)
            voiceGameSvg.setVideoItem(svgLoveCutDownBg)
            voiceGameSvg.startAnimation()
        }
    }

    // 团战倒计时动画
    fun showTeamPkCutDown(context: Context, onTeamPkSvgFinish: ((Boolean) -> Unit)? = null) {
        val svgTeamCutDownBg: SVGAVideoEntity? = VoiceGameSvgHelper.svgTeamCutDownBg

        if (svgTeamCutDownBg == null) {
            VoiceGameSvgHelper.initTeamPkSvg()
            onTeamPkSvgFinish?.invoke(false)
            return
        }

        fitterViewSize(voiceGameSvg, { screenW }, { (it * 0.827).toInt() })

        val disReal = dp2px(context, 70 + 10 + 82 + 82 + 40) //  + top1

        val disNow = (245 * screenW * 1f / 750).toInt()      // 现在间距

        NSLog.d(Tag, "real : $disReal , now : $disNow")

        fitterViewPosition(this, ORIENTATION_TOP, { disReal - disNow })

        if (svgTeamCutDownBg != null) {
            voiceGameSvg.callback = object : SVGACallbackImpl() {
                override fun onFinished() {
                    super.onFinished()
                    onTeamPkSvgFinish?.invoke(true)
                }
            }

            this.setVisible(true)
            voiceGameSvg.setVisible(true)
            voiceGameSvg.setVideoItem(svgTeamCutDownBg)
            voiceGameSvg.startAnimation()
        }
    }

    // 团战svg背景消失动画
    fun disappearTeamPkSvg(context: Context, onTeamPkSvgFinish: ((Boolean) -> Unit)? = null) {       // Boolean : 是否正常结束
        val svgTeamDisappear: SVGAVideoEntity? = VoiceGameSvgHelper.svgTeamDisAppear

        if (svgTeamDisappear == null) {
            VoiceGameSvgHelper.initTeamPkSvg()
            onTeamPkSvgFinish?.invoke(false)
            return
        }


        // 适配
        fitterViewSize(voiceGameSvg, { screenW }, { (it * 1.333).toInt() })

        /**
         * 状态栏 : top1
         * 直播间头部 : 43.5 + 26
         * 头部 : 62 + 4 + 14 + 2(paddingBottom)
         */
        val disReal = dp2px(context, 70 + 82 + 10) //  + top1

        val disNow = (332 * screenW * 1f / 750).toInt()      // 现在间距

        NSLog.d(Tag, "real : $disReal , now : $disNow")

        fitterViewPosition(this, ORIENTATION_TOP, {
            disReal - disNow
        })

        if (svgTeamDisappear != null) {
            voiceGameSvg.callback = object : SVGACallbackImpl() {
                override fun onFinished() {
                    onTeamPkSvgFinish?.invoke(true)
                }
            }
            this.setVisible(true)
            voiceGameSvg.setVisible(true)
            voiceGameSvg.setVideoItem(svgTeamDisappear)
            voiceGameSvg.startAnimation()
        }
    }


    private var shouldDoSetAnimation = true         // 做麦位动画(防止多次调用)
    private var showldShowPkView = true

    // 团战svg背景动画
    fun showTeamPkSvg(context: Context, onTeamPkSvgFinish: ((Boolean) -> Unit)? = null, onTeamSetAnimationStart: (() -> Unit)? = null) {       // Boolean : 是否正常结束
        val svgTeamPkBg: SVGAVideoEntity? = VoiceGameSvgHelper.svgTeamPkBg

        if (svgTeamPkBg == null) {
            VoiceGameSvgHelper.initTeamPkSvg()
            onTeamPkSvgFinish?.invoke(false)
            return
        }


        // 适配
        fitterViewSize(voiceGameSvg, { screenW }, { (it * 1.333).toInt() })

        /**
         * 状态栏 : top1
         * 直播间头部 : 43.5 + 26
         * 头部 : 62 + 4 + 14 + 2(paddingBottom)
         */
        val disReal = dp2px(context, 70 + 82 + 12) //  + top1

        val disNow = (328 * screenW * 1f / 750).toInt()      // 现在间距

        NSLog.d(Tag, "real : $disReal , now : $disNow")

        fitterViewPosition(this, ORIENTATION_TOP, {
            disReal - disNow
        })

        if (svgTeamPkBg != null) {
            voiceGameSvg.callback = object : SVGACallbackImpl() {
                override fun onFinished() {
                    // onTeamPkSvgFinish?.invoke(true)
                }

                override fun onStep(frame: Int, percentage: Double) {
                    super.onStep(frame, percentage)
                    // NSLog.d("VoiceGameSvgView : ", "fragme : $frame , percentage : $percentage")
                    if (percentage > 0.02 && shouldDoSetAnimation) {
                        shouldDoSetAnimation = false
                        onTeamSetAnimationStart?.invoke()
                    }

                    if(percentage > 0.4 && showldShowPkView) {
                        showldShowPkView = false
                        onTeamPkSvgFinish?.invoke(true)
                    }

                    if (percentage >= 1) {
                        shouldDoSetAnimation = true
                        showldShowPkView = true
                    }
                }
            }
            this.setVisible(true)
            voiceGameSvg.setVisible(true)
            voiceGameSvg.setVideoItem(svgTeamPkBg)
            voiceGameSvg.startAnimation()
        }
    }

    // 大乱斗倒计时动画
    fun showChaosPkCutDown(context: Context,leftName: String?,rightName :String?, onChaosPkSvgFinish: ((Boolean) -> Unit)? = null) {
        val svgVoiceChaosStartBg: SVGAVideoEntity? = VoiceGameSvgHelper.svgVoiceChaosStartBg

        if (svgVoiceChaosStartBg == null) {
            VoiceGameSvgHelper.initChaosStartSvg()
            onChaosPkSvgFinish?.invoke(false)
            return
        }

        fitterViewSize(voiceGameSvg, { screenW }, { screenW })

        val disReal = dp2px(context, 70 + 82 + 82 + 40) //  + top1

        val disNow = (245 * screenW * 1f / 750).toInt()      // 现在间距

        NSLog.d(Tag, "real : $disReal , now : $disNow")

        fitterViewPosition(this, ORIENTATION_TOP, { disReal - disNow })

        voiceGameSvg.scaleType = ImageView.ScaleType.CENTER_CROP
        if (svgVoiceChaosStartBg != null) {
            voiceGameSvg.callback = object : SVGACallbackImpl() {
                override fun onFinished() {
                    super.onFinished()
                    onChaosPkSvgFinish?.invoke(true)
                }
            }
            this.setVisible(true)
            voiceGameSvg.setVisible(true)
            if (!leftName.isNullOrEmpty() && !rightName.isNullOrEmpty()) {
                val dynamicEntity = SVGADynamicEntity()
                val textPaint = TextPaint()
                textPaint.color = Color.WHITE
                textPaint.textSize = 28f
                textPaint.alpha = 255
                dynamicEntity.setDynamicText(leftName, textPaint, "index")
                dynamicEntity.setDynamicText(rightName, textPaint, "index1")
                dynamicEntity.setHidden(false, "index")
                dynamicEntity.setHidden(false, "index1")
                val svgaDrawable = SVGADrawable(svgVoiceChaosStartBg, dynamicEntity)
                voiceGameSvg.setImageDrawable(svgaDrawable)
            }else{
                voiceGameSvg.setVideoItem(svgVoiceChaosStartBg)
            }
            voiceGameSvg.startAnimation()
        }
    }

    // 宝箱领取动画
    fun showBoxSvga(context: Context, onTeamPkSvgFinish: ((Boolean) -> Unit)? = null,resourcesSrc :Int) {       // Boolean : 是否正常结束
        val svgBox: SVGAVideoEntity? = VoiceGameSvgHelper.svgVoiceChaosOpenBox

        if (svgBox == null) {
            VoiceGameSvgHelper.initOpenBoxSvg()
            onTeamPkSvgFinish?.invoke(false)
            return
        }

        // 适配
        fitterViewSize(voiceGameSvg, { 700 }, { 700 })


        val disReal = dp2px(context, 70 + +12 + 82*3 + 16) //  + top1

        val disNow = 360     // 现在间距

        NSLog.d(Tag, "real : $disReal , now : $disNow")

        fitterViewPosition(this, ORIENTATION_TOP, { disReal - disNow })

        voiceGameSvg.scaleType = ImageView.ScaleType.CENTER_CROP
        if (svgBox != null) {
            voiceGameSvg.callback = object : SVGACallbackImpl() {
                override fun onFinished() {
                     onTeamPkSvgFinish?.invoke(true)
                    voiceGameSvg.scaleType = ImageView.ScaleType.FIT_XY
                }
            }
            this.setVisible(true)
            voiceGameSvg.setVisible(true)
            val dynamicEntity = SVGADynamicEntity()
            val src = BitmapFactory.decodeResource(resources, resourcesSrc)
            dynamicEntity.setDynamicImage(src, "img_16")
            val drawable = SVGADrawable(svgBox, dynamicEntity)
            voiceGameSvg.setImageDrawable(drawable)
            voiceGameSvg.startAnimation()
//            voiceGameSvg.setVideoItem(svgBox)
//            voiceGameSvg.startAnimation()
        }
    }

    // 重置操作,防止高度影响其他view的显示(如直播间聊天区域)
    fun reset(){
        voiceGameSvg.scaleType = ImageView.ScaleType.FIT_XY
        this.setVisible(false)
        fitterViewSize(voiceGameSvg, { screenW }, { ViewGroup.LayoutParams.WRAP_CONTENT })
        fitterViewPosition(this, ORIENTATION_TOP, {0})
    }


}