package com.ninexiu.sixninexiu.view

import android.content.Context
import android.text.TextUtils
import android.util.AttributeSet
import android.view.LayoutInflater
import android.widget.FrameLayout
import android.widget.ImageView
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.common.util.NSLog
import com.opensource.svgaplayer.SVGACallback
import com.opensource.svgaplayer.SVGAImageView
import com.opensource.svgaplayer.SVGAParser
import com.opensource.svgaplayer.SVGAVideoEntity
import okhttp3.OkHttpClient
import okhttp3.Request
import java.io.IOException
import java.io.InputStream
import java.net.MalformedURLException
import java.net.URL

/**
 *
 * @ProjectName:
 * @Package:
 * @ClassName:
 * @Description:    多人语音连麦声音动画
 * @Author:         gh
 * @CreateDate:     2021/06/03 0008 17:04
 * @Version:
 */

class VoiceSouceSVGView : FrameLayout {

    private val TAG: String = "VoiceSouceSVGView"
    private lateinit var mContext: Context
    lateinit var mGiftIv: SVGAImageView

    constructor(context: Context) : super(context) {
        init(context)
    }

    constructor(context: Context, attrs: AttributeSet?) : super(context, attrs) {
        init(context)
    }

    constructor(context: Context, attrs: AttributeSet?, defStyleAttr: Int) : super(context, attrs, defStyleAttr) {
        init(context)
    }

    private fun init(context: Context) {
        this.mContext = context
        LayoutInflater.from(context).inflate(R.layout.mblive_enter_layout, this)
        mGiftIv = findViewById(R.id.svg_enterlocaltycoon_flying)

        setSVGAImageViewCallBack(mGiftIv)
    }

    private fun setSVGAImageViewCallBack(mSv: SVGAImageView) {

        with(mSv) {
            loops = 10
            callback = object : SVGACallback {
                override fun onPause() {}

                override fun onFinished() {


                }

                override fun onRepeat() {}

                override fun onStep(frame: Int, percentage: Double) {}
            }
        }
    }

    fun loadSvga(path: String) {
        if (TextUtils.isEmpty(path) || mGiftIv == null){
            return
        }
        loadAnimation(path, mGiftIv)
    }

    fun release() {
        if (mGiftIv != null) {
            mGiftIv.stopAnimation()
        }
    }

    private fun loadAnimation(path: String, mSVGAImageView: SVGAImageView) {
        with(mSVGAImageView) {
            val mParseCompletion = object : SVGAParser.ParseCompletion {
                override fun onComplete(videoItem: SVGAVideoEntity) {

                    NSLog.e(TAG, "ParseCompletion onComplete")

                    setVideoItem(videoItem)

                    startAnimation()
                    mSVGAImageView.setTag(R.id.tag_svg_loading, true)
                }

                override fun onError() {
                    NSLog.e(TAG, "ParseCompletion onError ")
                    mSVGAImageView.setTag(R.id.tag_svg_loading, false)
                }
            }

            var parser = SVGAParser.Companion.shareParser()

            if (path.startsWith("http") || path.startsWith("https")) {
                try {
                    parser?.decodeFromURL(URL(path), mParseCompletion, null)
                } catch (e: MalformedURLException) {
                    e.printStackTrace()
                    mSVGAImageView.setTag(R.id.tag_svg_loading, false)
                }
            } else {
                parser?.decodeFromAssets(path, mParseCompletion,null)
            }

        }
    }

    /**
     * 设置下载器，这是一个可选的配置项。
     *
     * @param parser
     */
    private fun resetDownloader(parser: SVGAParser) {

        parser.fileDownloader = object : SVGAParser.FileDownloader() {
            override fun resume(url: URL, complete: Function1<InputStream, Unit>,
                failure: Function1<Exception, Unit>): Function0<Unit> {
                //可以试一下协程
                Thread(Runnable {
                    val client = OkHttpClient()
                    val request = Request.Builder().url(url).get().build()
                    try {
                        val response = client.newCall(request).execute()
                        complete.invoke(response.body()!!.byteStream())
                    } catch (e: IOException) {
                        e.printStackTrace()
                        failure.invoke(e)
                    }
                }).start()
                return super.resume(url, complete, failure)
            }
        }
    }

    override fun onDetachedFromWindow() {
        super.onDetachedFromWindow()
        mGiftIv.stopAnimation()
    }
}
