package com.ninexiu.sixninexiu.view

import android.annotation.SuppressLint
import android.content.Context
import android.text.TextWatcher
import android.util.AttributeSet
import android.view.LayoutInflater
import android.widget.RelativeLayout
import com.kpswitch.util.KeyboardUtil
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.common.util.listener.EditTextWatcher
import kotlinx.android.synthetic.main.item_zhifu.view.*

/**
 * <pre>
 *     @author : hpf
 *     time   : 2020/12/25
 *     desc   : 封装的支付选项(包括自定义金额)
 *     version: 1.0
 * </pre>
 */
class ZhiFuItemView @JvmOverloads constructor(context: Context, attrs: AttributeSet? = null, defStyleAttr: Int = 0) : RelativeLayout(context, attrs, defStyleAttr) {
    var userInputMoney : ((CharSequence?) -> Unit)? = null

    init {
        LayoutInflater.from(context).inflate(R.layout.item_zhifu, this)

        // 初始化
        setContentVisible()

        etMoney.addTextChangedListener(object : EditTextWatcher(){
            override fun onTextChanged(s: CharSequence?, start: Int, before: Int, count: Int) {
                super.onTextChanged(s, start, before, count)
                userInputMoney?.invoke(s)
            }
        })
    }

    companion object {
        // 类型 : normal & custom
        const val NORMAL = 0
        const val CUSTOM = 1
    }

    var type = NORMAL
        private set

    // 设置类型
    fun setType(type: Int): ZhiFuItemView {
        this.type = type
        setContentVisible()
        return this
    }

    // 设置可见性
    private fun setContentVisible() {
        when (type) {
            NORMAL -> {
                llMoney.setVisible(true)
                rlMonoey.setVisible(false)
            }
            CUSTOM -> {
                llMoney.setVisible(false)
                rlMonoey.setVisible(true)
            }
        }
    }

    // 设置九币和人民币
    @SuppressLint("SetTextI18n")
    fun setMoney(coin: Int, money: Int): ZhiFuItemView {
        if (type == NORMAL) {
            tvCoin.text = "${coin}九币"
            tvMoney.text = "${money}元"
        }
        return this
    }

    // 显示键盘
    fun showKeyBoard(){
        etMoney?.let{
            it.post { KeyboardUtil.showKeyboard(it) }
        }
    }

    // 设置选择
    fun setZhiFuSelected(selected: Boolean): ZhiFuItemView {
        when (selected) {
            true -> {
                setBackgroundResource(R.drawable.shap_item_zhifu_selected)
                tvCoin.setTextColor(resources.getColor(R.color.color_ff567b))
                tvMoney.setTextColor(resources.getColor(R.color.color_ff567b))
                ivSelected.setVisible(true)

                if (type == CUSTOM) {
                    tvCover.setVisible(false)
                    etMoney.setVisible(true)
                    tvCustomMoney.setVisible(true)
                    // 弹出键盘
                    etMoney.post {
                        KeyboardUtil.showKeyboard(etMoney)
                    }
                }

            }
            false -> {
                setBackgroundResource(R.drawable.shap_item_zhifu_normal)
                tvCoin.setTextColor(resources.getColor(R.color.color_333333))
                tvMoney.setTextColor(resources.getColor(R.color.color_cccccc))
                ivSelected.setVisible(false)

                if (type == CUSTOM) {
                    tvCover.setVisible(true)
                    etMoney.setVisible(false)
                    tvCustomMoney.setVisible(false)
                    etMoney.setText("")
                    etMoney.post {
                        KeyboardUtil.hideKeyboard(etMoney)
                    }
                }
            }
        }
        return this
    }
}