package com.ninexiu.sixninexiu.view.alphaVideo

import android.content.Context
import android.text.TextUtils
import android.util.AttributeSet
import android.util.Log
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.FrameLayout
import android.widget.RelativeLayout
import com.ninexiu.sixninexiu.BuildConfig
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.common.util.NSLog
import com.tencent.qgame.animplayer.AnimConfig
import com.tencent.qgame.animplayer.AnimView
import com.tencent.qgame.animplayer.Constant
import com.tencent.qgame.animplayer.inter.IAnimListener
import com.tencent.qgame.animplayer.util.ALog
import com.tencent.qgame.animplayer.util.IALog
import kotlinx.android.synthetic.main.view_video_gift.view.*
import java.io.File
import java.lang.Exception

/**
 * created by dengzhuoyao on 2020/07/08
 */
class VideoGiftView @JvmOverloads constructor(
        context: Context, attrs: AttributeSet? = null, defStyleAttr: Int = 0
) : FrameLayout(context, attrs, defStyleAttr) , IAnimListener {

    companion object {
        const val TAG = "VideoGiftView >> "
        const val ORIENTATION_TOP = 0
        const val ORIENTATION_LEFT = 1

        // 注意 : 相对于视频中的框来计算比例的
        const val BUTTON_WIDTH_PERCENT = 0.42f

        // 按钮自己的高宽比例
        const val BUTTON_SELF_PERCENT = 0.314f
    }

    val density: Float by lazy {
        context.resources.displayMetrics.density
    }

    val screenWidth: Int by lazy {
        context.resources.displayMetrics.widthPixels
    }

    val screenHeight: Int by lazy {
        context.resources.displayMetrics.heightPixels
    }

    // 记录视频整体的大小
    val allFrame = intArrayOf(750, 1334)

    // 记录视频里面框的位置(左上角和右下角)
    val arrFrame = intArrayOf(112, 223, 642, 1025)

    private val mVideoContainer: RelativeLayout

    init {
        LayoutInflater.from(context).inflate(getResourceLayout(), this)
        mVideoContainer = findViewById(R.id.video_view)

        // 适配视频整体的宽和高度(也不用适配)
        fitterViewSize(video_view, {
            screenWidth
        }, {
            ((allFrame[1].toFloat() * it / allFrame[0])).toInt()
        })

        // 整体缩放比例
        val ratio = screenWidth.toFloat() / allFrame[0]

        // 实际视频中框的宽度
        val frameRealWidth = (arrFrame[2] - arrFrame[0]) * ratio

        NSLog.d(TAG, "ratio : $ratio , frameRealWidth : $frameRealWidth")

        // 适配按钮的大小
        fitterViewSize(ivHug, {
            (frameRealWidth * BUTTON_WIDTH_PERCENT).toInt()
        }, {
            (it * BUTTON_SELF_PERCENT).toInt()
        })

        // 适配按钮的大小
        fitterViewSize(ivNoNotification, {
            (frameRealWidth * BUTTON_WIDTH_PERCENT).toInt()
        }, {
            (it * BUTTON_SELF_PERCENT).toInt()
        })

        // 算出按钮的摆放位置
        fitterViewPosition(llBt, ORIENTATION_TOP, {
            (arrFrame[3] * ratio + density * 20).toInt()
        })

        // 适配close按钮
        val top = (arrFrame[1] * ratio).toInt()
        val right = ((arrFrame[2] * ratio) - density * 24).toInt()

        val params = ivClose.layoutParams as? MarginLayoutParams
        params?.topMargin = top
        params?.leftMargin = right
        params?.let { ivClose.layoutParams = it }


        // 设置点击回调
        ivClose.setOnClickListener {
            callBack?.onClose()
        }
        ivHug.setOnClickListener {
            callBack?.onHugLiveRoom()
        }

        ivNoNotification.setOnClickListener {
            callBack?.onNoNotification()
        }
    }

    private fun getResourceLayout(): Int {
        return R.layout.view_video_gift
    }

    private var callBack: AlphaVideoGiftCallBack? = null
    private var mAnimView: AnimView? = null

    fun initPlayerController(callBack: AlphaVideoGiftCallBack? = null) {
        this.callBack = callBack

        createView()

        initLog()
        mAnimView?.setAnimListener(this)
    }




    // 开始播放
    fun startVideoGift(filePath: String, fileName: String) {
        var path = "$filePath/$fileName"
        if (TextUtils.isEmpty(path)) {
            return
        }


        if (mAnimView == null && context != null){
            createView()
        }

        Thread {
            val file = File(path)
            // 开始播放动画文件
            mAnimView?.startPlay(file)
        }.start()
    }

    /**
     * 创建视频播放View
     */
    private fun createView(){
        try {
            mAnimView = AnimView(context)
            mVideoContainer.removeAllViews()
            val param = LayoutParams(LayoutParams.MATCH_PARENT, LayoutParams.MATCH_PARENT)
            mAnimView?.layoutParams = param
            mAnimView?.setLoop(Int.MAX_VALUE)
            mAnimView?.supportMask(true,true)
            mAnimView?.enableAutoTxtColorFill(true)
            mAnimView?.setVideoMode(Constant.VIDEO_MODE_SPLIT_HORIZONTAL)
            mAnimView?.enableVersion1(true)
            mVideoContainer.addView(mAnimView)
        } catch (e:Exception) {
            e.printStackTrace()
        }

    }

    private fun initLog() {
        ALog.isDebug = BuildConfig.DEBUG
        ALog.log = object : IALog {
            override fun i(tag: String, msg: String) {
                Log.i(tag, msg)
            }

            override fun d(tag: String, msg: String) {
                Log.d(tag, msg)
            }

            override fun e(tag: String, msg: String) {
                Log.e(tag, msg)
            }

            override fun e(tag: String, msg: String, tr: Throwable) {
                Log.e(tag, msg, tr)
            }
        }
    }

    /**
     * 视频信息准备好后的回调，用于检查视频准备好后是否继续播放
     * @return true 继续播放 false 停止播放
     */
    override fun onVideoConfigReady(config: AnimConfig): Boolean {
        callBack?.onPrepared()
        return true
    }

    /**
     * 失败回调
     * 一次播放时可能会调用多次，建议onFailed只做错误上报
     * @param errorType 错误类型
     * @param errorMsg 错误消息
     */
    override fun onFailed(errorType: Int, errorMsg: String?) {
        NSLog.d(TAG,"errorType  = $errorType     errorMsg = $errorMsg")
    }

    /**
     * 视频播放结束(失败也会回调onComplete)
     */
    override fun onVideoComplete() {
        callBack?.onEndAction()
        NSLog.d(TAG,"onVideoComplete")
    }

    /**
     * 播放器被销毁情况下会调用onVideoDestroy
     */
    override fun onVideoDestroy() {
        callBack?.onError()
        NSLog.d(TAG,"onVideoDestroy")
    }

    /**
     * 视频渲染每一帧时的回调
     * @param frameIndex 帧索引
     */
    override fun onVideoRender(frameIndex: Int, config: AnimConfig?) {
        NSLog.d(TAG,"frameIndex  = $frameIndex     config = ${config.toString()}")
    }

    /**
     * 视频开始回调
     */
    override fun onVideoStart() {
//        callBack?.onPrepared()
        NSLog.d(TAG,"onVideoStart")
    }



    private inline fun <T : View> fitterViewPosition(view: T, orientation: Int, setmargin: (T) -> Int) {
        val params = view.layoutParams as? ViewGroup.MarginLayoutParams
        when (orientation) {
            ORIENTATION_TOP -> params?.topMargin = setmargin.invoke(view)
            ORIENTATION_LEFT -> {
                params?.leftMargin = setmargin.invoke(view)
                params?.rightMargin = setmargin.invoke(view)
            }
        }

        view.layoutParams = params
    }

    /**
     * 适配 View 的正确宽高
     */
    private inline fun <T : View> fitterViewSize(view: T, fitterWidth: () -> Int, noinline fitterHeight: ((Int) -> Int)? = null) {
        val params = view.layoutParams
        val width = fitterWidth.invoke()
        params.width = width

        val height = fitterHeight?.invoke(width)
        height?.let { params.height = it }
        view.layoutParams = params
    }

    fun release(){
        mVideoContainer?.removeCallbacks(null)
        mVideoContainer?.removeAllViews()
        mAnimView?.stopPlay()
    }

}