package com.ninexiu.sixninexiu.view.bottomtablayout

import android.annotation.SuppressLint
import android.content.Context
import android.text.TextUtils
import android.util.AttributeSet
import android.view.LayoutInflater
import androidx.annotation.ColorRes
import androidx.annotation.DrawableRes
import androidx.constraintlayout.widget.ConstraintLayout
import androidx.core.content.ContextCompat
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.common.AppCnfSpHelper
import com.ninexiu.sixninexiu.common.util.NSLog
import com.ninexiu.sixninexiu.common.util.Utils
import com.ninexiu.sixninexiu.view.ViewUtils
import com.ninexiu.sixninexiu.view.setVisible
import com.opensource.svgaplayer.SVGAParser
import com.opensource.svgaplayer.SVGAVideoEntity
import kotlinx.android.synthetic.main.ns_maintab_item_view_new.view.*

/**
 * <pre>
 *     @author : wtengfei
 *     time   : 2021/8/18
 *     desc   :
 *     version: 1.0
 * </pre>
 */
class TabButton : ConstraintLayout {

    private var mContext: Context
    private var svgaFileName:String? = ""   //svga 文件名称
    @DrawableRes
    private var imageSelector = 0    //选中图片
    private var title:String? = ""            //text的内容
    @ColorRes
    private var textColor:Int = R.color.selector_color_main_tab             //字的颜色
    private var isDefChecked = false                       //当前是否选中，默认是否选中
    private var isIconCheckChangeSize = false           //选中时是否更换图片大小
    private var iconSize = 26f
    private var iconChangeSize = 44f          //选中图片大小
    private var isUseSvga = false
    private var mSVGAParser: SVGAParser? = null
    private var index = 0
    private var svgaVideoEntity: SVGAVideoEntity? = null
    private var mBottomTabMessageManager: BottomTabMessageManager? = null

    constructor(mContext: Context) : this(mContext,null)

    constructor(mContext: Context, attrs: AttributeSet?) : this(mContext, attrs,0)

    @SuppressLint("Recycle")
    constructor(mContext: Context, attrs: AttributeSet?, defStyleAttr: Int) : super(mContext, attrs,defStyleAttr){
        this.mContext = mContext
        LayoutInflater.from(context).inflate(R.layout.ns_maintab_item_view_new, this)
        attrs?.let { attrit ->
            val typedArray = context.obtainStyledAttributes(attrit, R.styleable.TabButton, 0, 0)
            typedArray.let{
                if(it.hasValue(R.styleable.TabButton_tbn_svga_file_name)){
                    this.svgaFileName = it.getString(R.styleable.TabButton_tbn_svga_file_name)
                }

                if(it.hasValue(R.styleable.TabButton_tbn_image_selector)){
                    imageSelector = it.getResourceId(R.styleable.TabButton_tbn_image_selector,R.drawable.main_tab_dynamic_pressed)
                }
                if(it.hasValue(R.styleable.TabButton_tbn_title)){
                    this.title = it.getString(R.styleable.TabButton_tbn_title)
                }
                if(it.hasValue(R.styleable.TabButton_tbn_text_color)){
                    textColor = it.getResourceId(R.styleable.TabButton_tbn_text_color,R.color.selector_color_main_tab)
                }
                if(it.hasValue(R.styleable.TabButton_tbn_checked)){
                    isDefChecked = it.getBoolean(R.styleable.TabButton_tbn_checked,false)
                }
                if(it.hasValue(R.styleable.TabButton_tbn_icon_checked_change_size)){
                    isIconCheckChangeSize = it.getBoolean(R.styleable.TabButton_tbn_icon_checked_change_size,false)
                }
                it.recycle()
            }
        }
    }

    fun setSvgaFileName(svgaFileName:String){
        this.svgaFileName = svgaFileName
    }

    fun setImageSelector(@DrawableRes imageSelector:Int){
        this.imageSelector = imageSelector
        svgImageView.setImageResource(imageSelector)
    }

    fun setTitle(title:String){
        this.title = title
        textview.text = title
    }

    fun setTextColor(@ColorRes textColor:Int){
        this.textColor = textColor
        textview.setTextColor(ContextCompat.getColorStateList(context,textColor))
    }

    fun isIconCheckChangeSize(isIconCheckChangeSize:Boolean){
        this.isIconCheckChangeSize = isIconCheckChangeSize
    }

    fun setUseSvga(isUseSvga:Boolean){
        this.isUseSvga = isUseSvga
    }

    /**
     * 需先设置 isUseSvga 与 svgaFileName
     */
    fun setSVGAParser(svgaParser :SVGAParser){
        this.mSVGAParser = svgaParser
        if(!TextUtils.isEmpty(svgaFileName)){
            if(mSVGAParser!=null){
                initAnimator()
            }else{
                if(isUseSvga){
                    mSVGAParser = SVGAParser(mContext)
                    initAnimator()
                }
            }
        }
    }

    fun setChecked(checked :Boolean){
        this.isDefChecked = checked
        isSelected = isDefChecked
    }

    fun setBottomManager(mBottomTabMessageManager: BottomTabMessageManager){
        this.mBottomTabMessageManager = mBottomTabMessageManager
    }
    fun setIndex(index :Int){
        this.index = index
    }

    fun initAnimator(){
        try {
            svgaFileName?.let {
                mSVGAParser?.decodeFromAssets(it, object :SVGAParser.ParseCompletion{
                    override fun onComplete(videoItem: SVGAVideoEntity) {
                        svgaVideoEntity = videoItem
                        if(isIconCheckChangeSize && isDefChecked){
                            svgImageView.setVideoItem(videoItem)
                            setFirstTabScale(true)
                            svgImageView.startAnimation()
                        }
                    }
                    override fun onError() {
                        svgImageView.setImageResource(imageSelector)
                        NSLog.e("onError parseSVGA " + 0)
                    }

                })
            }
        } catch (e:Exception) {
            svgImageView.setImageResource(imageSelector)
            e.printStackTrace()
        }
    }

    /**
     * bottomlayout tab 点击设置选中view状态
     */
    fun clickComment() {
        // 没有活动的话播放动画
        if (isUseSvga) {
            if (index == 0 && isIconCheckChangeSize) {
                setFirstTabScale(true)         // 第一个tab放大
            }
            try {
                // 选中的tab设置svga
                svgImageView.setVideoItem(svgaVideoEntity)
                svgImageView.startAnimation()
//                iconImageList.get(mCurrentTabIndex).setVideoItem(videoEntitySparseArray.get(mCurrentTabIndex))
//                iconImageList.get(mCurrentTabIndex).startAnimation()
            } catch (e: Exception) {
                NSLog.d("animation " + e.message)
            }
        }

        isDefChecked = true
        isSelected = true
    }

    /**
     * bottomlayout tab 点击释放上次选中的view
     */
    fun clickReset(){
        if (svgImageView.isAnimating) {
            svgImageView.stopAnimation()
        }
        svgImageView.setImageResource(imageSelector)
        if (index == 0 && isIconCheckChangeSize) {
            setFirstTabScale(false)        // 第一个tab恢复
        }
        isDefChecked = false
        isSelected = false
    }

    fun hideMessageView(){
        ViewUtils.hideView(imageview_tag)
        ViewUtils.hideView(tv_sysmsg_count)
        ViewUtils.hideView(tv_msg_count)
    }

    fun refershInfoRemind(){
        ViewUtils.hideView(tv_sysmsg_count)
        mBottomTabMessageManager?.postHotRemindMessage(imageview_tag, tv_msg_count)
    }

    fun refreshTabView(index: Int,showSysMsg: Int){
        val position = index
        when (position) {
            2 -> {
                if (showSysMsg == 0) {
                    ViewUtils.hideView(tv_sysmsg_count)
                    ViewUtils.hideView(tv_msg_count)
                } else {
                    ViewUtils.showView(tv_sysmsg_count)
                }
            }
            3 -> {
                if (AppCnfSpHelper.getInstance().showGameCenter == 0) {
                    val isUseOnkeyRegist = NineShowApplication.isUseOnekeyReister()
                    val isonkeyRegistChangePwd = NineShowApplication.isChangeOnekeyReisterPwd()
                    if (NineShowApplication.mAccountManager.isUserLogin
                            && isUseOnkeyRegist && !isonkeyRegistChangePwd) {
                        ViewUtils.hideView(imageview_tag)
                    }
                } else {
                    val isClick = AppCnfSpHelper.getInstance().isClickDiscover
                    if (isClick) {
                        ViewUtils.hideView(imageview_tag)
                    } else {
                        ViewUtils.showView(imageview_tag)
                    }
                }
            }
            4 -> {
                val isUseOnkeyRegist = NineShowApplication.isUseOnekeyReister()
                val isonkeyRegistChangePwd = NineShowApplication.isChangeOnekeyReisterPwd()
                if (NineShowApplication.mAccountManager.isUserLogin
                        && isUseOnkeyRegist && !isonkeyRegistChangePwd) {
                    ViewUtils.hideView(imageview_tag)
                }
            }
            else -> {
            }
        }
    }

    fun refershMessageUnread(){
        mBottomTabMessageManager?.refershMessageUnread(tv_msg_count)
    }

    fun hidePersonalCenterTag(){
        imageview_tag?.let {
            it.bringToFront()
            ViewUtils.hideView(it)
        }
    }

    fun hideSysMsgCountView(){
        ViewUtils.hideView(tv_sysmsg_count)
    }

    // 设置第一个条目的变化
    private fun setFirstTabScale(scale: Boolean) {
        textview.setVisible(!scale)

        val params = svgImageView.layoutParams
        val getWidth = if(scale){
            Utils.dip2px(context, iconChangeSize)
        }else{
            Utils.dip2px(context, iconSize)
        }
        params.width = getWidth
        params.height = getWidth
        svgImageView.layoutParams = params
    }

}