package com.ninexiu.sixninexiu.view.dialog

import android.content.Context
import android.graphics.Color
import android.text.TextUtils
import android.view.Gravity
import android.view.View
import android.view.Window
import androidx.core.content.ContextCompat
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.bean.BaseResultInfo
import com.ninexiu.sixninexiu.common.net.NSGsonObjectNewCallback
import com.ninexiu.sixninexiu.common.net.NSRequestParams
import com.ninexiu.sixninexiu.common.net.NsOkHttpClient
import com.ninexiu.sixninexiu.common.util.*
import com.ninexiu.sixninexiu.view.fitterViewSize
import com.tencent.qcloud.tim.uikit.PushContants
import kotlinx.android.synthetic.main.dialog_activity_jimiao_card.*
import org.json.JSONObject

/**
 * <pre>
 *     @author : gh
 *     time   : 2021/1/11 0011
 *     desc   : 新年集喵-卡片弹框
 *     version: 1.0
 *     dstUid : 不为空- 赠送， 空- 领取
 *     status : 1- 已使用， 0- 可以使用
 * </pre>
 */
class ActivityJiMiaoCardDialog(val mContext: Context, val dstUid: String, val uniKey: String, val status: Int) : BaseDialog(mContext), View.OnClickListener {

    var onSubmitInterface: OnSubmitInterface? = null

    private val screenWidth: Int by lazy {
        NineShowApplication.applicationContext.resources.displayMetrics.widthPixels
    }

    override fun getContentView() = R.layout.dialog_activity_jimiao_card

    override fun initView() {
        super.initView()
        if (PushContants.ISINLIVEROOM){
            fitterViewSize(bottom_view, { 100 }, { (screenWidth * 0.06666).toInt() })
        }
    }

    override fun initDatas() {
        super.initDatas()

        getData()
    }

    override fun initEvents() {
        super.initEvents()
        btn_activity_jimiao_look.setOnClickListener(this)

    }

    override fun getWindows(window: Window?) {
        super.getWindows(window)
        if (window != null && PushContants.ISINLIVEROOM){
            window.setGravity(Gravity.BOTTOM)
        }
    }

    /**
     * 获取详细喵信息
     */
    private fun getData() {
        var nsOkHttpClient = NsOkHttpClient.getNsOkHttpClient()
        val params = NSRequestParams()
        params.put("uni_key", uniKey)
        params.put("type", if (!TextUtils.isEmpty(dstUid))  "send" else "claim")
        nsOkHttpClient.doGet(Constants.GET_USER_STOCK_MIAO_INFO, params, object : NSGsonObjectNewCallback<BaseResultInfo>() {

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: BaseResultInfo?) {
                if (responseString != null) {
                    val jsonObject: JSONObject
                    try {
                        jsonObject = JSONObject(responseString)
                        val code = jsonObject.optInt("code")
                        val msg = jsonObject.optString("message")
                        if (code == 200) {
                            val data = jsonObject.optJSONObject("data")
                            val cover_url = data.optString("cover_url")
                            val count = data.optInt("count")
                            // 是否在活动期限内
                            val is_expire = data.optInt("is_expire")

                            if (!TextUtils.isEmpty(dstUid)) {
                                btn_activity_jimiao_look.text = "赠送1只"
                                btn_activity_jimiao_look.setTextColor(Color.parseColor("#FFD18D"))

                            } else {
                                btn_activity_jimiao_look.text = "收下"
                                btn_activity_jimiao_look.setTextColor(Color.parseColor("#FB2418"))
                            }

                            if (status == 0 && is_expire == 0) {

                                btn_activity_jimiao_look.isEnabled = true
                                mContext?.let {
                                    if (!TextUtils.isEmpty(dstUid)) {
                                        btn_activity_jimiao_look.background = ContextCompat.getDrawable(it, R.drawable.btn_activity_jimiao_card_give)
                                    } else {
                                        btn_activity_jimiao_look.background = ContextCompat.getDrawable(it, R.drawable.activity_im_jimiao_card_btn)
                                    }
                                }


                            } else {

                                btn_activity_jimiao_look.isEnabled = false
                                btn_activity_jimiao_look.setTextColor(Color.parseColor("#FFFFFF"))
                                btn_activity_jimiao_look.background = ContextCompat.getDrawable(context, R.drawable.btn_activity_jimiao_card_no)
                            }

                            if (count <= 0) {
                                tv_miao_count.visibility = View.GONE
                            } else {
                                tv_miao_count.visibility = View.VISIBLE
                                tv_miao_count.text = "${count}"
                            }

                            GlideUtils.loadNormalImg(context, cover_url, iv_jimiao_card_icon)

                        } else {
                            if (!TextUtils.isEmpty(msg)) {
                                MyToast.showShort(msg)
                            } else {
                                MyToast.MakeToast("获取失败")
                            }
                        }

                    } catch (e: Exception) {
                        e.printStackTrace()
                        MyToast.MakeToast("获取失败")
                    }
                }
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                if (!TextUtils.isEmpty(errorMsg)) {
                    MyToast.MakeToast(errorMsg)
                }
            }

        })
    }

    override fun onClick(v: View?) {
        if (!isShowing) {
            return
        }
        when (v?.id) {
            R.id.btn_activity_jimiao_look -> {
                if (btn_activity_jimiao_look.background == ContextCompat.getDrawable(context, R.drawable.btn_activity_jimiao_card_no)) {
                    dismiss()
                    return
                }

                sendData()
            }

        }
    }


    /**
     * @type 0- 赠送； 1- 领取
     */
    fun sendData() {
        val asyncHttpClient = NsOkHttpClient.getNsOkHttpClient()
        val params = NSRequestParams()
        var url = Constants.GET_CLAIM_MIAO
        if (!TextUtils.isEmpty(dstUid)) {
            url = Constants.GET_GIVE_ASKER_MIAO
            params.put("dstuid", dstUid)
        }
        params.put("uni_key", uniKey)
        asyncHttpClient.doPost(url, params, object : NSGsonObjectNewCallback<BaseResultInfo?>() {

            override fun onSuccess(statusCode: Int, rawJsonResponse: String?, message: String?, response: BaseResultInfo?) {

                if (rawJsonResponse != null && context != null) {
                    val jsonObject: JSONObject
                    try {
                        jsonObject = JSONObject(rawJsonResponse)
                        val code = jsonObject.optInt("code")
                        val message = jsonObject.optString("message")

                        if (code == 200 || code == 402) {
                            onSubmitInterface?.onSumitSuccess(uniKey)
                        }

                        MyToast.showShort(message)
                        if (isShowing) dismiss()

                    } catch (e: Exception) {
                        e.printStackTrace()
                        MyToast.showShort(if (!TextUtils.isEmpty(dstUid)) "赠送" else "领取" + "卡片失败")
                        if (isShowing) dismiss()
                    }
                }
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {
                MyToast.showShort(errorMsg)
                if (isShowing) dismiss()
            }
        })
    }

    interface OnSubmitInterface {

        fun onSumitSuccess(uniKey: String)
    }

}