package com.ninexiu.sixninexiu.view.dialog

import android.content.Context
import android.util.Pair
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.common.util.MyToast
import com.ninexiu.sixninexiu.common.util.NSLog
import kotlinx.android.synthetic.main.dialog_announcement_edit.*

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/09/10
 *     desc   : 针对多人语音房，主持人编辑公告
 *     version: 1.0
 * </pre>
 */
class AnnouncementEditDialog(context: Context, val title: String?, val content: String?) : BaseDialog(context) {
    companion object {
        const val ANNOUNCEMENT_SAVE = 0     // 保存公告
        const val ANNOUNCEMENT_SEND = 1     // 发送公告
    }

    var saveOrSendClick: ((Int, String) -> Unit)? = null

    override fun initView() {
        super.initView()
        NSLog.d("TheAnnouncementTitle :", "title : ${title}, content : ${content}")
        tvInfo?.text = title ?: "输入话题"

        if(!content.isNullOrBlank()) {
            etContent?.setText(content)
        }else {
            etContent?.hint = "输入话题"
        }

        etContent.setSelection(etContent?.text?.toString()?.length?:0)

        tvSave.setOnClickListener {
            next(ANNOUNCEMENT_SAVE)
        }

        tvSend.setOnClickListener {
            next(ANNOUNCEMENT_SEND)
        }
    }

    fun updateTitleContent(pair: Pair<String?, String?>) {
        NSLog.d("TheAnnouncementTitle :", "title : ${pair.first}, content : ${pair.second}")
        tvInfo?.text = pair.first ?: "输入话题"

        val content : String? = pair.second
        if(!content.isNullOrBlank()) {
            etContent?.setText(content)
        }else {
            etContent?.hint = "输入话题"
        }

        etContent.setSelection(etContent?.text?.toString()?.length?:0)

        etContent?.clearFocus()
    }

    // 判断内容是否为空
    private fun next(type: Int) {
        val content = etContent?.text?.toString()
        if (content?.isBlank() != false) {
            MyToast.MakeToast("您输入的内容为空喔！")
            return
        }

        saveOrSendClick?.invoke(type, content)

        dismiss()
    }


    override fun getContentView() = R.layout.dialog_announcement_edit
    override fun isBottom() = true

}