package com.ninexiu.sixninexiu.view.dialog

import android.annotation.SuppressLint
import android.app.Activity
import android.content.Context
import android.graphics.Color
import android.graphics.drawable.ColorDrawable
import android.os.Handler
import android.text.TextUtils
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.ImageView
import android.widget.LinearLayout
import android.widget.PopupWindow
import android.widget.TextView
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.common.ConfigSpHelper
import com.ninexiu.sixninexiu.common.util.NSLog
import com.ninexiu.sixninexiu.common.util.TimeUtil
import com.ninexiu.sixninexiu.view.UserReturnGsonHelper
import com.ninexiu.sixninexiu.view.popwindow.BasePopupWindow

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/05/17
 *     desc   : 直播间关闭
 *     version: 1.0
 * </pre>
 */
class AnnouncementPopWindow(context: Context) : PopupWindow(context) {
    private var handler: Handler = Handler()
    private var ivWarm: ImageView? = null
    private var tvTitle: TextView? = null
    private var tvInfo: TextView? = null
    private var warn = false

    @SuppressLint("InflateParams")
    var view : View = LayoutInflater.from(context).inflate(R.layout.layout_announcement_pop,null,false)

    init {
        tvTitle = view.findViewById(R.id.tvTitle)
        tvInfo = view.findViewById(R.id.tvInfo)

        val llWarm: LinearLayout = view.findViewById(R.id.llWarm)
        ivWarm = view.findViewById(R.id.ivWarm)

        // 是否选择了今日不再提醒
        warn = ConfigSpHelper.getInstance().voiceRoomAnnounce
        setWarnImg(warn)

        llWarm.setOnClickListener {
            // 用户选择进入不再提醒
            warn = !warn
            ConfigSpHelper.getInstance().voiceRoomAnnounce = warn
            setWarnImg(warn)
        }


        contentView = view

        this.width = ViewGroup.LayoutParams.WRAP_CONTENT
        this.height = ViewGroup.LayoutParams.WRAP_CONTENT
        this.isFocusable = true
        val dw = ColorDrawable(Color.TRANSPARENT)
        setBackgroundDrawable(dw)


        setOnDismissListener {
            handler.removeCallbacks(runnable)
        }
    }


    private val runnable = Runnable {
        if (context != null && context is Activity && !context.isFinishing) {
            dismiss()
        }
    }

    private fun setWarnImg(warn: Boolean) {
        NSLog.d("AnnouncementPopWindow : ", "warn : $warn")
        if (warn) {
            ivWarm?.setImageResource(R.drawable.ic_announce_confirm)
        } else {
            ivWarm?.setImageResource(R.drawable.ic_announce_cancel)
        }
    }

    fun showCustom(tvAnnouncement: TextView?, title: String?, desc: String?, auto: Boolean) {  // auto : 是否要自动关闭
        tvTitle?.text = title
        tvInfo?.text = desc

        // 公告是自动打开的，需要自动关闭
        if(auto) {
            handler.removeCallbacks(runnable)
            handler.postDelayed(runnable, 2000)
        }

        showAsDropDown(tvAnnouncement)
    }

    // 获取公告弹出的时间(要求 : 公告可以设置不再提醒,但是只有一天有效期)
    companion object {
        fun getAnnouncementStatus() {
            val preTime = ConfigSpHelper.getInstance().voiceAnnounceMent

            val currentTime = TimeUtil.getUserReturnDayTime(System.currentTimeMillis())

            // NSLog.d("AnnouncementPopWindow : ", "pre : $preTime , cur : $currentTime")
            if (TextUtils.isEmpty(preTime) || preTime != currentTime) {
                // 重置弹窗里面的不再提醒
                ConfigSpHelper.getInstance().voiceRoomAnnounce = false
                // 时间更新
                ConfigSpHelper.getInstance().voiceAnnounceMent = currentTime
            }
        }

        // todo : 暂时先负责处理麦位顺序的转换
        fun transformMicNum(number : Int) : Int {
            var tempNum = number
            when(number) {
                3 -> tempNum = 5
                4 -> tempNum = 6
                5 -> tempNum = 3
                6 -> tempNum = 4
            }
            return tempNum
        }
    }
}