package com.ninexiu.sixninexiu.view.dialog

import android.annotation.SuppressLint
import android.app.Activity
import android.content.Context
import android.graphics.Paint
import android.text.TextUtils
import android.view.View
import androidx.recyclerview.widget.LinearLayoutManager
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.activity.AccountBindPhoneActivity
import com.ninexiu.sixninexiu.adapter.AutumnChargeTitleAdapter
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.bean.AutumnChargeBean
import com.ninexiu.sixninexiu.bean.AutumnChargeItemBean
import com.ninexiu.sixninexiu.broadcast.AppBroadcastHelper
import com.ninexiu.sixninexiu.common.net.NSGsonObjectNewCallback
import com.ninexiu.sixninexiu.common.net.NsOkHttpClient
import com.ninexiu.sixninexiu.common.util.*
import com.ninexiu.sixninexiu.pay.PayUtil
import com.ninexiu.sixninexiu.view.*
import kotlinx.android.synthetic.main.dialog_autumn_charge.*

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/08/06
 *     desc   :
 *     version: 1.0
 * </pre>
 */
class AutumnChargeDialog(val activity: Activity, val rid: Int) : BaseDialog(activity) {
    companion object {
        const val Tag = "AutumnChargeDialog : "
        const val from_type = "golden_fall"
        const val sub_type = "goldenFall"
    }

    override fun getContentView() = R.layout.dialog_autumn_charge

    override fun initDatas() {
        super.initDatas()
        getAutumnData()
    }

    // todo : https://www.9xiu.com/activity/activity_2021GoldenFall/getCanBuyPack
    private fun getAutumnData() {
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.GET_AUTUMN_GIFT, null, object : NSGsonObjectNewCallback<AutumnChargeBean>() {
            override fun onFailure(statusCode: Int, errorMsg: String?) {
                MyToast.showShort(errorMsg ?: "")
            }

            @SuppressLint("SetTextI18n")
            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: AutumnChargeBean?) {
                MyToast.showShort(message ?: "")
                if(statusCode == 200) {
                    setData(response?.data?.data)
                    tvTime?.text = "${response?.data?.starTime} - ${response?.data?.endTime}"
                }
            }
        })
    }

    // 处理数据
    var chosePos = -1

    var autumnData = mutableListOf<AutumnChargeItemBean>()
    private fun setData(data: List<AutumnChargeItemBean>?) {
        if (data.isNullOrEmpty()) {
            return
        }

        // 补充情况，移除直播间内的banner
        if(data[0].status == 2) {
            AppBroadcastHelper.getInstance().sendBroadcast(NSReceiverAction.ACTION_NEW_AUTUMN_ALREADY_CHARGE)
        }

        // todo : 存储状态
        UserReturnGsonHelper.setNewAutumnActiveStatus()

        chosePos = -1

        autumnData.clear()
        autumnData.addAll(data)

        for ((pos, item) in autumnData.withIndex()) {
            if (item.status == 1) {
                chosePos = pos
                item.selected = true
                break
            }
        }

        if (chosePos == -1) {
            chosePos = 0
            autumnData[0].selected = true
        }

        // 设置选中项
        setPriceTabSelected(chosePos)

        titleAdapter.notifyDataSetChanged()
    }

    private var autumnRulePop: AutumnRulePopWindow? = null
    private lateinit var titleAdapter: AutumnChargeTitleAdapter
    override fun initView() {
        super.initView()

        // 1. 初始化 recy
        recy.layoutManager = LinearLayoutManager(context, LinearLayoutManager.HORIZONTAL, false)
        titleAdapter = AutumnChargeTitleAdapter(context,autumnData)
        recy.adapter = titleAdapter

        // 切换tab
        titleAdapter.onItemClick = { pos ->
            if (!autumnData.isNullOrEmpty() && pos < autumnData.size) {
                chosePos = pos

                autumnData.forEachIndexed { index, item -> item.selected = index == pos }
                titleAdapter.notifyDataSetChanged()
                setPriceTabSelected(pos)
            }
        }

        // 规则
        ivRule.setOnClickListener {
            if (autumnRulePop == null) {
                autumnRulePop = AutumnRulePopWindow(context)
            }
            autumnRulePop?.showAsDropDown(ivRule, 0, 10)
        }

        tvPast.paint.flags = Paint.STRIKE_THRU_TEXT_FLAG; //中划线

        // 设置
        ivBuy.setOnClickListener {
            if (!autumnData.isNullOrEmpty() && chosePos < autumnData.size && autumnData[chosePos].status == 1) {
                showPayDialog(autumnData[chosePos])
            }
        }

        val widthScreen = getScreenWidth(context)

        dialogContainer.post {
            fitterViewSize(dialogContainer, { (0.8373 * widthScreen).toInt() }, { (1.46 * it).toInt() })
            fitterViewSize(constraintBottom, { (0.8373 * widthScreen).toInt() }, { (0.912 * widthScreen).toInt() })
            fitterViewSize(ivGift, { (0.7973 * widthScreen).toInt() }, { (0.8027 * it).toInt() })
            fitterViewPosition(recy, ORIENTATION_TOP, { (0.2267 * widthScreen).toInt() })
            fitterViewPosition(ivGift, ORIENTATION_TOP, { (0.1307 * widthScreen).toInt() })
            fitterViewPosition(tvTime, ORIENTATION_TOP, { (0.0533 * widthScreen).toInt() })
            // fitterViewSingleMargin(tvTime, ORIENTATION_LEFT, { (0.021 * widthScreen).toInt() })
        }
    }


    // 购买
    private fun showPayDialog(bean: AutumnChargeItemBean) {
        if (TextUtils.isEmpty(NineShowApplication.mUserBase?.phone)) {
            CommonConfirmCancelNoTitleDialog(context, "请先绑定手机号", "再想想", "去绑定", onConfirm = {
                AccountBindPhoneActivity.startActivity(context, AccountBindPhoneActivity.TYPE_BIND_PHONE)
            }).show()
            return
        }

        PayDialog.showDialog(context, rid, bean.price, PayUtil.NEW_AUTUMN_ORDER, sub_type, bean.img)
    }

    @SuppressLint("SetTextI18n")
    private fun setPriceTabSelected(pos: Int) {
        if (autumnData.isNullOrEmpty() || pos >= autumnData.size) {
            return
        }

        val item = autumnData[pos]
        if(activity != null && !activity.isFinishing) {
            GlideUtils.loadNormalImg(activity, item.img, ivGift)
        }
        if(item.status == 2) {
            ivBuy?.visibility = View.INVISIBLE
        }else {
            ivBuy.setVisible(true)
            ivBuy.setImageResource(if (item.status == 1) R.drawable.ic_autumn_can_buy else R.drawable.ic_autumn_can_not_buy)
        }
        tvPast.text = "${item.cost_price}元"
        tvNow.text = "${item.price}"
    }
}