package com.ninexiu.sixninexiu.view.dialog

import android.app.Activity
import android.graphics.Color
import android.text.TextUtils
import android.widget.TextView
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.bean.BaseResultInfo
import com.ninexiu.sixninexiu.common.net.NSGsonObjectNewCallback
import com.ninexiu.sixninexiu.common.net.NSRequestParams
import com.ninexiu.sixninexiu.common.net.NsOkHttpClient
import com.ninexiu.sixninexiu.common.util.Constants
import com.ninexiu.sixninexiu.common.util.MyToast
import kotlinx.android.synthetic.main.dialog_bidding_shop_bid.*
import org.json.JSONException
import org.json.JSONObject
import java.math.BigDecimal
import java.math.RoundingMode
import java.text.DecimalFormat

/**
 * <pre>
 *     @author : gh
 *     time   : 2021/4/13 0013
 *     desc   : 竞价商品购买
 *     version: 1.0
 * </pre>
 */
class BiddingShopBidDialog(val context: Activity) :BaseDialog(context){

    var biddingMarginRuleDialog:BiddingMarginRuleDialog? = null
    var bidShopInterface:BidShopInterface? = null

    val THOUSAND: Long = 1000
    val TENTHOUSAND: Long = 10000
    val TENMILLION: Long = 10000000
    val A_HUNDRED_MILLION: Long = 100000000

    override fun getContentView(): Int {
        return R.layout.dialog_bidding_shop_bid
    }

    override fun setDialogWith(): Float {
        return 1f
    }

    override fun setBackgroundDimAlpha(): Float {
        return 0f
    }

    override fun isBottomPop(): Boolean {
        return true
    }
    lateinit var goodsId: String
    var starPrice:String = ""
    var incrbyPrice:String = ""
    var depositPrice: String = ""
    var cache: String = "0.0"
    val df = DecimalFormat("0.00")


    fun refershPreice(starPrice: String){
        if (isShowing) {
            this.cache = starPrice
//            var currentPrice :Float =  starPrice.toFloat()
//            currentPrice += incrbyPrice.toFloat()
//            this.starPrice = "${df.format(currentPrice)}"
        }
    }



    fun showDialog(goodsId: String, starPrice:String, incrbyPrice:String, depositPrice: String){
        this.goodsId = goodsId
        this.starPrice = starPrice
        this.incrbyPrice = incrbyPrice
        this.depositPrice = depositPrice

        if (!isShowing){
            show()
        }
        if(TextUtils.isEmpty(starPrice)){
            this.starPrice = "0.0"
        }

        if(TextUtils.isEmpty(incrbyPrice)){
            this.incrbyPrice = "0.0"
        }

         if(TextUtils.isEmpty(depositPrice)){
            this.depositPrice = "0.0"
        }
        setTvPriceCompress(tv_remove_price, incrbyPrice.toFloat())
        setTvPriceCompress(tv_add_price, incrbyPrice.toFloat())
        //tv_remove_price?.text = "$incrbyPrice"
        //tv_add_price?.text = "$incrbyPrice"
        tv_num_price?.text = trimZero(starPrice.toFloat())

    }

    /**
     * 设置大数字的缩写
     */
    private fun setTvPriceCompress(tv: TextView, price: Float) {
        if (price < 0) {
            return
        }
        if (price >= TENTHOUSAND) {//大于1万
            tv.text = "${trimZero(price / TENTHOUSAND)}万"
        }else{
            tv.text = trimZero(price)
        }
    }

    /**
     * 保留两位 数字尾部去零
     */
    private fun trimZero(price: Float): String {
        val number = BigDecimal(price.toDouble())
        return number.setScale(2, RoundingMode.HALF_UP).stripTrailingZeros().toPlainString()
    }

    override fun onStop() {
        super.onStop()
        // 隐藏保证金弹框
        if (biddingMarginRuleDialog != null && biddingMarginRuleDialog!!.isShowing){
            biddingMarginRuleDialog?.dismiss()
        }
        bidShopInterface?.onBidHide()
    }

    override fun initView() {
        super.initView()
        ly_num?.delegate?.backgroundColor = Color.parseColor("#4D000000")
    }

    override fun initEvents() {
        super.initEvents()
        btn_submit.setOnClickListener {
            submitData()
        }

        tv_remove_price.setOnClickListener {

            var numberStr = tv_num_price?.text.toString()
            if (TextUtils.isEmpty(numberStr)){
                numberStr = "0.0"
            }

            var value:Float = 0.0f
            if (cache.toFloat() > numberStr.toFloat()){
                value = cache.toFloat()
            } else {
                value = numberStr.toFloat()
            }

            var currentPrice :Float = value
            currentPrice -= incrbyPrice.toFloat()
            if (currentPrice < starPrice.toFloat()){
                MyToast.showShort("不能低于已出价格！")
                return@setOnClickListener
            }
            tv_num_price.text = trimZero(currentPrice)
            cache = "${df.format(currentPrice)}"
        }

        tv_add_price.setOnClickListener {
            var numberStr = tv_num_price?.text.toString()
            if (TextUtils.isEmpty(numberStr)){
                numberStr = "0.0"
            }
            var value:Float = 0.0f
            if (cache.toFloat() > numberStr.toFloat()){
                value = cache.toFloat()
            } else {
                value = numberStr.toFloat()
            }
            var currentPrice :Float = value
            currentPrice += incrbyPrice.toFloat()
            if (currentPrice < starPrice.toFloat()){
                MyToast.showShort("不能高于起拍价！")
                return@setOnClickListener
            }
            tv_num_price.text = trimZero(currentPrice)
            cache = "${df.format(currentPrice)}"
        }

    }

    /**
     * 竞拍的商品-加价
     */
    fun submitData(){

        var okHttpClient = NsOkHttpClient.getNsOkHttpClient()
        var params = NSRequestParams()
        params.put("goods_id",goodsId)
        params.put("amount",tv_num_price?.text.toString())
        okHttpClient.doGet(Constants.GET_SHOP_SUBMITAUCTIONPRICE, params, object : NSGsonObjectNewCallback<BaseResultInfo>() {

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: BaseResultInfo?) {
                if (context == null){
                    return
                }
                if (statusCode == 401){
                    if (biddingMarginRuleDialog == null){
                        biddingMarginRuleDialog = BiddingMarginRuleDialog(context)
                    }

                    biddingMarginRuleDialog?.showDialog(goodsId,depositPrice)

                } else if (statusCode == 403) {
                    MyToast.showShort(message)
                    try {
                        var jsonObject = JSONObject(responseString)
                        var dataBean = jsonObject?.optJSONObject("data")
                        var amount = dataBean?.optString("amount")
                        if (TextUtils.isEmpty(amount)){
                            amount = "0"
                        }
                        cache = df.format(amount?.toFloat())
                    } catch (e: JSONException) {
                        e.printStackTrace()
                    }
                } else {
                    MyToast.showShort(message)
                }
            }

            override fun onFailure(statusCode: Int, errorMsg: String?) {

            }

        })
    }

    interface BidShopInterface {
        fun onBidHide()
    }

}
