package com.ninexiu.sixninexiu.view.dialog

import android.content.Context
import android.graphics.Color
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.view.dp2px
import com.ninexiu.sixninexiu.view.fitterViewSize
import com.selector.picture.utils.SystemUtils
import kotlinx.android.synthetic.main.dialog_common_confirm_cancel.*
import kotlinx.android.synthetic.main.dialog_common_confirm_cancel.dialogContainer
import kotlinx.android.synthetic.main.dialog_common_confirm_cancel.tvCancel
import kotlinx.android.synthetic.main.dialog_common_confirm_cancel.tvConfirm
import kotlinx.android.synthetic.main.dialog_common_confirm_cancel.tvInfo
import org.jetbrains.anko.displayMetrics

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/03/09
 *     desc   : 通用提示弹窗
 *     version: 1.0
 * </pre>
 */
class CommonConfirmCancelDialog(
    context: Context,
    val title: String? = null,
    val info: String? = null,
    val cancel: String? = null,
    val confirm: String? = null,
    val onCancel: (() -> Unit)? = null,
    val onConfirm: (() -> Unit)? = null
) : BaseDialog(context) {
    companion object {
        fun showDialog(
            context: Context,
            title: String? = null,
            info: String? = null,
            onConfirm: (() -> Unit)? = null
        ) {
            CommonConfirmCancelDialog(context, title, info, null, null, null, onConfirm).show()
        }

        fun showDialog(
            context: Context,
            title: String? = null,
            info: String? = null,
            cancel: String? = null,
            confirm: String? = null,
            onConfirm: (() -> Unit)? = null
        ) {
            CommonConfirmCancelDialog(context, title, info, cancel, confirm, null, onConfirm).show()
        }

        fun showDialog(context: Context, title: String? = null, info: String? = null) {
            CommonConfirmCancelDialog(context, title, info).show()
        }
    }

    override fun getContentView(): Int {
        return R.layout.dialog_common_confirm_cancel
    }

    fun cancelTextColor(color: String) {
        tvCancel.setTextColor(Color.parseColor(color))
    }

    fun cancelTextSize(sp: Float) {
        tvCancel.textSize = SystemUtils.sp2px(context,sp).toFloat()
    }

    fun contentTextColor(color: String) {
        tvCancel.setTextColor(Color.parseColor(color))
    }

    fun contentTextSize(sp: Float) {
        tvCancel.textSize = SystemUtils.sp2px(context,sp).toFloat()
    }

    fun commitTextColor(color: String) {
        tvCancel.setTextColor(Color.parseColor(color))
    }

    fun commitTextSize(sp: Float) {
        tvCancel.textSize = SystemUtils.sp2px(context,sp).toFloat()
    }

    override fun initView() {
        super.initView()
        tvTitle.text = title ?: "提示"
        tvInfo.text = info
        tvCancel.text = cancel ?: "取消"
        tvConfirm.text = confirm ?: "解绑"

        tvCancel.setOnClickListener {
            onCancel?.invoke()
            dismiss()
        }

        tvConfirm.setOnClickListener {
            onConfirm?.invoke()
            dismiss()
        }

        // 适配
        val width = context.displayMetrics.widthPixels
        fitterViewSize(dialogContainer, { (width * 0.72).toInt() }, { (it * 0.589).toInt() })
    }

    override fun dismiss() {
        super.dismiss()
    }

}