package com.ninexiu.sixninexiu.view.dialog

import android.annotation.SuppressLint
import android.app.Activity
import android.content.Context
import android.graphics.Color
import android.graphics.Rect
import android.graphics.drawable.ColorDrawable
import android.graphics.drawable.Drawable
import android.os.Build
import android.view.Gravity
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.PopupWindow
import android.widget.TextView
import androidx.annotation.ColorInt
import androidx.annotation.RequiresApi
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.view.dp2px
import com.ninexiu.sixninexiu.view.setViewsVisible
import com.ninexiu.sixninexiu.view.setVisible

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/05/17
 *     desc   : 直播间关闭
 *     version: 1.0
 * </pre>
 */
class DynamicPublishPopWindow(context: Context,var isAnchor : Boolean,onClick: ((Int) -> Unit)? = null) : PopupWindow(context) {
    companion object {
        const val TYPE_PUBLISH_DYNAMIC = 0
        const val TYPE_PUBLISH_VIDEO = 1
    }

    private var tvPublishDynamic: TextView? = null
    private var tvPublishVideo: TextView? = null
    private var viewDivider : View? = null

    @SuppressLint("InflateParams")
    var view: View = LayoutInflater.from(context).inflate(R.layout.layout_dynamic_publish_pop, null, false)

    init {
        tvPublishDynamic = view.findViewById(R.id.tvPublishDynamic)
        tvPublishVideo = view.findViewById(R.id.tvPublishVideo)
        viewDivider = view.findViewById(R.id.viewDivider)

        tvPublishDynamic?.setOnClickListener {
            onClick?.invoke(TYPE_PUBLISH_DYNAMIC)
            dismiss()
        }

        tvPublishVideo?.setOnClickListener {
            onClick?.invoke(TYPE_PUBLISH_VIDEO)
            dismiss()
        }

        contentView = view

        this.width = dp2px(context,122)
        if(isAnchor){
            this.height =  dp2px(context,102)
            viewDivider.setVisible(true)
            tvPublishVideo.setVisible(true)
        }else {
            this.height =  dp2px(context,54)
            viewDivider.setVisible(false)
            tvPublishVideo.setVisible(false)
        }

        this.isFocusable = true
        val dw = ColorDrawable(Color.TRANSPARENT)
        setBackgroundDrawable(dw)

        setOnDismissListener {
            clearBackgroundDim()
        }
    }

    fun showAsDropDownSelf(anchor: View, xoff: Int, yoff: Int) {
        handleBackgroundDim()
        showAsDropDown(anchor, xoff, yoff)
    }

    private fun handleBackgroundDim() {
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.JELLY_BEAN_MR2) {
            if (contentView != null && contentView.context != null &&
                    contentView.context is Activity) {
                val activity = contentView.context as? Activity
                activity?.let {
                    applyDim(it)
                }
            }
        }
    }

    @ColorInt
    private val mDimColor = Color.BLACK

    private val mDimValue = 0.3f

    @RequiresApi(api = Build.VERSION_CODES.JELLY_BEAN_MR2)
    private fun applyDim(activity: Activity) {
        val parent = activity.window.decorView.rootView as? ViewGroup
        val dimDrawable: Drawable = ColorDrawable(mDimColor)
        parent?.let {
            dimDrawable.setBounds(0, 0, parent.width, parent.height)
            dimDrawable.alpha = (255 * mDimValue).toInt()
            val overlay = parent.overlay
            overlay?.add(dimDrawable)
        }
    }


    private fun clearBackgroundDim() {
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.JELLY_BEAN_MR2) {
            if (contentView != null) {
                val activity = contentView.context as? Activity
                activity?.let { clearDim(it) }
            }
        }
    }

    @RequiresApi(api = Build.VERSION_CODES.JELLY_BEAN_MR2)
    private fun clearDim(activity: Activity) {
        val parent = activity.window.decorView.rootView as? ViewGroup
        val overlay = parent?.overlay
        overlay?.clear()
    }


}