package com.ninexiu.sixninexiu.view.dialog

import android.content.Context
import android.text.Editable
import android.text.TextUtils
import android.text.TextWatcher
import android.view.Gravity
import android.view.View
import android.view.View.OnLongClickListener
import android.view.Window
import androidx.core.content.ContextCompat
import com.blankj.utilcode.util.KeyboardUtils
import com.kpswitch.util.KeyboardUtil
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.common.util.*
import com.ninexiu.sixninexiu.common.util.manager.RequestManager
import com.tencent.qcloud.tim.uikit.PushContants
import kotlinx.android.synthetic.main.dialog_follow_hello_text_setting.*
import kotlinx.android.synthetic.main.layout_dynamic_input.*

/**
 * <pre>
 *     @author : zhangbing
 *     time   : 2021/04/06
 *     desc   : 关注自动回复，文字设置弹窗
 * </pre>
 */
class FollowHelloTextSettingDialog(context: Context, val title:Int, val content: String) : BaseDialog(context), View.OnClickListener {

    companion object {
        fun create(context: Context?, title :Int,content: String): FollowHelloTextSettingDialog? {
            return context?.let { FollowHelloTextSettingDialog(it, title, content) }
        }
    }

    override fun getContentView() = R.layout.dialog_follow_hello_text_setting

    override fun initView() {
        super.initView()
        tv_text_setting_title?.text="自定义招呼${title}"
    }

    override fun initDatas() {
        super.initDatas()
        if (!TextUtils.isEmpty(content)) {
            et_text_setting?.setText(content)

            val len = et_text_setting?.text.toString().length
            if (len < 140) {
                tv_text_setting_count.text = "$len/140"
                tv_text_setting_count.setTextColor(ContextCompat.getColor(context, R.color.color_999999))
            } else {
                tv_text_setting_count.text = "140/140"
                tv_text_setting_count.setTextColor(ContextCompat.getColor(context, R.color.color_fd4259))
            }
        }
    }

    fun opeKeyborad(){
        KeyboardUtils.showSoftInput(et_text_setting)
    }

    override fun initEvents() {
        super.initEvents()
        tv_text_setting_save.setOnClickListener(this)
        et_text_setting?.addTextChangedListener(object : TextWatcher {
            override fun afterTextChanged(p0: Editable?) {
                val len = et_text_setting?.text.toString().length
                if (len < 140) {
                    tv_text_setting_count.text = "$len/140"
                    tv_text_setting_count.setTextColor(ContextCompat.getColor(context, R.color.color_999999))
                } else {
                    tv_text_setting_count.text = "140/140"
                    tv_text_setting_count.setTextColor(ContextCompat.getColor(context, R.color.color_fd4259))
                }
            }

            override fun beforeTextChanged(p0: CharSequence?, p1: Int, p2: Int, p3: Int) {
            }

            override fun onTextChanged(p0: CharSequence?, p1: Int, p2: Int, p3: Int) {
            }
        })

    }

    override fun getWindows(window: Window?) {
        super.getWindows(window)
        if (window != null && PushContants.ISINLIVEROOM) {
            window.setGravity(Gravity.BOTTOM)
        }
    }

    override fun isBottom(): Boolean {
        return true
    }

    override fun onClick(v: View?) {
        if (Utils.isNotClickable()) {
            return
        }
        when (v?.id) {
            R.id.tv_text_setting_save -> {
                onSaveClick?.invoke(et_text_setting.text.toString().trim())
                dismiss()
            }
        }
    }


    var onSaveClick: ((content: String) -> Unit)? = null

}