package com.ninexiu.sixninexiu.view.dialog

import android.annotation.SuppressLint
import android.content.Context
import android.content.DialogInterface
import android.graphics.Color
import android.graphics.drawable.GradientDrawable
import android.os.Bundle
import android.text.TextUtils
import android.view.LayoutInflater
import android.view.View
import android.view.animation.Animation
import android.view.animation.ScaleAnimation
import androidx.constraintlayout.widget.ConstraintLayout
import androidx.recyclerview.widget.GridLayoutManager
import com.google.gson.Gson
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.adapter.AnchorDialogAdapter
import com.ninexiu.sixninexiu.application.NSApp
import com.ninexiu.sixninexiu.bean.*
import com.ninexiu.sixninexiu.broadcast.AppBroadcastHelper
import com.ninexiu.sixninexiu.broadcast.NSDataBroadcast
import com.ninexiu.sixninexiu.common.net.NSGsonObjectNewCallback
import com.ninexiu.sixninexiu.common.net.NSRequestParams
import com.ninexiu.sixninexiu.common.net.NsOkHttpClient
import com.ninexiu.sixninexiu.common.statistics.StatisticsEventID
import com.ninexiu.sixninexiu.common.statistics.StatisticsUtil
import com.ninexiu.sixninexiu.common.util.*
import com.ninexiu.sixninexiu.common.util.manager.RequestManager
import com.ninexiu.sixninexiu.common.util.manager.RequestManagerCallBack
import com.ninexiu.sixninexiu.view.*
import kotlinx.android.synthetic.main.dialog_leave_room_more_five_min.*
import kotlinx.android.synthetic.main.dialog_leave_room_more_five_min.txt_leave_room_close
import kotlinx.android.synthetic.main.dialog_leave_room_normal.*
import kotlinx.android.synthetic.main.fragment_dynamic_detail_new.*
import org.json.JSONObject

/**
 * @author: lou
 * @date: 2021/8/25
 * desc:离开直播间Dialog
 */
class LeaveRoomDialog(context: Context, var uid: Int) : BaseDialog(context) {

    //dialog宽度屏占比
    companion object {
        const val DIALOG_WIDTH_PERCENT = 0.72
    }

    //点击事件
    val leaveRoomListener = View.OnClickListener {
        when (it.id) {
            R.id.txt_leave_room_close -> {
                val bundle = Bundle()
                bundle.putInt("status", 1)
                AppBroadcastHelper.getInstance().sendBroadcast(
                    NSReceiverAction.ACTION_NEW_GOTOCLOSE_LIVEROOM,
                    NSDataBroadcast.TYPE_OPERATION_DEFAULT,
                    bundle)
                dismiss()
                StatisticsUtil.onEvent(StatisticsEventID.UM_ZBJ_OUT_FOLLOW_LEAVE)
            }
            R.id.txt_leave_room_follow -> {
                followAnchor()
            }
        }
    }

    override fun getContentView(): Int = R.layout.dialog_leave_room_more_five_min

    override fun initView() {
        super.initView()
        //计算dialog的宽度
        val width = (getScreenWidth(context) * DIALOG_WIDTH_PERCENT).toInt()
        //适配dialog的宽度
        cons_leave_room_dialog.post {
            fitterViewSize(cons_leave_room_dialog, { width })
        }

        txt_leave_room_close.setOnClickListener(leaveRoomListener)
        txt_leave_room_follow.setOnClickListener(leaveRoomListener)

        initFollowAnim()


    }

    lateinit var anim:ScaleAnimation

    /**
     * dialog出现时关注按钮加载缩放动画
     */
    private fun initFollowAnim() {

         anim = ScaleAnimation(
            1.0f,
            1.05f,
            1.0f,
            1.05f,
            Animation.RELATIVE_TO_SELF,
            0.5f,
            Animation.RELATIVE_TO_SELF,
            0.5f
        )
        anim.apply {
            duration = 350
            repeatCount = 1
            repeatMode = Animation.RESTART
        }
        NsOkHttpClient.getNsOkHttpClient().handler.postDelayed({
            txt_leave_room_follow.startAnimation(anim)

        }, 500)

    }

    override fun onDismiss(dialog: DialogInterface?) {
        super.onDismiss(dialog)
        anim.cancel()
    }

    /**
     * 加载用户信息
     */
    override fun initDatas() {
        super.initDatas()
        var okHttpClient = NsOkHttpClient.getNsOkHttpClient()
        var params = NSRequestParams()
        params.put("uid", uid)
        okHttpClient.doGet(
                Constants.GET_ANCHOR_INFO,
                params,
                object : NSGsonObjectNewCallback<BaseResultInfo>() {

                    @SuppressLint("LongLogTag")
                    override fun onSuccess(
                            statusCode: Int,
                            responseString: String?,
                            message: String?,
                            response: BaseResultInfo?
                    ) {

                        //防止後台亂返回數據
                        try {

                            if (statusCode == 200) {

                                NSLog.d("leaveRoomDialog$responseString")
                                var jsonObject = JSONObject(responseString)
                                var data: JSONObject? = jsonObject.optJSONObject("data") ?: return

                                val userInfo = GsonUtil.fromJson(
                                        jsonObject?.optString("data"),
                                        LeaveRoomDialogUserInfo::class.java
                                )


                                txt_leave_room_dialog_nickname.text = userInfo.nickname
                                txt_liave_room_dialog_address.text = userInfo.city
                                txt_liave_room_dialog_age.text = userInfo.age.toString()
                                GlideUtils.loadCirclePic(
                                        context,
                                        userInfo.headimage,
                                        img_leave_room_head
                                )

                                var myGrad = txt_liave_room_dialog_age.background as GradientDrawable
                                if (TextUtils.equals(userInfo.sex, "1")) {
                                    myGrad.setColor(Color.parseColor("#69C3FA"))
                                    img_sex.setImageResource(R.drawable.ic_person_center_man)

                                } else {
                                    img_sex.setImageResource(R.drawable.ic_person_center_woman)
                                    myGrad.setColor(Color.parseColor("#FF567B"))
                                }


                            }


                        } catch (e: Exception) {
                            sendCloseLiveRoomBroadCastReceiver(false)
                            NSLog.d("list.size=${e.toString()}")
                        }


                    }

                    @SuppressLint("LongLogTag")
                    override fun onFailure(statusCode: Int, errorMsg: String?) {
                        sendCloseLiveRoomBroadCastReceiver(false)
                        NSLog.d(
                                SummerUnionContestManger.TAG,
                                "onFailure: $errorMsg+errorCode$statusCode"
                        )
                    }

                })
    }


    //关注
    fun followAnchor() {
        RequestManager().attentionUser(
            uid.toString(), 1
        ) { code, _ ->
            if (code == 200) {
                StatisticsUtil.onEvent(StatisticsEventID.UM_ZBJ_OUT_FOLLOW_SUC)
                followAnchorAnim()
            }
        }
    }


    /**
     * 关注成功动画
     */
    fun followAnchorAnim() {

        val layoutParams = ConstraintLayout.LayoutParams(
            ConstraintLayout.LayoutParams.WRAP_CONTENT,
            ConstraintLayout.LayoutParams.WRAP_CONTENT
        )
        txt_leave_room_close.visibility = View.GONE
        txt_leave_room_follow.text = "关注成功"
        layoutParams.apply {

            bottomToBottom = R.id.cons_leave_room_dialog
            endToEnd = R.id.cons_leave_room_dialog
            bottomMargin = dp2px(context, 24)
            marginEnd = dp2px(context, 16)
            height = dp2px(context, 40)
            width = cons_leave_room_dialog.width - dp2px(context, 32)
        }

        txt_leave_room_follow.layoutParams = layoutParams

        beginDelayedTransition(cons_leave_room_dialog, 500)

        //关注成功加载完动画发送关闭直播间广播
        NsOkHttpClient.getNsOkHttpClient().handler.postDelayed(
            {
                sendCloseLiveRoomBroadCastReceiver(false)
                dismiss()
            }, 1000
        )


    }

    override fun setOnBackgroundDismiss(): Boolean {
        return false
    }

}