package com.ninexiu.sixninexiu.common.util

import android.Manifest.permission.RECORD_AUDIO
import android.app.Activity
import android.content.DialogInterface
import android.os.Build
import android.text.Editable
import android.text.TextUtils
import android.view.KeyEvent
import android.view.View
import android.view.inputmethod.EditorInfo
import android.widget.EditText
import androidx.core.content.ContextCompat
import androidx.fragment.app.FragmentActivity
import com.kpswitch.util.KeyboardUtil
import com.loopj.android.http.TextHttpResponseHandler
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.activity.AccountIdentityDialog
import com.ninexiu.sixninexiu.adapter.TagAdapter
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.bean.BaseResultInfo
import com.ninexiu.sixninexiu.bean.MyManagerRoomInfo
import com.ninexiu.sixninexiu.bean.RoomInfo
import com.ninexiu.sixninexiu.broadcast.AppBroadcastHelper
import com.ninexiu.sixninexiu.common.AppCnfSpHelper
import com.ninexiu.sixninexiu.common.inter.InputLayoutDismissListener
import com.ninexiu.sixninexiu.common.net.NSAsyncHttpClient
import com.ninexiu.sixninexiu.common.net.NSGsonObjectNewCallback
import com.ninexiu.sixninexiu.common.net.NSRequestParams
import com.ninexiu.sixninexiu.common.net.NsOkHttpClient
import com.ninexiu.sixninexiu.common.statistics.StatisticsEventID
import com.ninexiu.sixninexiu.common.statistics.StatisticsUtil
import com.ninexiu.sixninexiu.common.util.CountTechnology.TDEventMap
import com.ninexiu.sixninexiu.common.util.CountTechnology.TDEventName
import com.ninexiu.sixninexiu.common.util.CountTechnology.TDTracker
import com.ninexiu.sixninexiu.common.util.listener.EditTextWatcher
import com.ninexiu.sixninexiu.common.util.manager.PermissionManager
import com.ninexiu.sixninexiu.fragment.MBLiveChatFragment
import com.ninexiu.sixninexiu.thirdfunc.voiceinput.VoiceListener
import com.ninexiu.sixninexiu.thirdfunc.voiceinput.XFSpeechManagerNew
import com.ninexiu.sixninexiu.view.HotWordRoomView
import com.ninexiu.sixninexiu.view.InputTypeAnimatorView
import com.ninexiu.sixninexiu.view.ViewUtils
import com.ninexiu.sixninexiu.view.dialog.BaseDialog
import com.ninexiu.sixninexiu.view.dialog.EditInputFilter
import com.ninexiu.sixninexiu.view.dialog.ParentsModleHintDialog
import com.tencent.qcloud.tim.uikit.utils.SoftKeyBoardUtil
import cz.msebera.android.httpclient.Header
import kotlinx.android.synthetic.main.include_live_voice_layout.*
import kotlinx.android.synthetic.main.mb_layout_liveroom_input_copy_dialog.*
import org.jetbrains.anko.displayMetrics
import org.json.JSONException
import org.json.JSONObject

/**
 * <pre>
 *     @author : hpf
 *     time   : 2020/12/16
 *     desc   : 键盘改用dialog的方式重写
 *     version: 1.0
 * </pre>
 */
class MBInputDialogHelper(val context: Activity, val fragment: LiveBaseInterface, private val isLive: Boolean = false, private val onDismissCallBack: ((Boolean) -> Unit)? = null) : BaseDialog(context) {
    companion object {
        const val MIC_REQUEST_CODE = 110
        const val Tag = "MBInputDiaogHelper >> "
    }

    // 上次是否显示的聊天界面
    private var isLastChatShowing: Boolean = false

    // 是否正在显示聊天界面
    private var isChatShowing: Boolean = false

    private val roomInfo: RoomInfo? by lazy {
        fragment.roomInfo
    }

    private val roomId by lazy{
        fragment.roomId
    }

    override fun getContentView(): Int = R.layout.mb_layout_liveroom_input_copy_dialog

    // 底部热词adapter
    private val hotWordAdapter = TagAdapter<String>(context)

    private var filter: EditInputFilter? = null

    override fun initView() {
        super.initView()
        if (!TextUtils.isEmpty(NineShowApplication.liveroom_public_chat_hint)) {
            etInput.hint = NineShowApplication.liveroom_public_chat_hint
        }

        recyInput.initOnce(HotWordRoomView.TYPE_LIVE_ROOM_INPUT,fragment)

        // 顶部热词显示
//        recyInput.layoutManager = LinearLayoutManager(context, LinearLayoutManager.HORIZONTAL, false)
//        recyInput.adapter = topAdapter
//        val list = NineShowApplication.getHotWordList()
//        topAdapter.setData(
//                if (null != list && list.size > 0) {
//                    list
//                } else {
//                    mutableListOf("666", "哈哈哈", "主播好漂亮")
//                }
//        )
//
//        topAdapter.setOnItemClickListner { _, position ->
//            inputTypeView.dismiss()
//            if (!Utils.isNotClickable()) {
//                etInput.setText(topAdapter.datas[position])
//                if (topAdapter.datas[position] == "瑰宝如你") {
//                    postSpringCall()
//                }
//                sendChatMsg()
//            }
//        }
        // 底部热词显示
//        flow_tag.adapter = hotWordAdapter
//        flow_tag.setOnTagClickListener { parent, _, position ->
//            inputTypeView.dismiss()
//            etInput.setText(parent.adapter.getItem(position).toString())
//            sendChatMsg()
//        }

        val newDataSource = NineShowApplication.getHotWordList()

        if (null != newDataSource && newDataSource.isNotEmpty()) {
            hotWordAdapter.clearAndAddAll(newDataSource)
        } else {
            val dataSource = mutableListOf(
                    "嗨!",
                    "画面太美我不敢看!",
                    "大家好!",
                    "666",
                    "主播好漂亮!",
                    "真棒!",
                    "感觉身体被掏空了",
                    "我就静静看一会!",
                    "我的心里只有你没有他"
            )
            hotWordAdapter.clearAndAddAll(dataSource)
        }

        ivVoiceInput.setVisible(!isLive)

        rlRootInput.visibility = View.GONE

        filter = EditInputFilter(etInput, 80)
        etInput.filters = arrayOf(filter)

        initChatData()

        isChatShowing = true
        isLastChatShowing = true
    }

    private var isInputShow = false

    // 重写show方法
    fun show(isPlayRoom: Boolean, isMenu: Boolean) {
        show()
        onDismissCallBack?.invoke(true)
        isInputShow = true
        hintString = if (isPlayRoom) {
            context.getString(R.string.mb_liveroom_iput_edt_hint, "大家")
        } else {
            context.getString(R.string.mb_liveroom_iput_edt_hint, "主播")
        }
        setChatNormalHint()

        // 用户刚开始打开时自动弹出软键盘
        etInput.requestFocus()
        etInput.postDelayed({
            KeyboardUtil.showKeyboard(etInput)
        }, 150)


        // 表情和键盘图标切换
        SoftKeyBoardUtil.SoftKeyboardStateHelperNew(context.window.decorView, object : SoftKeyBoardUtil.SoftKeyboardStateListener {
            override fun onSoftKeyboardOpened(keyboardHeightInPx: Int) {
                NSLog.d(Tag, "onSoftKeyboard -> Opened : $keyboardHeightInPx")
                mInputLayoutDismissListener?.onKeyboardShowing(true)
                changeCallBack(rootView.height + keyboardHeightInPx)
                closeDialog = true
            }

            override fun onSoftKeyboardClosed() {
                NSLog.d(Tag, "onSoftKeyboard -> Closed")
                if (closeDialog) {
                    dismiss()
                    closeDialog = false
                } else {
                    rootView.postDelayed({
                        mInputLayoutDismissListener?.onKeyboardShowing(false)
                        changeCallBack(rootView.height)
                    }, 150)
                }
            }
        })
    }

    private var closeDialog = false

    /**
     * 普通模式 hint
     */
    private fun setChatNormalHint(){
        if (TextUtils.isEmpty(NineShowApplication.liveroom_public_chat_hint)) {
            etInput.hint = hintString
        }else{
            etInput.hint = NineShowApplication.liveroom_public_chat_hint
        }
    }

    private var preHeight: Int = 0
    private var preShow: Boolean = false

    private fun changeCallBack(height: Int) {
        if (preShow == isInputShow && height == preHeight) {
            return
        }

        NSLog.d(Tag, "inputStatus  : show : $isInputShow  ,  height : $height")
        inputDialogHeightChange?.invoke(isInputShow, height)

        preHeight = height
        preShow = isInputShow
    }


    // 监听View的高度变化和键盘的高度   Boolean : dialog是否显示
    var inputDialogHeightChange: ((Boolean, Int) -> Unit)? = null


    override fun initEvents() {
        super.initEvents()
        etInput.addTextChangedListener(object : EditTextWatcher() {
            override fun afterTextChanged(s: Editable?) {
                inputTypeView.dismiss()
                if (null != s && s.isNotEmpty()) {
                    btSendInput.background = ContextCompat.getDrawable(context, R.drawable.shape_gradient_recharge)
                    btSendInput.setTextColor(ContextCompat.getColor(context, R.color.white))
                } else {
                    btSendInput.background = ContextCompat.getDrawable(context, R.drawable.shape_gradient_recharge_dark)
                    btSendInput.setTextColor(ContextCompat.getColor(context, R.color.color_BF9D9D))
                }
            }
        })

        // 发送消息
        etInput.setOnEditorActionListener { _, actionId, event ->
            inputTypeView.dismiss()
            if (actionId == EditorInfo.IME_ACTION_SEND || (null != event && event.keyCode == KeyEvent.KEYCODE_ENTER)) {
                handlerSendEvent()
                true
            } else {
                false
            }
        }

        ivFaceInput.setOnClickListener {
            inputTypeView.dismiss()   // todo : 1
            when (ivFaceInput.drawable.level) {
                0 -> {
                    closeDialog = false
                    // 显示表情
                    ivFaceInput.setImageLevel(1)
                    ivVoiceInput.setImageLevel(0)
                    hideShowRootAndKeyBoard(show = true, showFace = true)
                }
                1 -> {
                    closeDialog = true
                    // 显示键盘
                    ivFaceInput.setImageLevel(0)
                    hideShowRootAndKeyBoard(show = false)
                }
            }
        }

        // 发送
        btSendInput.setOnClickListener {
            inputTypeView.dismiss()
            if (!Utils.isNotClickable()) {
                var roomSend = TDEventMap.getLiveRoomEventMapIntValue(TDEventName.LIVE_ROOM_SEND)
                roomSend++
                TDEventMap.putLiveRoomEventMapIntValue(TDEventName.LIVE_ROOM_SEND,roomSend)
                handlerSendEvent()
            }
        }

        ivVoiceInput.setOnClickListener {
            closeDialog = false
            inputTypeView.dismiss()
            when (ivVoiceInput.drawable.level) {
                0 -> {
                    // 显示语音输入界面
                    ivVoiceInput.setImageLevel(1)
                    ivFaceInput.setImageLevel(0)
                    hideShowRootAndKeyBoard(show = true, showVoice = true)
                }
                1 -> {
                    // 显示键盘
                    ivVoiceInput.setImageLevel(0)
                    hideShowRootAndKeyBoard(show = false)
                }
            }
        }

        ivVoice.setOnClickListener {
            inputTypeView.dismiss()
            toAccessMicPer()
        }


        // 自定义EditText,在用户Touch的Action_up阶段回调 : 在键盘弹起前消失View
        etInput.getFocus = {
            inputTypeView.dismiss()
            ivFaceInput.setImageLevel(0)
            ivVoiceInput.setImageLevel(0)
            rlRootInput.setVisible(false)
        }

        // 用户切换类型
        inputTypeView.choseTypeCallback = { type ->
            showPopWindow(type)
        }
    }

    // 录音权限
    val permissions = arrayOf(RECORD_AUDIO)

    // 语音识别加入输入框中
    private fun toAccessMicPer() {
        if (context !is FragmentActivity) {
            return
        }
        PermissionManager.create().showAudio(context) {
            XFSpeechManagerNew(context, ivVoice, etInput, waveInput, null, object : VoiceListener {
                override fun showVoiceType(type: Int, volume: Int) {
                    when (type) {
                        0 -> {
                            llVoice.setVisible(false)
                            inputVoiceWaveView.setVisible(true)
                        }
                        2 -> {
                            tvVoiceInfo.text = context.getString(R.string.input_voice_info_start)
                            llVoice.setVisible(true)
                            inputVoiceWaveView.setVisible(false)
                        }
                        1 -> {
                            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.LOLLIPOP) {
                                inputVoiceWaveView.startVoiceInput(volume)
                            }
                        }
                    }
                }

                override fun showError(msg: String?) {
                    llVoice.setVisible(true)
                    tvVoiceInfo.text = msg ?: ""
                    inputVoiceWaveView.setVisible(false)
                }

                // 录音结果回调
                override fun showResult(content: String, isLast: Boolean) {
                    if (isLast) {
                        val selectIndex: Int = etInput.selectionStart
                        when (val lastLength = filter?.lastLength ?: 0) {
                            -1 -> etInput?.text?.insert(selectIndex, content)       // 输入没有限制
                            0 -> {
                                MyToast.MakeToast(getContext(), "聊天输入超出限制")
                            }
                            else -> {
                                if (lastLength < 0) {
                                    NSLog.d(Tag, "输入异常")
                                } else {
                                    if (lastLength > content.length) {
                                        etInput?.text?.insert(selectIndex, content)
                                    } else if (lastLength < content.length) {
                                        val subContent = content.substring(0, lastLength)
                                        etInput?.text?.insert(selectIndex, subContent)
                                    }
                                }
                            }
                        }
                    }
                }
            })
        }
    }

    // 键盘和底层布局之间的切换
    private fun hideShowRootAndKeyBoard(show: Boolean? = false, showFace: Boolean = false, showHot: Boolean = false, showVoice: Boolean = false) {
        when (show) {
            true -> {  // 显示底层布局
                rlRootInput.postDelayed({
                    showRootLayout(showFace, showHot, showVoice)  // todo : 2
                }, 100)
                KeyboardUtil.hideKeyboard(etInput)
            }
            false -> { // 显示键盘布局
                rlRootInput.setVisible(false)
                KeyboardUtil.showKeyboard(etInput)
            }
        }
    }


    // 表情，热词，语音三种布局之间的切换
    private fun showRootLayout(showFace: Boolean, showHot: Boolean, showVoice: Boolean) {
        rlRootInput.setVisible(true)
        when {
            showFace -> {
                live_face_layout.setVisible(true)
                live_hot_word_layout.setVisible(false)
                live_voice_layout.setVisible(false)
            }
            showHot -> {
                live_face_layout.setVisible(false)
                live_hot_word_layout.setVisible(true)
                live_voice_layout.setVisible(false)
            }
            showVoice -> {
                live_face_layout.setVisible(false)
                live_hot_word_layout.setVisible(false)
                live_voice_layout.setVisible(true)
            }
        }
    }

    private var faceManager: MBLiveFaceManager? = null
    private fun initChatData() {
        /*val content = etInput.text.toString().trim()
        if (TextUtils.isEmpty(content)) {
            charType = 0
            tvTypeInput.text = "公屏"
        }*/
        etInput.requestFocus()

        faceManager = MBLiveFaceManager(fragment, context, etInput, rlRootInput, true)

        faceManager?.setMaxLength(-1)

        setInputLength()
    }

    private fun setInputLength() {
        val userBase = NineShowApplication.mUserBase
        if (fragment is MBLiveChatFragment && null != userBase) {
            if (userBase.vipId == 800004 || userBase.vipId == 800003 || userBase.vipId == 800002) {
                setEditFaceLength(80, 80)
            } else {
                val wealthLevel = userBase.wealthlevel
                when {
                    wealthLevel == 0 -> {
                        setEditFaceLength(15, 15)
                    }
                    wealthLevel in 1..10 -> {
                        setEditFaceLength(50, 50)
                    }
                    wealthLevel >= 11 -> {
                        setEditFaceLength(80, 80)
                    }
                }
            }
        } else {
            setEditFaceLength(50, 50)
        }
    }


    private val typeArr = arrayOf("公屏", "飞屏", "广播")

    // 处理发送的点击事件
    private fun handlerSendEvent() {

        if (RoomUtils.send_chat_status == 1) {

            //限制聊天输入   显示toast
            MyToast.MakeToast(NineShowApplication.applicationContext.getString(R.string.system_update_not_use))

            return
        }

        val inputStr = etInput.text.toString().trim()
        when (inputTypeView.currentType) {
            InputTypeAnimatorView.TYPE_FLY -> {
                if (TextUtils.isEmpty(inputStr)) {
                    MyToast.MakeToast("请输入${typeArr[1]}内容")
                    return
                }

                if (filter?.canSend() == false) {
                    MyToast.MakeToast("${typeArr[1]}内容过长，请保持在50个字以内")
                    return
                }

                // MyToast.MakeToast(getContext().getString(R.string.yue_not_enough))
                LiveBroadCastManager.sendBarrage(context, fragment.roomId, inputStr) {
                    sendChatMsg(isFly = 1)
                    etInput.setText("")
                }

                //上报进入直播间事件
                roomInfo?.let { TDTracker.setLiveChatEvent("飞屏",inputStr, it) }
                StatisticsUtil.onEvent(StatisticsEventID.LIVEROOM_FEIPING_SEND)
            }
            InputTypeAnimatorView.TYPE_BROADCAST -> {
                if (TextUtils.isEmpty(inputStr)) {
                    MyToast.MakeToast("请输入${typeArr[2]}内容")
                    return
                }

                if (filter?.canSend() == false) {
                    MyToast.MakeToast("${typeArr[2]}内容过长，请保持在50个字以内")
                    return
                }

                sendBroadCast(inputStr)
                roomInfo?.let { TDTracker.setLiveChatEvent("广播",inputStr, it) }
                StatisticsUtil.onEvent(StatisticsEventID.LIVEROOM_BROADCAST_SEND)
            }
            InputTypeAnimatorView.TYPE_PUBLIC -> {
                sendChatMsg()
                roomInfo?.let { TDTracker.setLiveChatEvent("公屏",inputStr, it) }
            }
            else -> {
                sendChatMsg()
            }
        }
    }

    fun sendChatMsg() {
        sendChatMsg(isFly = 0)
    }

    fun sendChatMsg(editText: EditText? = etInput, isFly: Int) {
        if (null != fragment.talkUtil && null != editText && filter?.canSend() == true) {
            fragment.talkUtil.sendBtn(false, editText, isFly, true)
        }
    }

    // 用于直播间发送消息
    fun sendChatMsgLive(editText: EditText? = etInput, isFly: Int) {
        if (null != fragment.talkUtil && null != editText) {
            fragment.talkUtil.sendBtn(false, editText, isFly, true)
        }
    }


    // 设置输入框和表情输入长度
    private fun setEditFaceLength(inputLength: Int, faceLength: Int = 0) {
        filter?.setLimitLength(inputLength)
        faceManager?.setMaxLength(faceLength)
    }

    // 设置输入框的hint和长度
    fun setInputViewHint(hintName: String) {
        when (inputTypeView.currentType) {
            InputTypeAnimatorView.TYPE_FLY -> {
                etInput.setHint(R.string.mb_liveroom_iput_edt_danmucharge_hint)
                setEditFaceLength(50, 50)
            }
            InputTypeAnimatorView.TYPE_BROADCAST -> {
                etInput.setHint(R.string.broadcast_hint)
                setEditFaceLength(50, 50)
            }
            else -> {
                hintString = context.getString(R.string.mb_liveroom_iput_edt_hint, hintName)
                setChatNormalHint()
                setInputLength()
            }
        }
    }

    /**
     * 隐藏键盘跟表情
     */
    fun hidePanelAndKeyboard(): Boolean {
        rlRootInput.setVisible(false)
        return true
    }

    /**
     * 隐藏输入的布局
     */
    fun goneInputLayout(): Boolean {
        dismiss()
        if (!isChatShowing) {
            hideShowBroadCastBackground(NSReceiverAction.ACTION_SHOW_CHAT_AND_FOOTER_VIEW)
        }
        return true
    }

    override fun onDismiss(dialog: DialogInterface?) {
        super.onDismiss(dialog)

        isInputShow = false

        // 初始化类型选择框
        inputTypeView.initTab()

        // 初始化状态
        etInput.setText("")
        ivFaceInput.setImageLevel(0)
        ivVoiceInput.setImageLevel(0)
        rlRootInput.setVisible(false)

        mInputLayoutDismissListener?.onInputLayoutDismiss()
        KeyboardUtil.hideKeyboard(etInput)
        onDismissCallBack?.invoke(false)
        changeCallBack(0)
    }

    /**
     * 1.发广播时隐藏一些背景
     * 2.广播界面消失时显示一些背景
     */
    private fun hideShowBroadCastBackground(filter: String) {
        AppBroadcastHelper.getInstance().sendBroadcast(filter, null)
    }

    private fun View?.setVisible(visible: Boolean) {
        if (visible) {
            ViewUtils.showView(this)
        } else {
            ViewUtils.hideView(this)
        }
    }

    private var hintString: String = ""

    // 用户选择公屏，飞屏或者广播
    private fun showPopWindow(type: Int) {
        when (type) {
            InputTypeAnimatorView.TYPE_PUBLIC -> {
                setChatNormalHint()
                setInputLength()
            }
            InputTypeAnimatorView.TYPE_FLY -> {
                if (TextUtils.equals(roomId, "99003")) {
                    MyToast.makeToastMiddle(context, "当前房间暂不开放飞屏功能，请谅解...")
                } else {
                    val base = NineShowApplication.mUserBase
                    if (null != base && base.family_module == 1) {
                        ParentsModleHintDialog(context).show()
                    } else {
                        etInput.setHint(R.string.mb_liveroom_iput_edt_danmucharge_hint)
                        setEditFaceLength(50, 50)
                    }
                }
            }
            InputTypeAnimatorView.TYPE_BROADCAST -> {
                val userBase = NineShowApplication.mUserBase
                if (null != userBase && userBase.family_module == 1) {
                    ParentsModleHintDialog(context).show()
                    return
                }

                etInput.setHint(R.string.broadcast_hint)
                setEditFaceLength(50, 50)
            }
        }
    }

    // 用户发送广播
    private fun sendBroadCast(content: String) {
        val params = NSRequestParams().apply { put("rid", roomId) }.apply { put("msg", content) }
        NSAsyncHttpClient.getInstance().get(Constants.LIVE_SEND_LOUDSPEAKER, params, object : TextHttpResponseHandler() {
            override fun onSuccess(statusCode: Int, headers: Array<out Header>?, responseString: String?) {
                responseString ?: return
                try {
                    val jsonObj = JSONObject(responseString)
                    val code = jsonObj.optInt("code")
                    val msg: String? = jsonObj.optString("message")

                    when (code) {
                        200 -> {
                            etInput.setText("")
                        }
                        4202 -> {
                            // 只需要给出提示即可
                            // MyDialogs.showBuyWindow(context, roomId.toInt())
                            MyToast.MakeToast(getContext().getString(R.string.yue_not_enough))
                        }
                        9002, 9003 -> {
                            AccountIdentityDialog.showDialog(getContext(), code.toString(), msg)
                        }
                        else -> {
                            MyToast.MakeToast(msg ?: "发送广播失败")
                        }
                    }

                } catch (e: JSONException) {
                    e.printStackTrace()
                }

            }

            override fun onFailure(statusCode: Int, headers: Array<out Header>?, responseString: String?, throwable: Throwable?) {
                MyToast.MakeToast("连接超时")
            }

        })
    }

    fun dp2px(dp: Int) = (context.displayMetrics.density * dp).toInt()

    fun setInputLayoutDismissListener(mInputLayoutDismissListener: InputLayoutDismissListener) {
        this.mInputLayoutDismissListener = mInputLayoutDismissListener
    }

    var mInputLayoutDismissListener: InputLayoutDismissListener? = null

    override fun setBackgroundDimAlpha() = 0f


    override fun isBottom(): Boolean {
        return true
    }
}
