package com.ninexiu.sixninexiu.view.dialog

import android.animation.ObjectAnimator
import android.animation.ValueAnimator
import android.content.Context
import android.content.DialogInterface
import android.view.animation.AccelerateInterpolator
import android.view.animation.Animation
import android.view.animation.LinearInterpolator
import android.view.animation.RotateAnimation
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.activity.AccountBindPhoneActivity
import com.ninexiu.sixninexiu.view.ORIENTATION_TOP
import com.ninexiu.sixninexiu.view.fitterViewPosition
import com.ninexiu.sixninexiu.view.fitterViewSize
import com.ninexiu.sixninexiu.view.setVisible
import kotlinx.android.synthetic.main.dialog_s11_result.*

/**
 * <pre>
 *     @author : hpf
 *     time   : 2021/05/06
 *     desc   :
 *     version: 1.0
 * </pre>
 */
class S11ResultDialog(context: Context, val code: Int, val message: String?) : BaseDialog(context) {
    companion object {
        const val CODE_NORMAL = 221         // 正常弹窗
        const val CODE_ICE_CARD = 222       // 本人获得冰冻卡弹窗
    }

    override fun getContentView(): Int = R.layout.dialog_s11_result

    private val screenWidth by lazy {
        context.resources.displayMetrics.widthPixels
    }

    override fun initView() {
        super.initView()

        container.post {
            fitterViewSize(ivLight, { (screenWidth * 0.272).toInt() }, {it})
            fitterViewSize(container, { (screenWidth * 0.614).toInt() }, { (it * 0.7826).toInt() })
            fitterViewPosition(tvSuperInfo, ORIENTATION_TOP, { (screenWidth * 0.197).toInt() })
            fitterViewPosition(ivIce, ORIENTATION_TOP, { (screenWidth * 0.0906).toInt() })
            fitterViewPosition(ivLight, ORIENTATION_TOP, { (screenWidth * 0.032).toInt() })
        }

        when (code) {
            401 -> {
                ivSuperBind.setVisible(true)
                ivSuperConfirm.setVisible(false)
                tvSuperInfo.setVisible(true)
                constraintIce.setVisible(false)

                tvSuperInfo.text = message ?: ""
            }
            CODE_ICE_CARD -> {
                ivSuperBind.setVisible(false)
                ivSuperConfirm.setVisible(true)
                tvSuperInfo.setVisible(false)
                constraintIce.setVisible(true)

                tvSuperInfoIce.text = message ?: ""

                doLightAnimation()
            }
            else -> {
                ivSuperBind.setVisible(false)
                ivSuperConfirm.setVisible(true)
                tvSuperInfo.setVisible(true)
                constraintIce.setVisible(false)

                tvSuperInfo.text = message ?: ""
            }
        }


    }

    private fun doLightAnimation() {
        ivLight?.post {
            val rotate = RotateAnimation(0f, 359f, Animation.RELATIVE_TO_SELF, 0.5f, Animation.RELATIVE_TO_SELF, 0.5f)
            rotate.interpolator = LinearInterpolator()
            rotate.duration = 5000
            rotate.repeatCount = -1
            rotate.fillAfter = true
            ivLight?.animation = rotate
            rotate.start()
        }
    }

    override fun initEvents() {
        super.initEvents()

        ivSuperBind.setOnClickListener {
            AccountBindPhoneActivity.startActivity(context, AccountBindPhoneActivity.TYPE_BIND_PHONE)
            dismiss()
        }

        ivSuperConfirm.setOnClickListener {
            dismiss()
        }
    }

    override fun onDismiss(dialog: DialogInterface?) {
        super.onDismiss(dialog)
        ivLight?.clearAnimation()
    }
}