package com.ninexiu.sixninexiu.view.dialog

import android.content.Context
import android.view.View
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.common.util.NSLog
import kotlinx.android.synthetic.main.dialog_user_return_rule.*
import org.jetbrains.anko.displayMetrics

/**
 * <pre>
 *     @author : hpf
 *     time   : 2020/11/20
 *     desc   : 用户回归充值 和 用户回归福利 dialog
 *     version: 1.0
 * </pre>
 */
class UserReturnRuleDialog(context: Context, val type: Int = 0, private val egg: Int) : BaseDialog(context) {

    constructor(context: Context, type: Int = 0) : this(context, type, -1)

    companion object {
        const val USER_RETURN_PAY_TYPE = 0
        const val USER_RETURN_TOGETHER_TYPE = 1
        const val USER_RETURN_LUCK_WITHDRAW_EGG = 2
        const val USER_RETURN_LUCK_WITHDRAW_LUCKY = 3

        const val DIALOG_BOT_CONTENT = 0.68

        const val DIALOG_TOP_IV_PERCENT = 0.77
        const val DIALOG_TOP_IV_H_W_PERCENT = 0.12
    }

    override fun getContentView() = R.layout.dialog_user_return_rule

    override fun initView() {
        super.initView()
        // 区分 用户回归充值文案 和 用户回归福利文案
        when (type) {
            USER_RETURN_PAY_TYPE -> {
                tvTitle1.visibility = View.GONE
                tvTitle2.visibility = View.GONE
                tvContent1.visibility = View.VISIBLE
                tvContent2.visibility = View.GONE
                tvContent1.text = context.getString(R.string.dialog_user_return_pay_rule)
            }
            USER_RETURN_TOGETHER_TYPE -> {
                if (egg == 0) {
                    tvTitle1.visibility = View.GONE
                    tvContent1.visibility = View.GONE
                } else {
                    tvTitle1.visibility = View.VISIBLE
                    tvContent1.visibility = View.VISIBLE
                }
                tvTitle2.visibility = View.VISIBLE
                tvContent2.visibility = View.VISIBLE
                tvTitle1.text = context.getString(R.string.dialog_user_return_together_title_one)
                tvTitle2.text = context.getString(R.string.dialog_user_return_together_title_sec)
                tvContent1.text = context.getString(R.string.dialog_user_return_together_content_one)
                tvContent2.text = context.getString(R.string.dialog_user_return_together_content_sec)
            }
            USER_RETURN_LUCK_WITHDRAW_EGG -> {
                tvTitle1.visibility = View.GONE
                tvTitle2.visibility = View.GONE
                tvContent1.visibility = View.VISIBLE
                tvContent2.visibility = View.GONE
                tvTitle1.text = context.getString(R.string.dialog_user_return_together_title_one)
                tvContent1.text = context.getString(R.string.dialog_user_return_together_content_one_egg)
            }
            USER_RETURN_LUCK_WITHDRAW_LUCKY -> {
                tvTitle1.visibility = View.GONE
                tvTitle2.visibility = View.GONE
                tvContent1.visibility = View.VISIBLE
                tvContent2.visibility = View.GONE
                tvTitle1.text = context.getString(R.string.dialog_user_return_together_title_one)
                tvContent1.text = context.getString(R.string.dialog_user_return_together_content_one_lucky)
            }
        }

        ivDialogClose.setOnClickListener { dismiss() }

        ivDialogTop.post {
            fitterView()
        }
    }

    override fun isBottom() = (type == USER_RETURN_PAY_TYPE)

    /**
     * 适配 View
     */
    private fun fitterView() {
        val width = context.displayMetrics.widthPixels
        NSLog.d("user_return_dialog_width : ", "$width")
        ivDialogTop.setViewLayoutParams({
            (width * DIALOG_TOP_IV_PERCENT).toInt()
        }, {
            (it * DIALOG_TOP_IV_H_W_PERCENT).toInt()
        })


        val scale = if (type == USER_RETURN_TOGETHER_TYPE && egg != 0) {
            1.32f
        } else {
            0.7f
        }

        nestedScrollView.setViewLayoutParams({
            (width * DIALOG_BOT_CONTENT).toInt()
        }, {
            (it * scale).toInt()
        })
    }

    // 适配方法
    private inline fun View.setViewLayoutParams(getWidth: () -> Int, noinline getHeight: ((Int) -> Int)? = null) {
        val params = this.layoutParams
        val width = getWidth()
        params.width = width
        getHeight?.let { params.height = it.invoke(width) }
        this.layoutParams = params
    }

    override fun setOnBackgroundDismiss() = false
}