package com.ninexiu.sixninexiu.view.dialog

import android.annotation.SuppressLint
import android.app.Activity
import android.app.AlertDialog
import android.app.Dialog
import android.content.Context
import android.content.DialogInterface
import android.content.Intent
import android.graphics.Bitmap
import android.graphics.Rect
import android.net.ConnectivityManager
import android.net.Uri
import android.net.http.SslError
import android.os.Build
import android.os.Handler
import android.os.Message
import android.provider.Settings
import android.text.TextUtils
import android.util.Log
import android.view.View
import android.webkit.SslErrorHandler
import android.webkit.WebSettings
import android.webkit.WebView
import android.webkit.WebViewClient
import android.widget.ImageView
import android.widget.Toast
import androidx.recyclerview.widget.GridLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.alipay.sdk.app.PayTask
import com.ninexiu.sixninexiu.R
import com.ninexiu.sixninexiu.activity.AccountIdentityDialog
import com.ninexiu.sixninexiu.activity.AdvertiseActivity
import com.ninexiu.sixninexiu.adapter.ZhiFuAdapter
import com.ninexiu.sixninexiu.application.NineShowApplication
import com.ninexiu.sixninexiu.bean.*
import com.ninexiu.sixninexiu.common.net.*
import com.ninexiu.sixninexiu.common.statistics.StatisticsEventID
import com.ninexiu.sixninexiu.common.statistics.StatisticsUtil
import com.ninexiu.sixninexiu.common.util.*
import com.ninexiu.sixninexiu.pay.*
import com.ninexiu.sixninexiu.values.Global
import com.ninexiu.sixninexiu.view.*
import com.ninexiu.sixninexiu.view.banner.BGABanner
import kotlinx.android.synthetic.main.activity_zhifu.*
import kotlinx.android.synthetic.main.activity_zhifu.btConfirm
import kotlinx.android.synthetic.main.activity_zhifu.recy
import kotlinx.android.synthetic.main.activity_zhifu.zhifuTypeAli
import kotlinx.android.synthetic.main.activity_zhifu.zhifuTypeWechat
import kotlinx.android.synthetic.main.dialog_zhifu_fast.*
import org.json.JSONException
import org.json.JSONObject
import java.util.HashMap
import kotlin.concurrent.thread

/**
 * <pre>
 *     @author : hpf
 *     time   : 2020/12/30
 *     desc   : 快捷支付dialog
 *     version: 1.0
 * </pre>
 */
class ZhiFuFastDialog private constructor(context: Context, val rid: Int, private val disMoney: Long? = 0, private val onZhiFuFastDialogDismissListener: OnZhiFuFastDialogDismissListener? = null)
    : BaseDialog(context) {
    companion object {
        fun showBugDialog(context: Context, rid: Int = 0, disMoney: Long? = 0L, onZhiFuFastDialogDismissListener: OnZhiFuFastDialogDismissListener?) {
            val dialog = ZhiFuFastDialog(context, rid, disMoney, onZhiFuFastDialogDismissListener)
            dialog.show()
        }

        fun showBugDialog(context: Context, disMoney: Long? = 0, onZhiFuFastDialogDismissListener: OnZhiFuFastDialogDismissListener?) {
            showBugDialog(context, 0, disMoney, onZhiFuFastDialogDismissListener)
        }

        fun showBugDialog(context: Context, onZhiFuFastDialogDismissListener: OnZhiFuFastDialogDismissListener?) {
            showBugDialog(context, 0, null, onZhiFuFastDialogDismissListener)
        }
    }

    private val datas = mutableListOf<Option>()
    private val adapter = ZhiFuAdapter(datas, ZhiFuAdapter.ZHIFU_FAST_TYPE)
    private var money: Long = 0L
        get() = NineShowApplication.mUserBase?.money ?: 0L

    // 支付类型 : 支付宝或微信
    var payType = ZhiFuActivity.PAY_WECHAT

    @SuppressLint("SetTextI18n")
    override fun initView() {
        super.initView()
        StatisticsUtil.onEvent(StatisticsEventID.UM_PAY_FAST_DIALOG_COUNT)
        // 适配
        fitterViewSize(zhifuTypeWechat, { (widthScreen - dp2px(context, 32)) / 2 }, { (it * 0.256).toInt() })
        fitterViewSize(zhifuTypeAli, { (widthScreen - dp2px(context, 32)) / 2 }, { (it * 0.256).toInt() })

        // recy : 充值选项
        recy.layoutManager = GridLayoutManager(context, 3)
        recy.addItemDecoration(decoration)
        recy.adapter = adapter

        // 设置充值类型 ： 支付宝或微信
        zhifuTypeWechat.setPayType(ZhiFuItemTypeView.WECHAT).setPaySelected(true)
        zhifuTypeAli.setPayType(ZhiFuItemTypeView.ALIPAY)

        // 记录支付方式
        zhifuTypeWechat.setOnClickListener {
            payType = ZhiFuActivity.PAY_WECHAT
            zhifuTypeWechat.setPaySelected(true)
            zhifuTypeAli.setPaySelected(false)
        }

        zhifuTypeAli.setOnClickListener {
            payType = ZhiFuActivity.PAY_ALI
            zhifuTypeWechat.setPaySelected(false)
            zhifuTypeAli.setPaySelected(true)
        }

        llOther.setOnClickListener {
            ZhiFuActivity.startActivity(context)
        }

        // 用户选择不同的支付item
        adapter.onSelected = { pos, _ ->
            chosePayItem(pos)
        }

        // 确认支付
        btConfirm.setOnClickListener {
            userPayConfirm()
        }

        // 快付微信支付 初始化webview
        initKuaiFuPay()

        // 更新系统配置的支付信息
        getRoomSystemMessage()

        // 设置当前余额和差多少九币
        tvYu.text = "${money}九币"
        tvDis.text = "$disMoney"

        // 如果获取到的支付存储数据为空，则从接口自己拉取
        val result = UserZhiFuGsonHelper.getUserZhiFuData()
        if (result == null) {
            getPayData()
        } else {
            result.data?.let { setData(it) }
            setBanner(result.data?.banners)
        }
    }

    // 获取支付界面整体数据 : 支付选项 & 提示信息
    private fun getPayData() {
        NsOkHttpClient.getNsOkHttpClient().doGet(Constants.ZHIFU_PAY_DETAIL, null, object : NSGsonObjectNewCallback<ZhiFuResult>() {
            override fun onFailure(statusCode: Int, errorMsg: String?) {
                NSLog.d(ZhiFuActivity.Tag, "status 0 : $statusCode")
                MyToast.MakeToast(errorMsg ?: "")
            }

            override fun onSuccess(statusCode: Int, responseString: String?, message: String?, response: ZhiFuResult?) {
                NSLog.d(ZhiFuActivity.Tag, "status : $statusCode")
                if (statusCode == 200) {

                    UserZhiFuGsonHelper.saveUserZhiFuData(response)

                    response?.data?.let {
                        setData(it)
                    }

                    setBanner(response?.data?.banners)
                }
            }
        })
    }

    // 设置数据
    @SuppressLint("SetTextI18n")
    private fun setData(data: Data) {
        data.options?.let {
            // 集合
            datas.clear()
            datas.addAll(data.options)
            datas[0].selected = true
            adapter.notifyDataSetChanged()

            // 设置确认充值
            btConfirm.text = context.getString(R.string.zhifu_confirm, datas[0].amount)
        }
        if (null != disMoney) {
            chosePayItemFirst(disMoney)
        } else {
            tv2.setVisible(false)
            tvDis.setVisible(false)
            tv4.setVisible(false)
        }

    }

    // 进来根据所差金额动态设置
    private fun chosePayItemFirst(disM: Long) {
        var choseIndex = 0
        for ((index, payItem) in datas.withIndex()) {
            if (index + 1 > datas.size - 1) {
                choseIndex = datas.size - 1
                break
            }

            if (disM.toInt() <= payItem.money) {
                choseIndex = index
                break
            }

            if (datas[index + 1].money >= disM && disM > payItem.money) {
                choseIndex = index + 1
            }
        }

        if (datas.size > 0) {
            btConfirm.text = context.getString(R.string.zhifu_confirm, datas[choseIndex].amount)
        }

        chosePayItem(choseIndex)
    }


    // 用户选择不同的支付选项
    private fun chosePayItem(pos: Int) {
        if (pos >= 0 && pos < datas.size) {
            payItemPosition = pos
            datas.forEach {
                it.selected = false
            }
            datas[pos].selected = true
            adapter.notifyDataSetChanged()
            // 设置确认按钮数字
            btConfirm.text = context.getString(R.string.zhifu_confirm, datas[pos].amount)

            // 设置埋点
            setStatisticsEvent(pos)
        }
    }

    private fun setStatisticsEvent(pos: Int) {
        if (!datas.isNullOrEmpty() && pos >= 0 && pos < datas.size) {
            when (datas[pos].amount) {
                10 -> StatisticsUtil.onEvent(StatisticsEventID.ZHIFU_NUMBER_10)
                50 -> StatisticsUtil.onEvent(StatisticsEventID.ZHIFU_NUMBER_50)
                100 -> StatisticsUtil.onEvent(StatisticsEventID.ZHIFU_NUMBER_100)
                500 -> StatisticsUtil.onEvent(StatisticsEventID.ZHIFU_NUMBER_500)
                1000 -> StatisticsUtil.onEvent(StatisticsEventID.ZHIFU_NUMBER_1000)
            }
        }
    }

    private val payUtil = PayUtil()

    // 支付item选择(下标)
    private var payItemPosition = 0

    private var chargeType: Int = 0// 110：支付宝官方;126：微信官方;114：手机银联(android); 146：快付微信 163 银联闪付宝

    private fun userPayConfirm() {
        StatisticsUtil.onEvent(StatisticsEventID.UM_PAY_FAST_DIALOG_CONFIRM)
        // 处于家长模式
        if (NineShowApplication.mUserBase != null && NineShowApplication.mUserBase?.family_module ?: 2 == 1) {
            ParentsModleHintDialog(context).show()
            return
        }

        // 充值 : 1. 判断是否绑定手机号
        val userBase = NineShowApplication.mUserBase ?: return

        /*if (userBase.request_bind == 1) {
            showPhoneAuthDialog()
            return
        }*/

        var money = 0
        // 固定选项支付
        if (payItemPosition >= 0 && payItemPosition < datas.size) { // 这里去除自定义选项
            money = datas[payItemPosition].amount
        }
        NSLog.d(ZhiFuActivity.Tag, "确认支付 : $money")

        // 充值 : 2. 判断金额是否满足条件  return & 提示信息
        if (money < 10) {
            MyToast.MakeToast("充值金额过低")
            return
        }

        if (money.toString().length > 6) {
            MyToast.MakeToast("充值金额过大")
            return
        }


        // 充值 : 3. 统一调用
        if (!Utils.isLongPeriodNotClickable()) {
            when (payType) {
                ZhiFuActivity.PAY_WECHAT -> {  // 微信支付
                    StatisticsUtil.onEvent(StatisticsEventID.ZHIFU_TYPE_WEIXIN)
                    chargeType = if (Global.WEIXIN_CHARGE_TYPE != 0) {
                        Global.WEIXIN_CHARGE_TYPE
                    } else {
                        PayUtil.PAY_TYPE_JX_WXPAY
                    }
                }
                ZhiFuActivity.PAY_ALI -> {      // 阿里(支付宝)支付
                    StatisticsUtil.onEvent(StatisticsEventID.ZHIFU_TYPE_ZHIFUBAO)
                    chargeType = if (Global.ALIPAY_CHARGE_TYPE != 0) {
                        Global.ALIPAY_CHARGE_TYPE
                    } else {
                        PayUtil.PAY_TYPE_JX_ALIPAY
                    }
                }
            }


            // 充值 : 4. 根据对应的支付方式生成订单
            getOrderdate(money, chargeType)
        }
    }

    private var isClikcPayBtn = true //一次点击支付对应一次调起
    /*private val chargeRid: Int by lazy {
        intent?.getIntExtra("rid", 0) ?: 0
    }*/

    // 生成订单
    private fun getOrderdate(money: Int, type: Int) {
        isClikcPayBtn = true
        showOrDismissDialog(true, "请稍候...")
        // todo : chargeRid
        PayUtil.createOrderRequest(money.toString(), type.toString(), NineShowApplication.mUserBase, rid, context, object : PayUtil.CreateOrderListener {
            override fun success(result: String?) {
                showOrDismissDialog(false)

                result?.let {
                    generateOrderResult(type, it)
                }
            }

            override fun failure() {
                showOrDismissDialog(false)
                Utils.MakeToast("服务器连接超时，请重试")
            }

        })
    }

    // 服务端返回的签名数据
    private var orderId: String? = null
    private var param: String? = null

    // 充值 : 5. 生成订单结果
    private fun generateOrderResult(type: Int, result: String) {
        try {
            val jsonObject = JSONObject(result)
            val code: String? = jsonObject.optString("code")
            val msg: String? = jsonObject.optString("message")

            when {
                TextUtils.equals(code, "200") -> {
                    val jsonObject2 = jsonObject.optJSONObject("data")
                    orderId = jsonObject2?.optString("orderid") // 后台生成的订单号

                    var realChargeType = jsonObject2?.optInt("type", -1) ?: -1
                    if (realChargeType == -1) {
                        realChargeType = type
                    }
                    NSLog.e("pay type  = $realChargeType")
                    param = if (realChargeType == PayUtil.PAY_TYPE_JX_ALIPAY) { //支付宝(支付宝官方)
                        jsonObject2?.optString("sign")
                    } else {
                        jsonObject2?.optString("transid") //签名数据
                    }

                    when (realChargeType) {
                        // 支付宝(官方)
                        PayUtil.PAY_TYPE_JX_ALIPAY -> {
                            aliPayTask()
                        }

                        // 快付支付通道app支付 , 微信支付(官方)
                        PayUtil.PAY_TYPE_KF_APP_WXPAY, PayUtil.PAY_TYPE_JX_WXPAY -> {
                            jsonObject2?.optJSONObject("params")?.let { doPayWeixinTask(it) }
                        }

                        // 云更新支付宝 , 云更新微信支付（微信官方h5) , 微信支付（快付）,
                        PayUtil.PAY_TYPE_YGX_ALIPAY, PayUtil.PAY_TYPE_YGX_WXPAY, PayUtil.PAY_TYPE_JX_WX_KUAIPAY,
                            // 百度微信 , 百度支付宝 , 九秀官方h5
                        PayUtil.PAY_TYPE_BD_WXPAY, PayUtil.PAY_TYPE_BD_ALIPAY, PayUtil.PAY_TYPE_JX_WXPAY_H5 -> {
                            jsonObject2?.optString("url")?.let { kuaiFuWXPay(it, realChargeType) }
                        }

                    }

                }
                TextUtils.equals(code, "4001") -> {
                    Utils.MakeToast("第三方生成订单失败")
                }
                TextUtils.equals(code, "9002") || TextUtils.equals(code, "9003") -> {
                    code?.let{
                        AccountIdentityDialog.showDialog(context,it,msg)
                    }
                }
                else -> {
                    Utils.MakeToast(msg)
                }
            }
        } catch (e: JSONException) {
            e.printStackTrace()
        }
    }

    // 绑定手机号弹窗
    private fun showPhoneAuthDialog() {
        /*CommonRemindDialog.create(context)
                .setCurrencyText("去认证")
                .setTitleText(Html.fromHtml("由于相关法律法规<br/>想要进行此操作<br/>您需要进行<b>实名手机号</b>认证"))
                .setOnClickCallback { type ->
                    if (type == BaseDialog.SELECT_SECOND) {
                        val intent = Intent(context, RegisterActivity::class.java).also { it.putExtra("type", 3) }
                        context.startActivity(intent)
                    }
                }*/
        AccountIdentityDialog.showDialog(context, AccountIdentityDialog.CODE_BIND_PHONE)
    }

    private var isNoCallBackPay = false //是不是没有回调的支付方式
    private var pay_webview: WebView? = null

    private fun kuaiFuWXPay(payinfo: String, realChargeType: Int) {
        isNoCallBackPay = true
        if (pay_webview == null) {
            initKuaiFuPay()
        }
        if (TextUtils.isEmpty(payinfo)) {
            MyToast.MakeToast(context, "支付参数错误，请重新下单")
            return
        }

        when (realChargeType) {
            PayUtil.PAY_TYPE_YGX_WXPAY -> { //云更新微信支付
                val map: MutableMap<String, String> = HashMap()
                map["Referer"] = "https://www.feihuo.com"
                pay_webview?.loadUrl(payinfo, map)
            }
            PayUtil.PAY_TYPE_BD_WXPAY -> { //百度微信支付
                val map: MutableMap<String, String> = HashMap()
                map["Referer"] = "https://v.xiaodutv.com"
                pay_webview?.loadUrl(payinfo, map)
            }
            PayUtil.PAY_TYPE_JX_WX_KUAIPAY -> { //快付
                pay_webview?.loadUrl(payinfo)
            }
            else -> {
                pay_webview?.loadUrl(payinfo)
            }
        }
    }

    /**
     * 快付微信支付 初始化webview
     */
    @SuppressLint("SetJavaScriptEnabled")
    private fun initKuaiFuPay() {
        pay_webview = WebView(context)
        pay_webview?.visibility = View.VISIBLE
        pay_webview?.let {
            val webSettings = it.settings

            with(webSettings) {
                javaScriptEnabled = true
                defaultTextEncodingName = "UTF-8"
                // 设置可以访问文件
                allowFileAccess = true
                // 设置支持缩放
                // 设置支持缩放
                builtInZoomControls = true
                cacheMode = WebSettings.LOAD_NO_CACHE
                // 使用localStorage则必须打开
                // 使用localStorage则必须打开
                domStorageEnabled = true
                setGeolocationEnabled(true)
            }
        }

        pay_webview?.webViewClient = object : WebViewClient() {
            override fun onPageStarted(view: WebView?, url: String, favicon: Bitmap?) {
                NSLog.i("KuaiFu", "onPageStarted url:$url")
                showOrDismissDialog(true, "正在启动微信...")
            }

            override fun onReceivedSslError(view: WebView?, handler: SslErrorHandler?, error: SslError?) {
                handler?.proceed()
            }

            override fun onPageFinished(view: WebView?, url: String?) {
                super.onPageFinished(view, url)
                showOrDismissDialog(false)
            }

            override fun shouldOverrideUrlLoading(view: WebView?, url: String?): Boolean {
                url ?: return false
                NSLog.i("KuaiFu", "支付 url:$url")
                // 如下方案可在非微信内部WebView的H5页面中调出微信支付
                if (url.startsWith("weixin://wap/pay?") || url.startsWith("alipays://platformapi/startApp?")) {
                    if (!isClikcPayBtn) {
                        return false
                    }
                    isClikcPayBtn = false
                    if (url.startsWith("alipays://platformapi/startApp?")) {
                        if (!checkAliPayInstalled()) { //支付宝未安装
                            isNoCallBackPay = false
                            MyToast.MakeSysToast(NineShowApplication.applicationContext, "支付失败!支付宝未安装!")
                            return true
                        }
                    } else if (url.startsWith("weixin://wap/pay?")) {
                        if (!checkWxInstalled()) { //微信未安装
                            isNoCallBackPay = false
                            MyToast.MakeSysToast(NineShowApplication.applicationContext, "支付失败!微信未安装!")
                            return true
                        }
                    }
                    val intent = Intent()
                    intent.action = Intent.ACTION_VIEW
                    intent.data = Uri.parse(url)
                    context.startActivity(intent)
                    return true
                } else if (parseScheme(url)) {
                    try {
                        val intent: Intent = Intent.parseUri(url, Intent.URI_INTENT_SCHEME)
                        intent.addCategory("android.intent.category.BROWSABLE")
                        intent.component = null
                        context.startActivity(intent)
                        return true
                    } catch (e: java.lang.Exception) {
                        e.printStackTrace()
                    }
                }
                return false
            }
        }
    }

    private fun parseScheme(url: String): Boolean {
        return if (url.contains("platformapi/startapp")) {
            true
        } else Build.VERSION.SDK_INT > Build.VERSION_CODES.M && url.contains("platformapi") && url.contains("startapp")
    }

    // 检测支付宝是否已安装
    private fun checkAliPayInstalled(): Boolean {
        val uri = Uri.parse("alipays://platformapi/startApp")
        val intent = Intent(Intent.ACTION_VIEW, uri)
        val componentName = intent.resolveActivity(NineShowApplication.applicationContext.packageManager)
        return componentName != null
    }

    // 检测微信是否安装
    private fun checkWxInstalled(): Boolean {
        val uri = Uri.parse("weixin://wap/pay?")
        val intent = Intent(Intent.ACTION_VIEW, uri)
        val componentName = intent.resolveActivity(NineShowApplication.applicationContext.packageManager)
        return componentName != null
    }

    private val mWXPayCallBack: WXPay.WXPayResultCallBack = object : WXPay.WXPayResultCallBack {
        override fun onSuccess() {
            NineShowApplication.setCharged(true)
            checkOrder()
        }

        override fun onError(error_code: Int) {
            when (error_code) {
                WXPay.NO_OR_LOW_WX -> Toast.makeText(context, "未安装微信或微信版本过低", Toast.LENGTH_SHORT).show()
                WXPay.ERROR_PAY_PARAM -> Toast.makeText(context, "参数错误", Toast.LENGTH_SHORT).show()
                WXPay.ERROR_PAY -> Toast.makeText(context, "支付失败", Toast.LENGTH_SHORT).show()
            }
        }

        override fun onCancel() {
            Toast.makeText(context, "支付取消", Toast.LENGTH_SHORT).show()
        }
    }


    // 调用微信支付(官方)
    private fun doPayWeixinTask(param: JSONObject) {    // 包含签名数据的参数
        StatisticsUtil.onEvent(StatisticsEventID.UM_PAY_SHOW_THREAD_PAY)
        val appid: String? = param.optString("appid")
        if (null == appid) {
            mWXPayCallBack.onError(WXPay.ERROR_PAY_PARAM)
            return
        }
        WXPay.init(context, appid)
        val manager: ConnectivityManager? = context.getSystemService(Context.CONNECTIVITY_SERVICE) as? ConnectivityManager
        val networkinfo = manager?.activeNetworkInfo
        if (networkinfo != null && networkinfo.isConnected) {
            WXPay.getInstance().doPay(param, mWXPayCallBack)
        } else { //若无网，则应用原来逻辑
            val builder = AlertDialog.Builder(context, R.style.CustomBgTransparentDialog)
            builder.setIcon(R.drawable.logo)
            builder.setTitle("网络状态")
            builder.setMessage("没有可用网络,是否进入设置面板")
            builder.setPositiveButton("是") { _, _ -> context.startActivity(Intent(Settings.ACTION_WIRELESS_SETTINGS)) }
            builder.setNegativeButton("否") { _, _ -> Toast.makeText(context, "联网失败", Toast.LENGTH_SHORT).show() }
            builder.create().show()
        }

    }

    // 调用支付宝支付(支付宝官方)
    private fun aliPayTask() {
        StatisticsUtil.onEvent(StatisticsEventID.UM_PAY_SHOW_THREAD_PAY)
        thread {
            (context as? Activity)?.let {
                val alipay = PayTask(it)
                // 构造PayTask对象，调用支付接口，获取支付结果
                val result = alipay.pay(param)

                val msg = Message.obtain()
                msg.what = PayUtil.MSG_ZHIFUBAO
                msg.obj = result
                mHandler.sendMessage(msg)
            }
        }
    }

    @SuppressLint("HandlerLeak")
    private val mHandler = object : Handler() {
        override fun handleMessage(msg: Message) {
            try {
                val strRet = msg.obj as? String
                when (msg.what) {
                    PayUtil.MSG_ZHIFUBAO -> {       //支付宝支付成功的结果处理（支付宝官方）
                        // 处理交易结果
                        try {
                            strRet ?: return
                            var tradeStatus = "resultStatus={"
                            val imemoStart = strRet.indexOf("resultStatus=") + tradeStatus.length
                            val imemoEnd = strRet.indexOf("};memo=")
                            tradeStatus = strRet.substring(imemoStart, imemoEnd)
                            // 先验签通知
                            val resultChecker = ResultChecker(strRet)
                            val retVal = resultChecker.checkSign()
                            // 验签失败
                            if (retVal == ResultChecker.RESULT_CHECK_SIGN_FAILED) {
                                (context as? Activity)?.let {
                                    BaseHelper.showDialog(context, "提示", context.getResources().getString(R.string.check_sign_failed), android.R.drawable.ic_dialog_alert)
                                }
                            } else {
                                // 验签成功。验签成功后再判断交易状态码 -> 判断交易状态码，只有9000表示交易成功
                                if (TextUtils.equals(tradeStatus, "9000")) {
                                    NineShowApplication.setCharged(true)
                                    checkOrder()
                                } else {
                                    (context as? Activity)?.let {
                                        BaseHelper.showDialog(context, "提示", "支付失败.", R.drawable.infoicon)
                                    }

                                }
                            }
                        } catch (e: Exception) {
                            e.printStackTrace()
                            (context as? Activity)?.let {
                                BaseHelper.showDialog(context, "提示", strRet, R.drawable.infoicon)
                            }
                        }
                    }
                    PayUtil.TRUE_LOVE_POWDER -> {
                        showOrDismissDialog(false)
                        NineShowApplication.setFirstPayGiftTips(false)
                        Utils.MakeToast("充值成功！已经到账。")
                        /* if (isChargeGuide) {
                             StatisticsUtil.onEvent(StatisticsEventID.PAYED_FROM_GUIDE)
                         }*/
                    }
                    PayUtil.MSG_CHECK_FAILURE -> {
                        showOrDismissDialog(false)
                        Utils.MakeToast("充值失败,请检查网络后重试！")
                    }
                    PayUtil.MSG_PAY_THIRD -> {   //充值轮询未查询到
                        MyToast.MakeSysToast(NineShowApplication.applicationContext, "确认充值成功后在三十分钟内到账,如未到账请联系客服处理!")
                    }
                }

            } catch (e: Exception) {
                NSLog.d(ZhiFuActivity.Tag, e.message)
            }
        }
    }

    // 轮询服务器，检查是否支付成功
    private fun checkOrder() {
        showOrDismissDialog(true, "正在充值……")
        payUtil.checkOrder(object : PayUtil.OrderRequest {
            override fun checkOrder() {
                PayUtil.checkOrderRequest(orderId, NineShowApplication.mUserBase, object : PayUtil.PayEndListener {
                    override fun success(firstchargeType: Int, gainNumber: Int) {
                        showOrDismissDialog(false)
                        checkOrderSuccess(firstchargeType)
                    }

                    override fun failure() {
                        showOrDismissDialog(false)
                        mHandler.sendEmptyMessage(PayUtil.MSG_CHECK_FAILURE)
                    }

                })
            }

            override fun failure() {
                showOrDismissDialog(false)
                mHandler.sendEmptyMessage(PayUtil.MSG_CHECK_FAILURE)
            }

        }, PayUtil.PERIOD_ZHIFUBAO, 1000, PayUtil.COUNT, mHandler)
    }

    private fun checkOrderSuccess(firstchargeType: Int) {
        Log.e("checkCount:  ", "checkOrderSuccess--")
        val msg = mHandler.obtainMessage()
        msg.what = PayUtil.TRUE_LOVE_POWDER
        msg.arg1 = firstchargeType
        mHandler.sendMessage(msg)
        notifyUserInfo()
        payUtil.stopCheck()
    }

    private fun notifyUserInfo() {
        StatisticsUtil.onEvent(StatisticsEventID.UM_PAY_SUCCESS)
        StatisticsUtil.onEvent(StatisticsEventID.UM_PAY_FAST_DIALOG_SUCCESS)
        PayUtil.notifyUserInfoRequest(NineShowApplication.mUserBase, object : PayUtil.NotifyUserInfoListener {
            override fun success(result: String?) {
                if (result != null) {
                    val jsonObject: JSONObject
                    try {
                        jsonObject = JSONObject(result)
                        val code: String? = jsonObject.optString("code")
                        if (TextUtils.equals("200", code)) {
                            val data: JSONObject? = jsonObject.optJSONObject("data")
                            data?.optInt("money")?.toLong()?.let { NineShowApplication.mUserBase?.money = it }
                            data?.optInt("tokencoin")?.toLong()?.let { NineShowApplication.mUserBase?.tokencoin = it }
                            data?.optInt("wealthlevel")?.let { NineShowApplication.mUserBase?.wealthlevel = it }
                            NineShowApplication.getManager().notifyState() //若从个人中心跳转过来的 则更改个人中心的 金额显示
                            // getUserMoney() // 刷新余额
                            tvMoney.text = NineShowApplication.mUserBase?.money?.toString() ?: "--"
                        }

                        // 修改用户是否支付
                        val userBase = NineShowApplication.mUserBase
                        if (userBase != null) {
                            userBase.isCharge = 1
                        }
                    } catch (e: java.lang.Exception) {
                        e.printStackTrace()
                    }
                }
            }

            override fun failure() {
                Utils.MakeToast("更新金币信息失败！ 请重新登录")
            }
        })
    }

    /**
     * 更新系统配置的支付信息
     */
    private fun getRoomSystemMessage() {
        val asyncHttpClient = NSAsyncHttpClient.getInstance()
        val params = NSRequestParams()
        params.put("channel", NineShowApplication.UMENG_CHANNEL)
        asyncHttpClient[Constants.NS_ROOM_APPCONF, params, object : NSJsonResponseHandler<RoomSystemMsgResultInfo?>() {
            override fun onSuccess(statusCode: Int, rawJsonResponse: String?, response: RoomSystemMsgResultInfo?) {
                if (response != null) {
                    if (response.data != null && response.data.priv != null && response.data.priv.size > 0) { //房间系统消息有配置
                        NineShowApplication.setRoomSystemMessageList(response.data.priv)
                    }
                    if (response.data != null && response.data.chatWord != null && response.data.chatWord.size > 0) { //房间系统消息有配置
                        NineShowApplication.setHotWordList(response.data.chatWord)
                    }
                    if (response.data != null) {
                        NineShowApplication.isShowDouTu = response.data.isDoupic
                    }
                    if (response.data != null && response.data.payType != null) { //支付方式
                        Global.ALIPAY_CHARGE_TYPE = response.data.payType.ali_pay
                        Global.WEIXIN_CHARGE_TYPE = response.data.payType.wx_pay
                    }
                    if (response.data != null && response.data.showwwj == 1) {
                        NineShowApplication.isShowHotGame = true
                    }
                    if (response.data != null && response.data.topUserLevel != null && response.data.topUserLevel.size > 0) { //自定义的等级图标
                        NineShowApplication.setUserCustomLevelList(response.data.topUserLevel)
                    }
                }
            }

            override fun onFailure(statusCode: Int, errorMsg: String) {}
        }]
    }

    // 等候弹窗
    private var dialog: Dialog? = null
    private fun showOrDismissDialog(show: Boolean, msg: String? = null) {
        when (show) {
            true -> {
                dialog = Utils.showProgressDialog(context, msg, true)
                dialog?.show()
            }
            false -> {
                dialog?.dismiss()
            }
        }
    }

    private val widthScreen: Int by lazy {
        context.resources?.displayMetrics?.widthPixels ?: 0
    }

    override fun getContentView() = R.layout.dialog_zhifu_fast

    val decoration = object : RecyclerView.ItemDecoration() {
        override fun getItemOffsets(outRect: Rect, view: View, parent: RecyclerView, state: RecyclerView.State) {
            super.getItemOffsets(outRect, view, parent, state)
            val index = parent.getChildAdapterPosition(view)

            when {
                index % 3 == 0 -> {
                    outRect.right = (ZhiFuActivity.ITEM_PERCENT * widthScreen).toInt()
                }
                index % 3 == 1 -> {
                    outRect.right = (ZhiFuActivity.ITEM_PERCENT * widthScreen).toInt()
                    outRect.left = (ZhiFuActivity.ITEM_PERCENT * widthScreen).toInt()
                }
                else -> {
                    outRect.left = (ZhiFuActivity.ITEM_PERCENT * widthScreen).toInt()
                }
            }

            if (index > 2) {
                outRect.top = dp2px(context, 13)
            }
        }
    }

    // 设置Banner数据 & 适配头部高度
    private fun setBanner(bannerTempDatas: MutableList<Banner>?) {
        val bannerDatas = bannerTempDatas?.filter {
            !TextUtils.isEmpty(it.alert_banner)
        }
        val userInfo = NineShowApplication.mUserBase
        if (null != userInfo && userInfo.isCharge == 0 && null != bannerDatas) { // 用户信息没有充值过并且返回信息也没有充值过才显示
            // 适配banner高度
            fitterViewSize(ivBanner, { widthScreen }, { (it * 0.1654).toInt() })
            ivBanner.setData(bannerDatas, null)
            ivBanner.setAdapter(object : BGABanner.Adapter<ImageView, Banner> {
                override fun fillBannerItem(banner: BGABanner?, itemView: ImageView?, model: Banner?, position: Int) {
                    NSLog.d(ZhiFuActivity.Tag, "展示 : ${model?.banner}")
                    itemView?.let {
                        GlideUtils.loadBannerPic(context, model?.alert_banner, itemView)
                    }
                }
            })
            ivBanner.setDelegate(object : BGABanner.Delegate<ImageView, Banner> {
                override fun onBannerItemClick(banner: BGABanner?, itemView: ImageView?, model: Banner?, position: Int) {
                    NSLog.d(ZhiFuActivity.Tag, "点击 ${model?.act_url}")
                    model?.act_url?.let {
                        AdvertiseActivity.start(context, false, it)
                    }
                }
            })
            ivBanner.setVisible(true)
        } else {
            ivBanner.setVisible(false)
        }
    }

    override fun isBottom(): Boolean = true

    // 消失回调 -> 用于另外的dialog的回弹或者通过广播方式发送
    override fun onDismiss(dialog: DialogInterface?) {
        onZhiFuFastDialogDismissListener?.ondismissCallback()
    }

}

interface OnZhiFuFastDialogEqualDismissListener {
    fun ondismissEqualCallback(type :Int)
}

interface OnZhiFuFastDialogDismissListener {
    fun ondismissCallback()
}